@@ -6,8 +6,6 @@
 
 $g_currenttime=gmtime;
 $g_currentuser = getlogin || getpwuid($<) || "Unknown";
-$g_examplecolor="#FF0000";
-$g_examplebgcolor="#F5F5F5";
 $g_notetablebgcolor="#F0F0F0";
 $g_notetextcolor="#909090";
 $g_syntaxcolor="#802000";
@@ -121,12 +119,22 @@ sub print_header
 	print $g_filehandle "<html>\n";
 	print $g_filehandle "<head>\n";
 	print $g_filehandle "<title>$_[0]</title>\n";
+
+	print $g_filehandle "<style type=\"text/css\">\n";
+	print $g_filehandle "body {\n"; 
+	print $g_filehandle " font-size: 11pt;\n";
+	print $g_filehandle " margin-left: 8px;\n";
+	print $g_filehandle " margin-right: 8px;\n";
+	print $g_filehandle " margin-top: 6px;\n";
+	print $g_filehandle " margin-bottom: 6px;\n";
+	print $g_filehandle " font-family:Helvetica,Arial,Verdana;\n";
+	print $g_filehandle "}\n";
+
+	print $g_filehandle "</style>\n";
+	print $g_filehandle "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\" >\n";
 	print $g_filehandle "</head>\n";
 	print $g_filehandle "<body bgcolor=\"$g_bodybgcolor\" text=\"$g_bodytextcolor\">\n";
 
-	#print $g_filehandle "<table width=\"100%\" cellpadding=\"1\" cellspacing=\"0\" border=\"0\"><tr><td bgcolor=\"$g_headerborderlightcolor\">\n";
-	#print $g_filehandle "<table width=\"100%\" cellpadding=\"1\" cellspacing=\"0\" border=\"0\"><tr><td bgcolor=\"$g_headerborderdarkcolor\">\n";
-
 	print $g_filehandle "<table width=\"100%\" cellpadding=\"1\" cellspacing=\"0\" border=\"0\">\n";
 	print $g_filehandle " <tr>\n";
 	print $g_filehandle "  <td align=\"left\" bgcolor=\"$g_headerbgcolor\">\n";
@@ -137,9 +145,6 @@ sub print_header
 	print $g_filehandle "  </td>\n";
 	print $g_filehandle " </tr>\n";
 	print $g_filehandle "</table>\n";
-
-	#print $g_filehandle "</td></tr></table>\n";
-	#print $g_filehandle "</td></tr></table>\n";
 }
 
 sub print_footer
@@ -151,13 +156,13 @@ sub print_footer
 
 sub print_tablestart
 {
-	print $g_filehandle "<table width=\"100%\" cellpadding=\"3\" cellspacing=\"1\" border=\"0\"\n";
-	print $g_filehandle "<tr><td bgcolor=\"$g_tablebgcolor\">\n";
+	print $g_filehandle "<table width=\"100%\" cellpadding=\"3\" cellspacing=\"1\" border=\"0\">\n";
+	#print $g_filehandle "<tr><td bgcolor=\"$g_tablebgcolor\">\n";
 }
 
 sub print_tableend
 {
-	print $g_filehandle "</td></tr>\n";
+	#print $g_filehandle "</td></tr>\n";
 	print $g_filehandle "</table>\n";
 }
 
@@ -524,7 +529,7 @@ sub build_usage_from_kvs_syntax
 sub process_kvs_syntax_line
 {
 	$_[0] =~ s/\&lt\;([A-Za-z0-9_]+):([A-Za-z0-9_]+)\&gt\;/\&lt\;\1\<font color=\"$g_kvstypenamecolor\"\>:\2\<\/font\>\&gt\;/g;
-	$_[0] =~ s/\[([A-Za-z0-9_]+):([A-Za-z0-9_]+)\]/\[;\1\<font color=\"$g_kvstypenamecolor\"\>:\2\<\/font\>\]/g;
+	$_[0] =~ s/\[([A-Za-z0-9_]+):([A-Za-z0-9_]+)\]/\[\1\<font color=\"$g_kvstypenamecolor\"\>:\2\<\/font\>\]/g;
 	$_[0] =~ s/^\&lt\;([A-Za-z0-9_]+)\&gt\;/\&lt\;\<font color=\"$g_kvstypenamecolor\"\>\1\<\/font\>\&gt\;/g;
 	$_[0] =~ s/^([A-Za-z0-9_\.]+)/\<b\>\1\<\/b\>/g;
 	$_[0] =~ s/(\$[A-Za-z0-9_\.]*)/\<b\>\1\<\/b\>/g;
@@ -566,8 +571,19 @@ sub process_body_line
 	$_[0] =~ s/\[p\]/\<p\>/g;
 	$_[0] =~ s/\[\/p\]/\<\/p\>/g;
 	$_[0] =~ s/\[\/b\]/\<\/b\>/g;
-	$_[0] =~ s/\[big\]/\<h2\>/g;
-	$_[0] =~ s/\[\/big\]/\<\/h2\>/g;
+	# [big][/big] is an alias to [title][/title]
+	$_[0] =~ s/\[big\]/\<\/td\>\<\/tr\>\<tr\>\<td bgcolor=\"#A7D3DB\"\>\<div style=\"font-size:16pt;font-weight:800;\"\>/g;
+	$_[0] =~ s/\[\/big\]/\<\/div\>\<\/td\>\<\/tr\>\<tr\>\<td bgcolor=\"$g_bodytablebgcolor\"\>/g;
+#	$_[0] =~ s/\[title\]/\<\/td\>\<\/tr\>\<tr\>\<td bgcolor=\"#A7D3DB\"\>\<div style=\"font-size:16pt;font-weight:800;\"\>/g;
+#	$_[0] =~ s/\[\/title\]/\<\/div\>\<\/td\>\<\/tr\>\<tr\>\<td bgcolor=\"$g_bodytablebgcolor\"\>/g;
+	$_[0] =~ s/\[title\]/\<\/td\>\<\/tr\>\<tr\>\<td bgcolor=\"#A7D3DB\"\>\<div style=\"font-size:16pt;font-weight:800;\"\>/g;
+	$_[0] =~ s/\[\/title\]/\<\/div\>\<\/td\>\<\/tr\>\<tr\>\<td bgcolor=\"$g_bodytablebgcolor\"\>/g;
+#	$_[0] =~ s/\[title\]/\<table width="100%" border="0" cellpadding="1" cellspacing="0" bgcolor=\"#80B3BB\"\>\<tr\>\<td\>\<table align=\"left\" width="100%" border="0" cellpadding="3" cellspacing="0" bgcolor=\"#A7D3DB\"\>\<tr\>\<td\>\<div style=\"font-size:16pt;font-weight:800;\"\>/g;
+#	$_[0] =~ s/\[\/title\]/\<\/div\>\<\/td\>\<\/tr\>\<\/table\>\<\/td\>\<\/tr\>\<\/table\>/g;
+	$_[0] =~ s/\[subtitle\]/\<\/td\>\<\/tr\>\<tr\>\<td bgcolor=\"#D6E0E8\"\>\<div style=\"font-size:13pt;font-weight:800;\"\>/g;
+	$_[0] =~ s/\[\/subtitle\]/\<\/div\>\<\/td\>\<\/tr\>\<tr\>\<td bgcolor=\"$g_bodytablebgcolor\"\>/g;
+#	$_[0] =~ s/\[subtitle\]/\<table width="100%" border="0" cellpadding="1" cellspacing="0" bgcolor=\"#A6C0C8\"\>\<tr\>\<td\>\<table align=\"left\" width="100%" border="0" cellpadding="3" cellspacing="0" bgcolor=\"#D6E0E8\"\>\<tr\>\<td\>\<div style=\"font-size:13pt;font-weight:800;\"\>/g;
+#	$_[0] =~ s/\[\/subtitle\]/\<\/div\>\<\/td\>\<\/tr\>\<\/table\>\<\/td\>\<\/tr\>\<\/table\>/g;
 	$_[0] =~ s/\[pre\]/\<pre\>/g;
 	$_[0] =~ s/\[\/pre\]/\<\/pre\>/g;
 	$_[0] =~ s/\[center\]/\<center\>/g;
@@ -575,7 +591,7 @@ sub process_body_line
 	$_[0] =~ s/\[i\]/\<i\>/g;
 	$_[0] =~ s/\[\/i\]/\<\/i\>/g;
 	$_[0] =~ s/\[ul\]/\<ul\>/g;
-	$_[0] =~ s/\[\/ul\]/\<\/ul\>/g;
+	$_[0] =~ s/\[\/ul\]/\<\/ul\>/g; 
 	$_[0] =~ s/\[li\]/\<li\>/g;
 	$_[0] =~ s/\[\/li\]/\<\/li\>/g;
 	$_[0] =~ s/\[table\]/\<table bgcolor=\"$g_internaltablecolor\" width=\"100\%\"\>/g;
@@ -584,8 +600,10 @@ sub process_body_line
 	$_[0] =~ s/\[\/tr\]/\<\/tr\>/g;
 	$_[0] =~ s/\[td\]/\<td\>/g;
 	$_[0] =~ s/\[\/td\]/\<\/td\>/g;
-	$_[0] =~ s/\[example\][ 	\n]*/\<table width=\"100%\"\ cellpadding=\"2\">\<tr\>\<td\ bgcolor=\"$g_examplebgcolor\">\<pre\>\<code\>\<font color=\"$g_examplecolor\"\>/g;
-	$_[0] =~ s/\[\/example\]/\<\/font\>\<\/code\>\<\/pre\>\<\/td\>\<\/tr\>\<\/table\>/g;
+#	$_[0] =~ s/\[example\][ 	\n]*/<p><table width=\"100%\" cellpadding=\"1\" cellspacing=\"0\" border=\"0\" bgcolor=\"#D5D5D5\"><tr><td><table align=\"left\" width=\"100%\" cellpadding=\"3\" cellspacing=\"0\" border=\"0\" bgcolor=\"#F5F5F5\">\<tr\>\<td\>\<pre\>\<code\>\<font color=\"#FF0000\"\>/g;
+#	$_[0] =~ s/\[\/example\]/<\/font><\/code><\/pre><\/td><\/tr><\/table><\/td><\/tr><\/table><\/p>/g;
+	$_[0] =~ s/\[example\][ 	\n]*/<p><table width=\"100%\" cellpadding=\"3\" cellspacing=\"1\" border=\"0\" bgcolor=\"#D5D5D5\">\<tr\>\<td bgcolor=\"#F5F5F5\"\>\<pre\>\<code\>\<font color=\"#FF0000\"\>/g;
+	$_[0] =~ s/\[\/example\]/<\/font><\/code><\/pre><\/td><\/tr><\/table><\/p>/g;
 	$_[0] =~ s/\[comment\]/\<font color=\"$g_commentcolor\"\>/g;
 	$_[0] =~ s/\[\/comment\]/\<\/font\>/g;
 	$_[0] =~ s/\[doc\]([a-zA-Z0-9_]*)\[\/doc\]/\<a href=\"doc_\L\1$g_fileextension">\1\<\/a\>/g;
@@ -610,8 +628,8 @@ sub process_body_line
 	$_[0] =~ s/\[\/anchorlink\]/\<\/a\>/g;
 	$_[0] =~ s/\[anchor:([a-zA-Z0-9_]*)\]/\<a name=\"\1"\>/g;
 	$_[0] =~ s/\[\/anchor\]/\<\/a\>/g;
-	$_[0] =~ s/\[note\][ 	\n]*/\<table width=\"100%\"\ cellpadding=\"2\">\<tr\>\<td\ bgcolor=\"$g_notetablebgcolor\">\<font color=\"$g_notetextcolor\" size=\"-1\"\>/g;
-	$_[0] =~ s/\[\/note\]/\<\/font\>\<\/td\>\<\/tr\>\<\/table\>/g;
+	$_[0] =~ s/\[note\][ 	\n]*/<p>\<table width=\"100%\"\ cellpadding=\"2\">\<tr\>\<td\ bgcolor=\"$g_notetablebgcolor\">\<font color=\"$g_notetextcolor\" size=\"-1\"\>/g;
+	$_[0] =~ s/\[\/note\]/\<\/font\>\<\/td\>\<\/tr\>\<\/table\><\/p>/g;
 }
 
 sub process_file
