@@ -49,7 +49,7 @@
 #define KVI_DEFAULT_USERNAME "kvirc"
 #define KVI_DEFAULT_REALNAME "KVIrc " VERSION " '" KVI_RELEASE_NAME "' http://kvirc.net/"
 
-#define KVI_DEFAULT_PART_MESSAGE "Time makes no sense"
+#define KVI_DEFAULT_PART_MESSAGE "No matter how dark the night, somehow the Sun rises once again"
 #define KVI_DEFAULT_QUIT_MESSAGE "KVIrc $version $version(r) http://www.kvirc.net/"
 #define KVI_DEFAULT_CTCP_USERINFO_REPLY "I'm too lazy to edit this field."
 #define KVI_DEFAULT_CTCP_PAGE_REPLY "Your message has been received and logged"
