@@ -91,7 +91,7 @@
 #define KVI_BUILD_DATE BUILD_DATE
 #define KVI_BUILD_FLAGS BUILD_FLAGS
 
-#define KVI_RELEASE_NAME "Anomalies"
+#define KVI_RELEASE_NAME "Virgo"
 
 // We want _GNU_SOURCE features
 #ifndef _GNU_SOURCE
@@ -132,6 +132,9 @@
 */
 #define KVI_DEPRECATED
 
+#ifdef COMPILE_USE_QT4
+	#define debug qDebug
+#endif
 
 
 #endif //_KVI_SETTINGS_H_
