@@ -32,6 +32,11 @@
 /* define if you want to compile with new parser */
 #define COMPILE_NEW_KVS 1
 
+/* define if you want to use the Qt 4.x support */
+/* #undef COMPILE_USE_QT4 */
+
+#define COMPILE_USE_QT4
+
 /* define if you want to use only the new KVS parser */
 #define COMPILE_ONLY_NEW_KVS 1
 
@@ -149,9 +154,9 @@
 #define PACKAGE "kvirc"
 
 /* Version number of package */
-#define VERSION "3.2.4"
+#define VERSION "3.4.0"
 
-#define VERSION_BRANCH "3.2"
+#define VERSION_BRANCH "3.4"
 
 
 /* Define if the system does not provide POSIX.1 features except with this
