@@ -34,6 +34,7 @@
 #include "kvi_qstring.h"
 #include "kvi_string.h"
 #include "kvi_malloc.h"
+#include "kvi_locale.h"
 
 #include <ctype.h> // for tolower()
 #include <stdio.h> // for sprintf()
@@ -43,14 +44,19 @@
 extern unsigned char iso88591_toLower_map[256];
 extern unsigned char iso88591_toUpper_map[256];
 
+#define MY_MIN(a,b) (((a) < (b)) ? (a) : (b))
+
 namespace KviQString
 {
+	// The global empty (and null) string
+	const QString empty;
+
 	bool equalCSN(const QString &sz1,const QString &sz2,unsigned int len)
 	{
 		if(len == 0)return true; // assume equal
 		const QChar * c1 = sz1.unicode();
 		const QChar * c2 = sz2.unicode();
-		unsigned int lmin = QMIN(sz1.length(),sz2.length());
+		unsigned int lmin = MY_MIN(sz1.length(),sz2.length());
 		if(lmin < len)return false;
 		const QChar * c1e = c1 + len;
 		
@@ -70,7 +76,7 @@ namespace KviQString
 		if(len == 0)return true; // assume equal
 		const QChar * c1 = sz1.unicode();
 		const QChar * c2 = sz2.unicode();
-		unsigned int lmin = QMIN(sz1.length(),sz2.length());
+		unsigned int lmin = MY_MIN(sz1.length(),sz2.length());
 		if(lmin < len)return false;
 		const QChar * c1e = c1 + len;
 
@@ -78,7 +84,11 @@ namespace KviQString
 
 		while(c1 < c1e)
 		{
+#ifdef COMPILE_USE_QT4
+			if(c1->toLower().unicode() != c2->toLower().unicode())return false;
+#else
 			if(c1->lower().unicode() != c2->lower().unicode())return false;
+#endif
 			c1++;
 			c2++;
 		}
@@ -116,7 +126,11 @@ namespace KviQString
 
 		while((c1 < c1e) && (*sz2))
 		{
+#ifdef COMPILE_USE_QT4
+			if(c1->toLower().unicode() != tolower(*sz2))return false;
+#else
 			if(c1->lower().unicode() != tolower(*sz2))return false;
+#endif
 			c1++;
 			sz2++;
 		}
@@ -136,13 +150,41 @@ namespace KviQString
 
 		while((c1 < c1e) && (sz2->unicode()))
 		{
+#ifdef COMPILE_USE_QT4
+			if(c1->toLower().unicode() != sz2->toLower().unicode())return false;
+#else
 			if(c1->lower().unicode() != sz2->lower().unicode())return false;
+#endif
 			c1++;
 			sz2++;
 		}
 		return (c1 == c1e);
 	}
 
+	QString makeSizeReadable(size_t bytes)
+	{
+		double size = bytes;
+		if(size<900)
+			return QString(__tr2qs("%1 bytes")).arg(size,0,'f',3);
+
+		size/=1024;
+		if(size<900)
+			return QString(__tr2qs("%1 KB")).arg(size,0,'f',3);
+
+		size/=1024;
+		if(size<900)
+			return QString(__tr2qs("%1 MB")).arg(size,0,'f',3);
+
+		//Pirated DVD?;)
+		size/=1024;
+		if(size<900)
+			return QString(__tr2qs("%1 GB")).arg(size,0,'f',3);
+
+		//Uhm.. We are downloading a whole internet:)))
+		size/=1024;
+		return QString(__tr2qs("%1 TB")).arg(size,0,'f',3);
+	}
+
 	bool equalCS(const QString &sz1,const QString &sz2)
 	{
 		if(sz1.length() != sz2.length())return false;
@@ -174,7 +216,11 @@ namespace KviQString
 
 		while(c1 < c1e)
 		{
+#ifdef COMPILE_USE_QT4
+			if(c1->toLower().unicode() != c2->toLower().unicode())return false;
+#else
 			if(c1->lower().unicode() != c2->lower().unicode())return false;
+#endif
 			c1++;
 			c2++;
 		}
@@ -192,7 +238,11 @@ namespace KviQString
 		while(c1 < c1e)
 		{
 			if(!sz2->unicode())return false; // sz1 has at least another character
+#ifdef COMPILE_USE_QT4
+			if(c1->toLower().unicode() != sz2->toLower().unicode())return false;
+#else
 			if(c1->lower().unicode() != sz2->lower().unicode())return false;
+#endif
 			c1++;
 			sz2++;
 		}
@@ -224,7 +274,11 @@ namespace KviQString
 
 		while((c1 < c1e) && (*sz2))
 		{
+#ifdef COMPILE_USE_QT4
+			if(c1->toLower().unicode() != tolower(*sz2))return false;
+#else
 			if(c1->lower().unicode() != tolower(*sz2))return false;
+#endif
 			c1++;
 			sz2++;
 		}
@@ -283,12 +337,24 @@ namespace KviQString
 		{
 			if(c1 >= c1e)
 			{
+#ifdef COMPILE_USE_QT4
+				if(c2 < c2e)return /* 0 */ - (c2->toLower().unicode());
+#else
 				if(c2 < c2e)return /* 0 */ - (c2->lower().unicode());
+#endif
 				return 0;
 			}
+#ifdef COMPILE_USE_QT4
+			if(c2 >= c2e)return c1->toLower().unicode() /* - 0 */;
+#else
 			if(c2 >= c2e)return c1->lower().unicode() /* - 0 */;
+#endif
 
+#ifdef COMPILE_USE_QT4
+			int diff = c1->toLower().unicode() - c2->toLower().unicode();
+#else
 			int diff = c1->lower().unicode() - c2->lower().unicode();
+#endif
 			if(diff)return diff;
 
 			c1++;
@@ -301,8 +367,8 @@ namespace KviQString
 	int cmpCIN(const QString &sz1,const QString &sz2,unsigned int len)
 	{
 		if(len == 0)return 0; // assume equal
-		unsigned int l1 = QMIN(len,sz1.length());
-		unsigned int l = QMIN(l1,sz2.length()); // FIXME: THIS IS NOT OK
+		unsigned int l1 = MY_MIN(len,sz1.length());
+		unsigned int l = MY_MIN(l1,sz2.length()); // FIXME: THIS IS NOT OK
 
 		const QChar * c1 = sz1.unicode();
 		const QChar * c2 = sz2.unicode();
@@ -317,7 +383,11 @@ namespace KviQString
 
 		int diff = 0;
 
+#ifdef COMPILE_USE_QT4
+		while((c1 < c1e) && !(diff = (c1->toLower().unicode() - c2->toLower().unicode())))
+#else
 		while((c1 < c1e) && !(diff = (c1->lower().unicode() - c2->lower().unicode())))
+#endif
 		{
 			c1++;
 			c2++;
@@ -394,13 +464,21 @@ namespace KviQString
 
 	void detach(QString &sz)
 	{
+#ifdef COMPILE_USE_QT4
+		sz.resize(sz.length());
+#else
 		sz.setLength(sz.length());
+#endif
 	}
 
 	const QChar * nullTerminatedArray(const QString &sz)
 	{
 		//sz.setLength(sz.length()); // detach!
+#ifdef COMPILE_USE_QT4
+		return sz.constData();
+#else
 		return (const QChar *)sz.ucs2(); // MAY BE NULL!
+#endif
 	}
 	
 	void appendNumber(QString &s,double dReal)
@@ -488,7 +566,7 @@ namespace KviQString
 			if(reallen == allocsize)INCREMENT_MEM
 
 			//copy up to a '%'
-			if(*fmt != '%')
+			if(fmt->unicode() != '%')
 			{
 				*p++ = *fmt;
 				reallen++;
@@ -496,24 +574,18 @@ namespace KviQString
 			}
 
 			++fmt; //skip this '%'
-			switch(*fmt)
+			switch(fmt->unicode())
 			{
 				case 's': // char * string
 				{
 					argString = kvi_va_arg(list,char *);
-					if(!argString)
-					{
-						argString = "[!NULL!]";
-						argValue = 8;
-					} else {
-						argValue = (long)strlen(argString);
-					}
-					//check for space...
-					if((allocsize - reallen) < argValue)INCREMENT_MEM_BY(argValue)
+					if(!argString)argString = "[!NULL!]";
 					QString str(argString);
 					if(str.isEmpty())continue;
 					int len = str.length();
 					const QChar * ch = str.unicode();
+					if(!ch)continue;
+					if((allocsize - reallen) < len)INCREMENT_MEM_BY(len)
 					while(len--)*p++ = *ch++;
 					reallen += str.length();
 					continue;
@@ -534,8 +606,9 @@ namespace KviQString
 					if(!str)continue;
 					if(str->isEmpty())continue;
 					int len = str->length();
-					if((allocsize - reallen) < len)INCREMENT_MEM_BY(len)
 					const QChar * ch = str->unicode();
+					if(!ch)continue;
+					if((allocsize - reallen) < len)INCREMENT_MEM_BY(len)
 					while(len--)*p++ = *ch++;
 					reallen += str->length();
 					continue;
@@ -648,7 +721,7 @@ namespace KviQString
 				{
 					*p++ = '%';  //write it
 					reallen++;
-					if(*fmt)
+					if(fmt->unicode())
 					{
 						if(reallen == allocsize)INCREMENT_MEM
 						*p++ = *fmt;
@@ -708,9 +781,14 @@ namespace KviQString
 		//      s1
 		//
 
+#ifdef COMPILE_USE_QT4
+		const QChar * m1 = (const QChar *)szM1.constData();
+		const QChar * m2 = (const QChar *)szM2.constData();
+#else
 		const QChar * m1 = (const QChar *)szM1.ucs2();
 		const QChar * m2 = (const QChar *)szM2.ucs2();
-		
+#endif
+
 		if(!(m1 && m2 && (m1->unicode())))return false;
 		const QChar * savePos1 = 0;
 		const QChar * savePos2 = m2;
@@ -726,7 +804,11 @@ namespace KviQString
 				continue;                   //and return
 			}
 			if(!m2->unicode())return false;         //m2 finished and we had something to match here!
+#ifdef COMPILE_USE_QT4
+			if(m1->toLower()==m2->toLower())
+#else
 			if(m1->lower()==m2->lower())
+#endif
 			{
 				//chars matched
 				m1++;                       //Go ahead in the two strings
@@ -782,7 +864,11 @@ namespace KviQString
 	bool matchStringCI(const QString &szExp,const QString &szStr,bool bIsRegExp,bool bExact)
 	{
 		QString szWildcard;
+#ifdef COMPILE_USE_QT4
+		QChar* ptr=(QChar*)szExp.constData();
+#else
 		QChar* ptr=(QChar*)szExp.ucs2();
+#endif
 		if(!ptr) return 0;
 		while(ptr->unicode())
 		{
@@ -796,15 +882,27 @@ namespace KviQString
 			}
 			ptr++;
 		}
+#ifdef COMPILE_USE_QT4
+		QRegExp re(szWildcard,Qt::CaseInsensitive,bIsRegExp ? QRegExp::RegExp : QRegExp::Wildcard);
+#else
 		QRegExp re(szWildcard,false,!bIsRegExp);
+#endif
 		if(bExact) return re.exactMatch(szStr);
+#ifdef COMPILE_USE_QT4
+		return re.indexIn(szStr) != -1;
+#else
 		return re.search(szStr) != -1;
+#endif
 	}
 
 	bool matchStringCS(const QString &szExp,const QString &szStr,bool bIsRegExp,bool bExact)
 	{
 		QString szWildcard;
+#ifdef COMPILE_USE_QT4
+		QChar* ptr=(QChar*)szExp.constData();
+#else
 		QChar* ptr=(QChar*)szExp.ucs2();
+#endif
 		if(!ptr) return 0;
 		while(ptr->unicode())
 		{
@@ -818,28 +916,48 @@ namespace KviQString
 			}
 			ptr++;
 		}
+#ifdef COMPILE_USE_QT4
+		QRegExp re(szWildcard,Qt::CaseSensitive,bIsRegExp ? QRegExp::RegExp : QRegExp::Wildcard);
+#else
 		QRegExp re(szWildcard,true,!bIsRegExp);
+#endif
 		if(bExact) return re.exactMatch(szStr);
+#ifdef COMPILE_USE_QT4
+		return re.indexIn(szStr) != -1;
+#else
 		return re.search(szStr) != -1;
+#endif
 	}
 
 	void cutFromFirst(QString &s,const QChar &c,bool bIncluded)
 	{
+#ifdef COMPILE_USE_QT4
+		int idx = s.indexOf(c);
+#else
 		int idx = s.find(c);
+#endif
 		if(idx == -1)return;
 		s.truncate(bIncluded ? idx : idx + 1);
 	}
 
 	void cutFromLast(QString &s,const QChar &c,bool bIncluded)
 	{
+#ifdef COMPILE_USE_QT4
+		int idx = s.lastIndexOf(c);
+#else
 		int idx = s.findRev(c);
+#endif
 		if(idx == -1)return;
 		s.truncate(bIncluded ? idx : idx + 1);
 	}
 	
 	void cutToFirst(QString &s,const QChar &c,bool bIncluded,bool bClearIfNotFound)
 	{
+#ifdef COMPILE_USE_QT4
+		int idx = s.indexOf(c);
+#else
 		int idx = s.find(c);
+#endif
 		if(idx == -1)
 		{
 			if(bClearIfNotFound)s = "";
@@ -850,7 +968,11 @@ namespace KviQString
 	
 	void cutToLast(QString &s,const QChar &c,bool bIncluded,bool bClearIfNotFound)
 	{
+#ifdef COMPILE_USE_QT4
+		int idx = s.lastIndexOf(c);
+#else
 		int idx = s.findRev(c);
+#endif
 		if(idx == -1)
 		{
 			if(bClearIfNotFound)s = "";
@@ -861,21 +983,33 @@ namespace KviQString
 
 	void cutFromFirst(QString &s,const QString &c,bool bIncluded)
 	{
+#ifdef COMPILE_USE_QT4
+		int idx = s.indexOf(c);
+#else
 		int idx = s.find(c);
+#endif
 		if(idx == -1)return;
 		s.truncate(bIncluded ? idx : idx + c.length());
 	}
 
 	void cutFromLast(QString &s,const QString &c,bool bIncluded)
 	{
+#ifdef COMPILE_USE_QT4
+		int idx = s.lastIndexOf(c);
+#else
 		int idx = s.findRev(c);
+#endif
 		if(idx == -1)return;
 		s.truncate(bIncluded ? idx : idx + c.length());
 	}
 	
 	void cutToFirst(QString &s,const QString &c,bool bIncluded,bool bClearIfNotFound)
 	{
+#ifdef COMPILE_USE_QT4
+		int idx = s.indexOf(c);
+#else
 		int idx = s.find(c);
+#endif
 		if(idx == -1)
 		{
 			if(bClearIfNotFound)s = "";
@@ -886,7 +1020,11 @@ namespace KviQString
 	
 	void cutToLast(QString &s,const QString &c,bool bIncluded,bool bClearIfNotFound)
 	{
+#ifdef COMPILE_USE_QT4
+		int idx = s.lastIndexOf(c);
+#else
 		int idx = s.findRev(c);
+#endif
 		if(idx == -1)
 		{
 			if(bClearIfNotFound)s = "";
@@ -951,7 +1089,7 @@ namespace KviQString
 	void transliterate(QString &s,const QString &szToFind,const QString &szReplacement)
 	{
 		int i=0;
-		int il = QMIN(szToFind.length(),szReplacement.length());
+		int il = MY_MIN(szToFind.length(),szReplacement.length());
 		while(i < il)
 		{
 			int k=0;
@@ -969,7 +1107,11 @@ namespace KviQString
 	
 	void bufferToHex(QString &szRetBuffer,const unsigned char * buffer,unsigned int len)
 	{
+#ifdef COMPILE_USE_QT4
+		szRetBuffer.resize(len * 2);
+#else
 		szRetBuffer.setLength(len * 2);
+#endif
 		unsigned int i=0;
 		while(i < (len*2))
 		{
