@@ -34,11 +34,21 @@
 #include "kvi_settings.h"
 #include "kvi_inttypes.h"
 #include "kvi_stdarg.h"
+#include "kvi_qcstring.h"
 
 #include <qstring.h>
 
+///
+/// \namespace KviQString
+///
+/// \brief A namespace for QString helper functions
+///
+/// This namespace contains several helper functions
+/// that are used when dealing with QString.
+///
 namespace KviQString
 {
+	extern KVILIB_API QString makeSizeReadable(size_t size);
 	extern KVILIB_API bool equalCS(const QString &sz1,const QString &sz2);
 	extern KVILIB_API bool equalCI(const QString &sz1,const QString &sz2);
 	extern KVILIB_API bool equalCS(const QString &sz1,const char * sz2);
@@ -120,6 +130,144 @@ namespace KviQString
 	extern KVILIB_API void transliterate(QString &s,const QString &szToFind,const QString &szReplacement);
 
 	extern KVILIB_API void bufferToHex(QString &szRetBuffer,const unsigned char * buffer,unsigned int len);
+
+	// a global empty string (note that this is ALSO NULL under Qt 3.x)
+	extern KVILIB_API const QString empty;
+
+	///
+	/// A portability wrapper which with Qt3 and Qt4.
+	/// Returns a lowcase version of the parameter string.
+	///
+	inline QString toLower(const QString &s)
+	{
+#ifdef COMPILE_USE_QT4
+		return s.toLower();
+#else
+		return s.lower();
+#endif
+	}
+	
+	inline int find(const QString &s,QChar c,int index = 0,bool cs = true)
+	{
+#ifdef COMPILE_USE_QT4
+		return s.indexOf(c,index,cs ? Qt::CaseSensitive : Qt::CaseInsensitive);
+#else
+		return s.find(c,index,cs);
+#endif
+	}
+
+	inline int find(const QString &s,char c,int index = 0,bool cs = true)
+	{
+#ifdef COMPILE_USE_QT4
+		return s.indexOf(c,index,cs ? Qt::CaseSensitive : Qt::CaseInsensitive);
+#else
+		return s.find(c,index,cs);
+#endif
+	}
+
+	inline int find(const QString &s,const QString & str,int index = 0,bool cs = true)
+	{
+#ifdef COMPILE_USE_QT4
+		return s.indexOf(str,index,cs ? Qt::CaseSensitive : Qt::CaseInsensitive);
+#else
+		return s.find(str,index,cs);
+#endif
+	}
+
+	inline int find(const QString &s,const QRegExp & rx,int index = 0)
+	{
+#ifdef COMPILE_USE_QT4
+		return s.indexOf(rx,index);
+#else
+		return s.find(rx,index);
+#endif
+	}
+
+	inline int find(const QString &s,const char * str,int index = 0)
+	{
+#ifdef COMPILE_USE_QT4
+		return s.indexOf(QString(str),index);
+#else
+		return s.find(str,index);
+#endif
+	}
+
+	inline int findRev(const QString &s,QChar c,int index = -1,bool cs = true)
+	{
+#ifdef COMPILE_USE_QT4
+		return s.lastIndexOf(c,index,cs ? Qt::CaseSensitive : Qt::CaseInsensitive);
+#else
+		return s.findRev(c,index,cs);
+#endif
+	}
+
+	inline int findRev(const QString &s,char c,int index = -1,bool cs = true)
+	{
+#ifdef COMPILE_USE_QT4
+		return s.lastIndexOf(c,index,cs ? Qt::CaseSensitive : Qt::CaseInsensitive);
+#else
+		return s.findRev(c,index,cs);
+#endif
+	}
+
+	inline int findRev(const QString &s,const QString & str,int index = -1,bool cs = true)
+	{
+#ifdef COMPILE_USE_QT4
+		return s.lastIndexOf(str,index,cs ? Qt::CaseSensitive : Qt::CaseInsensitive);
+#else
+		return s.findRev(str,index,cs);
+#endif
+	}
+
+	inline int findRev(const QString &s,const QRegExp & rx,int index = -1)
+	{
+#ifdef COMPILE_USE_QT4
+		return s.lastIndexOf(rx,index);
+#else
+		return s.findRev(rx,index);
+#endif
+	}
+
+	inline int findRev(const QString &s,const char * str,int index = -1)
+	{
+#ifdef COMPILE_USE_QT4
+		return s.lastIndexOf(QString(str),index);
+#else
+		return s.findRev(str,index);
+#endif
+	}
+
+	inline QString trimmed(const QString &s)
+	{
+#ifdef COMPILE_USE_QT4
+		return s.trimmed();
+#else
+		return s.stripWhiteSpace();
+#endif
+	}
+
+	// WARNING: DO NOT USE CONSTRUCTS LIKE char * c = KviQString::toUtf8(something).data();
+	//          They are dangerous since with many compilers the returned string gets destroyed
+	//          at the end of the instruction and the c pointer gets thus invalidated.
+	//          Use
+	//           KviQCString tmp = KviQString::toUtf8(something);
+	//           char * c = tmp.data(); 
+	//          instead.
+	//          Yes, I know that it sucks, but it's the only way to
+	//          transit to qt 4.x more or less cleanly...
+	inline KviQCString toUtf8(const QString &s)
+	{
+#ifdef COMPILE_USE_QT4
+		return s.toUtf8();
+#else
+		return s.utf8();
+#endif
+	}
+
+	inline KviQCString toLocal8Bit(const QString &s)
+	{
+		return s.local8Bit();
+	}
 	
 	inline kvi_i64_t toI64(QString &szNumber,bool * bOk)
 	{
@@ -140,5 +288,6 @@ namespace KviQString
 	}
 };
 
+// QT4SUX: Because QString::null is gone. QString() is SLOWER than QString::null since it invokes a constructor and destructor.
 
 #endif //!_KVI_QSTRING_H_
