@@ -1,9 +1,10 @@
+//=============================================================================
 //
 //   File : kvi_cmdformatter.cpp
 //   Creation date : Tue Jun 12 2001 03:08:12 CEST by Szymon Stefanek
 //
 //   This file is part of the KVirc irc client distribution
-//   Copyright (C) 2001 Szymon Stefanek (pragma at kvirc dot net)
+//   Copyright (C) 2001-2007 Szymon Stefanek (pragma at kvirc dot net)
 //
 //   This program is FREE software. You can redistribute it and/or
 //   modify it under the terms of the GNU General Public License
@@ -19,11 +20,10 @@
 //   along with this program. If not, write to the Free Software Foundation,
 //   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 //
+//=============================================================================
 
 #define __KVILIB__
 
-
-#define _KVI_CMDFORMATTER_CPP_
 #include "kvi_cmdformatter.h"
 
 namespace KviCommandFormatter
@@ -63,7 +63,11 @@ namespace KviCommandFormatter
 			} else {
 				// we pretend this line to be empty
 				QString tmp = *it;
-				tmp.stripWhiteSpace();
+#ifdef COMPILE_USE_QT4
+				tmp = tmp.trimmed();
+#else
+				tmp = tmp.stripWhiteSpace();
+#endif
 				if(!tmp.isEmpty())return false;
 				*it = ""; // set it to empty also in the main buffer
 			}
@@ -123,7 +127,11 @@ namespace KviCommandFormatter
 
 	void unindent(QString &buffer)
 	{
+#ifdef COMPILE_USE_QT4
+		QStringList list = buffer.split("\n",QString::KeepEmptyParts);
+#else
 		QStringList list = QStringList::split("\n",buffer,true);
+#endif
 		while(hasLeadingChars(list,QChar('\t')) || hasLeadingChars(list,QChar(' ')))trimLeading(list);
 		//buffer = list.join("\n"); join implementation sux :D
 		// we WANT the last newline
@@ -154,7 +162,11 @@ namespace KviCommandFormatter
 
 	void bufferFromBlock(QString &buffer)
 	{
-		buffer.stripWhiteSpace();
+#ifdef COMPILE_USE_QT4
+		buffer = buffer.trimmed();
+#else
+		buffer = buffer.stripWhiteSpace();
+#endif
 
 		if(buffer.isEmpty())return;
 
@@ -162,13 +174,17 @@ namespace KviCommandFormatter
 		{
 			buffer.remove(0,1);
 			buffer.remove(buffer.length() - 1,1);
-			while((buffer.at(0) == QChar('\n')) || (buffer.at(0) == QChar('\r')))
+			while((buffer.length() > 0) && ((buffer.at(0) == QChar('\n')) || (buffer.at(0) == QChar('\r'))))
 				buffer.remove(0,1);
 		}
 
 		unindent(buffer);
 
+#ifdef COMPILE_USE_QT4
+		buffer = buffer.trimmed();
+#else
 		buffer = buffer.stripWhiteSpace();
+#endif
 	}
 
 
@@ -187,7 +203,11 @@ namespace KviCommandFormatter
 
 	void indent(QString &buffer)
 	{
+#ifdef COMPILE_USE_QT4
+		QStringList list = buffer.split("\n",QString::KeepEmptyParts);
+#else
 		QStringList list = QStringList::split("\n",buffer,true);
+#endif
 		addLeading(list,QChar('\t'));
 		//buffer = list.join("\n"); join implementation sux :D
 		// we WANT the last newline
