@@ -85,6 +85,19 @@ int KviDataBuffer::find(const unsigned char * block,int uSize)
 	return -1;
 }
 
+int KviDataBuffer::find(unsigned char c)
+{
+	const unsigned char * p = m_pData;
+	const unsigned char * e = p + m_uSize;
+	while(p < e)
+	{
+		if(*p == c)return (p - m_pData);
+		p++;
+	}
+	return -1;
+}
+
+
 void KviDataBuffer::remove(int uSize)
 {
 	__range_valid((uSize <= m_uSize) && (uSize > 0));
