@@ -40,4 +40,4 @@ namespace KviOsInfo
 	extern KVILIB_API QString hostname();
 };
 
-#endif
\ No newline at end of file
+#endif //!_KVI_OSINFO_H_
