@@ -25,9 +25,11 @@
 
 #define __KVILIB__
 
-
 #include "kvi_debug.h"
+
+#define _KVI_REGUSERDB_CPP_
 #include "kvi_regusersdb.h"
+
 #include "kvi_config.h"
 #include "kvi_locale.h"
 
@@ -123,6 +125,8 @@
 // KviRegisteredMask
 //
 
+KVILIB_API KviRegisteredUserDataBase* g_pRegisteredUserDataBase = 0;
+
 KviRegisteredMask::KviRegisteredMask(KviRegisteredUser * u,KviIrcMask * m)
 {
 	m_pUser = u;
@@ -138,9 +142,11 @@ KviRegisteredMask::KviRegisteredMask(KviRegisteredUser * u,KviIrcMask * m)
 
 KviRegisteredUser::KviRegisteredUser(const QString & name)
 {
+	m_iIgnoreFlags  =0;
+	m_bIgnoreEnabled=false;
 	m_szName        = name;
 	m_pPropertyDict = 0;
-	m_pMaskList     = new KviPtrList<KviIrcMask>;
+	m_pMaskList     = new KviPointerList<KviIrcMask>;
 	m_pMaskList->setAutoDelete(true);
 }
 
@@ -150,6 +156,12 @@ KviRegisteredUser::~KviRegisteredUser()
 	delete m_pMaskList;
 }
 
+bool KviRegisteredUser::isIgnoreEnabledFor(IgnoreFlags flag)
+{
+	if(!m_bIgnoreEnabled) return false;
+	return m_iIgnoreFlags & flag;
+}
+
 KviIrcMask * KviRegisteredUser::findMask(const KviIrcMask &mask)
 {
 	for(KviIrcMask * m = m_pMaskList->first();m;m = m_pMaskList->next())
@@ -204,18 +216,25 @@ bool KviRegisteredUser::matchesFixed(const QString & nick,const QString & user,c
 	return false;
 }
 
+void KviRegisteredUser::setProperty(const QString &name,bool value)
+{
+	setProperty(name,value ? QString("true") : QString("false"));
+}
 
 void KviRegisteredUser::setProperty(const QString & name,const QString & value)
 {
-	if(value && *value)
+	if(!value.isEmpty())
 	{
 		if(!m_pPropertyDict)
 		{
-			m_pPropertyDict = new QDict<QString>(7,false);
+			m_pPropertyDict = new KviPointerHashTable<QString,QString>(7,false);
 			m_pPropertyDict->setAutoDelete(true);
 		}
-		QString * val = new QString(value);
-		val->stripWhiteSpace();
+#ifdef COMPILE_USE_QT4
+		QString * val = new QString(value.trimmed());
+#else
+		QString * val = new QString(value.stripWhiteSpace());
+#endif
 		if(!val->isEmpty())
 		{
 			m_pPropertyDict->replace(name,val);
@@ -240,17 +259,17 @@ bool KviRegisteredUser::getProperty(const QString & name,QString &value)
 
 const QString & KviRegisteredUser::getProperty(const QString & name)
 {
-	if(!m_pPropertyDict) return QString::null;
-	if(name.isEmpty()) return QString::null;
+	if(!m_pPropertyDict)return KviQString::empty;
+	if(name.isEmpty())return KviQString::empty;
 	QString * pValue = m_pPropertyDict->find(name);
 	if(pValue)return *pValue;
-	return QString::null;
+	return KviQString::empty;
 }
 
-bool KviRegisteredUser::getBoolProperty(const QString & name)
+bool KviRegisteredUser::getBoolProperty(const QString & name,bool def)
 {
-	if(!m_pPropertyDict)return false;
-	if(name.isEmpty()) return false;
+	if(!m_pPropertyDict)return def;
+	if(name.isEmpty()) return def;
 	QString * pValue = m_pPropertyDict->find(name);
 	if(pValue)
 	{
@@ -258,8 +277,11 @@ bool KviRegisteredUser::getBoolProperty(const QString & name)
 		if(KviQString::equalCS(*pValue,"1"))return true;
 		if(KviQString::equalCI(*pValue,"true"))return true;
 		if(KviQString::equalCI(*pValue,"yes"))return true;
+		//if(KviQString::equalCI(*pValue,"yeah"))return true;
+		//if(KviQString::equalCI(*pValue,"sure"))return true;
+		//if(KviQString::equalCI(*pValue,"sureashell"))return true;
 	}
-	return false;
+	return def;
 }
 
 //============================================================================================================
@@ -284,21 +306,22 @@ KviRegisteredUserGroup::~KviRegisteredUserGroup()
 
 KviRegisteredUserDataBase::KviRegisteredUserDataBase()
 {
-	m_pUserDict = new QDict<KviRegisteredUser>(31,false); // do not copy keys
+	m_pUserDict = new KviPointerHashTable<QString,KviRegisteredUser>(31,false); // do not copy keys
 	m_pUserDict->setAutoDelete(true);
 
 	m_pWildMaskList = new KviRegisteredMaskList;
 	m_pWildMaskList->setAutoDelete(true);
 
-	m_pMaskDict = new QDict<KviRegisteredMaskList>(49,false); // copy keys here!
+	m_pMaskDict = new KviPointerHashTable<QString,KviRegisteredMaskList>(49,false); // copy keys here!
 	m_pMaskDict->setAutoDelete(true);
 	
-	m_pGroupDict = new  QDict<KviRegisteredUserGroup>(5,false); // copy keys here!
+	m_pGroupDict = new  KviPointerHashTable<QString,KviRegisteredUserGroup>(5,false); // copy keys here!
 	m_pGroupDict->setAutoDelete(true);
 }
 
 KviRegisteredUserDataBase::~KviRegisteredUserDataBase()
 {
+	emit(databaseCleared());
 	delete m_pUserDict;
 	delete m_pWildMaskList;
 	delete m_pMaskDict;
@@ -311,6 +334,7 @@ KviRegisteredUser * KviRegisteredUserDataBase::addUser(const QString & name)
 	if(m_pUserDict->find(name))return 0;
 	KviRegisteredUser * u = new KviRegisteredUser(name);
 	m_pUserDict->replace(u->name(),u); //u->name() because we're NOT copying keys!
+	emit(userAdded(name));
 	return u;
 }
 
@@ -419,35 +443,38 @@ void KviRegisteredUserDataBase::copyFrom(KviRegisteredUserDataBase * db)
 	m_pWildMaskList->clear();
 	m_pMaskDict->clear();
 	m_pGroupDict->clear();
+	emit(databaseCleared());
 
-	QDictIterator<KviRegisteredUser> it(*(db->m_pUserDict));
+	KviPointerHashTableIterator<QString,KviRegisteredUser> it(*(db->m_pUserDict));
 
 	while(KviRegisteredUser * theCur = it.current())
 	{
 		KviRegisteredUser * u = getUser(theCur->name());
 		// copy masks
-		KviPtrList<KviIrcMask> * l = theCur->maskList();
+		KviPointerList<KviIrcMask> * l = theCur->maskList();
 		for(KviIrcMask * m=l->first();m;m = l->next())
 		{
 			KviIrcMask * m2 = new KviIrcMask(*m);
 			addMask(u,m2);
 		}
 		// copy properties
-		QDict<QString> * pd = theCur->propertyDict();
+		KviPointerHashTable<QString,QString> * pd = theCur->propertyDict();
 		if(pd)
 		{
-			QDictIterator<QString> pdi(*pd);
+			KviPointerHashTableIterator<QString,QString> pdi(*pd);
 			while(pdi.current())
 			{
 				u->setProperty(pdi.currentKey(),*(pdi.current()));
 				++pdi;
 			}
 		}
+		u->m_iIgnoreFlags=theCur->m_iIgnoreFlags;
+		u->m_bIgnoreEnabled=theCur->m_bIgnoreEnabled;
 		u->setGroup(theCur->group());
 		++it;
 	}
 	
-	QDictIterator<KviRegisteredUserGroup> git(*db->m_pGroupDict);
+	KviPointerHashTableIterator<QString,KviRegisteredUserGroup> git(*db->m_pGroupDict);
 	while(git.current())
 	{
 		addGroup(git.currentKey());	
@@ -464,8 +491,9 @@ bool KviRegisteredUserDataBase::removeUser(const QString & name)
 	while(KviIrcMask * mask = u->maskList()->first())
 	{
 		if(!removeMaskByPointer(mask))
-			debug("Ops... removeMaskByPointer(%s) failed ?",name.utf8().data());
+			debug("Ops... removeMaskByPointer(%s) failed ?",KviQString::toUtf8(name).data());
 	}
+	emit(userRemoved(name));
 	m_pUserDict->remove(name);
 	return true;
 }
@@ -481,7 +509,12 @@ bool KviRegisteredUserDataBase::removeMask(const KviIrcMask &mask)
 	// find the mask pointer
 	KviRegisteredMask * m = findExactMask(mask);
 	// and remove it
-	if(m)return removeMaskByPointer(m->mask());
+	if(m){
+		if(removeMaskByPointer(m->mask()))
+		{
+			return true;
+		}
+	}
 	return 0;
 }
 
@@ -496,6 +529,7 @@ bool KviRegisteredUserDataBase::removeMaskByPointer(KviIrcMask * mask)
 			if(m->mask() == mask)
 			{
 				// ok..got it, remove from the list and from the user struct (user struct deletes it!)
+				emit(userChanged(mask->nick()));
 				m->user()->removeMask(mask);    // this one deletes m->mask()
 				m_pWildMaskList->removeRef(m);  // this one deletes m
 				return true;
@@ -512,6 +546,7 @@ bool KviRegisteredUserDataBase::removeMaskByPointer(KviIrcMask * mask)
 				if(m->mask() == mask)
 				{
 					QString nick = mask->nick();
+					emit(userChanged(nick));
 					m->user()->removeMask(mask); // this one deletes m->mask() (or mask)
 					l->removeRef(m);             // this one deletes m
 					if(l->count() == 0)m_pMaskDict->remove(nick);
@@ -616,6 +651,7 @@ void KviRegisteredUserDataBase::load(const QString & filename)
 	KviConfigIterator it(*cfg.dict());
 	while(it.current())
 	{
+		cfg.setGroup(it.currentKey());
 		szCurrent=it.currentKey();
 		if(KviQString::equalCSN("#Group ",szCurrent,7))
 		{
@@ -626,6 +662,8 @@ void KviRegisteredUserDataBase::load(const QString & filename)
 			
 			if(u)
 			{
+				u->setIgnoreEnabled(cfg.readBoolEntry("IgnoreEnabled",false));
+				u->setIgnoreFlags(cfg.readIntEntry("IgnoreFlags",0));
 				KviConfigGroupIterator sdi(*(it.current()));
 				while(sdi.current())
 				{
@@ -659,15 +697,17 @@ void KviRegisteredUserDataBase::save(const QString & filename)
 	cfg.clear();
 	cfg.preserveEmptyGroups(true);
 
-	QDictIterator<KviRegisteredUser> it(*m_pUserDict);
+	KviPointerHashTableIterator<QString,KviRegisteredUser> it(*m_pUserDict);
 
 	while(it.current())
 	{
 		cfg.setGroup(it.current()->name());
 		// Write properties
+		cfg.writeEntry("IgnoreEnabled",it.current()->ignoreEnagled());
+		cfg.writeEntry("IgnoreFlags",it.current()->ignoreFlags());
 		if(it.current()->propertyDict())
 		{
-			QDictIterator<QString> pit(*(it.current()->propertyDict()));
+			KviPointerHashTableIterator<QString,QString> pit(*(it.current()->propertyDict()));
 			while(pit.current())
 			{
 				QString tmp = "prop_";
@@ -691,7 +731,7 @@ void KviRegisteredUserDataBase::save(const QString & filename)
 		++it;
 	}
 	
-	QDictIterator<KviRegisteredUserGroup> git(*m_pGroupDict);
+	KviPointerHashTableIterator<QString,KviRegisteredUserGroup> git(*m_pGroupDict);
 	QString szTmp;
 	while(git.current())
 	{
