@@ -31,9 +31,80 @@
 #include "kvi_qstring.h"
 #include <stdio.h>
 
+QString g_szGlobalDir;
+QString g_szLocalDir;
+
 namespace KviStringConversion
 {
 
+	void init(const QString& szGlobalDir,const QString& szLocalDir)
+	{
+		g_szGlobalDir=szGlobalDir;
+		g_szLocalDir=szLocalDir;
+	}
+
+	void encodePath(QString& buffer)
+	{
+		if(!buffer.isEmpty())
+		{
+			if(!g_szLocalDir.isEmpty())
+			{
+				if(KviQString::find(buffer,g_szLocalDir)==0)
+				{
+					buffer.remove(0,g_szLocalDir.length());
+					buffer.prepend("local://");
+				}
+			}
+			if(!g_szGlobalDir.isEmpty())
+			{
+				if(KviQString::find(buffer,g_szGlobalDir)==0)
+				{
+					buffer.remove(0,g_szGlobalDir.length());
+					buffer.prepend("global://");
+				}
+			}
+		}
+	}
+
+	void decodePath(QString& buffer)
+	{
+		if(!buffer.isEmpty())
+		{
+			if(!g_szLocalDir.isEmpty())
+			{
+				if(KviQString::find(buffer,"local://")==0)
+				{
+					buffer.remove(0,8);
+					buffer.prepend(g_szLocalDir);
+				}
+			}
+			if(!g_szGlobalDir.isEmpty())
+			{
+				if(KviQString::find(buffer,"global://")==0)
+				{
+					buffer.remove(0,9);
+					buffer.prepend(g_szGlobalDir);
+				}
+			}
+		}
+	}
+	
+	void encodePath(QStringList& buffer)
+	{
+		for ( QStringList::Iterator it = buffer.begin(); it != buffer.end(); ++it )
+		{
+			encodePath(*it);
+		}
+	}
+
+	void decodePath(QStringList& buffer)
+	{
+		for ( QStringList::Iterator it = buffer.begin(); it != buffer.end(); ++it )
+		{
+			decodePath(*it);
+		}
+	}
+
 	void toString(const bool bValue,QString &buffer)
 	{
 		buffer = bValue ? '1' : '0';
@@ -77,7 +148,8 @@ namespace KviStringConversion
 	
 	bool fromString(const QString & szValue,QRect &buffer)
 	{
-		const char * c = szValue.latin1();
+		KviQCString tmp = KviQString::toUtf8(szValue);
+		const char * c = tmp.data();
 		if(!c)return false;
 		int l,t,w,h;
 		if(sscanf(c,"%d,%d,%d,%d",&l,&t,&w,&h) != 4)return false;
@@ -98,12 +170,20 @@ namespace KviStringConversion
 	
 	void toString(const KviPixmap &pValue,QString &buffer)
 	{
-		buffer = pValue.path();
+		buffer=pValue.path();
+		encodePath(buffer);
 	}
 	
 	bool fromString(const QString & szValue,KviPixmap &buffer)
 	{
-		return buffer.load(szValue.latin1());
+		QString szPath(szValue);
+		decodePath(szPath);
+		if(szPath.isEmpty()) {
+			buffer.setNull();
+			return true;
+		} else {
+			return buffer.load(szPath);
+		}
 	}
 	
 	void toString(const KviMsgType &mValue,QString &buffer)
@@ -115,9 +195,10 @@ namespace KviStringConversion
 	{
 		int iId,iLog,iLevel;
 		unsigned int uFore,uBack;
-		const char * c = szValue.latin1();
-		if(!c)return false;
-		if(sscanf(c,"%d,%u,%u,%d,%d",&iId,&uFore,&uBack,&iLog,&iLevel) != 5)return false;
+		KviQCString tmp = KviQString::toUtf8(szValue);
+		char * cx = tmp.data();
+		if(!cx)return false;
+		if(sscanf(cx,"%d,%u,%u,%d,%d",&iId,&uFore,&uBack,&iLog,&iLevel) != 5)return false;
 		buffer = KviMsgType(buffer.m_szType,iId,uFore,uBack,iLog,iLevel);
 		return true;
 	}
@@ -135,7 +216,7 @@ namespace KviStringConversion
 	void toString(const QFont &fValue,QString &buffer)
 	{
 		QString family(fValue.family());
-		buffer.sprintf("%s,%d,%d,%d",family.utf8().data(),fValue.pointSize(),fValue.styleHint(),fValue.weight());
+		buffer.sprintf("%s,%d,%d,%d",KviQString::toUtf8(family).data(),fValue.pointSize(),fValue.styleHint(),fValue.weight());
 		QString options;
 		if(fValue.bold())options.append('b');
 		if(fValue.italic())options.append('i');
@@ -185,7 +266,11 @@ namespace KviStringConversion
 	
 	bool fromString(const QString & szValue,QStringList &buffer)
 	{
+#ifdef COMPILE_USE_QT4
+		buffer = szValue.split(",");
+#else
 		buffer = QStringList::split(",",szValue);
+#endif
 		return true;
 	}
 
