@@ -4,7 +4,7 @@
 //   Creation date : Mon Dec 17 2001 00:04:12 by Szymon Stefanek
 //
 //   This file is part of the KVirc irc client distribution
-//   Copyright (C) 2001-2002 Szymon Stefanek (pragma at kvirc dot net)
+//   Copyright (C) 2001-2007 Szymon Stefanek (pragma at kvirc dot net)
 //
 //   This program is FREE software. You can redistribute it and/or
 //   modify it under the terms of the GNU General Public License
@@ -26,7 +26,7 @@
 
 
 #include "kvi_file.h"
-#include "kvi_bswap.h"
+#include "kvi_byteorder.h"
 
 
 KviFile::KviFile()
@@ -43,19 +43,73 @@ KviFile::~KviFile()
 {
 }
 
+bool KviFile::openForReading()
+{
+#ifdef COMPILE_USE_QT4
+	return open(QFile::ReadOnly);
+#else
+	return open(IO_ReadOnly);
+#endif
+}
+
+bool KviFile::openForWriting(bool bAppend)
+{
+#ifdef COMPILE_USE_QT4
+	return open(QFile::WriteOnly | (bAppend ? QFile::Append : QFile::Truncate));
+#else
+	return open(IO_WriteOnly | (bAppend ? IO_Append : IO_Truncate));
+#endif
+}
+
+
+bool KviFile::save(const QByteArray &bData)
+{
+	if(!save((kvi_u32_t)(bData.size())))return false;
+	return (writeBlock(bData.data(),bData.size()) == ((int)(bData.size())));
+}
+
+bool KviFile::load(QByteArray &bData)
+{
+	kvi_u32_t iLen;
+	if(!load(iLen))return false;
+	bData.resize(iLen); // it is automatically null terminated in Qt 4.x... BLEAH :D
+	if(readBlock((char *)(bData.data()),iLen) != iLen)return false;
+	return true;
+}
+
+#ifndef COMPILE_USE_QT4
+
+bool KviFile::save(const KviQCString &szData)
+{
+	if(!save((kvi_u32_t)(szData.length())))return false;
+	return (writeBlock(szData.data(),szData.length()) == ((int)(szData.length())));
+}
+
+bool KviFile::load(KviQCString &szData)
+{
+	kvi_u32_t iLen;
+	if(!load(iLen))return false;
+	szData.resize(iLen + 1); // this would allocate one extra byte with Qt 4.x...
+	if(readBlock((char *)(szData.data()),iLen) != iLen)return false;
+	*(szData.data() + iLen) = 0;
+	return true;
+}
+
+#endif
+
 
 bool KviFile::save(const QString &szData)
 {
-	QCString c = szData.utf8();
-	if(!save(c.length()))return false;
+	KviQCString c = KviQString::toUtf8(szData);
+	if(!save((kvi_u32_t)(c.length())))return false;
 	return (writeBlock(c.data(),c.length()) == ((int)(c.length())));
 }
 
 bool KviFile::load(QString &szData)
 {
-	int iLen;
+	kvi_u32_t iLen;
 	if(!load(iLen))return false;
-	QCString tmp;
+	KviQCString tmp;
 	tmp.resize(iLen + 1);
 	if(readBlock((char *)(tmp.data()),iLen) != iLen)return false;
 	*(tmp.data() + iLen) = 0;
@@ -65,70 +119,82 @@ bool KviFile::load(QString &szData)
 
 bool KviFile::save(const KviStr &szData)
 {
-	if(!save(szData.len()))return false;
+	if(!save((kvi_u32_t)(szData.len())))return false;
 	return (writeBlock(szData.ptr(),szData.len()) == (int) szData.len());
 }
 
 bool KviFile::load(KviStr &szData)
 {
-	int iLen;
+	kvi_u32_t iLen;
 	if(!load(iLen))return false;
 	szData.setLength(iLen);
 	return (readBlock((char *)(szData.ptr()),iLen) == iLen);
 }
 
-bool KviFile::save(kvi_i32_t t)
+bool KviFile::save(kvi_u32_t t)
 {
-#ifdef BIGENDIAN_MACHINE_BYTE_ORDER
-	t = kvi_swap32(t);
+#ifndef LOCAL_CPU_LITTLE_ENDIAN
+	t = kvi_localCpuToLittleEndian32(t);
 #endif
-	return (writeBlock((const char *)(&t),sizeof(kvi_i32_t)) == sizeof(kvi_i32_t));
+	return (writeBlock((const char *)(&t),sizeof(kvi_u32_t)) == sizeof(kvi_u32_t));
 }
 
-bool KviFile::load(kvi_i32_t &t)
+bool KviFile::load(kvi_u32_t &t)
 {
-#ifdef BIGENDIAN_MACHINE_BYTE_ORDER
-	if(!(readBlock((char *)(&t),sizeof(kvi_i32_t)) == sizeof(kvi_i32_t)))return false;
-	t = kvi_swap32(t);
+	if(!(readBlock((char *)(&t),sizeof(kvi_u32_t)) == sizeof(kvi_u32_t)))return false;
+#ifndef LOCAL_CPU_LITTLE_ENDIAN
+	t = kvi_littleEndianToLocalCpu32(t);
+#endif
 	return true;
-#else
-	return (readBlock((char *)(&t),sizeof(kvi_i32_t)) == sizeof(kvi_i32_t));
-#endif
 }
 
-bool KviFile::save(kvi_i16_t t)
+bool KviFile::save(kvi_u64_t t)
 {
-#ifdef BIGENDIAN_MACHINE_BYTE_ORDER
-	t = kvi_swap16(t);
+#ifndef LOCAL_CPU_LITTLE_ENDIAN
+	t = kvi_localCpuToLittleEndian64(t);
 #endif
-	return (writeBlock((const char *)(&t),sizeof(kvi_i16_t)) == sizeof(kvi_i16_t));
+	return (writeBlock((const char *)(&t),sizeof(kvi_u64_t)) == sizeof(kvi_u64_t));
 }
 
-bool KviFile::load(kvi_i16_t &t)
+bool KviFile::load(kvi_u64_t &t)
 {
-#ifdef BIGENDIAN_MACHINE_BYTE_ORDER
-	if(!(readBlock((char *)(&t),sizeof(kvi_i16_t)) == sizeof(kvi_i16_t)))return false;
-	t = kvi_swap32(t);
+	if(!(readBlock((char *)(&t),sizeof(kvi_u32_t)) == sizeof(kvi_u32_t)))return false;
+#ifndef LOCAL_CPU_LITTLE_ENDIAN
+	t = kvi_littleEndianToLocalCpu32(t);
+#endif
 	return true;
-#else
-	return (readBlock((char *)(&t),sizeof(kvi_i16_t)) == sizeof(kvi_i16_t));
+}
+
+
+bool KviFile::save(kvi_u16_t t)
+{
+#ifndef LOCAL_CPU_LITTLE_ENDIAN
+	t = kvi_localCpuToLittleEndian16(t);
 #endif
+	return (writeBlock((const char *)(&t),sizeof(kvi_u16_t)) == sizeof(kvi_u16_t));
 }
 
-bool KviFile::save(kvi_i8_t t)
+bool KviFile::load(kvi_u16_t &t)
 {
-	return (writeBlock((const char *)(&t),sizeof(kvi_i8_t)) == sizeof(kvi_i8_t));
+	if(!(readBlock((char *)(&t),sizeof(kvi_u16_t)) == sizeof(kvi_u16_t)))return false;
+#ifndef LOCAL_CPU_LITTLE_ENDIAN
+	t = kvi_littleEndianToLocalCpu16(t);
+#endif
+	return true;
 }
 
-bool KviFile::load(kvi_i8_t &t)
+bool KviFile::save(kvi_u8_t t)
 {
-	return (readBlock((char *)(&t),sizeof(kvi_i8_t)) == sizeof(kvi_i8_t));
+	return (writeBlock((const char *)(&t),sizeof(kvi_u8_t)) == sizeof(kvi_u8_t));
+}
+
+bool KviFile::load(kvi_u8_t &t)
+{
+	return (readBlock((char *)(&t),sizeof(kvi_u8_t)) == sizeof(kvi_u8_t));
 }
 
 
-
-
-bool KviFile::save(KviPtrList<KviStr> * pData)
+bool KviFile::save(KviPointerList<KviStr> * pData)
 {
 	if(!save((int)(pData->count())))return false;
 	for(KviStr * s = pData->first();s;s = pData->next())
@@ -138,7 +204,7 @@ bool KviFile::save(KviPtrList<KviStr> * pData)
 	return true;
 }
 
-bool KviFile::load(KviPtrList<KviStr> * pData)
+bool KviFile::load(KviPointerList<KviStr> * pData)
 {
 	pData->clear();
 	int iCount;
@@ -161,9 +227,9 @@ bool KviFile::skipFirst(char t,unsigned int maxdist)
 {
 	while(maxdist > 0)
 	{
-		int c = getch();
+		char c;
+		if(!getChar(&c))return false;
 		if(((char)c) == t)return true;
-		if(c == -1)return false;
 		maxdist--;
 	}
 	return false;
@@ -174,13 +240,13 @@ bool KviFile::skipFirst(const KviStr &t,unsigned int maxdist)
 	char * ptr = t.ptr();
 	while(maxdist > 0)
 	{
-		int c = getch();
+		char c;
+		if(!getChar(&c))return false;
 		if(c == *ptr)
 		{
 			ptr++;
 			if(!*ptr)return true;
 		} else {
-			if(c == -1)return false;
 			ptr = t.ptr();
 		}
 		maxdist--;
