@@ -152,11 +152,14 @@ QPixmap * KviAvatar::scaledPixmap(unsigned int w,unsigned int h)
 		scaleH = h;
 		scaleW = (scaleH * curW) / curH;
 	}
-	
+
+#ifdef COMPILE_USE_QT4
+	m_pScaledPixmap = new QPixmap(m_pPixmap->scaled(scaleW,scaleH));
+#else
 	QImage img = m_pPixmap->convertToImage();
 
 	m_pScaledPixmap = new QPixmap();
 	m_pScaledPixmap->convertFromImage(img.smoothScale(scaleW,scaleH));
-
+#endif
 	return m_pScaledPixmap;
 }
