@@ -268,7 +268,13 @@ KviIrcMask::KviIrcMask(const QString &szMask)
 		p++;
 		b=p;
 		while(p->unicode())p++;
-		m_szHost.setUnicode(b,p-b);
+		if(p != b)
+		{
+			m_szHost.setUnicode(b,p-b);
+		} else {
+			m_szHost = szWild; // ???
+		}
+		
 	} else {
 		m_szUser = szWild;
 		m_szHost = szWild;
@@ -293,7 +299,11 @@ bool KviIrcMask::hasNumericHost() const
 			else {
 				if((uc < '0') || (uc > '9'))
 				{
+#ifdef COMPILE_USE_QT4
+					uc = p->toUpper().unicode();
+#else
 					uc = p->upper().unicode();
+#endif
 					if((uc < 'A') || (uc > 'F'))return false;
 				}
 			}
@@ -397,13 +407,17 @@ void KviIrcMask::mask(QString &szMask,MaskType eMaskType) const
 			szMask.append(m_szWild);
 			break;
 		default:
-			if(m_szUser[0].unicode() != '*')szMask.append(m_szWild);
-			if((m_szUser[0].unicode() == '~') ||
-				(m_szUser[0].unicode() == '^') ||
-				(m_szUser[0].unicode() == '+') ||
-				(m_szUser[0].unicode() == '-') ||
-				(m_szUser[0].unicode() == '='))szMask.append(m_szUser.right(m_szUser.length() - 1));
-			else szMask.append(m_szUser);
+			if (m_szUser.length() > 0) {
+				if(m_szUser[0].unicode() != '*')
+					szMask.append(m_szWild);
+				if ((m_szUser[0].unicode() == '~') ||
+					(m_szUser[0].unicode() == '^') ||
+					(m_szUser[0].unicode() == '+') ||
+					(m_szUser[0].unicode() == '-') ||
+					(m_szUser[0].unicode() == '='))szMask.append(m_szUser.right(m_szUser.length() - 1));
+				else
+					szMask.append(m_szUser);
+			}
 		break;
 	}
 	szMask.append('@');
@@ -721,17 +735,21 @@ int KviIrcMask::nonWildChars()
 	const QChar * aux = KviQString::nullTerminatedArray(m_szNick);
 	if(!aux)return 0;
 	unsigned short uc;
+
 	while((uc = aux->unicode()))
 	{
 		if((uc != '*') && (uc != '?'))iCnt++;
 		aux++;
 	}
+
 	aux = KviQString::nullTerminatedArray(m_szUser);
 	while((uc = aux->unicode()))
 	{
 		if((uc != '*') && (uc != '?'))iCnt++;
 		aux++;
 	}
+
+
 	aux = KviQString::nullTerminatedArray(m_szHost);
 	while((uc = aux->unicode()))
 	{
