@@ -45,20 +45,21 @@
 //extern KVIRC_API KviProxyDataBase * g_pProxyDataBase;
 
 // FIXME: This should be renamed to KviServer or sth like that
-
 KviIrcServer::KviIrcServer()
 {
+	m_pReconnectInfo=0;
 	m_uFlags = 0;
 	m_uPort  = 6667;
 	m_pChannelList = 0;
 	m_bAutoConnect = false;
+	m_iProxy = -1;
 }
 
 KviProxy* KviIrcServer::proxyServer(KviProxyDataBase * pDb)
 {
 	int i=0;
 	if(proxy()<0) return 0;
-	KviPtrList<KviProxy> * proxylist = pDb->proxyList();
+	KviPointerList<KviProxy> * proxylist = pDb->proxyList();
 	for(KviProxy * p = proxylist->first();p;p = proxylist->next())
 	{
 		if(i==proxy()) return p;
@@ -69,6 +70,7 @@ KviProxy* KviIrcServer::proxyServer(KviProxyDataBase * pDb)
 
 KviIrcServer::KviIrcServer(const KviIrcServer &serv)
 {
+	m_pReconnectInfo     = 0;
 	m_szHostname         = serv.m_szHostname;
 	m_szIp               = serv.m_szIp;
 	m_szDescription      = serv.m_szDescription;
@@ -79,12 +81,13 @@ KviIrcServer::KviIrcServer(const KviIrcServer &serv)
 	m_szRealName         = serv.m_szRealName;
 	m_szEncoding         = serv.m_szEncoding;
 	m_uFlags             = serv.m_uFlags;
-	m_szInitUMode = serv.m_szInitUMode;
+	m_szInitUMode        = serv.m_szInitUMode;
 	m_szOnConnectCommand = serv.m_szOnConnectCommand;
 	m_szOnLoginCommand   = serv.m_szOnLoginCommand;
 	m_szLinkFilter       = serv.m_szLinkFilter;
 	m_szId               = serv.m_szId;
-	m_iProxy	     = serv.m_iProxy;
+	m_iProxy             = serv.m_iProxy;
+	m_szUserIdentityId   = serv.m_szUserIdentityId;
 	if(serv.m_pChannelList)
 		m_pChannelList = new QStringList(*(serv.m_pChannelList));
 	else m_pChannelList = 0;
@@ -108,6 +111,7 @@ void KviIrcServer::operator=(const KviIrcServer &serv)
 	m_szOnLoginCommand   = serv.m_szOnLoginCommand;
 	m_szLinkFilter       = serv.m_szLinkFilter;
 	m_szId               = serv.m_szId;
+	m_szUserIdentityId   = serv.m_szUserIdentityId;
 	m_iProxy	     = serv.m_iProxy;
 	if(m_pChannelList)delete m_pChannelList;
 	if(serv.m_pChannelList)
@@ -120,6 +124,7 @@ void KviIrcServer::operator=(const KviIrcServer &serv)
 KviIrcServer::~KviIrcServer()
 {
 	if(m_pChannelList)delete m_pChannelList;
+	if(m_pReconnectInfo) delete m_pReconnectInfo;
 }
 
 void KviIrcServer::generateUniqueId()
@@ -129,6 +134,24 @@ void KviIrcServer::generateUniqueId()
 	KviQString::sprintf(m_szId,"myserver%d%d%d",tv.tv_usec,rand() % 1000,rand() % 1000);
 }
 
+QString KviIrcServer::ircUri()
+{
+	QString uri("irc");
+	if(useSSL())uri += "s";
+	if(isIpV6())uri += "6";
+	uri += "://";
+	uri += m_szHostname;
+
+	if(m_uPort!=6667)
+	{
+		uri += ":";
+		QString num;
+		num.setNum(m_uPort);
+		uri += num;
+	}
+	return uri;
+}
+
 void KviIrcServer::setAutoJoinChannelList(QStringList * pNewChannelList)
 {
 	if(m_pChannelList)delete m_pChannelList;
@@ -182,6 +205,8 @@ bool KviIrcServer::load(KviConfig * cfg,const QString &prefix)
 	setUseSSL(cfg->readBoolEntry(tmp,false));
 	KviQString::sprintf(tmp,"%QProxy",&prefix);
 	setProxy(cfg->readIntEntry(tmp,-2));
+	KviQString::sprintf(tmp,"%QUserIdentityId",&prefix);
+	m_szUserIdentityId = cfg->readQStringEntry(tmp);
 	return true;
 }
 
@@ -282,6 +307,11 @@ void KviIrcServer::save(KviConfig * cfg,const QString &prefix)
 		KviQString::sprintf(tmp,"%QProxy",&prefix);
 		cfg->writeEntry(tmp,proxy());
 	}
+	if(!m_szUserIdentityId.isEmpty())
+	{
+		KviQString::sprintf(tmp,"%QUserIdentityId",&prefix);
+		cfg->writeEntry(tmp,m_szUserIdentityId);
+	}
 }
 
 
@@ -330,6 +360,7 @@ void KviIrcNetwork::copyFrom(const KviIrcNetwork &src)
 	m_szRealName = src.m_szRealName;
 	m_szUserName = src.m_szUserName;
 	m_bAutoConnect = src.m_bAutoConnect;
+	m_szUserIdentityId = src.m_szUserIdentityId;
 	m_szOnConnectCommand  = src.m_szOnConnectCommand;
 	m_szOnLoginCommand = src.m_szOnLoginCommand;
 	if(m_pChannelList)delete m_pChannelList;
@@ -340,6 +371,3 @@ void KviIrcNetwork::copyFrom(const KviIrcNetwork &src)
 	else m_pNickServRuleSet = 0;
 }
 
-
-
-
