@@ -39,7 +39,7 @@
 KviIrcServerDataBaseRecord::KviIrcServerDataBaseRecord(KviIrcNetwork * n)
 {
 	m_pNetwork = n;
-	m_pServerList = new KviPtrList<KviIrcServer>;
+	m_pServerList = new KviPointerList<KviIrcServer>;
 	m_pServerList->setAutoDelete(true);
 	m_pCurrentServer = 0;
 }
@@ -90,7 +90,7 @@ KviIrcServer * KviIrcServerDataBaseRecord::currentServer()
 
 KviIrcServerDataBase::KviIrcServerDataBase()
 {
-	m_pRecords = new QDict<KviIrcServerDataBaseRecord>(17,false);
+	m_pRecords = new KviPointerHashTable<QString,KviIrcServerDataBaseRecord>(17,false);
 	m_pRecords->setAutoDelete(true);
 	m_pAutoConnectOnStartupServers = 0;
 	m_pAutoConnectOnStartupNetworks = 0;
@@ -149,7 +149,7 @@ KviIrcServerDataBaseRecord * KviIrcServerDataBase::currentRecord()
 	if(!m_szCurrentNetwork.isEmpty())r = m_pRecords->find(m_szCurrentNetwork);
 	if(r)return r;
 
-	QDictIterator<KviIrcServerDataBaseRecord> it(*m_pRecords);
+	KviPointerHashTableIterator<QString,KviIrcServerDataBaseRecord> it(*m_pRecords);
 	r = it.current();
 	if(!r)return 0;
 	m_szCurrentNetwork = r->network()->name();
@@ -158,7 +158,7 @@ KviIrcServerDataBaseRecord * KviIrcServerDataBase::currentRecord()
 
 void KviIrcServerDataBase::updateServerIp(KviIrcServer * pServer,const QString & ip)
 {
-	QDictIterator<KviIrcServerDataBaseRecord> it(*m_pRecords);
+	KviPointerHashTableIterator<QString,KviIrcServerDataBaseRecord> it(*m_pRecords);
 	while(KviIrcServerDataBaseRecord * r = it.current())
 	{
 		KviIrcServer * srv = r->findServer(pServer);
@@ -184,8 +184,13 @@ bool KviIrcServerDataBase::makeCurrentBestServerInNetwork(const QString &szNetNa
 
 	for(KviIrcServer * s = r->m_pServerList->first();s;s = r->m_pServerList->next())
 	{
+#ifdef COMPILE_USE_QT4
+		if(s->m_szDescription.contains("random",Qt::CaseInsensitive) ||
+			(s->m_szDescription.contains("round",Qt::CaseInsensitive) && s->m_szDescription.contains("robin",Qt::CaseInsensitive)))
+#else
 		if(s->m_szDescription.contains("random",false) ||
 			(s->m_szDescription.contains("round",false) && s->m_szDescription.contains("robin",false)))
+#endif
 		{
 			r->setCurrentServer(s);
 			return true;
@@ -220,7 +225,7 @@ bool KviIrcServerDataBase::makeCurrentServer(KviIrcServerDefinition * d,QString
 {
 	KviIrcServer * pServer = 0;
 
-	QDictIterator<KviIrcServerDataBaseRecord> it(*m_pRecords);
+	KviPointerHashTableIterator<QString,KviIrcServerDataBaseRecord> it(*m_pRecords);
 	KviIrcServerDataBaseRecord * r = 0;
 	KviIrcServer * srv;
 
@@ -338,7 +343,11 @@ search_finished:
 	if(!(bIsValidIpV4 || bIsValidIpV6))
 	{
 		// is it a valid hostname ? (must contain at least one dot)
+#ifdef COMPILE_USE_QT4
+		if(!d->szServer.contains('.'))
+#else
 		if(d->szServer.contains('.') < 1)
+#endif
 		{
 			// assume it is a network name!
 			KviIrcServerDataBaseRecord * r = m_pRecords->find(d->szServer);
@@ -387,7 +396,128 @@ search_finished:
 	
 	return true;
 }
+				
+void parseMircServerRecord(QString entry,QString& szNet,
+						   QString& szDescription,QString& szHost,QString& szPort,bool& bSsl,kvi_u32_t& uPort)
+{
+	bSsl = false;
+	int idx = KviQString::find(entry,"SERVER:");
+	if(idx != -1)
+	{
+		szDescription = entry.left(idx);
+		szNet=szDescription.section(':',0,0);
+		szDescription=szDescription.section(':',1,1);
 
+		entry.remove(0,idx + 7);
+		idx = KviQString::find(entry,"GROUP:");
+		if(idx != -1)
+		{
+			szHost = entry.left(idx);
+		} else {
+			szHost = entry;
+		}
+
+		szPort = szHost.section(':',1,1);
+		if(szPort[0]=='+')
+		{
+			bSsl = true;
+			szPort.remove(0,1);
+		}
+		szHost = szHost.section(':',0,0);
+
+		bool bOk;
+		uPort = szPort.toUInt(&bOk);
+		if(!bOk)uPort = 6667;
+	}
+}
+
+void KviIrcServerDataBase::loadFromMircIni(const QString & filename, const QString & szMircIni, QStringList& recentServers)
+{
+	clear();
+	recentServers.clear();
+	QString szDefaultServer;
+	KviConfig mircCfg(szMircIni,KviConfig::Read,true);
+	if(mircCfg.hasGroup("mirc"))
+	{
+		mircCfg.setGroup("mirc");
+		szDefaultServer = mircCfg.readQStringEntry("host");
+	}
+
+	KviConfig cfg(filename,KviConfig::Read,true);
+	int i = 0;
+
+	QString entry;
+	QString key;
+	if(cfg.hasGroup("recent"))
+	{
+		cfg.setGroup("recent");
+		do {
+			KviQString::sprintf(key,"n%d",i);
+			entry = cfg.readEntry(key);
+			if(!entry.isEmpty())
+			{
+				QString szNet;
+				QString szDescription;
+				QString szHost;
+				QString szPort;
+				bool bSsl = false;
+				kvi_u32_t uPort = 0;
+
+				parseMircServerRecord(entry,szNet,
+						   szDescription,szHost,szPort,bSsl,uPort);
+
+				recentServers << (bSsl ? "ircs://" : "irc://" ) +szHost+":"+szPort;
+			}
+			i++;
+		} while(!entry.isEmpty());
+	}
+
+	i = 0;
+	if(cfg.hasGroup("servers"))
+	{
+		cfg.setGroup("servers");
+		do {
+			KviQString::sprintf(key,"n%d",i);
+			entry = cfg.readEntry(key);
+			if(!entry.isEmpty())
+			{
+				bool bDefault = false;
+				QString szNet;
+				QString szDescription;
+				QString szHost;
+				QString szPort;
+				bool bSsl = false;
+				kvi_u32_t uPort = 0;
+				// <net>:<description>SERVER:<server:port>GROUP:<group???>
+				if(entry==szDefaultServer)
+					bDefault = true;
+				
+				parseMircServerRecord(entry,szNet,
+						   szDescription,szHost,szPort,bSsl,uPort);
+
+				KviIrcServerDataBaseRecord * r = findRecord(szNet);
+
+				if(!r) {
+					KviIrcNetwork * n = new KviIrcNetwork(szNet);
+					r = insertNetwork(n);
+				}
+
+				KviIrcServer *s = new KviIrcServer();
+				s->m_szHostname = szHost;
+				s->m_szDescription = szDescription;
+				s->m_uPort = uPort;
+				
+
+				r->m_pServerList->append(s);
+				if(bDefault)
+				{
+					m_szCurrentNetwork = szNet;
+				}
+			}
+			i++;
+		} while(!entry.isEmpty());
+	}
+}
 
 
 void KviIrcServerDataBase::load(const QString & filename)
@@ -415,11 +545,12 @@ void KviIrcServerDataBase::load(const QString & filename)
 			n->m_szOnLoginCommand = cfg.readQStringEntry("OnLoginCommand");
 			n->m_pNickServRuleSet = KviNickServRuleSet::load(&cfg,QString::null);
 			n->m_bAutoConnect = cfg.readBoolEntry("AutoConnect",false);
+			n->m_szUserIdentityId = cfg.readQStringEntry("UserIdentityId");
 			if(n->m_bAutoConnect)
 			{
 				if(!m_pAutoConnectOnStartupNetworks)
 				{
-					m_pAutoConnectOnStartupNetworks = new KviPtrList<KviIrcServerDataBaseRecord>;
+					m_pAutoConnectOnStartupNetworks = new KviPointerList<KviIrcServerDataBaseRecord>;
 					m_pAutoConnectOnStartupNetworks->setAutoDelete(false);
 				}
 				m_pAutoConnectOnStartupNetworks->append(r);
@@ -443,7 +574,7 @@ void KviIrcServerDataBase::load(const QString & filename)
 					{
 						if(!m_pAutoConnectOnStartupServers)
 						{
-							m_pAutoConnectOnStartupServers = new KviPtrList<KviIrcServer>;
+							m_pAutoConnectOnStartupServers = new KviPointerList<KviIrcServer>;
 							m_pAutoConnectOnStartupServers->setAutoDelete(false);
 						}
 						m_pAutoConnectOnStartupServers->append(s);
@@ -462,7 +593,7 @@ void KviIrcServerDataBase::save(const QString &filename)
 
 	cfg.clear(); // clear any old entry
 
-	QDictIterator<KviIrcServerDataBaseRecord> it(*m_pRecords);
+	KviPointerHashTableIterator<QString,KviIrcServerDataBaseRecord> it(*m_pRecords);
 
 	QString tmp;
 
@@ -491,7 +622,8 @@ void KviIrcServerDataBase::save(const QString &filename)
 		if(n->autoJoinChannelList())
 			cfg.writeEntry("AutoJoinChannels",*(n->autoJoinChannelList()));
 		if(n->m_szName == m_szCurrentNetwork)cfg.writeEntry("Current",true);
-
+		if(!n->m_szUserIdentityId.isEmpty())
+			cfg.writeEntry("UserIdentityId",n->m_szUserIdentityId);
 		int i=0;
 		for(KviIrcServer *s = r->m_pServerList->first();s;s = r->m_pServerList->next())
 		{
