@@ -27,10 +27,11 @@
 
 #include "kvi_settings.h"
 
-#include <qdict.h>
+#include "kvi_pointerhashtable.h"
 
 #include "kvi_string.h"
 #include "kvi_avatar.h"
+#include "kvi_regusersdb.h"
 
 class KviIrcUserDataBase;
 
@@ -40,6 +41,13 @@ class KVILIB_API KviIrcUserEntry
 public:
 	KviIrcUserEntry(const QString &user,const QString &host);
 	~KviIrcUserEntry();
+
+	enum Gender {
+		Male = 0,
+		Female = 1,
+		Unknown = 3
+	};
+
 protected:
 	QString     m_szUser;
 	QString     m_szHost;
@@ -47,19 +55,32 @@ protected:
 	QString     m_szServer;
 	QString     m_szRealName;
 	int         m_iHops;
+	Gender      m_eGender;
 	
 	bool        m_bAway;
 
 	KviAvatar * m_pAvatar;
 
 	int         m_nRefs;
+	bool        m_bBot;
+
+	bool        m_bNotFoundRegUserLoockup;
+	QString     m_szRegisteredUserName;
+	QString     m_szLastRegisteredMatchNick;
+
+	QColor      m_cachedColor;
+	bool        m_bUseCustomColor;
 public:
+	Gender gender() { return m_eGender; };
+	void setBot(bool bIsBot) { m_bBot = bIsBot; };
+	bool isBot() { return m_bBot; };
+	void setGender(Gender g) { m_eGender=g; };
 	void setUser(const QString &user)   { m_szUser = user; };
 	bool hasUser()                      { return (!m_szUser.isEmpty()); };
 	void setHost(const QString &host)   { m_szHost = host; };
 	bool hasHost()                      { return (!m_szHost.isEmpty()); };
 	void setServer(const QString &serv) { m_szServer = serv; };
-	void setRealName(const QString &rn) { m_szRealName = rn; };
+	void setRealName(const QString &rn);
 	void setHops(int hops)              { m_iHops = hops; };
 	const QString &user()               { return m_szUser; };
 	const QString &host()               { return m_szHost; };
@@ -92,19 +113,33 @@ public:
 #define KVI_USERFLAG_MODEMASK KVI_USERFLAG_MASK
 
 
-class KVILIB_API KviIrcUserDataBase
+class KVILIB_API KviIrcUserDataBase : public QObject
 {
+	Q_OBJECT
 public:
 	KviIrcUserDataBase();
 	~KviIrcUserDataBase();
 private:
-	QDict<KviIrcUserEntry> * m_pDict;
+	KviPointerHashTable<QString,KviIrcUserEntry> * m_pDict;
 public:
 	void clear();
 	KviIrcUserEntry * insertUser(const QString &nick,const QString &user,const QString &hostname);
 	KviIrcUserEntry * find(const QString &nick){ return m_pDict->find(nick); };
 	void removeUser(const QString &nick,KviIrcUserEntry * e);
-	QDict<KviIrcUserEntry> * dict(){ return m_pDict; };
+	KviPointerHashTable<QString,KviIrcUserEntry> * dict(){ return m_pDict; };
+
+	KviRegisteredUser* registeredUser(const QString & nick);
+	KviRegisteredUser* registeredUser(const QString & nick,const QString & user,const QString & host);
+
+	bool haveCustomColor(const QString & nick);
+	QColor* customColor(const QString & nick);
+
+	void setupConnectionWithReguserDb();
+protected slots:
+	void registeredUserRemoved(const QString&);
+	void registeredUserChanged(const QString&);
+	void registeredUserAdded  (const QString&);
+	void registeredDatabaseCleared();
 };
 
 #endif //_KVI_IRCUSERDB_H_
