@@ -141,7 +141,7 @@ bool KviNickServRuleSet::loadPrivate(KviConfig * cfg,const QString &prefix,unsig
 {
 	if(m_pRules)m_pRules->clear();
 	else {
-		m_pRules = new KviPtrList<KviNickServRule>;
+		m_pRules = new KviPointerList<KviNickServRule>;
 		m_pRules->setAutoDelete(true);
 	}
 
@@ -183,7 +183,7 @@ void KviNickServRuleSet::addRule(KviNickServRule * r)
 {
 	if(!m_pRules)
 	{
-		m_pRules = new KviPtrList<KviNickServRule>;
+		m_pRules = new KviPointerList<KviNickServRule>;
 		m_pRules->setAutoDelete(true);
 	}
 	m_pRules->append(r);
@@ -200,14 +200,22 @@ KviNickServRule * KviNickServRuleSet::matchRule(const QString &szNick,const KviI
 	if(!m_pRules)return 0;
 	for(KviNickServRule *r = m_pRules->first();r;r = m_pRules->next())
 	{
-		if(!KviQString::equalCI(r->registeredNick(),szNick))continue;
+		if(!KviQString::matchStringCI(r->registeredNick(),szNick,false,true)) continue;
 		if(!szServer.isEmpty())
 		{
+#ifdef COMPILE_USE_QT4
+			QRegExp res(r->serverMask(),Qt::CaseInsensitive,QRegExp::Wildcard);
+#else
 			QRegExp res(r->serverMask(),false,true);
+#endif
 			if(!res.exactMatch(szServer))continue;
 		}
 		if(!nickServ->matchedBy(KviIrcMask(r->nickServMask())))continue;
+#ifdef COMPILE_USE_QT4
+		QRegExp re(r->messageRegexp(),Qt::CaseInsensitive,QRegExp::Wildcard);
+#else
 		QRegExp re(r->messageRegexp(),false,true);
+#endif
 		if(re.exactMatch(szMsg))return r;
 	}
 	return 0;
@@ -219,7 +227,7 @@ void KviNickServRuleSet::copyFrom(const KviNickServRuleSet &src)
 	{
 		if(m_pRules)m_pRules->clear();
 		else {
-			m_pRules = new KviPtrList<KviNickServRule>;
+			m_pRules = new KviPointerList<KviNickServRule>;
 			m_pRules->setAutoDelete(true);
 		}
 		for(KviNickServRule * r = src.m_pRules->first();r;r = src.m_pRules->next())
@@ -275,8 +283,7 @@ bool KviNickServRule::load(KviConfig * cfg,const QString &prefix)
 {
 	QString tmp;
 	KviQString::sprintf(tmp,"%QRegisteredNick",&prefix);
-	m_szRegisteredNick = cfg->readQStringEntry(tmp);
-	m_szRegisteredNick.stripWhiteSpace();
+	m_szRegisteredNick = KviQString::trimmed(cfg->readQStringEntry(tmp));
 	if(m_szRegisteredNick.isEmpty())return false;
 	KviQString::sprintf(tmp,"%QNickServMask",&prefix);
 	m_szNickServMask = cfg->readQStringEntry(tmp);
