@@ -4,7 +4,7 @@
 //   Creation date : Sat Aug 17 13:43:32 2002 GMT by Szymon Stefanek
 //
 //   This file is part of the KVirc irc client distribution
-//   Copyright (C) 2002-2004 Szymon Stefanek (pragma at kvirc dot net)
+//   Copyright (C) 2002-2006 Szymon Stefanek (pragma at kvirc dot net)
 //
 //   This program is FREE software. You can redistribute it and/or
 //   modify it under the terms of the GNU General Public License
@@ -27,6 +27,7 @@
 
 #include <qdir.h>
 #include <qtimer.h>
+//#include <zlib.h>
 
 #include "kvi_http.h"
 #include "kvi_locale.h"
@@ -36,6 +37,9 @@
 #include "kvi_debug.h"
 #include "kvi_socket.h"
 #include "kvi_time.h"
+#ifdef COMPILE_SSL_SUPPORT
+	#include "kvi_ssl.h"
+#endif
 
 
 #define KVI_HTTP_REQUEST_THREAD_EVENT_CONNECTED (KVI_THREAD_USER_EVENT_BASE + 0xCAFE)
@@ -102,6 +106,10 @@ void KviHttpRequest::resetData()
 	m_url = "";
 	m_uMaxContentLength = 0;
 	m_uContentOffset = 0;
+	m_bChunkedTransferEncoding = false;
+	m_bGzip = false;
+	m_bIgnoreRemainingData = false;
+	m_uRemainingChunkSize = 0;
 }
 
 void KviHttpRequest::reset()
@@ -111,7 +119,7 @@ void KviHttpRequest::reset()
 	resetInternalStatus();
 }
 
-bool KviHttpRequest::get(const KviUrl &u,ProcessingType p,const char * szFileName)
+bool KviHttpRequest::get(const KviUrl &u,ProcessingType p,const QString &szFileName)
 {
 	reset();
 	setUrl(u);
@@ -137,7 +145,7 @@ bool KviHttpRequest::start()
 		if((m_eExistingFileAction == Resume) && (m_uContentOffset == 0))
 		{
 			// determine the content offset automatically
-			if(QFile::exists(m_szFileName))
+			if(KviFile::exists(m_szFileName))
 			{
 				// we check it
 				QFileInfo fi(m_szFileName);
@@ -153,7 +161,7 @@ bool KviHttpRequest::start()
 		return false;
 	}
 
-	if(!kvi_strEqualCI(m_url.protocol().ptr(),"http"))
+	if((!kvi_strEqualCI(m_url.protocol().ptr(),"http")) && (!kvi_strEqualCI(m_url.protocol().ptr(),"https")))
 	{
 		resetInternalStatus();
 		m_szLastError=__tr2qs("Unsupported protocol %1").arg(m_url.protocol().ptr());
@@ -182,25 +190,25 @@ bool KviHttpRequest::startDnsLookup()
 		return false;
 	}
 
-	KviStr tmp(KviStr::Format,__tr2qs("Looking up host %s"),m_url.host().ptr());
-	emit status(tmp.ptr());
+	QString tmp;
+	KviQString::sprintf(tmp,__tr2qs("Looking up host %s"),m_url.host().ptr());
+	emit status(tmp); // FIXME
 
-	emit resolvingHost(m_url.host().ptr());
+	emit resolvingHost(QString(m_url.host().ptr()));
 
 	return true;
 }
 
 void KviHttpRequest::dnsLookupDone(KviDns *d)
 {
-	__range_valid(m_pDns == d);
-
 	if(d->state() == KviDns::Success)
 	{
 		m_szIp = d->firstIpAddress();
 		delete m_pDns;
 		m_pDns = 0;
-		KviStr tmp(KviStr::Format,__tr2qs("Host %s resolved to %s"),m_url.host().ptr(),m_szIp.ptr());
-		emit status(tmp.ptr());
+		QString tmp;
+		KviQString::sprintf(tmp,__tr2qs("Host %s resolved to %Q"),m_url.host().ptr(),&m_szIp);
+		emit status(tmp);
 		haveServerIp();
 	} else {
 		int iErr = d->error();
@@ -215,21 +223,22 @@ void KviHttpRequest::haveServerIp()
 	unsigned short uPort = m_url.port();
 	if(uPort == 0)uPort = 80;
 
-	KviStr tmp;
-	tmp.sprintf("%s:%u",m_szIp.ptr(),uPort);
-	emit contactingHost(tmp.ptr());
+	QString tmp;
+	KviQString::sprintf(tmp,"%Q:%u",&m_szIp,uPort);
+	emit contactingHost(tmp);
 
 	if(m_pThread)delete m_pThread;
 
 	m_pThread = new KviHttpRequestThread(
 						this,
 						m_url.host().ptr(),
-						m_szIp.ptr(),
+						m_szIp,
 						uPort,
 						m_url.path().ptr(),
 						m_uContentOffset,
 						(m_eProcessingType == HeadersOnly) ? KviHttpRequestThread::Head : (m_szPostData.isEmpty() ? KviHttpRequestThread::Get : KviHttpRequestThread::Post),
-						m_szPostData);
+						m_szPostData,
+						kvi_strEqualCI(m_url.protocol().ptr(),"https"));
 
 	if(!m_pThread->start())
 	{
@@ -239,8 +248,8 @@ void KviHttpRequest::haveServerIp()
 		return;
 	}
 
-	tmp.sprintf(__tr2qs("Contacting host %s on port %u"),m_szIp.ptr(),uPort);
-	emit status(tmp.ptr());
+	KviQString::sprintf(tmp,__tr2qs("Contacting host %Q on port %u"),&m_szIp,uPort);
+	emit status(tmp);
 }
 
 bool KviHttpRequest::event(QEvent *e)
@@ -264,8 +273,12 @@ bool KviHttpRequest::event(QEvent *e)
 			break;
 			case KVI_HTTP_REQUEST_THREAD_EVENT_REQUESTSENT:
 			{
-				KviStr * req = ((KviThreadDataEvent<KviStr> *)e)->getData();
-				QStringList sl = QStringList::split("\r\n",req->ptr());
+				QString * req = ((KviThreadDataEvent<QString> *)e)->getData();
+#ifdef COMPILE_USE_QT4
+				QStringList sl = req->split("\r\n");
+#else
+				QStringList sl = QStringList::split("\r\n",*req);
+#endif
 				emit requestSent(sl);
 				delete req;
 				return true;
@@ -282,8 +295,13 @@ bool KviHttpRequest::event(QEvent *e)
 				switch(m_eProcessingType)
 				{
 					case WholeFile:
+						// happens always
 						emit binaryData(*m_pBuffer);
 					break;
+					case Blocks:
+						// an unprocessed block ?.. should never happend.. but well :D
+						if(m_pBuffer->size() > 0)emit binaryData(*m_pBuffer);
+					break;
 					case Lines:
 						if(m_pBuffer->size() > 0)
 						{
@@ -293,7 +311,7 @@ bool KviHttpRequest::event(QEvent *e)
 						}
 					break;
 					case StoreToFile:
-						// should never happen.. but well :D
+						// same as above... should never happen.. but well :D
 						if(m_pFile && m_pBuffer->size() > 0)m_pFile->writeBlock((const char *)(m_pBuffer->data()),m_pBuffer->size());
 					break;
 					default:
@@ -308,7 +326,7 @@ bool KviHttpRequest::event(QEvent *e)
 			case KVI_THREAD_EVENT_ERROR:
 			{
 				KviStr * err = ((KviThreadDataEvent<KviStr> *)e)->getData();
-				m_szLastError = __tr_no_xgettext(err->ptr());
+				m_szLastError = __tr2qs_no_xgettext(err->ptr());
 				delete err;
 				resetInternalStatus();
 				emit terminated(false);
@@ -318,7 +336,7 @@ bool KviHttpRequest::event(QEvent *e)
 			case KVI_THREAD_EVENT_MESSAGE:
 			{
 				KviStr * msg = ((KviThreadDataEvent<KviStr> *)e)->getData();
-				emit status(__tr_no_xgettext(msg->ptr()));
+				emit status(__tr2qs_no_xgettext(msg->ptr()));
 				delete msg;
 				return true;
 			}
@@ -328,15 +346,15 @@ bool KviHttpRequest::event(QEvent *e)
 	return QObject::event(e);
 }
 
-void KviHttpRequest::emitLines()
+void KviHttpRequest::emitLines(KviDataBuffer * pDataBuffer)
 {
-	int idx = m_pBuffer->find((const unsigned char *)"\n",1);
+	int idx = pDataBuffer->find((const unsigned char *)"\n",1);
 	while(idx != -1)
 	{
 		KviStr tmp((const char *)(m_pBuffer->data()),idx);
 		tmp.stripRight('\r');
-		m_pBuffer->remove(idx + 1);
-		idx = m_pBuffer->find((const unsigned char *)"\n",1);
+		pDataBuffer->remove(idx + 1);
+		idx = pDataBuffer->find((const unsigned char *)"\n",1);
 		emit data(tmp);
 	}
 }
@@ -373,16 +391,16 @@ bool KviHttpRequest::openFile()
 {
 	if(m_eProcessingType != StoreToFile)return true;
 
-	int iOpenFlags = IO_WriteOnly;
+	bool bAppend = false;
 
 	// take action when the file is existing
-	if(QFile::exists(m_szFileName))
+	if(KviFile::exists(m_szFileName))
 	{
 		switch(m_eExistingFileAction)
 		{
 			case Resume:
 			{
-				iOpenFlags = IO_WriteOnly | IO_Append;
+				bAppend = true;
 			}
 			break;
 			case RenameIncoming:
@@ -392,7 +410,7 @@ bool KviHttpRequest::openFile()
 				do {
 					i++;
 					m_szFileName = tmp + QString(".kvirnm-%1").arg(i);
-				} while(QFile::exists(m_szFileName));
+				} while(KviFile::exists(m_szFileName));
 			}
 			break;
 			case RenameExisting:
@@ -402,7 +420,7 @@ bool KviHttpRequest::openFile()
 				do {
 					i++;
 					tmp = m_szFileName + QString(".kvirnm-%1").arg(i);
-				} while(QFile::exists(tmp));
+				} while(KviFile::exists(tmp));
 				QDir d;
 				if(!d.rename(m_szFileName,tmp))
 				{
@@ -421,12 +439,12 @@ bool KviHttpRequest::openFile()
 		}
 	}
 
-	m_pFile = new QFile(m_szFileName);
+	m_pFile = new KviFile(m_szFileName);
 
-	if(!m_pFile->open(iOpenFlags))
+	if(!m_pFile->openForWriting(bAppend))
 	{
 		resetInternalStatus();
-		m_szLastError.sprintf(__tr2qs("Can't open file \"%s\" for writing"),m_szFileName.utf8().data());
+		KviQString::sprintf(m_szLastError,__tr2qs("Can't open file \"%Q\" for writing"),&m_szFileName);
 		emit terminated(false);
 		return false;
 	}
@@ -481,12 +499,13 @@ bool KviHttpRequest::processHeader(KviStr &szHeader)
 		return false;
 	}
 
-	KviStr tmp(KviStr::Format,__tr2qs("Received HTTP response: %s"),szResponse.ptr());
+	QString tmp;
+	KviQString::sprintf(tmp,__tr2qs("Received HTTP response: %s"),szResponse.ptr());
 
-	emit status(tmp.ptr());
-	emit receivedResponse(szResponse.ptr());
+	emit status(tmp);
+	emit receivedResponse(QString(szResponse.ptr()));
 
-	KviPtrList<KviStr> hlist;
+	KviPointerList<KviStr> hlist;
 	hlist.setAutoDelete(true);
 
 	idx = szHeader.findFirstIdx("\r\n");
@@ -501,7 +520,7 @@ bool KviHttpRequest::processHeader(KviStr &szHeader)
 	}
 	if(szHeader.hasData())hlist.append(new KviStr(szHeader));
 
-	QAsciiDict<KviStr> hdr(11,false,true);
+	KviPointerHashTable<const char *,KviStr> hdr(11,false,true);
 	hdr.setAutoDelete(true);
 
 	for(KviStr * s = hlist.first();s;s = hlist.next())
@@ -525,6 +544,23 @@ bool KviHttpRequest::processHeader(KviStr &szHeader)
 		if(!bOk)m_uTotalSize = 0;
 	}
 
+	KviStr * contentEncoding = hdr.find("Content-encoding");
+	if(contentEncoding)
+	{
+		m_bGzip = contentEncoding->equalsCI("gzip");
+	}
+	
+	KviStr * transferEncoding = hdr.find("Transfer-Encoding");
+	if(transferEncoding)
+	{
+		if(kvi_strEqualCI(transferEncoding->ptr(),"chunked"))
+		{
+			// be prepared to handle the chunked transfer encoding as required by HTTP/1.1
+			m_bChunkedTransferEncoding = true;
+			m_uRemainingChunkSize = 0;
+		}
+	}
+
 	emit header(&hdr);
 
 	// check the status
@@ -598,46 +634,35 @@ bool KviHttpRequest::processHeader(KviStr &szHeader)
 
 	return true;
 }
+#define BUFFER_SIZE 32768
 
 void KviHttpRequest::processData(KviDataBuffer * data)
 {
-	if(m_bHeaderProcessed)
+//	unsigned char obuffer[BUFFER_SIZE];
+	if(m_bChunkedTransferEncoding && m_bIgnoreRemainingData)
 	{
-		// we're just getting data 
-		m_uReceivedSize += data->size();
-		//debug("RECEIVED: %u of %u bytes",m_uReceivedSize,m_uTotalSize);
-
-		switch(m_eProcessingType)
-		{
-			case Blocks:
-				emit binaryData(*data);
-			break;
-			case Lines:
-				m_pBuffer->append(*data);
-				emitLines();
-			break;
-			case StoreToFile:
-				m_pFile->writeBlock((const char *)(data->data()),data->size());
-			break;
-			default:
-				m_pBuffer->append(*data);
-			break;
-		}
-
-		if(((m_uTotalSize > 0) && (m_uReceivedSize > m_uTotalSize)) || ((m_uMaxContentLength > 0) && (m_uReceivedSize > m_uMaxContentLength)))
-		{
-			resetInternalStatus();
-			m_szLastError=__tr2qs("Stream exceeded expected length");
-			emit terminated(false);
-		}
+		// In chunked transfer encoding mode there may be additional headers
+		// after the last chunk of data. We simply ignore them.
 		return;
 	}
 
-	m_pBuffer->append(*data);
-
-	int idx = m_pBuffer->find((const unsigned char *)"\r\n\r\n",4);
-	if(idx != -1)
+	if(!m_bHeaderProcessed)
 	{
+		// time to process the header
+		m_pBuffer->append(*data);
+	
+		int idx = m_pBuffer->find((const unsigned char *)"\r\n\r\n",4);
+		if(idx == -1)
+		{
+			// header not complete
+			if(m_pBuffer->size() > 4096)
+			{
+				resetInternalStatus();
+				m_szLastError = __tr2qs("Header too long: exceeded 4096 bytes");
+				emit terminated(false);
+			}
+			return;
+		}
 		KviStr szHeader((const char *)(m_pBuffer->data()),idx);
 		m_pBuffer->remove(idx + 4);
 
@@ -650,7 +675,156 @@ void KviHttpRequest::processData(KviDataBuffer * data)
 		}
 
 		m_uReceivedSize = m_pBuffer->size();
+		
 
+		// here the header is complete and the eventual remaining data is in m_pBuffer. data has been already used.
+		
+	} else {
+		// header already processed
+		m_uReceivedSize += data->size();
+		
+		// here the header is complete and some data *might* be already in m_pBuffer. data is unused yet.
+		
+		// Optimisation: If the transfer is NOT chunked (so we don't have to parse it)
+		// and the requested processing type is either Blocks or StoreToFile
+		// then we just can avoid to copy the data to m_pBuffer.
+		// This is a good optimisation since for large files we can save allocating
+		// space for and moving megabytes of data...
+		
+
+		if((!m_bChunkedTransferEncoding) && ((m_eProcessingType == Blocks) || (m_eProcessingType == StoreToFile)))
+		{	
+			switch(m_eProcessingType)
+			{
+				case Blocks:
+					emit binaryData(*data);
+				break;
+				case StoreToFile:
+					m_pFile->writeBlock((const char *)(data->data()),data->size());
+				break;
+			}
+	
+			if(((m_uTotalSize > 0) && (m_uReceivedSize > m_uTotalSize)) || ((m_uMaxContentLength > 0) && (m_uReceivedSize > m_uMaxContentLength)))
+			{
+				resetInternalStatus();
+				m_szLastError=__tr2qs("Stream exceeded expected length");
+				emit terminated(false);
+			}
+			
+			return;
+		}
+		
+		// need to append to m_pBuffer and process it
+		m_pBuffer->append(*data);
+	}
+
+	// we're processing data in m_pBuffer here
+	if(m_bChunkedTransferEncoding)
+	{
+		// The transfer encoding is chunked: the buffer contains
+		// chunks of data with an initial header composed
+		// of a hexadecimal length, an optional bullshit and a single CRLF
+		// The transfer terminates when we read a last chunk of size 0
+		// that may be followed by optional headers...
+		// This sux :)
+		while(m_pBuffer->size() > 0) // <-- note that we may exit from this loop also for other conditions (there is a goto below)
+		{
+			// we process chunks of parts of chunks at a time.
+			if(m_uRemainingChunkSize > 0)
+			{
+				// process the current chunk data
+				unsigned int uProcessSize = m_uRemainingChunkSize;
+				if(uProcessSize > m_pBuffer->size())uProcessSize = m_pBuffer->size();
+				m_uRemainingChunkSize -= uProcessSize;
+
+				switch(m_eProcessingType)
+				{
+					case Blocks:
+						if(m_pBuffer->size() == uProcessSize)
+						{
+							// avoid copying to a new buffer
+							emit binaryData(*m_pBuffer);
+						} else {
+							// must copy
+							KviDataBuffer tmp(uProcessSize,m_pBuffer->data());
+							emit binaryData(tmp);
+							m_pBuffer->remove(uProcessSize);
+						}
+					break;
+					case Lines:
+						if(m_pBuffer->size() == uProcessSize)
+						{
+							// avoid copying to a new buffer
+							emitLines(m_pBuffer);
+						} else {
+							// must copy
+							KviDataBuffer tmp(uProcessSize,m_pBuffer->data());
+							emitLines(&tmp);
+							m_pBuffer->remove(uProcessSize);
+						}
+					break;
+					case StoreToFile:
+						m_pFile->writeBlock((const char *)(m_pBuffer->data()),uProcessSize);
+						m_pBuffer->remove(uProcessSize);
+					break;
+					default:
+						// nothing.. just make gcc happy
+					break;
+				}
+				// now either the buffer is empty or there is another chunk header: continue looping
+			} else {
+				// We're looking for the beginning of a chunk now.
+				// Note that we might be at the end of a previous chunk that has a CRLF terminator
+				// we need to skip it.
+				int crlf = m_pBuffer->find((const unsigned char *)"\r\n",2);
+				if(crlf != -1)
+				{
+					if(crlf == 0)
+					{
+						// This is a plain CRLF at the beginning of the buffer BEFORE a chunk header.
+						// It comes from the previous chunk terminator. Skip it.
+						m_pBuffer->remove(2);
+					} else {
+						// got a chunk header
+						KviStr szHeader((const char *)(m_pBuffer->data()),crlf);
+						szHeader.cutFromFirst(' ');
+						// now szHeader should contain a hexadecimal chunk length... (why the hell it is hex and not decimal ????)
+						QString szHexHeader = szHeader.ptr();
+						bool bOk;
+						m_uRemainingChunkSize = szHexHeader.toLong(&bOk,16);
+						if(!bOk)
+						{
+							resetInternalStatus();
+							m_szLastError = __tr2qs("Protocol error: invalid chunk size");
+							emit terminated(false);
+							return;
+						}
+						m_pBuffer->remove(crlf+2);
+						if(m_uRemainingChunkSize == 0)
+						{
+							// this is the last chunk of data. It may be followed by optional headers
+							// but we actually don't need them (since we're surely not in HEAD mode)
+							m_bIgnoreRemainingData = true;
+							m_pBuffer->clear();
+							goto check_stream_length;
+						}
+					}
+					// the rest is valid data of a non-zero chunk: continue looping
+				} else {
+					// chunk header not complete
+					if(m_pBuffer->size() > 4096)
+					{
+						resetInternalStatus();
+						m_szLastError = __tr2qs("Chunk header too long: exceeded 4096 bytes");
+						emit terminated(false);
+						return;
+					}
+					goto check_stream_length;
+				}
+			}
+		}
+	} else {
+		// the transfer encoding is not chunked: m_pBuffer contains only valid data
 		switch(m_eProcessingType)
 		{
 			case Blocks:
@@ -658,7 +832,7 @@ void KviHttpRequest::processData(KviDataBuffer * data)
 				m_pBuffer->clear();
 			break;
 			case Lines:
-				if(m_pBuffer->size() > 0)emitLines();
+				if(m_pBuffer->size() > 0)emitLines(m_pBuffer);
 			break;
 			case StoreToFile:
 				m_pFile->writeBlock((const char *)(m_pBuffer->data()),m_pBuffer->size());
@@ -668,14 +842,17 @@ void KviHttpRequest::processData(KviDataBuffer * data)
 				// nothing.. just make gcc happy
 			break;
 		}
-	} else {
-		if(m_pBuffer->size() > 4096)
-		{
-			resetInternalStatus();
-			m_szLastError = __tr2qs("Header too long: exceeded 4096 bytes");
-			emit terminated(false);
-		}
 	}
+
+check_stream_length:
+
+	if(((m_uTotalSize > 0) && (m_uReceivedSize > m_uTotalSize)) || ((m_uMaxContentLength > 0) && (m_uReceivedSize > m_uMaxContentLength)))
+	{
+		resetInternalStatus();
+		m_szLastError=__tr2qs("Stream exceeded expected length");
+		emit terminated(false);
+	}
+	return;
 }
 
 
@@ -693,8 +870,17 @@ void KviHttpRequest::processData(KviDataBuffer * data)
 
 
 
-KviHttpRequestThread::KviHttpRequestThread(KviHttpRequest * r,const char * szHost,const char * szIp,unsigned short uPort,const char * szPath,unsigned int uContentOffset,RequestMethod m,const QString &szPostData)
-: KviSensitiveThread()
+KviHttpRequestThread::KviHttpRequestThread(
+	KviHttpRequest * r,
+	const QString &szHost,
+	const QString &szIp,
+	unsigned short uPort,
+	const QString & szPath,
+	unsigned int uContentOffset,
+	RequestMethod m,
+	const QString &szPostData,
+	bool bUseSSL
+) : KviSensitiveThread()
 {
 	m_pRequest = r;
 	m_szHost = szHost;
@@ -704,6 +890,11 @@ KviHttpRequestThread::KviHttpRequestThread(KviHttpRequest * r,const char * szHos
 	m_uContentOffset = uContentOffset;
 	m_eRequestMethod = m;
 	m_szPostData = szPostData;
+	m_sock = KVI_INVALID_SOCKET;
+	m_bUseSSL = bUseSSL;
+#ifdef COMPILE_SSL_SUPPORT
+	m_pSSL = 0;
+#endif
 }
 
 KviHttpRequestThread::~KviHttpRequestThread()
@@ -733,12 +924,8 @@ bool KviHttpRequestThread::processInternalEvents()
 	return true;
 }
 
-bool KviHttpRequestThread::failure(const char * error)
+bool KviHttpRequestThread::failure(const char *error)
 {
-
-	if(m_sock != KVI_INVALID_SOCKET)kvi_socket_close(m_sock);
-	m_sock = KVI_INVALID_SOCKET;
-
 	if(error)
 	{
 		postEvent(m_pRequest,new KviThreadDataEvent<KviStr>(KVI_THREAD_EVENT_ERROR,new KviStr(error)));
@@ -758,7 +945,7 @@ bool KviHttpRequestThread::selectForWrite(int iTimeoutInSecs)
 	{
 		if(!processInternalEvents())
 		{
-			return failure();
+			return failure(0);
 		}
 
 		fd_set writeSet;
@@ -791,15 +978,13 @@ bool KviHttpRequestThread::selectForWrite(int iTimeoutInSecs)
 				if((err != EAGAIN) && (err != EINTR))
 #endif
 				{
-					KviStr tmp(KviStr::Format,__tr2qs("Select error: %s (errno=%d)"),
-						KviError::getDescription(KviError::translateSystemError(err)).utf8().data(),err);
-					return failure(tmp.ptr());
+					return failure(KviError::getUntranslatedDescription(KviError::translateSystemError(err)));
 				}
 			}
 		}
 
 
-		if((time(0) - startTime) > iTimeoutInSecs)return failure(__tr2qs("Operation timed out"));
+		if((time(0) - startTime) > iTimeoutInSecs)return failure(__tr_no_lookup("Operation timed out"));
 
 		usleep(100000); // 1/10 sec
 	}
@@ -807,19 +992,33 @@ bool KviHttpRequestThread::selectForWrite(int iTimeoutInSecs)
 	return false;
 }
 
+bool KviHttpRequestThread::sslFailure()
+{
+#ifdef COMPILE_SSL_SUPPORT
+	KviStr buffer;
+	if(m_pSSL->getLastErrorString(buffer))
+	{
+		failure(buffer.ptr());
+	} else {
+		failure(__tr_no_lookup("Unexpected SSL error"));
+	}
+#endif
+	return false;
+}
+
 bool KviHttpRequestThread::connectToRemoteHost()
 {
 	m_sock = kvi_socket_create(KVI_SOCKET_PF_INET,KVI_SOCKET_TYPE_STREAM,0); //tcp
 	if(m_sock == KVI_INVALID_SOCKET)
-		return failure(__tr2qs("Failed to create the socket"));
+		return failure(__tr_no_lookup("Failed to create the socket"));
 
 	if(!kvi_socket_setNonBlocking(m_sock))
-		return failure(__tr2qs("Failed to enter non blocking mode"));
+		return failure(__tr_no_lookup("Failed to enter non blocking mode"));
 
 	sockaddr_in saddr;
 
-	if(!kvi_stringIpToBinaryIp(m_szIp.ptr(),&(saddr.sin_addr)))
-		return failure(__tr2qs("Invalid target address"));
+	if(!KviNetUtils::stringIpToBinaryIp(m_szIp,&(saddr.sin_addr)))
+		return failure(__tr_no_lookup("Invalid target address"));
 
 	saddr.sin_port = htons(m_uPort);
 	saddr.sin_family = AF_INET;
@@ -829,16 +1028,13 @@ bool KviHttpRequestThread::connectToRemoteHost()
 		int err = kvi_socket_error();
 		if(!kvi_socket_recoverableConnectError(err))
 		{
-			KviStr tmp(KviStr::Format,__tr2qs("Connect error: %s (errno=%d)"),
-				KviError::getDescription(KviError::translateSystemError(err)).utf8().data(),err);
-			return failure(tmp.ptr());
+			return failure(KviError::getUntranslatedDescription(KviError::translateSystemError(err)));
 		}
 	}
 
 	// now loop selecting for write
 
 	//#warning "This should be a tuneable timeout"
-
 	if(!selectForWrite(60))return false;
 
 	int sockError;
@@ -849,11 +1045,60 @@ bool KviHttpRequestThread::connectToRemoteHost()
 		//failed
 		if(sockError > 0)sockError = KviError::translateSystemError(sockError);
 		else sockError = KviError_unknownError;
-		KviStr tmp(KviStr::Format,__tr2qs("Connect error: %s (errno=%d)"),
-			KviError::getDescription(sockError).utf8().data(),sockError);
-		return failure(tmp.ptr());
+		return failure(KviError::getUntranslatedDescription(sockError));
 	}
 
+#ifdef COMPILE_SSL_SUPPORT
+	if(m_bUseSSL)
+	{
+		m_pSSL = new KviSSL();
+		if(!m_pSSL->initContext(KviSSL::Client))
+			return failure(__tr_no_lookup("Failed to initialize the SSL context"));
+		if(!m_pSSL->initSocket(m_sock))
+			return failure(__tr_no_lookup("Failed to initialize the SSL connection"));
+		
+		for(;;)
+		{
+			switch(m_pSSL->connect())
+			{
+				case KviSSL::Success:
+					// done: connected.
+					return true;
+				break;
+				case KviSSL::WantRead:
+					if(!selectForRead(60))return false;
+				break;
+				case KviSSL::WantWrite:
+					if(!selectForWrite(60))return false;
+				break;
+				case KviSSL::RemoteEndClosedConnection:
+					return failure(__tr_no_lookup("Remote end has closed the connection"));
+				break;
+				case KviSSL::SSLError:
+					return sslFailure();
+				break;
+				case KviSSL::SyscallError:
+				{
+					// syscall problem
+					int err = kvi_socket_error();
+					if(!kvi_socket_recoverableError(err))
+					{
+						// Declare problems :)
+						return failure(__tr_no_lookup("Unrecoverable SSL error during handshake"));
+					} // else can recover ? (EAGAIN , EINTR ?) ... should select for read or for write 
+				}
+				break;
+				default:
+					return sslFailure();
+				break;
+			}
+		}
+	
+		// never here
+		return true;
+	}
+#endif
+
 	return true;
 }
 
@@ -869,7 +1114,18 @@ bool KviHttpRequestThread::sendBuffer(const char * buffer,int bufLen,int iTimeou
 	{
 		if(!processInternalEvents())return failure();
 
-		int wrtn = kvi_socket_send(m_sock,ptr,curLen);
+		int wrtn;
+#ifdef COMPILE_SSL_SUPPORT
+		if(m_pSSL)
+		{
+			wrtn = m_pSSL->write((char *)ptr,curLen);
+		} else {
+#endif
+			wrtn = kvi_socket_send(m_sock,ptr,curLen);
+#ifdef COMPILE_SSL_SUPPORT
+		}
+#endif
+
 		if(wrtn > 0)
 		{
 			curLen -= wrtn;
@@ -880,23 +1136,61 @@ bool KviHttpRequestThread::sendBuffer(const char * buffer,int bufLen,int iTimeou
 		} else {
 			if(wrtn < 0)
 			{
-				int err = kvi_socket_error();
-#ifdef COMPILE_ON_WINDOWS
-				if((err != EAGAIN) && (err != EINTR) && (err != WSAEWOULDBLOCK))
-#else
-				if((err != EAGAIN) && (err != EINTR))
-#endif
+#ifdef COMPILE_SSL_SUPPORT
+				if(m_pSSL)
 				{
-					KviStr tmp(KviStr::Format,__tr2qs("Write error: %s (errno=%d)"),
-							KviError::getDescription(KviError::translateSystemError(err)).utf8().data(),err);
-					return failure(tmp.ptr());
+					// ops...might be an SSL error
+					switch(m_pSSL->getProtocolError(wrtn))
+					{
+						case KviSSL::WantWrite:
+							if(!selectForWrite(60))return false;
+							break;
+						case KviSSL::WantRead:
+							if(!selectForRead(60))return false;
+							break;
+						case KviSSL::SyscallError:
+							if(wrtn == 0)
+							{
+								return failure(__tr_no_lookup("Remote end has closed the connection"));
+							} else {
+								int iSSLErr = m_pSSL->getLastError(true);
+								if(iSSLErr != 0)
+								{
+									return sslFailure();
+								} else {
+									goto handle_system_error;
+								}
+							}
+						break;
+						case KviSSL::SSLError:
+							return sslFailure();
+						break;
+						default:
+							return sslFailure();
+						break;
+					}
+				} else {
+#endif //COMPILE_SSL_SUPPORT
+
+handle_system_error:
+					int err = kvi_socket_error();
+#ifdef COMPILE_ON_WINDOWS
+					if((err != EAGAIN) && (err != EINTR) && (err != WSAEWOULDBLOCK))
+#else
+					if((err != EAGAIN) && (err != EINTR))
+#endif
+					{
+						return failure(KviError::getUntranslatedDescription(KviError::translateSystemError(err)));
+					}
+#ifdef COMPILE_SSL_SUPPORT
 				}
+#endif
 			}
 		}
 
 		int diff = time(0) - startTime;
 		if(diff > iTimeoutInSecs)
-			return failure(__tr2qs("Operation timed out"));
+			return failure(__tr_no_lookup("Operation timed out"));
 
 		usleep(10000);
 	}
@@ -941,9 +1235,7 @@ int KviHttpRequestThread::selectForReadStep()
 			if((err != EAGAIN) && (err != EINTR))
 #endif
 			{
-				KviStr tmp(KviStr::Format,__tr2qs("Select error: %s (errno=%d)"),
-					KviError::getDescription(KviError::translateSystemError(err)).utf8().data(),err);
-				failure(tmp.ptr());
+				failure(KviError::getUntranslatedDescription(KviError::translateSystemError(err)));
 				return -1;
 			}
 		}
@@ -977,7 +1269,7 @@ bool KviHttpRequestThread::selectForRead(int iTimeoutInSecs)
 
 		int diff = time(0) - startTime;
 		if(diff > iTimeoutInSecs)
-			return failure(__tr2qs("Operation timed out (while selecting for read)"));
+			return failure(__tr_no_lookup("Operation timed out (while selecting for read)"));
 
 		usleep(100000); // 1/10 sec
 	}
@@ -985,11 +1277,51 @@ bool KviHttpRequestThread::selectForRead(int iTimeoutInSecs)
 	return false;
 }
 
-bool KviHttpRequestThread::readData()
+bool KviHttpRequestThread::readDataStep()
 {
 	unsigned char buffer[2048];
+	int readed;
+
+	
+#ifdef COMPILE_SSL_SUPPORT
+	if(m_pSSL)
+	{
+		readed = m_pSSL->read((char *)buffer,2048);
+		if(readed <= 0)
+		{
+			// ssl error....?
+			switch(m_pSSL->getProtocolError(readed))
+			{
+				case KviSSL::ZeroReturn:
+					readed = 0;
+				break;
+				case KviSSL::WantRead:
+					return selectForRead(120);
+				break;
+				case KviSSL::WantWrite:
+					return selectForWrite(120);
+				break;
+				case KviSSL::SyscallError:
+				{
+					int iE = m_pSSL->getLastError(true);
+					if(iE != 0)return sslFailure();
+				}
+				break;
+				case KviSSL::SSLError:
+					return sslFailure();
+				break;
+				default:
+					return sslFailure();
+				break;
+			}
+		}
+	} else {
+#endif
+		readed = kvi_socket_read(m_sock,buffer,2048);
+#ifdef COMPILE_SSL_SUPPORT
+	}
+#endif
 
-	int readed = kvi_socket_read(m_sock,buffer,2048);
 	if(readed > 0)
 	{
 		postEvent(m_pRequest,new KviThreadDataEvent<KviDataBuffer>(KVI_THREAD_EVENT_BINARYDATA,new KviDataBuffer(readed,buffer)));
@@ -1005,25 +1337,53 @@ bool KviHttpRequestThread::readData()
 #endif
 			{
 				// yes...read error
-				KviStr tmp(KviStr::Format,__tr2qs("Read error: %s (errno=%d)"),
-						KviError::getDescription(KviError::translateSystemError(err)).utf8().data(),err);
-				return failure(tmp.ptr());
+				return failure(KviError::getUntranslatedDescription(KviError::translateSystemError(err)));
 			}
-			return true; // EINTR or EAGAIN...transient problem
+			return selectForRead(120); // EINTR or EAGAIN...transient problem
 		} else {
 			// readed == 0
 			// Connection closed by remote host
-			kvi_socket_close(m_sock);
 			postEvent(m_pRequest,new KviThreadEvent(KVI_THREAD_EVENT_SUCCESS));
 			return false;
 		}
 	}
-	return true;
+	return selectForRead(120);
 }
 
-
 void KviHttpRequestThread::run()
 {
+	// setup:
+	//    nothing needed
+	
+	// run:
+	runInternal();
+	
+	// cleanup:
+#ifdef COMPILE_SSL_SUPPORT
+	if(m_pSSL)
+	{
+		delete m_pSSL;
+		m_pSSL = 0;
+	}
+#endif
+
+	if(kvi_socket_isValid(m_sock))
+	{
+		kvi_socket_close(m_sock);
+		m_sock = KVI_INVALID_SOCKET;
+	}
+}
+
+void KviHttpRequestThread::runInternal()
+{
+#ifndef COMPILE_SSL_SUPPORT
+	if(m_bUseSSL)
+	{
+		failure(__tr_no_lookup("This KVIrc executable has no SSL support"));
+		return;
+	}
+#endif
+
 	if(!connectToRemoteHost())return;
 
 	postEvent(m_pRequest,new KviThreadEvent(KVI_HTTP_REQUEST_THREAD_EVENT_CONNECTED));
@@ -1038,31 +1398,30 @@ void KviHttpRequestThread::run()
 		case Get: szMethod = "GET"; break;
 	}
 	
-	KviStr szRequest(KviStr::Format,"%s %s HTTP/1.0\r\n" \
+	KviStr szRequest(KviStr::Format,"%s %s HTTP/1.1\r\n" \
 				"Host: %s\r\n" \
 				"Connection: Close\r\n" \
 				"User-Agent: KVIrc-http-slave/1.0.0\r\n" \
 				"Accept: */*\r\n",
-				szMethod.ptr(),m_szPath.ptr(),m_szHost.ptr());
+				szMethod.ptr(),KviQString::toUtf8(m_szPath).data(),KviQString::toUtf8(m_szHost).data());
 
 	if(m_uContentOffset > 0)
 		szRequest.append(KviStr::Format,"Range: bytes=%u-\r\n",m_uContentOffset);
 
-	QCString szPostData = m_szPostData.utf8();
-
 	if(m_eRequestMethod == Post)
 	{
 		szRequest.append(KviStr::Format,"Content-Type: application/x-www-form-urlencoded\r\n" \
 				"Content-Length: %u\r\n" \
-				"Pragma: no-cache\r\n",szPostData.length());
+				"Cache-control: no-cache\r\n" \
+				"Pragma: no-cache\r\n",m_szPostData.length());
 	}
 
 	szRequest += "\r\n";
 
 	if(m_eRequestMethod == Post)
 	{
-		if(!szPostData.isEmpty())
-			szRequest.append(szPostData.data());
+		if(!m_szPostData.isEmpty())
+			szRequest.append(m_szPostData);
 		szRequest += "\r\n";
 	}
 
@@ -1071,12 +1430,11 @@ void KviHttpRequestThread::run()
 	if(!sendBuffer(szRequest.ptr(),szRequest.len(),60))return;
 
 	// now loop reading data
-	postEvent(m_pRequest,new KviThreadDataEvent<KviStr>(KVI_HTTP_REQUEST_THREAD_EVENT_REQUESTSENT,new KviStr(szRequest)));
+	postEvent(m_pRequest,new KviThreadDataEvent<QString>(KVI_HTTP_REQUEST_THREAD_EVENT_REQUESTSENT,new QString(szRequest)));
 
 	for(;;)
 	{
-		if(!selectForRead(180))return;
-		if(!readData())return;
+		if(!readDataStep())return;
 	}
 }
 
