@@ -956,27 +956,29 @@ namespace KviNetUtils
 	{
 #ifndef HAVE_INET_ATON
 		QString szAddr = szStringIp.simplifyWhiteSpace();
-		Q_UINT32 iAddr;
+		Q_UINT32 iAddr=0;
 		QStringList ipv4 = QStringList::split(".", szAddr, FALSE);
 		if (ipv4.count() == 4) {
 			int i = 0;
 			bool ok = TRUE;
 			while(ok && i < 4) {
 				uint byteValue = ipv4[i].toUInt(&ok);
-				if (byteValue > 255)
-				ok = FALSE;
+				if ( (byteValue > 255) && ok )
+					ok = FALSE;
 				if (ok)
-				iAddr = (iAddr << 8) + byteValue;
+					iAddr = (iAddr << 8) + byteValue;
 				++i;
 			}
 			if (ok)
+			{
 				if(address)address->s_addr = htonl(iAddr);
 				return true;
+			}
 		}
 		return FALSE;
 #else //HAVE_INET_ATON
 		if(szStringIp.isEmpty())return false;
-		return (inet_aton(szStringIp.utf8().data(),address) != 0);
+		return (inet_aton(KviQString::toUtf8(szStringIp).data(),address) != 0);
 #endif //HAVE_INET_ATON
 	}
 
@@ -1003,7 +1005,7 @@ namespace KviNetUtils
 
 	{
 
-		return (inet_pton(AF_INET6,szStringIp.utf8().data(),(void *)address) == 1);
+		return (inet_pton(AF_INET6,KviQString::toUtf8(szStringIp).data(),(void *)address) == 1);
 
 	}
 
@@ -1021,6 +1023,15 @@ namespace KviNetUtils
 
 	}
 
+	bool binaryIpToStringIp_V6(struct in6_addr in,QString &szBuffer)
+	{
+		char buf[46];
+		bool bRet =  inet_ntop(AF_INET6,(void *)&in,buf,46);
+		szBuffer= buf;
+		return bRet;
+	}
+	
+
 #endif //COMPILE_IPV6_SUPPORT
 
 
@@ -1107,7 +1118,7 @@ namespace KviNetUtils
 
 
 
-		kvi_memmove(ifr.ifr_name,szInterfaceName.utf8().data(),len + 1);
+		kvi_memmove(ifr.ifr_name,KviQString::toUtf8(szInterfaceName).data(),len + 1);
 
 
 
@@ -1315,100 +1326,43 @@ bool kvi_getLocalHostAddress(QString &buffer)
 
 
 
-KviSockaddr::KviSockaddr(const char * szIpAddress,kvi_u32_t uPort,bool bIpV6)
+KviSockaddr::KviSockaddr(const char * szIpAddress,kvi_u32_t uPort,bool bIpV6,bool bUdp)
 
 {
-
 	struct addrinfo hints;
-
-
-
 	kvi_memset((void *)&hints,0,sizeof(hints));
-
-
-
 	hints.ai_flags = AI_NUMERICHOST;
-
-
-
 #ifdef COMPILE_IPV6_SUPPORT
-
 	hints.ai_family = bIpV6 ? PF_INET6 : PF_INET;
-
 #else
-
 	hints.ai_family = PF_INET;
-
 #endif
 
-
-
-	hints.ai_socktype = SOCK_STREAM;
+	hints.ai_socktype = bUdp ? SOCK_DGRAM : SOCK_STREAM;
 
 	hints.ai_protocol = 0;
-
-
-
 	m_pData = 0;
-
-
-
 	KviStr szPort(KviStr::Format,"%u",uPort);
-
-
-
 	getaddrinfo(szIpAddress,szPort.ptr(),&hints,(struct addrinfo **)&m_pData);
 
 }
 
 
-
-
-
-
-
-KviSockaddr::KviSockaddr(kvi_u32_t uPort,bool bIpV6) // passive sockaddr
+KviSockaddr::KviSockaddr(kvi_u32_t uPort,bool bIpV6,bool bUdp) // passive sockaddr
 
 {
-
 	struct addrinfo hints;
-
-
-
 	kvi_memset((void *)&hints,0,sizeof(hints));
-
-
-
 	hints.ai_flags = AI_NUMERICHOST | AI_PASSIVE;
-
-
-
 #ifdef COMPILE_IPV6_SUPPORT
-
 	hints.ai_family = bIpV6 ? PF_INET6 : PF_INET;
-
 #else
-
 	hints.ai_family = PF_INET;
-
 #endif
-
-
-
-	hints.ai_socktype = SOCK_STREAM;
-
+	hints.ai_socktype = bUdp ? SOCK_DGRAM : SOCK_STREAM;
 	hints.ai_protocol = 0;
-
-
-
 	m_pData = 0;
-
-
-
 	KviStr szPort(KviStr::Format,"%u",uPort);
-
-
-
 	getaddrinfo(0,szPort.ptr(),&hints,(struct addrinfo **)&m_pData);
 
 }
