@@ -59,13 +59,14 @@ void KviUrl::parse()
 	m_szPath = "";
 	m_szUser = "";
 	m_szPass = "";
-	m_uPort = 80;
 
 	m_szUrl.stripWhiteSpace();
 
 	KviStr u = m_szUrl;
 
 	// proto
+	
+	kvi_u32_t uDefaultPort = 80;
 
 	int i = u.findFirstIdx(":/");
 	if(i != -1)
@@ -75,11 +76,17 @@ void KviUrl::parse()
 		u.cutLeft(i + 2);
 		u.stripLeft('/');
 		u.stripWhiteSpace();
+		
+		// fix the default ports
+		if(kvi_strEqualCI(m_szProtocol,"https"))uDefaultPort = 443;
+		else if(kvi_strEqualCI(m_szProtocol,"ftp"))uDefaultPort = 21;
 	} else {
 		// no proto... assume http
 		u.stripLeft('/');
 		m_szProtocol = "http";
 	}
+	
+	m_uPort = uDefaultPort;
 
 	// user and pass
 
@@ -113,14 +120,15 @@ void KviUrl::parse()
 		i = h.findFirstIdx(':');
 		if(i != -1)
 		{
+			// has a port part
 			m_szHost = h.left(i);
 			h.cutLeft(i + 1);
 			h.stripWhiteSpace();
 			bool bOk;
 			m_uPort = h.toUInt(&bOk);
-			if(!bOk)m_uPort = 80;
+			if(!bOk)m_uPort = uDefaultPort;
 		} else {
-			// no port : assume 80
+			// no port : assume default
 			m_szHost = h;
 		}
 		m_szPath = u;
