@@ -29,6 +29,7 @@
 #include "kvi_settings.h"
 #include "kvi_qstring.h"
 #include "kvi_string.h"
+#include "kvi_pointerhashtable.h"
 
 #include <qapplication.h>
 
@@ -41,6 +42,7 @@ namespace KviLocale
 	{
 		char * szName;
 		char   bSmart; // is it a smart codec ?
+		char   bSendUtf8; // does it send utf8 or the local charset ?
 		char * szDescription;
 	} EncodingDescription;
 
@@ -49,11 +51,11 @@ namespace KviLocale
 	KVILIB_API EncodingDescription * encodingDescription(int iIdx);
 	KVILIB_API QTextCodec * codecForName(const char * szName);
 	KVILIB_API const KviStr & localeName();
-	KVILIB_API bool findCatalogue(KviStr &szBuffer,const char * name,const char * szLocaleDir);
-	KVILIB_API bool loadCatalogue(const char * name,const char * szLocaleDir);
-	KVILIB_API KviMessageCatalogue * getLoadedCatalogue(const char * name);
-	KVILIB_API bool unloadCatalogue(const char * name);
-	KVILIB_API void init(QApplication * app,const char * localeDir);
+	KVILIB_API bool findCatalogue(QString &szBuffer,const QString& name,const QString& szLocaleDir);
+	KVILIB_API bool loadCatalogue(const QString& name,const QString& szLocaleDir);
+	KVILIB_API KviMessageCatalogue * getLoadedCatalogue(const QString& name);
+	KVILIB_API bool unloadCatalogue(const QString& name);
+	KVILIB_API void init(QApplication * app,const QString& localeDir);
 	KVILIB_API void done(QApplication * app);
 	KVILIB_API const char * translate(const char * text,const char * context);
 	KVILIB_API const QString & translateToQString(const char * text,const char * context);
@@ -92,10 +94,11 @@ public:
 	KviMessageCatalogue();
 	~KviMessageCatalogue();
 protected:
-	QAsciiDict<KviTranslationEntry> * m_pMessages;
-	QTextCodec                      * m_pTextCodec;
+	//KviPointerHashTable<const char *,KviTranslationEntry> * m_pMessages;
+	KviPointerHashTable<const char *,KviTranslationEntry> * m_pMessages;
+	QTextCodec                                            * m_pTextCodec;
 public:
-	bool load(const char * name);
+	bool load(const QString& name);
 	const char * translate(const char * text);
 	const QString & translateToQString(const char * text);
 };
@@ -128,8 +131,15 @@ class KVILIB_API KviTranslator : public QTranslator
 		KviTranslator(QObject * parent,const char * name);
 		~KviTranslator();
 	public:
+#ifdef COMPILE_USE_QT4
+		virtual QString translate(const char * context,const char * message,const char * comment) const;
+#endif
+		// Deprecated in qt 4.x
 		virtual QString find(const char * context,const char * message) const;
+#ifndef COMPILE_USE_QT4
+		// Dead in qt 4.x
 		virtual QTranslatorMessage findMessage(const char * context,const char * sourceText,const char * comment = 0) const;
+#endif
 };
 
 
