@@ -175,7 +175,7 @@ KviThreadManager::KviThreadManager()
 
 
 	m_pMutex = new KviMutex();
-	m_pThreadList = new KviPtrList<KviThread>;
+	m_pThreadList = new KviPointerList<KviThread>;
 	m_pThreadList->setAutoDelete(false);
 
 	m_iWaitingThreads = 0;
@@ -184,22 +184,22 @@ KviThreadManager::KviThreadManager()
 
 	m_iTriggerCount = 0;
 
-	m_pEventQueue = new KviPtrList<KviThreadPendingEvent>;
+	m_pEventQueue = new KviPointerList<KviThreadPendingEvent>;
 	m_pEventQueue->setAutoDelete(true);
 
 	if(pipe(m_fd) != 0)
 	{
-		debug("Ops...thread manager pipe creation failed (%s)",KviError::getDescription(KviError::translateSystemError(errno)).utf8().data());
+		debug("Ops...thread manager pipe creation failed (%s)",KviQString::toUtf8(KviError::getDescription(KviError::translateSystemError(errno))).data());
 	}
 
 	if(fcntl(m_fd[KVI_THREAD_PIPE_SIDE_SLAVE],F_SETFL,O_NONBLOCK) == -1)
 	{
-		debug("Ops...thread manager slave pipe initialisation failed (%s)",KviError::getDescription(KviError::translateSystemError(errno)).utf8().data());
+		debug("Ops...thread manager slave pipe initialisation failed (%s)",KviQString::toUtf8(KviError::getDescription(KviError::translateSystemError(errno))).data());
 	}
 
 	if(fcntl(m_fd[KVI_THREAD_PIPE_SIDE_MASTER],F_SETFL,O_NONBLOCK) == -1)
 	{
-		debug("Ops...thread manager master pipe initialisation failed (%s)",KviError::getDescription(KviError::translateSystemError(errno)).utf8().data());
+		debug("Ops...thread manager master pipe initialisation failed (%s)",KviQString::toUtf8(KviError::getDescription(KviError::translateSystemError(errno))).data());
 	}
 
 	m_pSn = new QSocketNotifier(m_fd[KVI_THREAD_PIPE_SIDE_MASTER],QSocketNotifier::Read);
@@ -268,7 +268,7 @@ void KviThreadManager::killPendingEvents(QObject * receiver)
 void KviThreadManager::killPendingEventsByReceiver(QObject * receiver)
 {
 #ifndef COMPILE_ON_WINDOWS
-	KviPtrList<KviThreadPendingEvent> l;
+	KviPointerList<KviThreadPendingEvent> l;
 	l.setAutoDelete(false);
 	m_pMutex->lock();
 	for(KviThreadPendingEvent * ev = m_pEventQueue->first();ev;ev = m_pEventQueue->next())
@@ -586,7 +586,7 @@ KviSensitiveThread::KviSensitiveThread()
 : KviThread()
 {
 	m_pLocalEventQueueMutex = new KviMutex();
-	m_pLocalEventQueue = new KviPtrList<KviThreadEvent>;
+	m_pLocalEventQueue = new KviPointerList<KviThreadEvent>;
 	m_pLocalEventQueue->setAutoDelete(false);
 }
 
