@@ -1,12 +1,13 @@
 #ifndef _KVI_TAL_FILEDIALOG_H_
 #define _KVI_TAL_FILEDIALOG_H_
 
+//=============================================================================
 //
 //   File : kvi_tal_filedialog.h
 //   Creation date : Thu Sep 11 2003 04:41:08 by Szymon Stefanek
 //
 //   This file is part of the KVirc irc client distribution
-//   Copyright (C) 2003 Szymon Stefanek (pragma at kvirc dot net)
+//   Copyright (C) 2003-2007 Szymon Stefanek (pragma at kvirc dot net)
 //
 //   This program is FREE software. You can redistribute it and/or
 //   modify it under the terms of the GNU General Public License
@@ -22,13 +23,18 @@
 //   along with this program. If not, write to the Free Software Foundation,
 //   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 //
+//=============================================================================
 
 #include "kvi_settings.h"
 
-#ifdef COMPILE_KDE_SUPPORT
-	#include "kvi_tal_filedialog_kde.h"
+#ifdef COMPILE_USE_QT4
+	#include "kvi_tal_filedialog_qt4.h"
 #else
-	#include "kvi_tal_filedialog_qt.h"
+	#ifdef COMPILE_KDE_SUPPORT
+		#include "kvi_tal_filedialog_kde.h"
+	#else
+		#include "kvi_tal_filedialog_qt.h"
+	#endif
 #endif
 
 #endif // _KVI_TAL_FILEDIALOG_H_
