@@ -38,7 +38,7 @@
 #include "kvi_styled_controls.h"
 
 #include <qtoolbutton.h>
-#include <qpopupmenu.h>
+#include "kvi_tal_popupmenu.h"
 
 
 KviAction::~KviAction()
@@ -77,7 +77,8 @@ void KviAction::unregisterAccelerator()
 {
 	if(m_iAccelId != 0)
 	{
-		g_pFrame->unregisterAccelerator(m_iAccelId);
+		if(g_pFrame)
+			g_pFrame->unregisterAccelerator(m_iAccelId);
 		m_iAccelId = 0;
 	}
 }
@@ -373,7 +374,7 @@ void KviAction::activeContextStateChanged()
 	}
 }
 
-bool KviAction::addToPopupMenu(QPopupMenu *pMenu)
+bool KviAction::addToPopupMenu(KviTalPopupMenu *pMenu)
 {
 	if(!setupDone())setup();
 	QPixmap * p = smallIcon();
@@ -402,7 +403,7 @@ void KviAction::registerWidget(QWidget * b)
 	connect(b,SIGNAL(destroyed()),this,SLOT(widgetDestroyed()));
 	if(!m_pWidgetList)
 	{
-		m_pWidgetList = new KviPtrList<QWidget>;
+		m_pWidgetList = new KviPointerList<QWidget>;
 		m_pWidgetList->setAutoDelete(false);
 	}
 	m_pWidgetList->append(b);
@@ -417,6 +418,9 @@ QWidget * KviAction::addToCustomToolBar(KviCustomToolBar *pParentToolBar)
 			visibleName(),
 			visibleName(),
 			this,SLOT(activate()),pParentToolBar,m_szName);
+#ifdef COMPILE_USE_QT4
+	pParentToolBar->addWidget(b);
+#endif
 	if(!isEnabled())b->setEnabled(false);
 	registerWidget(b);
 	return b;
