@@ -25,7 +25,7 @@
 //=============================================================================
 
 #include "kvi_settings.h"
-#include "kvi_list.h"
+#include "kvi_pointerlist.h"
 
 #include <qobject.h>
 #include <qstring.h>
@@ -37,7 +37,7 @@
 // Known categories are: general (or empty), irc, script
 //
 
-class QPopupMenu;
+class KviTalPopupMenu;
 class QWidget;
 class KviCustomToolBar;
 class QPixmap;
@@ -74,7 +74,7 @@ protected:
 	KviActionCategory * m_pCategory;                // may be 0, not owned!
 	QString m_szBigIcon;
 	int     m_iSmallIconId;
-	KviPtrList<QWidget> * m_pWidgetList;
+	KviPointerList<QWidget> * m_pWidgetList;
 	unsigned short int m_uInternalFlags;
 	unsigned int m_uFlags;
 	QString m_szKeySequence;
@@ -128,14 +128,14 @@ public:
 	virtual void setEnabled(bool bEnabled);
 	virtual QPixmap * smallIcon();
 	virtual QPixmap * bigIcon();
-	virtual bool addToPopupMenu(QPopupMenu *pMenu);
+	virtual bool addToPopupMenu(KviTalPopupMenu *pMenu);
 	virtual QWidget * addToCustomToolBar(KviCustomToolBar *pParentToolBar);
 	void suicide() { delete this; };
 protected:
 	// called once before the FIRST button or menu item is created
 	bool setupDone() const { return (m_uInternalFlags & KVI_ACTION_FLAG_SETUPDONE); };
 	virtual void setup();
-	KviPtrList<QWidget> * widgetList(){ return m_pWidgetList; };
+	KviPointerList<QWidget> * widgetList(){ return m_pWidgetList; };
 	void registerAccelerator();
 	void unregisterAccelerator();
 	void registerWidget(QWidget * b);
