@@ -26,6 +26,7 @@
 
 #define _KVI_APP_CPP_
 
+#include "kvi_socket.h"
 #include "kvi_app.h"
 #include "kvi_debug.h"
 #include "kvi_frame.h"
@@ -34,7 +35,6 @@
 #include "kvi_input.h"
 #include "kvi_config.h"
 #include "kvi_colorwin.h"
-#include "kvi_uparser.h"
 #include "kvi_window.h"
 #include "kvi_ircserverdb.h"
 #include "kvi_proxydb.h"
@@ -43,7 +43,6 @@
 #include "kvi_sparser.h"
 #include "kvi_modulemanager.h"
 #include "kvi_mediatype.h"
-#include "kvi_scriptobject.h"
 #include "kvi_regusersdb.h"
 #include "kvi_thread.h"
 #include "kvi_sharedfiles.h"
@@ -54,7 +53,6 @@
 #include "kvi_out.h"
 #include "kvi_splash.h"
 #include "kvi_nickserv.h"
-//#include "kvi_timermanager.h"
 #include "kvi_xlib.h"
 #include "kvi_garbage.h"
 #include "kvi_texticonmanager.h"
@@ -68,12 +66,13 @@
 #include "kvi_kvs.h"
 #include "kvi_ircurl.h"
 #include "kvi_avatarcache.h"
-//#include "kvi_processmanager.h"
 #include "kvi_actionmanager.h"
 #include "kvi_customtoolbarmanager.h"
 #include "kvi_fileutils.h"
 #include "kvi_time.h"
 #include "kvi_doublebuffer.h"
+#include "kvi_stringconversion.h"
+#include "kvi_useridentity.h"
 
 #ifndef COMPILE_NO_IPC
 	#include "kvi_ipc.h"
@@ -86,12 +85,15 @@
 #include "kvi_kvs_eventtriggers.h"
 #include "kvi_sourcesdate.h"
 
-#include <qpopupmenu.h>
+#include "kvi_tal_popupmenu.h"
 #include <qsplitter.h>
 #include <qstringlist.h>
-#include <qasciidict.h>
+#include "kvi_pointerhashtable.h"
 #include <qmime.h>
-#include <qlistbox.h>
+#ifdef COMPILE_USE_QT4
+	#include <q3mimefactory.h>
+#endif
+#include "kvi_tal_listbox.h"
 #include <qclipboard.h>
 #include <qmessagebox.h>
 #include <qtextcodec.h>
@@ -101,7 +103,11 @@
 	#include "kvi_ssl.h"
 #endif
 
-
+#ifdef COMPILE_USE_QT4
+#ifdef COMPILE_ON_WINDOWS
+#include <QPluginLoader>
+#endif
+#endif
 
 KVIRC_API KviApp                       * g_pApp                    = 0; // global application pointer
 
@@ -113,12 +119,12 @@ KVIRC_API KviProxyDataBase             * g_pProxyDataBase          = 0;
 
 KVIRC_API KviColorWindow               * g_pColorWindow               = 0;
 KVIRC_API KviTextIconWindow            * g_pTextIconWindow            = 0;
-KVIRC_API QPopupMenu                   * g_pInputPopup                = 0;
+KVIRC_API KviTalPopupMenu              * g_pInputPopup                = 0;
 KVIRC_API QStringList                  * g_pRecentTopicList           = 0;
-//KVIRC_API QStringList                  * g_pBookmarkList              = 0;
-KVIRC_API QAsciiDict<KviWindow>        * g_pGlobalWindowDict          = 0;
+//KVIRC_API QStringList                  * g_pBookmarkList            = 0;
+KVIRC_API KviPointerHashTable<const char *,KviWindow>      * g_pGlobalWindowDict          = 0;
 KVIRC_API KviMediaManager              * g_pMediaManager              = 0;
-KVIRC_API KviRegisteredUserDataBase    * g_pRegisteredUserDataBase    = 0;
+//KVIRC_API KviRegisteredUserDataBase    * g_pRegisteredUserDataBase    = 0;
 KVIRC_API KviSharedFilesManager        * g_pSharedFilesManager        = 0;
 KVIRC_API KviNickServRuleSet           * g_pNickServRuleSet           = 0;
 //KVIRC_API KviTimerManager              * g_pTimerManager              = 0;
@@ -129,7 +135,7 @@ KVIRC_API KviInputHistory              * g_pInputHistory              = 0;
 KVIRC_API KviHistoryWindow             * g_pHistoryWindow             = 0;
 
 
-KVIRC_API bool                           g_bIdentDaemonRunning     = false; // this is eventually set by libkviident
+KVIRC_API int                            g_iIdentDaemonRunningUsers   = 0; // this is eventually set by libkviident
 
 KVIRC_API KviSplashScreen       * g_pSplashScreen           = 0;
 
@@ -163,7 +169,7 @@ QPixmap                             * g_pActivityMeterPixmap    = 0;
 	KVIRC_API KviCryptEngineManager * g_pCryptEngineManager = 0; // global crypt engine manager
 #endif
 
-KviApp::KviApp(int argc,char ** argv)
+KviApp::KviApp(int &argc,char ** argv)
 : KviTalApplication(argc,argv)
 {
 	// Ok...everything begins here
@@ -175,8 +181,10 @@ KviApp::KviApp(int argc,char ** argv)
 	m_pPendingAvatarChanges = 0;
 	m_pRecentChannelsDict   = 0;
 	m_pIpcSentinel          = 0;
+	m_iHeartbeatTimerId     = -1;
 	// next step is setup()
 	m_bSetupDone = false;
+	kvi_socket_flushTrafficCounters();
 }
 
 void KviApp::setup()
@@ -194,7 +202,7 @@ void KviApp::setup()
 
 #ifndef COMPILE_NO_IPC
 	// Create this very early
-	// FIXME: this is still not early enough...
+	// FIXME: this is still not early enough... we actually HAVE race conditions (should use a file for locking this ?)
 	createIpcSentinel();
 #endif
 
@@ -207,12 +215,25 @@ void KviApp::setup()
 
 	// Setup our filesystem and initalize locale
 	loadDirectories();
+	KviStringConversion::init(m_szGlobalKvircDir,m_szLocalKvircDir);
+
+#ifdef COMPILE_USE_QT4
+#ifdef COMPILE_ON_WINDOWS
+	//need to load image plugins:(
+	QString szPluginsDir;
+	getGlobalKvircDirectory(szPluginsDir,None,"qt-plugins/");
+	setLibraryPaths(QStringList(szPluginsDir));
+	//KviMessageBox::information(libraryPaths().join(";"));
+	//debug("%1",loader.isLoaded());
+#endif
+#endif
 
 	// check if we want to permanently disable the splash screen
 	// we do it once for every version: the user should see the new splash screens at least once
 	
 	QString szSplashDisableFile;
 	getLocalKvircDirectory(szSplashDisableFile,Pics,"disable-splash." KVI_VERSION);
+
 	if(KviFileUtils::fileExists(szSplashDisableFile))
 		m_bShowSplashScreen = false;
 
@@ -229,20 +250,24 @@ void KviApp::setup()
 
 	// Set the default help files search path
 	QStringList list;
-	KviStr tmp;
+	QString tmp;
 	getLocalKvircDirectory(tmp,Help); // localized help/lang or help if help/lang doesn't exist
-	list.append(tmp.ptr());
+	list.append(tmp);
 	getLocalKvircDirectory(tmp,HelpEN); // help/en
-	list.append(tmp.ptr());
+	list.append(tmp);
 	getLocalKvircDirectory(tmp,HelpNoIntl); // just help/
-	list.append(tmp.ptr());
+	list.append(tmp);
 	getGlobalKvircDirectory(tmp,Help);
-	list.append(tmp.ptr());
+	list.append(tmp);
 	getGlobalKvircDirectory(tmp,HelpEN);
-	list.append(tmp.ptr());
+	list.append(tmp);
 	getGlobalKvircDirectory(tmp,HelpNoIntl);
-	list.append(tmp.ptr());
+	list.append(tmp);
+#ifdef COMPILE_USE_QT4
+	Q3MimeSourceFactory::defaultFactory()->setFilePath(list);
+#else
 	QMimeSourceFactory::defaultFactory()->setFilePath(list);
+#endif
 
 	KVI_SPLASH_SET_PROGRESS(1)
 
@@ -267,14 +292,26 @@ void KviApp::setup()
 	KVI_SPLASH_SET_PROGRESS(5)
 
 	if(getReadOnlyConfigPath(tmp,KVI_CONFIGFILE_USERACTIONS))
-		KviActionManager::instance()->load(tmp.ptr());
+		KviActionManager::instance()->load(tmp);
 
 	KVI_SPLASH_SET_PROGRESS(8);
 
-	// Load the configuration
+	// Initialize and load the identities
+	KviUserIdentityManager::init();
+
+	KVI_SPLASH_SET_PROGRESS(9);
+
+	if(getReadOnlyConfigPath(tmp,KVI_CONFIGFILE_IDENTITIES))
+		KviUserIdentityManager::instance()->load(tmp);
+
+	KVI_SPLASH_SET_PROGRESS(12);
+
+	// Load the remaining configuration
+	// Note that loadOptions() assumes that the current progress is 12 and
+	// will bump it up to 45 in small steps
 	loadOptions();
 
-	KVI_SPLASH_SET_PROGRESS(42)
+	KVI_SPLASH_SET_PROGRESS(47)
 
 	// set the global font if needed
 	updateApplicationFont();
@@ -283,66 +320,66 @@ void KviApp::setup()
 	updatePseudoTransparency();
 #endif
 
-	KVI_SPLASH_SET_PROGRESS(44)
+	KVI_SPLASH_SET_PROGRESS(48)
 
 	// Load the win properties config
 	getLocalKvircDirectory(tmp,Config,KVI_CONFIGFILE_WINPROPERTIES);
-	g_pWinPropertiesConfig = new KviConfig(tmp.ptr(),KviConfig::ReadWrite);
+	g_pWinPropertiesConfig = new KviConfig(tmp,KviConfig::ReadWrite);
 
-	KVI_SPLASH_SET_PROGRESS(48)
+	KVI_SPLASH_SET_PROGRESS(50)
 
 	// Load the server database
 	g_pIrcServerDataBase   = new KviIrcServerDataBase();
 	if(getReadOnlyConfigPath(tmp,KVI_CONFIGFILE_SERVERDB))
-		g_pIrcServerDataBase->load(tmp.ptr());
+		g_pIrcServerDataBase->load(tmp);
 
-	KVI_SPLASH_SET_PROGRESS(51)
+	KVI_SPLASH_SET_PROGRESS(53)
 
 	// Load the proxy database
 	g_pProxyDataBase = new KviProxyDataBase();
 	if(getReadOnlyConfigPath(tmp,KVI_CONFIGFILE_PROXYDB))
-		g_pProxyDataBase->load(tmp.ptr());
+		g_pProxyDataBase->load(tmp);
 
 	KVI_SPLASH_SET_PROGRESS(54)
 
 	// Event manager
 	if(getReadOnlyConfigPath(tmp,KVI_CONFIGFILE_EVENTS))
-		KviKvs::loadAppEvents(tmp.ptr());
+		KviKvs::loadAppEvents(tmp);
 
 	KVI_SPLASH_SET_PROGRESS(59)
 
 	if(getReadOnlyConfigPath(tmp,KVI_CONFIGFILE_RAWEVENTS))
-		KviKvs::loadRawEvents(tmp.ptr());
+		KviKvs::loadRawEvents(tmp);
 
 	KVI_SPLASH_SET_PROGRESS(62)
 
 	// Popup manager
 	if(getReadOnlyConfigPath(tmp,KVI_CONFIGFILE_POPUPS))
-		KviKvs::loadPopups(tmp.ptr());
+		KviKvs::loadPopups(tmp);
 
 	KVI_SPLASH_SET_PROGRESS(67)
 
 	KviCustomToolBarManager::init();
 	if(getReadOnlyConfigPath(tmp,KVI_CONFIGFILE_CUSTOMTOOLBARS))
-		KviCustomToolBarManager::instance()->load(tmp.ptr());
+		KviCustomToolBarManager::instance()->load(tmp);
 	// THIS IS A COMPATIBILITY ENTRY ADDED AT 3.0.2 TIME THAT SHOULD BE DROPPED IN A COUPLE OF VERSION BUMPS!
 	getLocalKvircDirectory(tmp,Config,KVI_CONFIGFILE_SCRIPTTOOLBARS);
-	if(KviFileUtils::fileExists(tmp.ptr()))
-		KviCustomToolBarManager::instance()->loadScripttoolbarsCompat(tmp.ptr());
+	if(KviFileUtils::fileExists(tmp))
+		KviCustomToolBarManager::instance()->loadScripttoolbarsCompat(tmp);
 	// EOF COMPATIBILITY
 
 	KVI_SPLASH_SET_PROGRESS(70)
 
 	// Alias manager
 	if(getReadOnlyConfigPath(tmp,KVI_CONFIGFILE_ALIASES))
-		KviKvs::loadAliases(tmp.ptr());
+		KviKvs::loadAliases(tmp);
 
 	KVI_SPLASH_SET_PROGRESS(75)
 
 	// Script addons manager (this in fact has delayed loading, so we don't even care
 	// about showing up an entry in the splash screen)
 	if(getReadOnlyConfigPath(tmp,KVI_CONFIGFILE_SCRIPTADDONS))
-		KviKvs::loadScriptAddons(tmp.ptr());
+		KviKvs::loadScriptAddons(tmp);
 
 	KVI_SPLASH_SET_PROGRESS(77)
 
@@ -362,7 +399,7 @@ void KviApp::setup()
 	g_pMediaManager = new KviMediaManager();
 	g_pMediaManager->lock();
 	if(getReadOnlyConfigPath(tmp,KVI_CONFIGFILE_MEDIATYPES))
-		g_pMediaManager->load(tmp.ptr());
+		g_pMediaManager->load(tmp);
 	g_pMediaManager->unlock();
 
 
@@ -371,39 +408,39 @@ void KviApp::setup()
 	// registered user data base
 	g_pRegisteredUserDataBase = new KviRegisteredUserDataBase();
 	if(getReadOnlyConfigPath(tmp,KVI_CONFIGFILE_REGUSERDB))
-		g_pRegisteredUserDataBase->load(tmp.ptr());
+		g_pRegisteredUserDataBase->load(tmp);
 
 	KVI_SPLASH_SET_PROGRESS(84)
 
 	// registered channel data base
 	g_pRegisteredChannelDataBase = new KviRegisteredChannelDataBase();
 	if(getReadOnlyConfigPath(tmp,KVI_CONFIGFILE_REGCHANDB))
-		g_pRegisteredChannelDataBase->load(tmp.ptr());
+		g_pRegisteredChannelDataBase->load(tmp);
 
 	KVI_SPLASH_SET_PROGRESS(85)
 
 	// file trader
 	g_pSharedFilesManager = new KviSharedFilesManager();
 	if(getReadOnlyConfigPath(tmp,KVI_CONFIGFILE_SHAREDFILES))
-		g_pSharedFilesManager->load(tmp.ptr());
+		g_pSharedFilesManager->load(tmp);
 
 	KVI_SPLASH_SET_PROGRESS(86)
 
 	// nick serv data base
 	g_pNickServRuleSet = new KviNickServRuleSet();
 	if(getReadOnlyConfigPath(tmp,KVI_CONFIGFILE_NICKSERVDATABASE))
-		g_pNickServRuleSet->load(tmp.ptr());
+		g_pNickServRuleSet->load(tmp);
 
 	KVI_SPLASH_SET_PROGRESS(88)
 
 	g_pInputHistory = new KviInputHistory();
 	if(getReadOnlyConfigPath(tmp,KVI_CONFIGFILE_INPUTHISTORY))
-		g_pInputHistory->load(tmp.ptr());
+		g_pInputHistory->load(tmp);
 
 	KVI_SPLASH_SET_PROGRESS(89)
 	KviAvatarCache::init();
 	if(getReadOnlyConfigPath(tmp,KVI_CONFIGFILE_AVATARCACHE))
-		KviAvatarCache::instance()->load(tmp.ptr());
+		KviAvatarCache::instance()->load(tmp);
 
 	KVI_SPLASH_SET_PROGRESS(90)
 
@@ -415,24 +452,36 @@ void KviApp::setup()
 	g_pGarbageCollector = new KviGarbageCollector();
 
 	// and the input popup
-	g_pInputPopup = new QPopupMenu();
+	g_pInputPopup = new KviTalPopupMenu();
 
-	// create the parsers
-	g_pUserParser = new KviUserParser();
+	// create the server parser
 	g_pServerParser = new KviServerParser();
 
 	KVI_SPLASH_SET_PROGRESS(91)
 
 	// Global window dictionary
-	g_pGlobalWindowDict = new QAsciiDict<KviWindow>(41);
+	g_pGlobalWindowDict = new KviPointerHashTable<const char *,KviWindow>(41);
 	g_pGlobalWindowDict->setAutoDelete(false);
 	// Script object controller
-	g_pScriptObjectController = new KviScriptObjectController();
+	//g_pScriptObjectController = new KviScriptObjectController(); gone
 
 	KVI_SPLASH_SET_PROGRESS(92)
 
 	KviDoubleBuffer::init();
 
+#ifdef COMPILE_USE_QT4
+	QString szStylesheetFile;
+	getGlobalKvircDirectory(szStylesheetFile,Config,"style.css");
+	if(KviFileUtils::fileExists(szStylesheetFile))
+	{
+		QString szStyleData;
+		KviFileUtils::readFile(szStylesheetFile,szStyleData);
+		szStyleData.replace("global://",m_szGlobalKvircDir);
+		szStyleData.replace("local://",m_szLocalKvircDir);
+		setStyleSheet(szStyleData);
+	}
+#endif
+
 	// create the frame window, we're almost up and running...
 	createFrame();
 
@@ -443,8 +492,6 @@ void KviApp::setup()
 	{
 		// Finish the setup...
 		setupFinish();
-		// Load the default script
-		loadDefaultScript();
 	}
 
 	// hello world!
@@ -456,6 +503,9 @@ void KviApp::setup()
 	KVI_SPLASH_SET_PROGRESS(100)
 	//KVI_SPLASH_SET_TEXT(__tr2qs("Have fun! :)"))
 
+	if(KVI_OPTION_BOOL(KviOption_boolShowServersConnectDialogOnStart))
+			g_pFrame->executeInternalCommand(KVI_INTERNALCOMMAND_SERVERSJOIN_OPEN);
+
 	destroySplashScreen();
 
 	// check if we're in trouble...
@@ -517,6 +567,8 @@ KviApp::~KviApp()
 	// We should have almost no UI here: only certain dialogs or popup windows may
 	// still exist: they should be harmless tough.
 	saveOptions();
+	saveIdentities();
+	KviUserIdentityManager::done();
 	if(m_pRecentChannelsDict) delete m_pRecentChannelsDict;
 	// now kill the stuff that the frame depends on
 	saveIrcServerDataBase();
@@ -528,7 +580,6 @@ KviApp::~KviApp()
 	if(g_pTextIconWindow)delete g_pTextIconWindow;
 	delete g_pTextIconManager;
 	delete g_pIconManager;
-	delete g_pUserParser;
 	delete g_pServerParser;
 	saveMediaTypes();
 	delete g_pMediaManager;
@@ -559,7 +610,7 @@ KviApp::~KviApp()
 	saveInputHistory();
 	delete g_pInputHistory;
 	delete g_pInputPopup;
-	delete g_pScriptObjectController;
+	//delete g_pScriptObjectController;
 #ifdef COMPILE_CRYPT_SUPPORT
 	delete g_pCryptEngineManager;
 #endif
@@ -635,6 +686,8 @@ QTextCodec * KviApp::defaultTextCodec()
 
 void KviApp::contextSensitiveHelp()
 {
+	// this stuff doesn't work with Qt 4.x
+#ifndef COMPILE_USE_QT4
 	// the F1 Key has been pressed
 	// try to pass it to the active widget or one of its parents
 	QWidget * w = g_pApp->focusWidget();
@@ -657,6 +710,7 @@ void KviApp::contextSensitiveHelp()
 	// no way
 	// FIXME: just show up simple plain online help
 	//debug("No way: found no focus widget for that...");
+#endif
 }
 
 
@@ -677,7 +731,9 @@ void KviApp::loadDefaultScript()
 #endif
 	KviKvsScript::run(cmd,g_pFrame->firstConsole());
 	// now line up the toolbars (they may get messed while loading the script)
-	g_pFrame->lineUpDockWindows();
+#ifndef COMPILE_USE_QT4
+	g_pFrame->lineUpDockWindows(); // missing on Qt 4.x
+#endif
 }
 
 // 07.01.2005 06:01: Got this curious gcc error while writing
@@ -895,7 +951,7 @@ void KviApp::setClipboardText(const KviStr &str)
 
 void KviApp::setAvatarFromOptions()
 {
-	QAsciiDictIterator<KviWindow> it(*g_pGlobalWindowDict);
+	KviPointerHashTableIterator<const char *,KviWindow> it(*g_pGlobalWindowDict);
 
 	while(it.current())
 	{
@@ -912,7 +968,7 @@ void KviApp::setAvatarOnFileReceived(KviConsole * pConsole,const QString &szRemo
 {
 	if(!m_pPendingAvatarChanges)
 	{
-		m_pPendingAvatarChanges = new KviPtrList<KviPendingAvatarChange>;
+		m_pPendingAvatarChanges = new KviPointerList<KviPendingAvatarChange>;
 		m_pPendingAvatarChanges->setAutoDelete(true);
 	}
 
@@ -962,6 +1018,8 @@ void KviApp::fileDownloadTerminated(bool bSuccess,const QString &szRemoteUrl,con
 	if(!p)
 	{
 		// signal dcc completion only for NON-avatars
+		// FIXME: This option is misnamed and misplaced in the options dialog :(
+		//        it seems to refer only to DCC while it refers to any file transfer
 		if(KVI_OPTION_BOOL(KviOption_boolNotifyDccSendSuccessInNotifier) && (!bQuiet))
 		{
 			if(!g_pActiveWindow)return;
@@ -1307,66 +1365,66 @@ void KviApp::updateApplicationFont()
 
 void KviApp::loadRecentEntries()
 {
-	KviStr tmp;
+	QString tmp;
 	getLocalKvircDirectory(tmp,Config,KVI_CONFIGFILE_RECENT);
-	KviConfig cfg(tmp.ptr(),KviConfig::Read);
+	KviConfig cfg(tmp,KviConfig::Read);
 	*g_pRecentTopicList = cfg.readStringListEntry("RecentTopicList",QStringList());
 	//*g_pBookmarkList = cfg.readStringListEntry("Bookmarks",QStringList());
 }
 void KviApp::saveRecentEntries()
 {
-	KviStr tmp;
+	QString tmp;
 	getLocalKvircDirectory(tmp,Config,KVI_CONFIGFILE_RECENT);
-	KviConfig cfg(tmp.ptr(),KviConfig::Write);
+	KviConfig cfg(tmp,KviConfig::Write);
 	cfg.writeEntry("RecentTopicList",*g_pRecentTopicList);
 	//cfg.writeEntry("Bookmarks",*g_pBookmarkList);
 }
 
 void KviApp::saveAvatarCache()
 {
-	KviStr tmp;
+	QString tmp;
 	getLocalKvircDirectory(tmp,Config,KVI_CONFIGFILE_AVATARCACHE);
-	KviAvatarCache::instance()->save(tmp.ptr());
+	KviAvatarCache::instance()->save(tmp);
 }
 
 
 void KviApp::saveToolBars()
 {
-	KviStr tmp;
+	QString tmp;
 	getLocalKvircDirectory(tmp,Config,KVI_CONFIGFILE_CUSTOMTOOLBARS);
-	KviCustomToolBarManager::instance()->save(tmp.ptr());
+	KviCustomToolBarManager::instance()->save(tmp);
 }
 
 void KviApp::savePopups()
 {
-	KviStr tmp;
+	QString tmp;
 	getLocalKvircDirectory(tmp,Config,KVI_CONFIGFILE_POPUPS);
-	KviKvs::savePopups(tmp.ptr());
+	KviKvs::savePopups(tmp);
 }
 
 void KviApp::saveInputHistory()
 {
 	if(!KVI_OPTION_BOOL(KviOption_boolDisableInputHistory))
 	{
-		KviStr tmp;
+		QString tmp;
 		getLocalKvircDirectory(tmp,Config,KVI_CONFIGFILE_INPUTHISTORY);
-		g_pInputHistory->save(tmp.ptr());
+		g_pInputHistory->save(tmp);
 	}
 }
 
 
 void KviApp::saveAliases()
 {
-	KviStr tmp;
+	QString tmp;
 	getLocalKvircDirectory(tmp,Config,KVI_CONFIGFILE_ALIASES);
-	KviKvs::saveAliases(tmp.ptr());
+	KviKvs::saveAliases(tmp);
 }
 
 void KviApp::saveScriptAddons()
 {
-	KviStr tmp;
+	QString tmp;
 	getLocalKvircDirectory(tmp,Config,KVI_CONFIGFILE_SCRIPTADDONS);
-	KviKvs::saveScriptAddons(tmp.ptr());
+	KviKvs::saveScriptAddons(tmp);
 }
 
 void KviApp::saveTextIcons()
@@ -1376,74 +1434,81 @@ void KviApp::saveTextIcons()
 
 void KviApp::saveAppEvents()
 {
-	KviStr tmp;
+	QString tmp;
 	getLocalKvircDirectory(tmp,Config,KVI_CONFIGFILE_EVENTS);
-	KviKvs::saveAppEvents(tmp.ptr());
+	KviKvs::saveAppEvents(tmp);
 }
 
 void KviApp::saveRawEvents()
 {
-	KviStr tmp;
+	QString tmp;
 	getLocalKvircDirectory(tmp,Config,KVI_CONFIGFILE_RAWEVENTS);
-	KviKvs::saveRawEvents(tmp.ptr());
+	KviKvs::saveRawEvents(tmp);
 }
 
 void KviApp::saveMediaTypes()
 {
-	KviStr tmp;
+	QString tmp;
 	getLocalKvircDirectory(tmp,Config,KVI_CONFIGFILE_MEDIATYPES);
 	g_pMediaManager->lock();
-	g_pMediaManager->save(tmp.ptr());
+	g_pMediaManager->save(tmp);
 	g_pMediaManager->unlock();
 }
 
 void KviApp::saveIrcServerDataBase()
 {
-	KviStr tmp;
+	QString tmp;
 	getLocalKvircDirectory(tmp,Config,KVI_CONFIGFILE_SERVERDB);
-	g_pIrcServerDataBase->save(tmp.ptr());
+	g_pIrcServerDataBase->save(tmp);
 }
 
 void KviApp::saveProxyDataBase()
 {
-	KviStr tmp;
+	QString tmp;
 	getLocalKvircDirectory(tmp,Config,KVI_CONFIGFILE_PROXYDB);
-	g_pProxyDataBase->save(tmp.ptr());
+	g_pProxyDataBase->save(tmp);
 }
 
 void KviApp::saveRegisteredUsers()
 {
-	KviStr tmp;
+	QString tmp;
 	getLocalKvircDirectory(tmp,Config,KVI_CONFIGFILE_REGUSERDB);
-	g_pRegisteredUserDataBase->save(tmp.ptr());
+	g_pRegisteredUserDataBase->save(tmp);
 }
 
 void KviApp::saveRegisteredChannels()
 {
-	KviStr tmp;
+	QString tmp;
 	getLocalKvircDirectory(tmp,Config,KVI_CONFIGFILE_REGCHANDB);
-	g_pRegisteredChannelDataBase->save(tmp.ptr());
+	g_pRegisteredChannelDataBase->save(tmp);
 }
 
 void KviApp::saveNickServ()
 {
-	KviStr tmp;
+	QString tmp;
 	getLocalKvircDirectory(tmp,Config,KVI_CONFIGFILE_NICKSERVDATABASE);
-	g_pNickServRuleSet->save(tmp.ptr());
+	g_pNickServRuleSet->save(tmp);
 }
 
 void KviApp::saveSharedFiles()
 {
-	KviStr tmp;
+	QString tmp;
 	getLocalKvircDirectory(tmp,Config,KVI_CONFIGFILE_SHAREDFILES);
-	g_pSharedFilesManager->save(tmp.ptr());
+	g_pSharedFilesManager->save(tmp);
 }
 
 void KviApp::saveActions()
 {
-	KviStr tmp;
+	QString tmp;
 	getLocalKvircDirectory(tmp,Config,KVI_CONFIGFILE_USERACTIONS);
-	KviActionManager::instance()->save(tmp.ptr());
+	KviActionManager::instance()->save(tmp);
+}
+
+void KviApp::saveIdentities()
+{
+	QString tmp;
+	getLocalKvircDirectory(tmp,Config,KVI_CONFIGFILE_IDENTITIES);
+	KviUserIdentityManager::instance()->save(tmp);
 }
 
 void KviApp::saveConfiguration()
@@ -1451,6 +1516,7 @@ void KviApp::saveConfiguration()
 	// this is NOT called when the application is closing down
 	KviCustomToolBarManager::instance()->storeVisibilityState();
 	saveOptions();
+	saveIdentities();
 	saveActions();
 	saveIrcServerDataBase();
 	saveProxyDataBase();
@@ -1475,7 +1541,7 @@ void KviApp::saveConfiguration()
 
 void KviApp::autoConnectToServers()
 {
-	KviPtrList<KviIrcServer> * l = g_pIrcServerDataBase->autoConnectOnStartupServers();
+	KviPointerList<KviIrcServer> * l = g_pIrcServerDataBase->autoConnectOnStartupServers();
 	if(l)
 	{
 		for(KviIrcServer * s = l->first();s;s = l->next())
@@ -1489,7 +1555,7 @@ void KviApp::autoConnectToServers()
 		g_pIrcServerDataBase->clearAutoConnectOnStartupServers();
 	}
 	
-	KviPtrList<KviIrcServerDataBaseRecord> * lr = g_pIrcServerDataBase->autoConnectOnStartupNetworks();
+	KviPointerList<KviIrcServerDataBaseRecord> * lr = g_pIrcServerDataBase->autoConnectOnStartupNetworks();
 	if(lr)
 	{
 		for(KviIrcServerDataBaseRecord * r = lr->first();r;r = lr->next())
@@ -1548,7 +1614,7 @@ void KviApp::destroyFrame()
 
 bool KviApp::connectionExists(KviIrcConnection *cnn)
 {
-	QAsciiDictIterator<KviWindow> it(*g_pGlobalWindowDict);
+	KviPointerHashTableIterator<const char *,KviWindow> it(*g_pGlobalWindowDict);
 
 	while(it.current())
 	{
@@ -1561,7 +1627,7 @@ bool KviApp::connectionExists(KviIrcConnection *cnn)
 
 bool KviApp::windowExists(KviWindow *wnd)
 {
-	QAsciiDictIterator<KviWindow> it(*g_pGlobalWindowDict);
+	KviPointerHashTableIterator<const char *,KviWindow> it(*g_pGlobalWindowDict);
 
 	while(it.current())
 	{
@@ -1578,7 +1644,7 @@ unsigned int KviApp::windowCount()
 
 KviConsole * KviApp::findConsole(QString &server,QString &nick)
 {
-	QAsciiDictIterator<KviWindow> it(*g_pGlobalWindowDict);
+	KviPointerHashTableIterator<const char *,KviWindow> it(*g_pGlobalWindowDict);
 
 	while(it.current())
 	{
@@ -1623,7 +1689,7 @@ KviConsole * KviApp::findConsole(KviStr &server,KviStr &nick)
 
 void KviApp::restartLagMeters()
 {
-	QAsciiDictIterator<KviWindow> it(*g_pGlobalWindowDict);
+	KviPointerHashTableIterator<const char *,KviWindow> it(*g_pGlobalWindowDict);
 
 	while(it.current())
 	{
@@ -1638,7 +1704,7 @@ void KviApp::restartLagMeters()
 
 void KviApp::restartNotifyLists()
 {
-	QAsciiDictIterator<KviWindow> it(*g_pGlobalWindowDict);
+	KviPointerHashTableIterator<const char *,KviWindow> it(*g_pGlobalWindowDict);
 
 	while(it.current())
 	{
@@ -1653,7 +1719,7 @@ void KviApp::restartNotifyLists()
 
 void KviApp::resetAvatarForMatchingUsers(KviRegisteredUser * u)
 {
-	QAsciiDictIterator<KviWindow> it(*g_pGlobalWindowDict);
+	KviPointerHashTableIterator<const char *,KviWindow> it(*g_pGlobalWindowDict);
 
 	while(it.current())
 	{
@@ -1667,7 +1733,7 @@ void KviApp::resetAvatarForMatchingUsers(KviRegisteredUser * u)
 
 KviConsole * KviApp::findConsole(unsigned int ircContextId)
 {
-	QAsciiDictIterator<KviWindow> it(*g_pGlobalWindowDict);
+	KviPointerHashTableIterator<const char *,KviWindow> it(*g_pGlobalWindowDict);
 
 	while(it.current())
 	{
@@ -1693,7 +1759,7 @@ KviConsole * KviApp::topmostConnectedConsole()
 
 	// try ANY connected console
 
-	QAsciiDictIterator<KviWindow> it(*g_pGlobalWindowDict);
+	KviPointerHashTableIterator<const char *,KviWindow> it(*g_pGlobalWindowDict);
 
 	while(it.current())
 	{
@@ -1712,14 +1778,15 @@ KviWindow * KviApp::findWindow(const char * windowId)
 	return g_pGlobalWindowDict->find(windowId);
 }
 
-KviWindow * KviApp::findWindowByCaption(const QString &windowCaption)
+KviWindow * KviApp::findWindowByCaption(const QString &windowCaption,int iContextId)
 {
-	QAsciiDictIterator<KviWindow> it(*g_pGlobalWindowDict);
+	KviPointerHashTableIterator<const char *,KviWindow> it(*g_pGlobalWindowDict);
 
 	while(it.current())
 	{
-		if(KviQString::equalCI(windowCaption,it.current()->plainTextCaption()))
-			return it.current();
+		if(KviQString::equalCI(windowCaption,it.current()->plainTextCaption()) && 
+			(iContextId==-1 || it.current()->context()->id() == iContextId))
+				return it.current();
 		++it;
 	}
 	return 0;
@@ -1771,6 +1838,12 @@ static void merge_to_stringlist_option(const QString &item,int iOption,int iMaxE
 	KVI_OPTION_STRINGLIST(iOption).prepend(item);
 }
 
+void KviApp::addRecentUrl(const QString& text)
+{
+	merge_to_stringlist_option(text,KviOption_stringlistRecentIrcUrls,50);
+	emit(recentUrlsChanged());
+}
+
 void KviApp::addRecentNickname(const char * newNick)
 {
 	QString nk(newNick);
@@ -1779,7 +1852,6 @@ void KviApp::addRecentNickname(const char * newNick)
 
 void KviApp::addRecentNickname(const QString& newNick)
 {
-	
 	merge_to_stringlist_option(newNick,KviOption_stringlistRecentNicknames,KVI_MAX_RECENT_NICKNAMES);
 }
 
@@ -1803,7 +1875,7 @@ void KviApp::buildRecentChannels()
 {
 	if(m_pRecentChannelsDict)
 		delete m_pRecentChannelsDict;
-	m_pRecentChannelsDict = new QAsciiDict<QStringList>;
+	m_pRecentChannelsDict = new KviPointerHashTable<const char *,QStringList>;
 	m_pRecentChannelsDict->setAutoDelete(TRUE);
 	QString szChan,szNet;
 	for ( 
@@ -1838,7 +1910,7 @@ void KviApp::saveRecentChannels()
 	if(!m_pRecentChannelsDict) return;
 	QString szTmp;
 	KVI_OPTION_STRINGLIST(KviOption_stringlistRecentChannels).clear();
-	QAsciiDictIterator<QStringList> it( *m_pRecentChannelsDict );
+	KviPointerHashTableIterator<const char *,QStringList> it( *m_pRecentChannelsDict );
 	for( ; it.current(); ++it )
 	{
 		for ( QStringList::Iterator it_str = it.current()->begin(); it_str != it.current()->end(); ++it_str ) {
@@ -1857,13 +1929,12 @@ QStringList* KviApp::getRecentChannels(const QString& net)
 }
 
 
-void KviApp::addRecentServer(const char * server)
+void KviApp::addRecentServer(const QString& server)
 {
-	QString sr(server);
-	merge_to_stringlist_option(sr,KviOption_stringlistRecentServers,KVI_MAX_RECENT_SERVERS);
+	merge_to_stringlist_option(server,KviOption_stringlistRecentServers,KVI_MAX_RECENT_SERVERS);
 }
 
-void KviApp::fillRecentServersPopup(QPopupMenu * m)
+void KviApp::fillRecentServersPopup(KviTalPopupMenu * m)
 {
 // FIXME: #warning "MAYBE DISABLE THE SERVERS THAT WE ARE ALREADY CONNECTED TO ?"
 	m->clear();
@@ -1873,7 +1944,7 @@ void KviApp::fillRecentServersPopup(QPopupMenu * m)
 	}
 }
 
-void KviApp::fillRecentNicknamesPopup(QPopupMenu * m,KviConsole * pConsole)
+void KviApp::fillRecentNicknamesPopup(KviTalPopupMenu * m,KviConsole * pConsole)
 {
 	m->clear();
 	int id;
@@ -1893,7 +1964,7 @@ void KviApp::fillRecentNicknamesPopup(QPopupMenu * m,KviConsole * pConsole)
 	}
 }
 
-void KviApp::fillRecentChannelsPopup(QPopupMenu * m,KviConsole * pConsole)
+void KviApp::fillRecentChannelsPopup(KviTalPopupMenu * m,KviConsole * pConsole)
 {
 	m->clear();
 	int id;
@@ -1913,7 +1984,7 @@ void KviApp::fillRecentChannelsPopup(QPopupMenu * m,KviConsole * pConsole)
 
 
 /*
-void KviApp::fillRecentServersListBox(QListBox * l)
+void KviApp::fillRecentServersListBox(KviTalListBox * l)
 {
 	l->clear();
 	for(QStringList::Iterator it = KVI_OPTION_STRINGLIST(KviOption_stringlistRecentServers).begin(); it != KVI_OPTION_STRINGLIST(KviOption_stringlistRecentServers).end(); ++it)
