@@ -29,8 +29,9 @@
 #include "kvi_string.h"
 #include "kvi_qstring.h"
 #include "kvi_tal_application.h"
-#include "kvi_list.h"
+#include "kvi_pointerlist.h"
 #include "kvi_time.h"
+#include "kvi_pointerhashtable.h" // ?
 
 #define KVI_RECENT_CHANNELS_SEPARATOR ":"
 
@@ -47,9 +48,9 @@
 	class KviIpcSentinel;
 #endif // !COMPILE_NO_IPC
 
-class QPopupMenu;
+class KviTalPopupMenu;
 class QPixmap;
-class QListBox;
+class KviTalListBox;
 class QTextCodec;
 class QDomElement;
 
@@ -57,6 +58,7 @@ class KviConsole;
 class KviConfig;
 class KviRegisteredUser;
 class KviIrcConnection;
+class KviIrcServerDataBase;
 
 typedef struct _KviPendingAvatarChange
 {
@@ -67,19 +69,6 @@ typedef struct _KviPendingAvatarChange
 	QString      szHost;
 } KviPendingAvatarChange;
 
-typedef struct _KviThemeInfoTag
-{
-	QString szName; // name of the theme
-	QString szVersion; // version of the theme
-	QString szSubdirectory; // subdirectory of $LOCALKVIRCDIR/themes where the theme is saved to
-	QString szAbsoluteDirectory; // absolute directory where the theme should be saved to
-	QString szAuthor; // author of the theme
-	QString szDescription; // description of the theme
-	QString szDate; // theme creation date
-	QString szKvircVersion; // theme creation KVIrc version
-	bool    bIncludeMsgColors;
-} KviThemeInfo;
-
 #ifdef Unsorted
 	#undef Unsorted
 #endif
@@ -94,7 +83,7 @@ class KVIRC_API KviApp : public KviTalApplication
 	friend class KviSetupWizard; // this resides in a module!
 	Q_OBJECT
 public:
-	KviApp(int argc,char ** argv);
+	KviApp(int &argc,char ** argv);
 	~KviApp();
 
 protected:
@@ -105,9 +94,9 @@ protected:
 	bool                            m_bFirstTimeRun;
 	KviWindow                     * m_pActiveWindow;
 	bool                            m_bUpdateGuiPending;
-	KviPtrList<KviPendingAvatarChange> * m_pPendingAvatarChanges;
+	KviPointerList<KviPendingAvatarChange> * m_pPendingAvatarChanges;
 	bool                            m_bSetupDone;
-	QAsciiDict<QStringList>        *m_pRecentChannelsDict;
+	KviPointerHashTable<const char *,QStringList>     * m_pRecentChannelsDict;
 #ifdef COMPILE_PSEUDO_TRANSPARENCY
 	bool                            m_bUpdatePseudoTransparencyPending;
 #endif
@@ -132,7 +121,7 @@ public:
 		Avatars,      DefScript,     License,
 		Modules,      ConfigScripts, Filters,
 		Tmp,          Locale,        Themes,
-		Classes
+		Classes,      SmallIcons,    EasyPlugins
 	};
 
 public:
@@ -161,6 +150,7 @@ public:
 	bool firstTimeRun(){ return m_bFirstTimeRun; };
 	void setupBegin();
 	void setupFinish();
+	inline void emitRecentUrlsChanged() { emit(recentUrlsChanged()); };
 
 	// kvi_app.cpp (Saving options)
 	void saveIrcServerDataBase();
@@ -181,18 +171,12 @@ public:
 	void saveToolBars();
 	void saveActions();
 	void saveScriptAddons();
+	void saveIdentities();
 
 	// kvi_options.cpp : Options saving and loading (kvi.main.conf))
 	void loadOptions();
 	void saveOptions();
 
-	void saveTheme(KviThemeInfo &opt);
-	void saveXmlTheme(KviThemeInfo &opt,const QString& filename);
-	void loadXmlTheme(QDomElement *pElement);
-	// returns false if the theme informations can't be loaded or the theme dir do not appear to contain a valid theme
-	bool loadThemeInfo(const QString &themeDir,KviThemeInfo &inf);
-	void loadTheme(const QString &themeDir);
-
 	void listAvailableOptions(KviWindow *wnd);
 	bool getOptionString(const char * optName,QString &buffer);
 	bool setOptionValue(const char * optName,const QString &value);
@@ -205,9 +189,9 @@ public:
 	void getGlobalKvircDirectory(KviStr &szData,KvircSubdir dir,const QString &appendFile = QString::null);
 	void getLocalKvircDirectory(KviStr  &szData,KvircSubdir dir,const QString &appendFile = QString::null,bool bCreateIfNeeded = true);
 	void getLocalKvircDirectory(QString &szData,KvircSubdir dir,const QString &appendFile = QString::null,bool bCreateIfNeeded = true);
-	void getTmpFileName(KviStr &szBuffer,const char * pattern = 0);
+	void getTmpFileName(QString &szBuffer,const QString &szEndingFileName = QString::null);
 	bool trashFile(const char *filename);
-	void getChannelDumpLogFileName(KviStr &str);
+	void getChannelDumpLogFileName(QString &str);
 
 	static QTextCodec * defaultTextCodec();
 
@@ -223,13 +207,15 @@ public:
 	
 	bool findImage(KviStr &szRetPath,const char *filename);
 	bool findImage(QString &szRetPath,const char *filename);
+	bool findImageThemeOnlyCompat(QString &szRetPath,const char *filename); // temporary compat, will be removed soon (do not use)
+	bool findSmallIcon(QString &szRetPath,const char *filename);
 	// tries to map the full path filename to one of the KVIrc's mapped directories
 	// if it doesn't succeed it just returns the complete filename in szRetPath
 	bool mapImageFile(KviStr &szRetPath,const char * filename);
 	bool mapImageFile(QString &szRetPath,const char * filename);
 
 	//void getDefaultDccSaveFilePath(KviStr &path,const char *filename);
-	void completeDirectory(const QString &word,KviPtrList<QString> * matches);
+	void completeDirectory(const QString &word,KviPointerList<QString> * matches);
 	//
 	// Returns a config path suitable for reading (at least)
 	// First lookups the user local config directory,
@@ -240,10 +226,11 @@ public:
 	// directory is used
 	//
 	bool getReadOnlyConfigPath(KviStr &buffer,const char *config_name,KvircSubdir sbd = Config,bool bNoFail = false);
+	bool getReadOnlyConfigPath(QString &buffer,const char *config_name,KvircSubdir sbd = Config,bool bNoFail = false);
 
 	// kvi_app.cpp : Window stuff
 	KviWindow       * findWindow(const char * windowId);
-	KviWindow       * findWindowByCaption(const QString &windowCaption);
+	KviWindow       * findWindowByCaption(const QString &windowCaption,int iContextId=-1);
 	KviConsole      * findConsole(unsigned int ircContextId);
 	KviConsole      * findConsole(KviStr & server,KviStr & nick);
 	KviConsole      * findConsole(QString & servr,QString & nick);
@@ -280,14 +267,16 @@ public:
 	void addRecentChannel(const QString& chan,const QString& net);
 	QStringList* getRecentChannels(const QString& net);
 	
-	void addRecentServer(const char * server);
-	void fillRecentServersPopup(QPopupMenu * m);
-	void fillRecentNicknamesPopup(QPopupMenu * m,KviConsole * pConsole);
-	void fillRecentChannelsPopup(QPopupMenu * m,KviConsole * pConsole);
+	void addRecentServer(const QString& server);
+	void fillRecentServersPopup(KviTalPopupMenu * m);
+	void fillRecentNicknamesPopup(KviTalPopupMenu * m,KviConsole * pConsole);
+	void fillRecentChannelsPopup(KviTalPopupMenu * m,KviConsole * pConsole);
 	
 	void autoConnectToServers();
 	
 	void checkSuggestRestoreDefaultScript();
+	
+	void loadDefaultScript();
 protected:
 	void buildRecentChannels();
 	void saveRecentChannels();
@@ -305,6 +294,7 @@ public slots:
 	void kdeRootPixmapChanged(int iDesktop);
 	void updatePseudoTransparency();
 	void restoreDefaultScript();
+	void addRecentUrl(const QString& text);
 private:
 	void createSplashScreen();
 	void destroySplashScreen();
@@ -315,6 +305,12 @@ private:
 	bool findLocalKvircDirectory();
 	bool checkGlobalKvircDirectory(const QString);
 	bool checkLocalKvircDirectory(const QString);
+	bool checkFileAssociations();
+	void setupFileAssociations();
+
+	bool checkUriAssociations(char * proto);
+	void setupUriAssociations(char * proto);
+
 	void saveKvircDirectory();
 
 	// kvi_app.cpp : GUI stuff
@@ -327,7 +323,6 @@ private:
 		void downloadKdeRootPixmap();
 	#endif //COMPILE_KDE_SUPPORT
 #endif //COMPILE_PSEUDO_TRANSPARENCY
-	void loadDefaultScript();
 private:
 	// kvi_app.cpp : parts of setup()
 	void loadRecentEntries();
@@ -338,10 +333,12 @@ private:
 	void createFrame();
 signals:
 	void reloadImages();
+	void recentUrlsChanged();
 };
 
 #ifndef _KVI_APP_CPP_
 	extern KVIRC_API KviApp * g_pApp;
+	extern KVIRC_API KviIrcServerDataBase * g_pIrcServerDataBase;
 #endif
 
 #endif //_KVI_APP_H_
