@@ -4,7 +4,7 @@
 //   Creation date : Thu Dec 24 1998 04:05:26 by Szymon Stefanek
 //
 //   This file is part of the Kvirc irc client distribution
-//   Copyright (C) 1999-2002 Szymon Stefanek (pragma at kvirc dot net)
+//   Copyright (C) 1998-2006 Szymon Stefanek (pragma at kvirc dot net)
 //
 //   This program is FREE software. You can redistribute it and/or
 //   modify it under the terms of the GNU General Public License
@@ -33,9 +33,11 @@
 #include "kvi_time.h"
 #include "kvi_options.h"
 #include "kvi_defaults.h"
+#include "kvi_iconmanager.h"
 
 #include <qdir.h>
 #include <qfileinfo.h>
+#include <qdatetime.h>
 
 extern KviMediaManager * g_pMediaManager;
 
@@ -52,8 +54,9 @@ void KviApp::getGlobalKvircDirectory(QString &szData,KvircSubdir dir,const QStri
 		case Pics          : szData.append("pics");                                                    break;
 		case Modules       :
 		case Plugins       : szData.append("modules");                                                 break;
-		case ConfigPlugins : KviQString::appendFormatted(szData,"config%smodules",KVI_PATH_SEPARATOR);       break;
-		case ConfigScripts : KviQString::appendFormatted(szData,"config%sscripts",KVI_PATH_SEPARATOR);       break;
+		case EasyPlugins   : szData.append("easyplugins");                                             break;
+		case ConfigPlugins : KviQString::appendFormatted(szData,"config%smodules",KVI_PATH_SEPARATOR); break;
+		case ConfigScripts : KviQString::appendFormatted(szData,"config%sscripts",KVI_PATH_SEPARATOR); break;
 		case Help          :
 			szData.append("help");
 			{
@@ -68,7 +71,7 @@ void KviApp::getGlobalKvircDirectory(QString &szData,KvircSubdir dir,const QStri
 				}
 			}
 		break;
-		case HelpEN        : KviQString::appendFormatted(szData,"help%sen",KVI_PATH_SEPARATOR);              break;
+		case HelpEN        : KviQString::appendFormatted(szData,"help%sen",KVI_PATH_SEPARATOR);        break;
 		case HelpNoIntl    : szData.append("help");                                                    break;
 		case Log           : debug("WARNING Global log directory requested!");                         break;
 		case Incoming      : debug("WARNING Global incoming directory requested!");                    break;
@@ -86,6 +89,7 @@ void KviApp::getGlobalKvircDirectory(QString &szData,KvircSubdir dir,const QStri
 		case Tmp           : debug("WARNING Global tmp directory requested!");                         break;
 		case Themes        : szData.append("themes");                                                  break;
 		case Classes       : szData.append("classes");                                                 break;
+		case SmallIcons    : szData.append("pics"KVI_PATH_SEPARATOR KVI_SMALLICONS_SUBDIRECTORY);      break;
 	}
 
 	if(!appendFile.isEmpty())
@@ -106,6 +110,7 @@ void KviApp::getLocalKvircDirectory(QString &szData,KvircSubdir dir,const QStrin
 	{
 		case None          :                                                                     break;
 		case Pics          : szData.append("pics");                                              break;
+		case EasyPlugins   : szData.append("easyplugins");                                             break;
 		case Config        : szData.append("config");                                            break;
 		case ConfigPlugins : szData.append("config"KVI_PATH_SEPARATOR"modules");                 break;
 		case ConfigScripts : szData.append("config"KVI_PATH_SEPARATOR"scripts");                 break;
@@ -157,6 +162,7 @@ void KviApp::getLocalKvircDirectory(QString &szData,KvircSubdir dir,const QStrin
 		case Themes        : szData.append("themes");                                            break;
 		case DefScript     : szData.append("defscript");  /* should never happen! */             break;
 		case Classes       : szData.append("classes");                                           break;
+		case SmallIcons    : szData.append("pics"KVI_PATH_SEPARATOR KVI_SMALLICONS_SUBDIRECTORY); break;
 	}
 	if(bCreateIfNeeded)KviFileUtils::makeDir(szData);
 
@@ -187,19 +193,21 @@ void KviApp::getLocalKvircDirectory(KviStr &szData,KvircSubdir dir,const QString
 	szData=szBuffer;
 }
 
-void KviApp::getTmpFileName(KviStr &szBuffer,const char * pattern)
+void KviApp::getTmpFileName(QString &szBuffer,const QString &szEndingFileName)
 {
-	KviStr tmp;
+	QString tmp;
 	getLocalKvircDirectory(tmp,Tmp);
-	tmp.ensureLastCharIs(KVI_PATH_SEPARATOR_CHAR);
+	KviQString::ensureLastCharIs(tmp,KVI_PATH_SEPARATOR_CHAR);
 
 	struct timeval tmv;
 	kvi_gettimeofday(&tmv,0);
 
+	QString szFileName = szEndingFileName.isNull() ? QString("file.tmp") : szEndingFileName;
 	do {
-		szBuffer.append(KviStr::Format,"kvirc_%d_%s",tmv.tv_usec,pattern ? pattern : "file.tmp");
+		szBuffer = tmp;
+		KviQString::appendFormatted(szBuffer,"kvirc_%d_%Q",tmv.tv_usec,&szFileName);
 		tmv.tv_usec++;
-	} while(KviFileUtils::fileExists(szBuffer.ptr()));
+	} while(KviFileUtils::fileExists(szBuffer));
 }
 
 //====================== trashFile ====================//
@@ -235,7 +243,7 @@ bool KviApp::trashFile(const char *filename)
 	return KviFileUtils::renameFile(filename,trashFile.ptr());
 }
 
-void KviApp::completeDirectory(const QString &word,KviPtrList<QString> * matches)
+void KviApp::completeDirectory(const QString &word,KviPointerList<QString> * matches)
 {
 	QString szDir = word;
 	QString szFile = word;
@@ -296,13 +304,14 @@ void KviApp::completeDirectory(const QString &word,KviPtrList<QString> * matches
 // Returns a valid filename for the channel dump log
 //
 
-void KviApp::getChannelDumpLogFileName(KviStr &str)
+void KviApp::getChannelDumpLogFileName(QString &str)
 {
 	unsigned int logN = 0;
-	KviStr fPrefix="kick_";
+	QString fPrefix="kick_";
 	do{
-		KviStr fName(KviStr::Format,"%s%u.log",fPrefix.ptr(),logN);
-		getLocalKvircDirectory(str,Log,fName.ptr());
+		QString fName;
+		KviQString::sprintf(fName,"%Q%u.log",&fPrefix,logN);
+		getLocalKvircDirectory(str,Log,fName);
 		logN++;
 		if(logN > 9999)
 		{
@@ -310,8 +319,8 @@ void KviApp::getChannelDumpLogFileName(KviStr &str)
 			fPrefix+="x";
 			logN = 0;
 		}
-	} while(KviFileUtils::fileExists(str.ptr()));
-	kvi_adjustFilePath(str);
+	} while(KviFileUtils::fileExists(str));
+	KviFileUtils::adjustFilePath(str);
 }
 
 bool KviApp::findFileByMediaType(KviStr &szRetPath,const char * filename)
@@ -334,7 +343,9 @@ bool KviApp::findFileByMediaType(KviStr &szRetPath,const char * filename)
 				{
 					g_pMediaManager->unlock();
 					//if(retMediaType)*retMediaType = mt;
-					kvi_adjustFilePath(szRetPath);
+					QString szTmp = szRetPath.ptr(); // FIXME
+					KviFileUtils::adjustFilePath(szTmp);
+					szRetPath = szTmp;
 					return true;
 				} // else mime type not matched...we should not be looking there!
 			}
@@ -359,7 +370,9 @@ bool KviApp::findUserFile(KviStr &szRetPath,const char *filename)
 	if(kvi_isAbsolutePath(filename))
 	{
 		szRetPath=filename;
-		kvi_adjustFilePath(szRetPath);
+		QString szTmp = szRetPath.ptr(); // FIXME
+		KviFileUtils::adjustFilePath(szTmp);
+		szRetPath = szTmp;
 		return KviFileUtils::fileExists(filename);
 	}
 
@@ -564,19 +577,17 @@ bool KviApp::findImage(QString &szRetPath,const char *filename)
 
 		getGlobalKvircDirectory(szRetPath,KviApp::Themes,szTmp);
 		if(KviFileUtils::fileExists(szRetPath))return true;
-	} //else {
-		//debug("NO PATH YET");
-	//}
+	}
 
 	int i;
 
-	for(i= 0;i<2; i++)
+	for(i=0;i<2;i++)
 	{
 		getLocalKvircDirectory(szRetPath,pics_localsubdirs[i],filename);
 		if(KviFileUtils::fileExists(szRetPath))return true;
 	}
 
-	for(i= 0;i<2; i++)
+	for(i=0;i<2;i++)
 	{
 		getGlobalKvircDirectory(szRetPath,pics_globalsubdirs[i],filename);
 		if(KviFileUtils::fileExists(szRetPath))return true;
@@ -595,6 +606,87 @@ bool KviApp::findImage(QString &szRetPath,const char *filename)
 	return false;
 }
 
+bool KviApp::findImageThemeOnlyCompat(QString &szRetPath,const char *filename)
+{
+	// if we have a theme, look it up as first
+	if(!KVI_OPTION_STRING(KviOption_stringIconThemeSubdir).isEmpty())
+	{
+		QString szTmp = KVI_OPTION_STRING(KviOption_stringIconThemeSubdir);
+		szTmp.append(KVI_PATH_SEPARATOR_CHAR);
+		szTmp.append(filename);
+
+		getLocalKvircDirectory(szRetPath,KviApp::Themes,szTmp);
+		if(KviFileUtils::fileExists(szRetPath))return true;
+
+		getGlobalKvircDirectory(szRetPath,KviApp::Themes,szTmp);
+		if(KviFileUtils::fileExists(szRetPath))return true;
+	}
+
+	getLocalKvircDirectory(szRetPath,KviApp::Pics,filename);
+	if(KviFileUtils::fileExists(szRetPath))return true;
+
+
+	if(findImageInImageSearchPath(szRetPath,filename))return true;
+
+	szRetPath = filename;
+
+	return false;
+}
+
+bool KviApp::findSmallIcon(QString &szRetPath,const char *filename)
+{
+	// this is a bit optimized for the small builtin icons
+	// looks up less places.
+
+	//if(kvi_isAbsolutePath(filename))
+	//{
+		// BUG!.. we should never
+		//szRetPath=filename;
+		//return KviFileUtils::fileExists(filename);
+	//}
+
+	// if we have a theme, look it up as first
+	if(!KVI_OPTION_STRING(KviOption_stringIconThemeSubdir).isEmpty())
+	{
+		QString szTmp = KVI_OPTION_STRING(KviOption_stringIconThemeSubdir);
+		szTmp.append(KVI_PATH_SEPARATOR_CHAR);
+		szTmp.append(KVI_SMALLICONS_SUBDIRECTORY);
+		szTmp.append(KVI_PATH_SEPARATOR_CHAR);
+		szTmp.append(filename);
+
+		getLocalKvircDirectory(szRetPath,KviApp::Themes,szTmp);
+		if(KviFileUtils::fileExists(szRetPath))return true;
+
+		getGlobalKvircDirectory(szRetPath,KviApp::Themes,szTmp);
+		if(KviFileUtils::fileExists(szRetPath))return true;
+	}
+
+	int i;
+
+	// unlikely
+	getLocalKvircDirectory(szRetPath,KviApp::SmallIcons,filename);
+	if(KviFileUtils::fileExists(szRetPath))return true;
+
+	getLocalKvircDirectory(szRetPath,KviApp::Pics,filename);
+	if(KviFileUtils::fileExists(szRetPath))return true;
+
+	// likely
+	getGlobalKvircDirectory(szRetPath,KviApp::SmallIcons,filename);
+	if(KviFileUtils::fileExists(szRetPath))return true;
+
+	if(findImageInImageSearchPath(szRetPath,filename))return true;
+
+	// Last resort... bleah :/
+	szRetPath = QDir::homeDirPath();
+	KviQString::ensureLastCharIs(szRetPath,KVI_PATH_SEPARATOR_CHAR);
+	szRetPath.append(filename);
+	if(KviFileUtils::fileExists(szRetPath))return true;
+
+	szRetPath = filename;
+
+	return false;
+}
+
 
 //================== getReadOnlyConfigPath ====================//
 //
@@ -602,16 +694,25 @@ bool KviApp::findImage(QString &szRetPath,const char *filename)
 //
 
 bool KviApp::getReadOnlyConfigPath(KviStr &buffer,const char *config_name,KvircSubdir sbd,bool bNoFail)
+{
+	// DEPRECATED
+	QString tmp;
+	bool bRet = getReadOnlyConfigPath(tmp,config_name,sbd,bNoFail);
+	buffer = tmp;
+	return bRet;
+}
+
+bool KviApp::getReadOnlyConfigPath(QString &buffer,const char *config_name,KvircSubdir sbd,bool bNoFail)
 {
 	// Take a look in the local directory....
 	getLocalKvircDirectory(buffer,sbd,config_name);
 	//debug("%s %s %i |%s| %i",__FILE__,__FUNCTION__,__LINE__,buffer.ptr(),KviFileUtils::fileExists(buffer.ptr()));
-	if(!KviFileUtils::fileExists(buffer.ptr()))
+	if(!KviFileUtils::fileExists(buffer))
 	{
 		// No saved config yet... check for defaults
-		KviStr tmp;
+		QString tmp;
 		getGlobalKvircDirectory(tmp,sbd,config_name);
-		if(!KviFileUtils::fileExists(tmp.ptr()))
+		if(!KviFileUtils::fileExists(tmp))
 		{
 			// No defaults...no such config file at all.
 			if(bNoFail)getLocalKvircDirectory(buffer,sbd,config_name);
