@@ -37,7 +37,6 @@
 #include "kvi_mdimanager.h"
 #include "kvi_irctoolbar.h"
 #include "kvi_locale.h"
-//#include "kvi_uparser.h"
 #include "kvi_ircurl.h"
 #include "kvi_ircconnection.h"
 #include "kvi_ircconnectionuserinfo.h"
@@ -47,7 +46,7 @@
 
 #include "kvi_kvs_script.h"
 
-#include <qpopupmenu.h>
+#include "kvi_tal_popupmenu.h"
 #include <qobject.h>
 
 
@@ -69,6 +68,7 @@
 // Ctrl+Alt+H : Show help index
 // Ctrl+Alt+R : Edit regusers
 // Ctrl+Alt+M : Manage Script Addons
+// Ctrl+Alt+L : Manage Themes
 
 void register_core_actions(KviActionManager * m)
 {
@@ -210,6 +210,17 @@ void register_core_actions(KviActionManager * m)
 		0,
 		"Ctrl+Alt+T");
 
+	SCRIPT_ACTION(
+		KVI_COREACTION_MANAGETHEMES,
+		"theme.dialog",
+		__tr2qs("Manage Themes..."),
+		__tr2qs("Allows you to manage the themes"),
+		KviActionManager::categorySettings(),
+		"kvi_bigicon_theme.png",
+		KVI_SMALLICON_THEME,
+		0,
+		"Ctrl+Alt+L");
+
 	SCRIPT_ACTION(
 		KVI_COREACTION_TOOLBAREDITOR,
 		"toolbareditor.open",
@@ -355,6 +366,17 @@ void register_core_actions(KviActionManager * m)
 		0,
 		QString::null);
 
+	SCRIPT_ACTION(
+		KVI_COREACTION_SCREENSHOT,
+		"theme.screenshot",
+		__tr2qs("Acquire Screenshot"),
+		__tr2qs("Acquires a Screenshot of the KVIrc main window"),
+		KviActionManager::categoryGeneric(),
+		"kvi_bigicon_screenshot.png",
+		KVI_SMALLICON_SCREENSHOT,
+		0,
+		QString::null);
+
 
 	SLOT_ACTION(
 		KVI_COREACTION_CASCADEWINDOWS,
@@ -442,12 +464,15 @@ void KviIrcContextDisplayAction::setup()
 	connect(g_pFrame,SIGNAL(activeConnectionLagChanged()),this,SLOT(activeContextStateChanged()));
 }
 
-bool KviIrcContextDisplayAction::addToPopupMenu(QPopupMenu *p)
+bool KviIrcContextDisplayAction::addToPopupMenu(KviTalPopupMenu *p)
 {
+	// QT4SUX: Widgets can be no longer added to popup menus.. what about labels ?
+#ifndef COMPILE_USE_QT4
 	if(!setupDone())setup();
 	KviIrcContextDisplay * w = new KviIrcContextDisplay(p,"kvirc.irccontextdisplay");
 	registerWidget(w);
 	p->insertItem(w);
+#endif
 	return true;
 }
 
@@ -455,6 +480,9 @@ QWidget * KviIrcContextDisplayAction::addToCustomToolBar(KviCustomToolBar *t)
 {
 	if(!setupDone())setup();
 	KviIrcContextDisplay * w = new KviIrcContextDisplay(t,"kvirc.irccontextdisplay");
+#ifdef COMPILE_USE_QT4
+	t->addWidget(w);
+#endif
 	registerWidget(w);
 	return w;
 }
@@ -498,7 +526,7 @@ KviSeparatorAction::KviSeparatorAction(QObject * pParent)
 }
 
 
-bool KviSeparatorAction::addToPopupMenu(QPopupMenu *p)
+bool KviSeparatorAction::addToPopupMenu(KviTalPopupMenu *p)
 {
 	if(!setupDone())setup();
 	p->insertSeparator();
@@ -510,6 +538,9 @@ QWidget * KviSeparatorAction::addToCustomToolBar(KviCustomToolBar *t)
 	if(!setupDone())setup();
 	QWidget * w = new KviCustomToolBarSeparator(t,"kvirc.separator");
 	registerWidget(w);
+#ifdef COMPILE_USE_QT4
+	t->addWidget(w);
+#endif
 	return w;
 }
 
@@ -544,7 +575,7 @@ void KviConnectAction::activeContextChanged()
 void KviConnectAction::activeContextStateChanged()
 {
 
-	KviPtrList<QWidget> * bl = widgetList();
+	KviPointerList<QWidget> * bl = widgetList();
 	if(!bl)return;
 
 	QPixmap * p;
@@ -605,7 +636,7 @@ void KviConnectAction::activate()
 	if(c)c->connectOrDisconnect();
 }
 
-bool KviConnectAction::addToPopupMenu(QPopupMenu *p)
+bool KviConnectAction::addToPopupMenu(KviTalPopupMenu *p)
 {
 	if(!setupDone())setup();
 	KviIrcContext * c = g_pFrame->activeContext();
@@ -658,6 +689,9 @@ QWidget * KviConnectAction::addToCustomToolBar(KviCustomToolBar *t)
 			m_szConnectString,
 			this,SLOT(activate()),t,name());
 	registerWidget(b);
+#ifdef COMPILE_USE_QT4
+	t->addWidget(b);
+#endif
 	activeContextStateChanged();
 	return b;
 }
@@ -700,7 +734,7 @@ void KviSubmenuAction::setup()
 	KviKvsAction::setup();
 	if(!m_pPopup)
 	{
-		m_pPopup = new QPopupMenu();
+		m_pPopup = new KviTalPopupMenu();
 		connect(m_pPopup,SIGNAL(aboutToShow()),this,SLOT(popupAboutToShow()));
 		connect(m_pPopup,SIGNAL(activated(int)),this,SLOT(popupActivated(int)));
 	}
@@ -714,7 +748,7 @@ void KviSubmenuAction::popupActivated(int)
 {
 }
 
-bool KviSubmenuAction::addToPopupMenu(QPopupMenu *p)
+bool KviSubmenuAction::addToPopupMenu(KviTalPopupMenu *p)
 {
 	if(!setupDone())setup();
 	int id = p->insertItem(*(smallIcon()),visibleName(),m_pPopup);
@@ -731,8 +765,14 @@ QWidget * KviSubmenuAction::addToCustomToolBar(KviCustomToolBar *t)
 			visibleName(),
 			this,SLOT(activate()),t,name());
 	b->setPopup(m_pPopup);
-	b->setPopupDelay(1);
+	
+#ifdef COMPILE_USE_QT4
+	b->setPopupMode( scriptCode().isEmpty() ? QToolButton::InstantPopup :  QToolButton::MenuButtonPopup);
+	t->addWidget(b);
+#else
 	b->setShowSubmenuIndicator(true);
+	b->setPopupDelay(1);
+#endif
 	registerWidget(b);
 	if(!isEnabled())b->setEnabled(false);
 	return b;
@@ -870,7 +910,7 @@ void KviConnectToServerAction::popupActivated(int id)
 		} else {
 			KviStr szCommand;
 			KviStr szText = text;
-			if(parseIrcUrl(szText.ptr(),szCommand,KVI_IRCURL_CONTEXT_THIS))
+			if(KviIrcUrl::parse(szText.ptr(),szCommand,KVI_IRCURL_CONTEXT_THIS))
 			{
 				KviKvsScript::run(szCommand.ptr(),c);
 			}
@@ -885,7 +925,7 @@ void KviConnectToServerAction::popupActivated(int id)
 KviChangeUserModeAction::KviChangeUserModeAction(QObject * pParent)
 : KviSubmenuAction(pParent,
 	QString(KVI_COREACTION_USERMODEMENU),
-	QString("bug :D"),
+	QString(""),
 	__tr2qs("User Mode"),
 	__tr2qs("Shows a popup menu that allows quickly changing user modes"),
 	KviActionManager::categoryIrc(),
@@ -976,7 +1016,7 @@ void KviGoAwayAction::activeContextChanged()
 
 void KviGoAwayAction::activeContextStateChanged()
 {
-	KviPtrList<QWidget> * bl = widgetList();
+	KviPointerList<QWidget> * bl = widgetList();
 	if(!bl)return;
 
 	QPixmap * p;
@@ -1027,7 +1067,7 @@ void KviGoAwayAction::setup()
 	connect(g_pFrame,SIGNAL(activeConnectionAwayStateChanged()),this,SLOT(activeContextStateChanged()));
 }
 
-bool KviGoAwayAction::addToPopupMenu(QPopupMenu *p)
+bool KviGoAwayAction::addToPopupMenu(KviTalPopupMenu *p)
 {
 	if(!setupDone())setup();
 	KviIrcContext * c = g_pFrame->activeContext();
@@ -1071,6 +1111,9 @@ QWidget * KviGoAwayAction::addToCustomToolBar(KviCustomToolBar *t)
 			m_szAwayString,
 			this,SLOT(activate()),t,name());
 	registerWidget(b);
+#ifdef COMPILE_USE_QT4
+	t->addWidget(b);
+#endif
 	activeContextStateChanged();
 	return b;
 }
@@ -1088,7 +1131,7 @@ QWidget * KviGoAwayAction::addToCustomToolBar(KviCustomToolBar *t)
 KviIrcToolsAction::KviIrcToolsAction(QObject * pParent)
 : KviSubmenuAction(pParent,
 	QString(KVI_COREACTION_IRCTOOLS),
-	QString("bug"),
+	QString(""),
 	__tr2qs("Irc Tools"),
 	__tr2qs("Shows a popup menu with some IRC Tools"),
 	KviActionManager::categoryIrc(),
@@ -1124,7 +1167,7 @@ void KviIrcToolsAction::popupActivated(int id)
 KviIrcOperationsAction::KviIrcOperationsAction(QObject * pParent)
 : KviSubmenuAction(pParent,
 	QString(KVI_COREACTION_IRCACTIONS),
-	QString("bug"),
+	QString(""),
 	__tr2qs("Irc Actions"),
 	__tr2qs("Shows a popup menu with some IRC Actions"),
 	KviActionManager::categoryIrc(),
