@@ -29,11 +29,13 @@
 
 #include <qobject.h>
 
-#include "kvi_list.h"
+#include "kvi_pointerlist.h"
+#include "kvi_tal_listview.h"
 
 class KviFileTransfer;
 class KviWindow;
-class QPopupMenu;
+class KviTalPopupMenu;
+class QPainter;
 
 // This is for the external extension
 #define KVI_FILE_TRANSFER_WINDOW_EXTENSION_NAME "File transfer extension"
@@ -49,7 +51,7 @@ public:
 	KviFileTransferManager();
 	~KviFileTransferManager();
 protected:
-	KviPtrList<KviFileTransfer> * m_pTransferList;
+	KviPointerList<KviFileTransfer> * m_pTransferList;
 	KviWindow                   * m_pTransferWindow;
 protected:
 	static void cleanup();
@@ -60,7 +62,7 @@ public:
 	// might be zero!
 	KviWindow * transferWindow(){ return m_pTransferWindow; };
 	static KviFileTransferManager * instance();
-	KviPtrList<KviFileTransfer> * transferList(){ return m_pTransferList; };
+	KviPointerList<KviFileTransfer> * transferList(){ return m_pTransferList; };
 	void invokeTransferWindow(KviWindow * pWnd = 0,bool bCreateMinimized = false,bool bNoRaise = false);
 	void killAllTransfers();
 	void killTerminatedTransfers();
@@ -73,7 +75,6 @@ signals:
 #define COLUMN_FILEINFO 1
 #define COLUMN_PROGRESS 2
 
-class QListViewItem;
 
 class KVIRC_API KviFileTransfer : public QObject
 {
@@ -83,10 +84,10 @@ public:
 	~KviFileTransfer();
 protected:
 	int              m_iId;
-	QListViewItem  * m_pDisplayItem;
+	KviTalListViewItem  * m_pDisplayItem;
 public:
 	// This is called by KviFileTransferItem at any time
-	void setDisplayItem(QListViewItem * i){ m_pDisplayItem = i; };
+	void setDisplayItem(KviTalListViewItem * i){ m_pDisplayItem = i; };
 	int id(){ return m_iId; };
 	// this is just a convenience function : it's equivalent to !active()
 	bool terminated();
@@ -108,7 +109,7 @@ public:
 	virtual QString localFileName();
 	virtual QString retryCommand();
 	virtual int displayHeight(int iLineSpacing);
-	virtual void fillContextPopup(QPopupMenu * m,int column) = 0;
+	virtual void fillContextPopup(KviTalPopupMenu * m,int column) = 0;
 	virtual void die() = 0;
 };
 
