@@ -34,13 +34,20 @@
 #include "kvi_defaults.h"
 #include "kvi_locale.h"
 #include "kvi_fileutils.h"
+#include "kvi_options.h"
 
 #include <qlayout.h>
 #include <qlabel.h>
 
-#include <qdragobject.h>
+#ifndef COMPILE_USE_QT4
+	// In Qt.4 we need to use QMimeData ?
+	#include <qdragobject.h>
+#endif
 #include <qcursor.h>
 
+#ifdef COMPILE_USE_QT4
+	#include <qevent.h>
+#endif
 
 // kvi_app.cpp
 extern QPixmap * g_pUserChanStatePixmap;
@@ -336,11 +343,20 @@ static const char * g_szIconNames[KVI_NUM_SMALL_ICONS]=
 	"slurp", // 283
 	"namespace",  // 284
 	"saysmile", // 285
-	"saykvs" // 286
+	"saykvs", // 286
+	"themeoptions", // 287
+	"bug", // 288
+	"refresh", //289
+	"theme", // 290
+	"screenshot" // 291
 };
 
 KviIconWidget::KviIconWidget()
+#ifdef COMPILE_USE_QT4
+: QWidget(0,"global_icon_widget" /*,WType_TopLevel | WStyle_Customize | WStyle_Title | WStyle_StaysOnTop | WStyle_DialogBorder | WStyle_SysMenu | WStyle_Minimize*/)
+#else
 : QWidget(0,"global_icon_widget",WType_TopLevel | WStyle_Customize | WStyle_Title | WStyle_StaysOnTop | WStyle_DialogBorder | WStyle_SysMenu | WStyle_Minimize)
+#endif
 {
 	init();
 }
@@ -404,16 +420,19 @@ bool KviIconWidget::eventFilter(QObject * o,QEvent *e)
 			int iVal = szName.toInt(&bOk);
 			if(bOk)emit selected(iVal);
 
-			if(parentWidget() && isVisible() && parentWidget()->inherits("QPopupMenu"))
+			if(parentWidget() && isVisible() && parentWidget()->inherits("KviTalPopupMenu"))
 			{
 				parentWidget()->close();
 				return true;
 			} else {
-				if(QPixmap * pix = ((QLabel *)o)->pixmap())
+				if(const QPixmap * pix = ((QLabel *)o)->pixmap())
 				{
+// FIXME: In Qt 4.x this stuff needs to be ported to a different api.. which one ?
+#ifndef COMPILE_USE_QT4
 					QDragObject * drobj = new QTextDrag(o->name(),this);
 					drobj->setPixmap(*pix,((QLabel *)o)->mapFromGlobal(QCursor::pos()));
 					drobj->dragCopy();
+#endif
 					return true;
 				}
 			}
@@ -456,7 +475,7 @@ KviIconManager::KviIconManager()
 
 	//loadSmallIcons();
 
-	m_pCachedImages = new QDict<KviCachedPixmap>(21,true);
+	m_pCachedImages = new KviPointerHashTable<QString,KviCachedPixmap>(21,true);
 	m_pCachedImages->setAutoDelete(true);
 
 	m_uCacheTotalSize = 0;
@@ -474,6 +493,26 @@ KviIconManager::KviIconManager()
 	g_pActivityMeterPixmap = new QPixmap(buffer.ptr());
 	
 	m_pIconNames = 0;
+	
+	// TEMP
+	
+	/*
+	for(i=0;i<KVI_NUM_SMALL_ICONS;i++)
+	{
+		QPixmap * tmp = getSmallIcon(i);
+		QString nnn = "/home/pragma/kvismallicons/kcs_";
+		nnn += g_szIconNames[i];
+		nnn += ".png";
+		if(tmp->isNull())
+		{
+			debug("OPS, %s is NULL",nnn.latin1());
+		}
+		if(!tmp->save(nnn,"PNG",90))
+		{
+			debug("FAILED TO SAVE %s",nnn.latin1());
+		}
+	}
+	*/
 }
 
 KviIconManager::~KviIconManager()
@@ -501,7 +540,7 @@ int KviIconManager::getSmallIconIdFromName(const QString &szName)
 {
 	if(!m_pIconNames)
 	{
-		m_pIconNames = new QDict<int>(257,false);
+		m_pIconNames = new KviPointerHashTable<QString,int>(257,false);
 		m_pIconNames->setAutoDelete(true);
 		
 		for(int i=0;i<KVI_NUM_SMALL_ICONS;i++)
@@ -602,6 +641,57 @@ KviCachedPixmap * KviIconManager::getPixmapWithCache(const QString &szName)
 	return p;
 }
 
+KviCachedPixmap * KviIconManager::getPixmapWithCacheScaleOnLoad(const QString &szName,int iMaxWidth,int iMaxHeight)
+{
+	if(szName.isEmpty())return 0;
+
+	KviCachedPixmap * p = m_pCachedImages->find(szName);
+
+	if(p)
+	{
+		p->updateLastAccessTime();
+		return p;
+	}
+
+	QPixmap * pix = 0;
+
+	QString szRetPath;
+
+	if(g_pApp->findImage(szRetPath,szName))
+	{
+		pix = new QPixmap(szRetPath);
+		if(pix->isNull())
+		{
+			delete pix; // it is not an valid image!!! (really bad situation...)
+			pix = 0;
+			return 0;
+		}
+		if((pix->width() > iMaxWidth) || (pix->height() > iMaxHeight))
+		{
+			// scale to fit
+			int scaleW = iMaxWidth;
+			int scaleH;
+			scaleH = (pix->height() * iMaxWidth) / pix->width();
+			if(scaleH > iMaxHeight)
+			{
+				scaleH = iMaxHeight;
+				scaleW = (scaleH * pix->width()) / pix->height();
+			}
+	
+			QImage img = pix->convertToImage();
+			pix->convertFromImage(img.smoothScale(scaleW,scaleH));
+		}
+	} else {
+		return 0;
+	}
+
+	p = new KviCachedPixmap(pix,QString(szRetPath));
+	addToCache(szName,p);
+
+	return p;
+}
+
+
 void KviIconManager::addToCache(const QString &szName,KviCachedPixmap * p)
 {
 	if((m_uCacheTotalSize + p->size()) >= m_uCacheMaxSize)cacheCleanup();
@@ -720,8 +810,10 @@ KviAvatar * KviIconManager::getAvatar(const QString &szLocalPath,const QString &
 		szN = szName;
 	}
 
-	KviCachedPixmap * p = getPixmapWithCache(szP);
-
+	// avatars bigger than 1024x768 just sux: they can't be seen on tooltips anyway
+	KviCachedPixmap * p = KVI_OPTION_BOOL(KviOption_boolScaleAvatarsOnLoad) ? getPixmapWithCacheScaleOnLoad(szP,
+		KVI_OPTION_UINT(KviOption_uintScaleAvatarsOnLoadWidth)
+		,KVI_OPTION_UINT(KviOption_uintScaleAvatarsOnLoadHeight)) : getPixmapWithCache(szP);
 	if(!p)return 0;
 
 	return new KviAvatar(p->path(),szN,new QPixmap(*(p->pixmap())));
@@ -748,29 +840,48 @@ QPixmap * KviIconManager::loadSmallIcon(int idx)
 	if(idx >= KVI_NUM_SMALL_ICONS)return 0;
 	if(idx < 0)return 0;
 	
-	KviStr szFileName = KVI_SMALLICONS_IMAGELIB_PREFIX;
+	
+	// COMPATIBILITY ENTRY: To be removed in some time.
+	// This part loads the old smallicon library format kvi_smallicon_*.png
+	// to preserve backward compatibility with old themes.
+	// We lookup such files ONLY in the themes directories.
+
+	QString szFileName = KVI_SMALLICONS_IMAGELIB_PREFIX;
 
 	int fileidx = idx / 16;
 
-	if(fileidx >= 10)szFileName.append(KviStr::Format,"%d.png",fileidx);
-	else szFileName.append(KviStr::Format,"0%d.png",fileidx);
+	if(fileidx >= 10)KviQString::appendFormatted(szFileName,"%d.png",fileidx);
+	else KviQString::appendFormatted(szFileName,"0%d.png",fileidx);
 
-	KviStr buffer;
-	g_pApp->findImage(buffer,szFileName);
-
-	KviImageLibrary l1(buffer.ptr(),16,16);
-
-	int offset = fileidx * 16;
-
-
-	for(int i=0;i<16;i++)
+	QString buffer;
+	if(g_pApp->findImageThemeOnlyCompat(buffer,szFileName))
 	{
-		int io = i + offset;
-		if(io >= KVI_NUM_SMALL_ICONS)break;
-		if(m_smallIcons[io])delete m_smallIcons[io];
-		m_smallIcons[io] = new QPixmap(l1.getImage(i));
+		KviImageLibrary l1(buffer,16,16);
+	
+		int offset = fileidx * 16;
+	
+		for(int i=0;i<16;i++)
+		{
+			int io = i + offset;
+			if(io >= KVI_NUM_SMALL_ICONS)break;
+			if(m_smallIcons[io])delete m_smallIcons[io];
+			m_smallIcons[io] = new QPixmap(l1.getImage(i));
+		}
+
+		return m_smallIcons[idx];
 	}
 
+	// otherwise we use the NEW method: separate small icons in the "coresmall" subdirectory.
+	QString szPath;
+	KviQString::sprintf(szPath,KVI_SMALLICONS_PREFIX "%s.png",g_szIconNames[idx]);
+	
+	g_pApp->findSmallIcon(buffer,szPath);
+	m_smallIcons[idx] = new QPixmap(buffer);
+
+	//if(m_smallIcon[idx]->isNull())
+	//{
+	// // load an "unknown" image ?.. but should never happen
+	//}
 	return m_smallIcons[idx];
 }
 
@@ -778,7 +889,7 @@ void KviIconManager::cacheCleanup()
 {
 	QStringList l;
 
-	QDictIterator<KviCachedPixmap> it(*m_pCachedImages);
+	KviPointerHashTableIterator<QString,KviCachedPixmap> it(*m_pCachedImages);
 
 
 //#warning "IMPLEMENT CLEANUP"
