@@ -33,7 +33,7 @@
 #include <qpixmap.h>
 #include <qobject.h>
 #include <qwidget.h>
-#include <qdict.h>
+#include "kvi_pointerhashtable.h"
 
 
 
@@ -326,8 +326,12 @@
 #define KVI_SMALLICON_SAYSMILE 285
 #define KVI_SMALLICON_SAYKVS 286
 #define KVI_SMALLICON_THEMEOPTIONS 287
+#define KVI_SMALLICON_BUG 288
+#define KVI_SMALLICON_REFRESH 289
+#define KVI_SMALLICON_THEME 290
+#define KVI_SMALLICON_SCREENSHOT 291
 
-#define KVI_NUM_SMALL_ICONS 288
+#define KVI_NUM_SMALL_ICONS 292
 
 
 #define KVI_BIGICON_DISCONNECTED "kvi_bigicon_disconnected.png"
@@ -339,6 +343,7 @@
 #define KVI_BIGICON_UNKNOWN "kvi_bigicon_unknown.png"
 #define KVI_BIGICON_SEPARATOR "kvi_bigicon_separator.png"
 #define KVI_BIGICON_KVS "kvi_bigicon_kvs.png"
+#define KVI_BIGICON_THEME "kvi_bigicon_theme.png"
 #define KVI_BIGICON_ADDONS "kvi_bigicon_addons.png"
 
 #define KVI_BIGICON_HELPINDEX "kvi_bigicon_helpindex.png"
@@ -347,7 +352,18 @@
 #define KVI_BIGICON_HELPCLOSE "kvi_bigicon_helpclose.png"
 #define KVI_BIGICON_HELPSEARCH "kvi_bigicon_helpsearch.png"
 
-#define KVI_SMALLICONS_IMAGELIB_NAME "kvi_smallicon_00.png"
+#define KVI_BIGICON_OPEN "kvi_bigicon_open.png"
+#define KVI_BIGICON_SAVE "kvi_bigicon_save.png"
+#define KVI_BIGICON_REMOVE "kvi_bigicon_remove.png"
+#define KVI_BIGICON_WWW "kvi_bigicon_www.png"
+#define KVI_BIGICON_PACK "kvi_bigicon_pack.png"
+#define KVI_BIGICON_SCREENSHOT "kvi_bigicon_screenshot.png"
+#define KVI_BIGICON_REGUSERS "kvi_bigicon_regusers.png"
+
+#define KVI_SMALLICONS_SUBDIRECTORY "coresmall"
+#define KVI_SMALLICONS_PREFIX "kcs_"
+
+// FIXME: this should be removed
 #define KVI_SMALLICONS_IMAGELIB_PREFIX "kvi_smallicon_"
 
 #define KVI_USERCHANSTATE_IMAGE_NAME "kvi_userchanstate.png"
@@ -395,6 +411,25 @@ signals:
 
 
 
+//
+// This class manages the images used by KVIrc.
+//
+// We handle three types of images: builtin small icons, builtin big icons and generic images.
+//
+// The builtin small icons are in the pics/coresmall directory (this is to optimize the directory size
+//      since it's a linear search...), are 16x16 in size and are indexed by numbers in a way that their
+//      access is really fast. The icons used here are used mostly in KviIrcView (but not exclusively).
+//
+// The generic images are just "any" image that the underlying Qt engine
+//      is able to load. They are loaded by (relative) path and 
+//      cached by name.
+//
+// The builtin big icons are (actually) just generic images
+//      that are eventually scaled to 32x32 if needed. One can request
+//      a builtin small icon indexed by number to be scaled
+//      to the size of 32x32 as a big icon too.
+//
+
 class KVIRC_API KviIconManager : public QObject
 {
 	Q_OBJECT
@@ -405,8 +440,8 @@ private:
 	QPixmap                     * m_smallIcons[KVI_NUM_SMALL_ICONS];
 	KviIconWidget               * m_pIconWidget;
 
-	QDict<KviCachedPixmap>      * m_pCachedImages;
-	QDict<int>                  * m_pIconNames;
+	KviPointerHashTable<QString,KviCachedPixmap>      * m_pCachedImages;
+	KviPointerHashTable<QString,int>                  * m_pIconNames;
 	unsigned int                  m_uCacheTotalSize;
 	unsigned int                  m_uCacheMaxSize;
 public:
@@ -419,6 +454,10 @@ public:
 	// and can be deleted at any time : so don't store it
 	KviCachedPixmap * getPixmapWithCache(const QString &szName);
 
+	// The returned pointer is owned by the icon manager
+	// and can be deleted at any time : so don't store it
+	KviCachedPixmap * getPixmapWithCacheScaleOnLoad(const QString &szName,int iMaxWidth,int iMaxHeight);
+
 	// The returned pointer is owned by the icon manager
 	// and can be deleted at any time : so don't store it
 	QPixmap * getPixmap(const QString &szName)
