@@ -55,15 +55,22 @@ static char * internalCommandTable[KVI_NUM_INTERNAL_COMMANDS]=
 	"url.list",
 	"openurl http://www.kvirc.net/?id=themes",
 	"openurl http://www.kvirc.net/?id=mailinglist",
-	"openurl http://bugtrack.kvirc.omnikron.net",
+	"openurl https://svn.kvirc.de/kvirc/newticket",
 	"raweditor.open",
 	"popupeditor.open",
 	"dialog.file(open,\"Select a Script File\"){ if(!$str.isEmpty($0))parse $0; }",
 	"actioneditor.open",
 	"quit",
-	"openurl http://www.kvirc.ru"
+	"openurl http://www.kvirc.ru",
+	"openurl irc://freenode/kvirc",
+	"openurl irc://ircnet/kvirc",
+	"openurl irc://azzurra/kvirc.net",
+	"openurl http://kvirc-fr.info",
+	"openurl irc://freenode/kvirc-fr",
+	"openurl irc://irc.europnet.org/kvirc"
 };
 
+
 char * kvi_getInternalCommandBuffer(int idx)
 {
 	if(idx > 0 && idx < KVI_NUM_INTERNAL_COMMANDS)
