@@ -58,8 +58,14 @@
 #define KVI_INTERNALCOMMAND_ACTIONEDITOR_OPEN 31
 #define KVI_INTERNALCOMMAND_QUIT 32
 #define KVI_INTERNALCOMMAND_KVIRC_HOMEPAGE_RU 33
+#define KVI_INTERNALCOMMAND_OPENURL_KVIRC_ON_FREENODE 34
+#define KVI_INTERNALCOMMAND_OPENURL_KVIRC_ON_IRCNET 35
+#define KVI_INTERNALCOMMAND_OPENURL_KVIRC_IT_ON_AZZURRA 36
+#define KVI_INTERNALCOMMAND_KVIRC_HOMEPAGE_FR 37
+#define KVI_INTERNALCOMMAND_OPENURL_KVIRC_FR_ON_FREENODE 38
+#define KVI_INTERNALCOMMAND_OPENURL_KVIRC_FR_ON_EUROPNET 39
 
-#define KVI_NUM_INTERNAL_COMMANDS 34
+#define KVI_NUM_INTERNAL_COMMANDS 40
 
 extern KVIRC_API char * kvi_getInternalCommandBuffer(int idx);
 
