@@ -62,8 +62,9 @@
 #include "kvi_databuffer.h"
 #include "kvi_lagmeter.h"
 #include "kvi_kvs_eventtriggers.h"
-
 #include "kvi_kvs_script.h"
+#include "kvi_mirccntrl.h"
+#include "kvi_useridentity.h"
 
 #include <qtimer.h>
 #include <qtextcodec.h>
@@ -72,16 +73,18 @@ extern KVIRC_API KviIrcServerDataBase           * g_pIrcServerDataBase;
 extern KVIRC_API KviProxyDataBase               * g_pProxyDataBase;
 extern KVIRC_API KviGarbageCollector            * g_pGarbageCollector;
 
-KviIrcConnection::KviIrcConnection(KviIrcContext * pContext,KviIrcConnectionTarget * pTarget)
+KviIrcConnection::KviIrcConnection(KviIrcContext * pContext,KviIrcConnectionTarget * pTarget,KviUserIdentity * pIdentity)
 : QObject()
 {
+	m_bIdentdAttached = false;
 	m_pContext = pContext;
 	m_pConsole = pContext->console();
 	m_pFrame = m_pConsole->frame();
 	m_pTarget = pTarget;
-	m_pChannelList = new KviPtrList<KviChannel>;
+	m_pUserIdentity = pIdentity;
+	m_pChannelList = new KviPointerList<KviChannel>;
 	m_pChannelList->setAutoDelete(false);
-	m_pQueryList = new KviPtrList<KviQuery>;
+	m_pQueryList = new KviPointerList<KviQuery>;
 	m_pQueryList->setAutoDelete(false);
 	m_pLink = new KviIrcLink(this);
 	m_pUserDataBase = new KviIrcUserDataBase();
@@ -102,6 +105,8 @@ KviIrcConnection::KviIrcConnection(KviIrcContext * pContext,KviIrcConnectionTarg
 
 KviIrcConnection::~KviIrcConnection()
 {
+	if(m_bIdentdAttached) g_pFrame->executeInternalCommand(KVI_INTERNALCOMMAND_IDENT_STOP);
+	m_bIdentdAttached = false;
 	if(m_pLocalhostDns)
 	{
 		QObject::disconnect(m_pLocalhostDns,SIGNAL(lookupDone(KviDns *)),0,0);
@@ -141,6 +146,7 @@ KviIrcConnection::~KviIrcConnection()
 	delete m_pNetsplitDetectorData;
 	delete m_pAsyncWhoisData;
 	delete m_pStatistics;
+	delete m_pUserIdentity;
 }
 
 void KviIrcConnection::setEncoding(const QString &szEncoding)
@@ -198,7 +204,7 @@ void KviIrcConnection::setupTextCodec()
 	m_pConsole->setTextEncoding(QString(m_pTextCodec->name()));
 }
 
-QCString KviIrcConnection::encodeText(const QString &szText)
+KviQCString KviIrcConnection::encodeText(const QString &szText)
 {
 	if(!m_pTextCodec)return szText.utf8();
 	return m_pTextCodec->fromUnicode(szText);
@@ -263,6 +269,11 @@ void KviIrcConnection::abort()
 void KviIrcConnection::start()
 {
 	m_eState = Connecting;
+	if(KVI_OPTION_BOOL(KviOption_boolUseIdentService) && KVI_OPTION_BOOL(KviOption_boolUseIdentServiceOnlyOnConnect))
+	{
+		g_pFrame->executeInternalCommand(KVI_INTERNALCOMMAND_IDENT_START);
+		m_bIdentdAttached=true;
+	}
 	m_pLink->start();
 }
 
@@ -275,7 +286,7 @@ void KviIrcConnection::linkEstabilished()
 	m_pStatistics->setLastMessageTime(kvi_unixTime());
 	m_pServerInfo->setName(target()->server()->m_szHostname);
 
-	if(KviPtrList<KviIrcDataStreamMonitor> * l = context()->monitorList())
+	if(KviPointerList<KviIrcDataStreamMonitor> * l = context()->monitorList())
 	{
 		for(KviIrcDataStreamMonitor *m =l->first();m;m =l->next())
 			m->connectionInitiated();
@@ -290,6 +301,11 @@ void KviIrcConnection::linkEstabilished()
 
 void KviIrcConnection::linkTerminated()
 {
+	if(m_bIdentdAttached)
+	{
+		g_pFrame->executeInternalCommand(KVI_INTERNALCOMMAND_IDENT_STOP);
+		m_bIdentdAttached=false;
+	}
 	m_eState = Idle;
 	
 	if(m_pNotifyListManager)
@@ -304,7 +320,7 @@ void KviIrcConnection::linkTerminated()
 		m_pLagMeter = 0;
 	}
 	
-	if(KviPtrList<KviIrcDataStreamMonitor> * l = context()->monitorList())
+	if(KviPointerList<KviIrcDataStreamMonitor> * l = context()->monitorList())
 	{
 		for(KviIrcDataStreamMonitor *m =l->first();m;m =l->next())
 			m->connectionTerminated();
@@ -316,6 +332,11 @@ void KviIrcConnection::linkTerminated()
 
 void KviIrcConnection::linkAttemptFailed(int iError)
 {
+	if(m_bIdentdAttached)
+	{
+		g_pFrame->executeInternalCommand(KVI_INTERNALCOMMAND_IDENT_STOP);
+		m_bIdentdAttached=false;
+	}
 	m_eState = Idle;
 	context()->connectionFailed(iError);
 }
@@ -393,11 +414,15 @@ KviChannel * KviIrcConnection::createChannel(const QString &szName)
 	if(c)
 	{
 		c->setAliveChan();
-		c->raise();
-		c->setFocus();
+		if(!KVI_OPTION_BOOL(KviOption_boolCreateMinimizedChannels))
+		{
+			c->raise();
+			c->setFocus();
+		}
 	} else {
 		c = new KviChannel(m_pFrame,m_pConsole,szName);
-		m_pFrame->addWindow(c);
+		m_pFrame->addWindow(c,!KVI_OPTION_BOOL(KviOption_boolCreateMinimizedChannels));
+		if(KVI_OPTION_BOOL(KviOption_boolCreateMinimizedChannels)) c->minimize();
 	}
 	return c;
 }
@@ -440,11 +465,15 @@ void KviIrcConnection::registerChannel(KviChannel * c)
 	m_pChannelList->append(c);
 	if(KVI_OPTION_BOOL(KviOption_boolLogChannelHistory))
 		g_pApp->addRecentChannel(c->windowName(),m_pTarget->networkName());
+	emit(channelRegistered(c));
+	emit(chanListChanged());
 }
 
 void KviIrcConnection::unregisterChannel(KviChannel * c)
 {
-	if(m_pChannelList->removeRef(c))return;
+	m_pChannelList->removeRef(c);
+	emit(channelUnregistered(c));
+	emit(chanListChanged());
 }
 
 void KviIrcConnection::registerQuery(KviQuery * c)
@@ -525,7 +554,7 @@ bool KviIrcConnection::sendFmtData(const char *fmt,...)
 	}
 
 	// notify the monitors
-	if(KviPtrList<KviIrcDataStreamMonitor> * l = context()->monitorList())
+	if(KviPointerList<KviIrcDataStreamMonitor> * l = context()->monitorList())
 	{
 		for(KviIrcDataStreamMonitor *m = l->first();m;m = l->next())
 			m->outgoingMessage((const char *)(pData->data()),iLen - 2);
@@ -549,7 +578,7 @@ bool KviIrcConnection::sendData(const char *buffer,int buflen)
 	*(pData->data()+buflen+1)='\n';
 
 	// notify the monitors
-	if(KviPtrList<KviIrcDataStreamMonitor> * l = context()->monitorList())
+	if(KviPointerList<KviIrcDataStreamMonitor> * l = context()->monitorList())
 	{
 		for(KviIrcDataStreamMonitor *m = l->first();m;m = l->next())
 			m->outgoingMessage((const char *)(pData->data()),buflen);
@@ -817,7 +846,8 @@ void KviIrcConnection::hostNameLookupTerminated(KviDns *pDns)
 			m_pConsole->output(KVI_OUT_SYSTEMMESSAGE,__tr2qs("Unable to resolve the local hostname as seen by the IRC server: %Q"),
 			&szErr);
 	} else {
-		m_pConsole->output(KVI_OUT_SYSTEMMESSAGE,__tr2qs("Local hostname as seen by the IRC server resolved to %s"),m_pLocalhostDns->firstIpAddress());
+		QString szIpAddr = m_pLocalhostDns->firstIpAddress();
+		m_pConsole->output(KVI_OUT_SYSTEMMESSAGE,__tr2qs("Local hostname as seen by the IRC server resolved to %Q"),&szIpAddr);
 		m_pUserInfo->setHostIp(m_pLocalhostDns->firstIpAddress());
 	}
 
@@ -856,7 +886,13 @@ void KviIrcConnection::loginToIrcServer()
 
 	// Nick stuff
 	pServer->m_szNick.stripWhiteSpace();
-	if(!pServer->m_szNick.isEmpty())
+	if(pServer->m_pReconnectInfo)
+	{
+		if(!_OUTPUT_MUTE)
+			m_pConsole->output(KVI_OUT_VERBOSE,__tr2qs("Using reconnect specific nickname (%Q)"),&(pServer->m_pReconnectInfo->m_szNick));
+		m_pUserInfo->setNickName(pServer->m_pReconnectInfo->m_szNick);
+		m_pStateData->setLoginNickIndex(0);
+	}else if(!pServer->m_szNick.isEmpty())
 	{
 		if(!_OUTPUT_MUTE)
 			m_pConsole->output(KVI_OUT_VERBOSE,__tr2qs("Using server specific nickname (%Q)"),&(pServer->m_szNick));
@@ -900,9 +936,9 @@ void KviIrcConnection::loginToIrcServer()
 	
 	// FIXME: The server's encoding!
 	setupTextCodec();
-	QCString szNick = encodeText(m_pUserInfo->nickName()); // never empty
-	QCString szUser = encodeText(m_pUserInfo->userName()); // never empty
-	QCString szReal = encodeText(m_pUserInfo->realName()); // may be empty
+	KviQCString szNick = encodeText(m_pUserInfo->nickName()); // never empty
+	KviQCString szUser = encodeText(m_pUserInfo->userName()); // never empty
+	KviQCString szReal = encodeText(m_pUserInfo->realName()); // may be empty
 
 	if(!szReal.data())szReal = "";
 
@@ -934,20 +970,35 @@ void KviIrcConnection::loginToIrcServer()
 		}
 	}
 	
+	
 	if(!sendFmtData("NICK %s",szNick.data()))
 	{
 		// disconnected :(
 		return;
 	}
+	
+	QString szGenderTag;
+	if(KVI_OPTION_BOOL(KviOption_boolPrependGenderInfoToRealname) && !KVI_OPTION_STRING(KviOption_stringCtcpUserInfoGender).isEmpty())
+	{
+		szGenderTag.append(KVI_TEXT_COLOR);
+		if(KVI_OPTION_STRING(KviOption_stringCtcpUserInfoGender).startsWith("m",false))
+		{
+			szGenderTag.append("1");
+		} else if(KVI_OPTION_STRING(KviOption_stringCtcpUserInfoGender).startsWith("f",false))
+		{
+			szGenderTag.append("2");
+		}
+		szGenderTag.append(KVI_TEXT_RESET);
+		szReal.prepend(KviQString::toUtf8(szGenderTag));
+	}
 
 	if(!sendFmtData("USER %s 0 %s :%s",szUser.data(),
-			pServer->m_szHostname.utf8().data(),szReal.data()))
+			KviQString::toUtf8(pServer->m_szHostname).data(),szReal.data()))
 	{
 		// disconnected in the meantime!
 		return;
 	}
 
-
 	// permanent info in the user database
 	m_pConsole->notifyListView()->join(m_pUserInfo->nickName(),"*","*");
 
@@ -965,25 +1016,40 @@ void KviIrcConnection::loginToIrcServer()
 			}
 		}
 	} // else buuug
+	
+	if(KVI_OPTION_STRING(KviOption_stringCtcpUserInfoGender).startsWith("m",false)){
+			e->setGender(KviIrcUserEntry::Male);
+	} else if(KVI_OPTION_STRING(KviOption_stringCtcpUserInfoGender).startsWith("f",false)){
+			e->setGender(KviIrcUserEntry::Female);
+	}
 
 	// on connect stuff ?
 
-	KviStr tmp = pNet->onConnectCommand();
+	QString tmp = pNet->onConnectCommand();
 	tmp.stripWhiteSpace();
-	if(tmp.hasData())
+	if(!tmp.isEmpty())
 	{
 		if(_OUTPUT_VERBOSE)
 			m_pConsole->output(KVI_OUT_VERBOSE,__tr2qs("Executing scheduled network specific \"on connect\" commands"));
-		KviKvsScript::run(tmp.ptr(),m_pConsole);
+		KviKvsScript::run(tmp,m_pConsole);
 	}
 
 	tmp = pServer->onConnectCommand();
 	tmp.stripWhiteSpace();
-	if(tmp.hasData())
+	if(!tmp.isEmpty())
 	{
 		if(_OUTPUT_VERBOSE)
 			m_pConsole->output(KVI_OUT_VERBOSE,__tr2qs("Executing scheduled server specific \"on connect\" commands"));
-		KviKvsScript::run(tmp.ptr(),m_pConsole);
+		KviKvsScript::run(tmp,m_pConsole);
+	}
+
+	tmp = m_pUserIdentity->onConnectCommand();
+	tmp.stripWhiteSpace();
+	if(!tmp.isEmpty())
+	{
+		if(_OUTPUT_VERBOSE)
+			m_pConsole->output(KVI_OUT_VERBOSE,__tr2qs("Executing scheduled identity specific \"on connect\" commands"));
+		KviKvsScript::run(tmp,m_pConsole);
 	}
 
 	// and wait for the server to agree...
@@ -1024,6 +1090,12 @@ void KviIrcConnection::loginComplete(const QString &szNickName)
 
 	context()->loginComplete();
 
+	if(m_bIdentdAttached)
+	{
+		g_pFrame->executeInternalCommand(KVI_INTERNALCOMMAND_IDENT_STOP);
+		m_bIdentdAttached=false;
+	}
+
 	if(szNickName != m_pUserInfo->nickName())
 	{
 		m_pConsole->output(KVI_OUT_SYSTEMMESSAGE,__tr2qs("The server refused the suggested nickname (%s) and named you %s instead"),
@@ -1043,22 +1115,31 @@ void KviIrcConnection::loginComplete(const QString &szNickName)
 	resurrectDeadQueries();
 
 	// on connect stuff ?
-	KviStr tmp = target()->network()->onLoginCommand();
+	QString tmp = target()->network()->onLoginCommand();
 	tmp.stripWhiteSpace();
-	if(tmp.hasData())
+	if(!tmp.isEmpty())
 	{
 		if(_OUTPUT_VERBOSE)
 			m_pConsole->output(KVI_OUT_VERBOSE,__tr2qs("Executing scheduled network specific \"on login\" commands"));
-		KviKvsScript::run(tmp.ptr(),m_pConsole);
+		KviKvsScript::run(tmp,m_pConsole);
 	}
 
 	tmp = target()->server()->onLoginCommand();
 	tmp.stripWhiteSpace();
-	if(tmp.hasData())
+	if(!tmp.isEmpty())
 	{
 		if(_OUTPUT_VERBOSE)
 			m_pConsole->output(KVI_OUT_VERBOSE,__tr2qs("Executing scheduled server specific \"on login\" commands"));
-		KviKvsScript::run(tmp.ptr(),m_pConsole);
+		KviKvsScript::run(tmp,m_pConsole);
+	}
+
+	tmp = m_pUserIdentity->onLoginCommand();
+	tmp.stripWhiteSpace();
+	if(!tmp.isEmpty())
+	{
+		if(_OUTPUT_VERBOSE)
+			m_pConsole->output(KVI_OUT_VERBOSE,__tr2qs("Executing scheduled identity specific \"on login\" commands"));
+		KviKvsScript::run(tmp,m_pConsole);
 	}
 
 	// Set the configured umode
@@ -1081,7 +1162,7 @@ void KviIrcConnection::loginComplete(const QString &szNickName)
 
 
 	// join saved channels
-	QString szChannels,szProtectedChannels,szPasswords,szCurPass;
+	QString szChannels,szProtectedChannels,szPasswords,szCurPass,szCurChan;
 	
 	if(!(m_pStateData->commandToExecAfterConnect().isEmpty()))
 	{
@@ -1089,72 +1170,119 @@ void KviIrcConnection::loginComplete(const QString &szNickName)
 		KviKvsScript::run(tmp.ptr(),m_pConsole);
 	}
 	
-	if(target()->network()->autoJoinChannelList())
+	if(target()->server()->m_pReconnectInfo)
 	{
-		if(_OUTPUT_VERBOSE)
-			m_pConsole->output(KVI_OUT_VERBOSE,__tr2qs("Auto-joining network specific channels"));
+		if(!target()->server()->m_pReconnectInfo->m_szJoinChannels.isEmpty())
+			sendFmtData("JOIN %s",encodeText(target()->server()->m_pReconnectInfo->m_szJoinChannels).data());
 
-		QStringList * l = target()->network()->autoJoinChannelList();
-		if(l->count()!=0)
+		KviQuery * query;
+		
+		for(QStringList::Iterator it = target()->server()->m_pReconnectInfo->m_szOpenQueryes.begin();
+			it != target()->server()->m_pReconnectInfo->m_szOpenQueryes.end();it++)
 		{
-			for ( QStringList::Iterator it = l->begin(); it != l->end(); ++it ) {
-				
-				szCurPass=(*it).section(':',1);
-				if(szCurPass.isEmpty())
+			QString szNick = *it;
+			query = findQuery(szNick);
+			if(!query) {
+				query = createQuery(szNick);
+				QString user;
+				QString host;
+				KviIrcUserDataBase * db = userDataBase();
+				if(db)
 				{
-					if(!szChannels.isEmpty())
-						szChannels.append(",");
-					szChannels.append((*it).section(':',0,0));
-				} else {
-					if(!szProtectedChannels.isEmpty())
-						szProtectedChannels.append(",");
-					szProtectedChannels.append((*it).section(':',0,0));
-					if(!szPasswords.isEmpty())
-						szPasswords.append(",");
-					szPasswords.append(szCurPass);
+					KviIrcUserEntry * e = db->find(szNick);
+					if(e)
+					{
+						user = e->user();
+						host = e->host();
+					}
 				}
+				query->setTarget(szNick,user,host);
 			}
-		}	
-	}
-
-	if(server()->autoJoinChannelList())
-	{
-		if(_OUTPUT_VERBOSE)
-			m_pConsole->output(KVI_OUT_VERBOSE,__tr2qs("Auto-joining server specific channels"));
-
-		QStringList * l = server()->autoJoinChannelList();
-		if(l->count()!=0)
+			query->autoRaise();
+			query->setFocus();
+		}
+		delete target()->server()->m_pReconnectInfo;
+		target()->server()->m_pReconnectInfo=0;
+	}else {
+		if(target()->network()->autoJoinChannelList())
 		{
-			for ( QStringList::Iterator it = l->begin(); it != l->end(); ++it ) {
-				szCurPass=(*it).section(':',1);
-				if(szCurPass.isEmpty())
-				{
-					if(!szChannels.isEmpty())
-						szChannels.append(",");
-					szChannels.append((*it).section(':',0,0));
-				} else {
-					if(!szProtectedChannels.isEmpty())
-						szProtectedChannels.append(",");
-					szProtectedChannels.append((*it).section(':',0,0));
-					if(!szPasswords.isEmpty())
-						szPasswords.append(",");
-					szPasswords.append(szCurPass);
+			if(_OUTPUT_VERBOSE)
+				m_pConsole->output(KVI_OUT_VERBOSE,__tr2qs("Auto-joining network specific channels"));
+
+			QStringList * l = target()->network()->autoJoinChannelList();
+			if(l->count()!=0)
+			{
+				for ( QStringList::Iterator it = l->begin(); it != l->end(); ++it ) {
+					
+					szCurPass=(*it).section(':',1);
+					if(szCurPass.isEmpty())
+					{
+						if(!szChannels.isEmpty())
+							szChannels.append(",");
+						szCurChan = (*it).section(':',0,0);
+						if(!(szCurChan[0]=='#' || szCurChan[0]=='&' || szCurChan[0]=='!'))
+								szCurChan.prepend('#');
+						szChannels.append(szCurChan);
+					} else {
+						if(!szProtectedChannels.isEmpty())
+							szProtectedChannels.append(",");
+						szCurChan = (*it).section(':',0,0);
+						if(!(szCurChan[0]=='#' || szCurChan[0]=='&' || szCurChan[0]=='!'))
+								szCurChan.prepend('#');
+						szProtectedChannels.append(szCurChan);
+						if(!szPasswords.isEmpty())
+							szPasswords.append(",");
+						szPasswords.append(szCurPass);
+					}
+				}
+			}	
+		}
+
+		if(server()->autoJoinChannelList())
+		{
+			if(_OUTPUT_VERBOSE)
+				m_pConsole->output(KVI_OUT_VERBOSE,__tr2qs("Auto-joining server specific channels"));
+
+			QStringList * l = server()->autoJoinChannelList();
+			if(l->count()!=0)
+			{
+				for ( QStringList::Iterator it = l->begin(); it != l->end(); ++it ) {
+					szCurPass=(*it).section(':',1);
+					if(szCurPass.isEmpty())
+					{
+						if(!szChannels.isEmpty())
+							szChannels.append(",");
+						szCurChan = (*it).section(':',0,0);
+						if(!(szCurChan[0]=='#' || szCurChan[0]=='&' || szCurChan[0]=='!'))
+							szCurChan.prepend(':');
+						szChannels.append(szCurChan);
+					} else {
+						if(!szProtectedChannels.isEmpty())
+							szProtectedChannels.append(",");
+						szCurChan = (*it).section(':',0,0);
+						if(!(szCurChan[0]=='#' || szCurChan[0]=='&' || szCurChan[0]=='!'))
+								szCurChan.prepend('#');
+						szProtectedChannels.append(szCurChan);
+						if(!szPasswords.isEmpty())
+							szPasswords.append(",");
+						szPasswords.append(szCurPass);
+					}
 				}
 			}
 		}
-	}
-	
-	QString szCommand;
-	if( (!szChannels.isEmpty()) || (!szProtectedChannels.isEmpty()) )
-	{
-		szCommand.append(szProtectedChannels);
-		if(!szProtectedChannels.isEmpty() && !szChannels.isEmpty())
-			szCommand.append(',');
-		szCommand.append(szChannels);
-		szCommand.append(" ");
-		szCommand.append(szPasswords);
 		
-		sendFmtData("JOIN %s",encodeText(szCommand).data());
+		QString szCommand;
+		if( (!szChannels.isEmpty()) || (!szProtectedChannels.isEmpty()) )
+		{
+			szCommand.append(szProtectedChannels);
+			if(!szProtectedChannels.isEmpty() && !szChannels.isEmpty())
+				szCommand.append(',');
+			szCommand.append(szChannels);
+			szCommand.append(" ");
+			szCommand.append(szPasswords);
+			
+			sendFmtData("JOIN %s",encodeText(szCommand).data());
+		}
 	}
 	// minimize after connect
 	if(KVI_OPTION_BOOL(KviOption_boolMinimizeConsoleAfterConnect))
@@ -1165,7 +1293,7 @@ void KviIrcConnection::incomingMessage(const char * message)
 {
 	// A message has arrived from the current server
 	// First of all , notify the monitors
-	if(KviPtrList<KviIrcDataStreamMonitor> * l = context()->monitorList())
+	if(KviPointerList<KviIrcDataStreamMonitor> * l = context()->monitorList())
 	{
 		for(KviIrcDataStreamMonitor *m = l->first();m;m = l->next())
 		{
