@@ -26,7 +26,8 @@
 
 #include "kvi_settings.h"
 #include "kvi_qstring.h"
-#include "kvi_list.h"
+#include "kvi_qcstring.h"
+#include "kvi_pointerlist.h"
 #include "kvi_time.h"
 #include <qobject.h>
 
@@ -53,6 +54,7 @@ class KviIrcConnectionStatistics;
 class KviLagMeter;
 class KviNotifyListManager;
 class KviDns;
+class KviUserIdentity;
 
 class QTimer;
 class QTextCodec;
@@ -69,7 +71,7 @@ public:
 	// only KviConsole can create this
 	// pContext must NOT be null
 	// pTarget must NOT be null and must be allocated with new! this class takes the ownership
-	KviIrcConnection(KviIrcContext * pContext,KviIrcConnectionTarget * pTarget);
+	KviIrcConnection(KviIrcContext * pContext,KviIrcConnectionTarget * pTarget,KviUserIdentity * pIdentity);
 	~KviIrcConnection();
 public:
 	enum State { Idle, Connecting, Connected };
@@ -79,18 +81,25 @@ private:
 	KviIrcContext                        * m_pContext;              // shallow, never null
 	
 	State                                  m_eState;
+	bool                                   m_bIdentdAttached;
 
 	KviIrcConnectionTarget               * m_pTarget;               // owned, never null
 
 	KviIrcLink                           * m_pLink;                 // owned, never null
 	
+	// The initial informations about the user we'll send out to the server
+	// Note that the ACTUAL user informations are in m_pUserInfo instead
+	KviUserIdentity                      * m_pUserIdentity;         // owned, never null
+	
+	// The ACTUAL user informations
 	KviIrcConnectionUserInfo             * m_pUserInfo;             // owned, never null
+	// The ACTUAL server informations
 	KviIrcConnectionServerInfo           * m_pServerInfo;           // owned, never null
 
 	KviIrcConnectionStateData            * m_pStateData;            // owned, never null
 
-	KviPtrList<KviChannel>               * m_pChannelList;          // owned, never null, elements shallow
-	KviPtrList<KviQuery>                 * m_pQueryList;            // owned, never null, elements shallow
+	KviPointerList<KviChannel>               * m_pChannelList;          // owned, never null, elements shallow
+	KviPointerList<KviQuery>                 * m_pQueryList;            // owned, never null, elements shallow
 
 	KviIrcUserDataBase                   * m_pUserDataBase;         // owned, never null
 	
@@ -167,9 +176,8 @@ public:
 	// channel management
 	//
 	// ----> KviChannelManager ?
-	// FIXME: these two shouldn't be const QString & ?
 	KviChannel * findChannel(const QString &name);
-	KviPtrList<KviChannel> * channelList(){ return m_pChannelList; };
+	KviPointerList<KviChannel> * channelList(){ return m_pChannelList; };
 	int getCommonChannels(const QString &nick,QString &szChansBuffer,bool bAddEscapeSequences = true);
 	KviChannel * createChannel(const QString &name);
 	void registerChannel(KviChannel *c);
@@ -189,7 +197,7 @@ public:
 	//
 	// ----> KviQueryManager ?
 	KviQuery * findQuery(const QString &nick);
-	KviPtrList<KviQuery> * queryList(){ return m_pQueryList; };
+	KviPointerList<KviQuery> * queryList(){ return m_pQueryList; };
 	KviQuery * createQuery(const QString &nick);
 	void registerQuery(KviQuery *q);
 	void unregisterQuery(KviQuery *q);
@@ -244,19 +252,24 @@ protected:
 	//
 	// this signals that the connection attempt has failed
 	void linkAttemptFailed(int iError);
-	// this is called by KviIrcLink when a message is arriving from the server
-	void incomingMessage(const char * message);
 	// called by KviIrcLink when the socket state changes to Connected
 	void linkEstabilished();
 	// called by KviIrcLink when the socket state changes to Ready
 	void linkTerminated();
+public:
+	// this is called by KviIrcLink OR KviMexLinkFilter when a message is arriving from the server
+	// needs to be public because subclasses of KviMexLinkFilter may call it.
+	void incomingMessage(const char * message);
 signals:
 	void awayStateChanged();
 	void userModeChanged();
 	void nickNameChanged();
+	void channelRegistered(KviChannel*);
+	void channelUnregistered(KviChannel*);
+	void chanListChanged();
 public:
 	QString decodeText(const char * szText);
-	QCString encodeText(const QString &szText);
+	KviQCString encodeText(const QString &szText);
 private:
 	void setupTextCodec();
 };
@@ -266,3 +279,4 @@ private:
 
 
 #endif //!_KVI_IRCCONNECTION_H_
+
