@@ -26,8 +26,50 @@
 
 #include "kvi_settings.h"
 #include "kvi_qstring.h"
+#include "kvi_inttypes.h"
 
-#define KVI_NUM_POSSIBLE_MODE_PREFIX_CHARS 128
+class KVIRC_API KviBasicIrcServerInfo
+{
+protected:
+	QString m_szServerVersion;
+public:
+	KviBasicIrcServerInfo(const QString & version = KviQString::empty);
+	~KviBasicIrcServerInfo();
+protected:
+	virtual const QString & getCustomChannelModeDescription(QChar mode) { return KviQString::empty; };
+	virtual const QString & getCustomUserModeDescription(QChar mode) { return KviQString::empty; };
+private:
+	const QString & getBasicChannelModeDescription(QChar mode);
+	const QString & getBasicUserModeDescription(QChar mode);
+public:
+	const QString & getChannelModeDescription(QChar mode);
+	const QString & getUserModeDescription(QChar mode);
+	virtual char getRegisterModeChar() { return 0; };
+};
+
+class KVIRC_API KviUnrealIrcServerInfo : public KviBasicIrcServerInfo
+{
+public:
+	KviUnrealIrcServerInfo(const QString & version = KviQString::empty)
+		:KviBasicIrcServerInfo(version) {;};
+	virtual char getRegisterModeChar() { return 'r'; };
+};
+
+class KVIRC_API KviBahamutIrcServerInfo : public KviBasicIrcServerInfo
+{
+public:
+	KviBahamutIrcServerInfo(const QString & version = KviQString::empty)
+		:KviBasicIrcServerInfo(version) {;};
+	virtual char getRegisterModeChar() { return 'r'; };
+};
+
+class KVIRC_API KviHyperionIrcServerInfo : public KviBasicIrcServerInfo
+{
+public:
+	KviHyperionIrcServerInfo(const QString & version = KviQString::empty)
+		:KviBasicIrcServerInfo(version) {;};
+	virtual char getRegisterModeChar() { return 'e'; };
+};
 
 class KVIRC_API KviIrcConnectionServerInfo
 {
@@ -38,11 +80,13 @@ protected:
 	KviIrcConnectionServerInfo();
 	~KviIrcConnectionServerInfo();
 private:
+	KviBasicIrcServerInfo * m_pServInfo;
 	QString m_szName;                      // the most actual server name (may be the one we specify or the one that the server wants to be known as)
 	QString m_szSupportedUserModes;        // the supported user modes
 	QString m_szSupportedChannelModes;     // the supported channel modes
 	QString m_szSupportedModePrefixes;     // the actually used mode prefixes  @+
-	unsigned char m_cModePrefixTable[KVI_NUM_POSSIBLE_MODE_PREFIX_CHARS]; // the mode prefixes above in a table
+	kvi_u32_t * m_pModePrefixTable;        // the mode prefixes above in a table
+	unsigned int m_uPrefixes;
 	QString m_szSupportedModeFlags;        // the actually used mode flags     ov
 	QString m_szSupportedChannelTypes;     // the supported channel types
 	bool m_bSupportsModesIe;               // supports the channel modes I and e ?
@@ -53,6 +97,7 @@ private:
 	QString m_szListModes; 
 	QString m_szPlainModes;
 public:
+	char  registerModeChar() { return m_pServInfo ?  m_pServInfo->getRegisterModeChar() : 0; };
 	const QString & name(){ return m_szName; };
 	const QString & supportedUserModes(){ return m_szSupportedUserModes; };
 	const QString & supportedChannelModes(){ return m_szSupportedChannelModes; };
@@ -64,15 +109,26 @@ public:
 	bool supportsModesIe(){ return m_bSupportsModesIe; };
 	bool supportsWatchList(){ return m_bSupportsWatchList; };
 	bool supportsCodePages(){ return m_bSupportsCodePages; };
-	bool isSupportedModePrefix(unsigned short c){ return (c < KVI_NUM_POSSIBLE_MODE_PREFIX_CHARS) ? (m_cModePrefixTable[c] != 0) : false; };
+
 	int maxTopicLen() { return m_iMaxTopicLen; };
 	int maxModeChanges() { return m_iMaxModeChanges; };
+	
+	void setServerVersion(const QString & version);
+	
+	const QString & getChannelModeDescription(QChar mode) { return m_pServInfo->getChannelModeDescription(mode); };
+	const QString & getUserModeDescription(QChar mode) { return m_pServInfo->getUserModeDescription(mode); };
+	
+	bool isSupportedModePrefix(QChar c);
+	bool isSupportedModeFlag(QChar c);
+	QChar modePrefixChar(kvi_u32_t flag);
+	QChar modeFlagChar(kvi_u32_t flag);
+	kvi_u32_t modeFlagFromPrefixChar(QChar c);
+	kvi_u32_t modeFlagFromModeChar(QChar c);
 protected:
 	void setName(const QString &szName){ m_szName = szName; };
 	void setSupportedUserModes(const QString &szSupportedUserModes){ m_szSupportedUserModes = szSupportedUserModes; };
-	void setSupportedModeFlags(const QString &szSupportedModeFlags){ m_szSupportedModeFlags = szSupportedModeFlags; };
 	void setSupportedChannelModes(const QString &szSupportedChannelModes);
-	void setSupportedModePrefixes(const QString &szSupportedModePrefixes);
+	void setSupportedModePrefixes(const QString &szSupportedModePrefixes,const QString &szSupportedModeFlags);
 	void setSupportedChannelTypes(const QString &szSupportedChannelTypes){ m_szSupportedChannelTypes = szSupportedChannelTypes; };
 	void setSupportsWatchList(bool bSupportsWatchList){ m_bSupportsWatchList = bSupportsWatchList; };
 	void setSupportsCodePages(bool bSupportsCodePages){ m_bSupportsCodePages = bSupportsCodePages; };
