@@ -44,15 +44,17 @@ private:
 	QString    m_szLocalHostIp;       // the local host ip as found by resolveLocalHost() at connection startup
 	QString    m_szHostName;          // the local host name that the server reports
 	QString    m_szHostIp;            // the host name above resolved, if possible
+	QString    m_szAwayReason;
 	bool       m_bAway;               // is the user away ?
 	kvi_time_t m_tAway;               // time at that the user went away
 	QString    m_szNickBeforeAway;    // the nickname that the user had just before going away
-	/*	From bugtrack:
-	On many IRC networks the host is masked or hashed, and if one also is connected through a LAN, it is basically impossible to initiate DCC transfers, as 192.168.0.13 or similar will be sent as IP.
-
-	But IRC servers usually (at least in my experience) send the unmasked host in the 001 raw event with something like ":Welcome to the Internet Relay Chat network, nick!ident@host". I think it'd be a good idea to just grab the IP from that event and use it for DCC transfers by default.
-	*/
-	QString	   m_szUnmaskedHostName;  
+	// From bugtrack:
+	// On many IRC networks the host is masked or hashed, and if one also is connected through a LAN,
+	// it is basically impossible to initiate DCC transfers, as 192.168.0.13 or similar will be sent as IP.
+	// But IRC servers usually (at least in my experience) send the unmasked host in the 001 raw event
+	// with something like ":Welcome to the Internet Relay Chat network, nick!ident@host". I think
+	// it'd be a good idea to just grab the IP from that event and use it for DCC transfers by default.
+	QString    m_szUnmaskedHostName;
 public:
 	const QString & realName(){ return m_szRealName; };
 	const QString & nickName(){ return m_szNickName; };
@@ -62,6 +64,7 @@ public:
 	const QString & hostName(){ return m_szHostName; };
 	const QString & unmaskedHostName(){ return m_szUnmaskedHostName; };
 	const QString & hostIp(){ return m_szHostIp; };
+	const QString & awayReason() { return m_szAwayReason; };
 	bool hasUserMode(const QChar & m);
 	bool isAway(){ return m_bAway; };
 	time_t awayTime(){ return m_tAway; };
@@ -77,6 +80,7 @@ protected:
 	void setLocalHostIp(const QString &szLocalHostIp){ m_szLocalHostIp = szLocalHostIp; };
 	bool addUserMode(const QChar &m); // returns false if the mode was already there
 	bool removeUserMode(const QChar &m); // returns fales if the mode was not there
+	void setAwayReason(const QString& szReazon) { m_szAwayReason=szReazon; };
 	void setAway();
 	void setBack();
 };
