@@ -49,6 +49,9 @@
 #include "kvi_kvs_eventtriggers.h"
 #include "kvi_kvs_script.h"
 #include "kvi_netutils.h"
+#include "kvi_ircurl.h"
+#include "kvi_qcstring.h"
+#include "kvi_useridentity.h"
 
 #define __KVI_DEBUG__
 #include "kvi_debug.h"
@@ -131,7 +134,7 @@ void KviIrcContext::registerDataStreamMonitor(KviIrcDataStreamMonitor * m)
 {
 	if(!m_pMonitorList)
 	{
-		m_pMonitorList = new KviPtrList<KviIrcDataStreamMonitor>;
+		m_pMonitorList = new KviPointerList<KviIrcDataStreamMonitor>;
 		m_pMonitorList->setAutoDelete(false);
 	}
 	m_pMonitorList->append(m);
@@ -223,7 +226,7 @@ void KviIrcContext::registerContextWindow(KviWindow * pWnd)
 {
 	if(!m_pContextWindows)
 	{
-		m_pContextWindows = new KviPtrList<KviWindow>;
+		m_pContextWindows = new KviPointerList<KviWindow>;
 		m_pContextWindows->setAutoDelete(false);
 	}
 	m_pContextWindows->append(pWnd);
@@ -233,7 +236,7 @@ void KviIrcContext::registerDeadChannel(KviChannel * c)
 {
 	if(!m_pDeadChannels)
 	{
-		m_pDeadChannels = new KviPtrList<KviChannel>;
+		m_pDeadChannels = new KviPointerList<KviChannel>;
 		m_pDeadChannels->setAutoDelete(false);
 	}
 	m_pDeadChannels->append(c);
@@ -243,7 +246,7 @@ void KviIrcContext::registerDeadQuery(KviQuery * q)
 {
 	if(!m_pDeadQueries)
 	{
-		m_pDeadQueries = new KviPtrList<KviQuery>;
+		m_pDeadQueries = new KviPointerList<KviQuery>;
 		m_pDeadQueries->setAutoDelete(false);
 	}
 	m_pDeadQueries->append(q);
@@ -422,6 +425,7 @@ void KviIrcContext::connectToCurrentServer()
 					m_pAsynchronousConnectionData->bPortIsOk = true;
 					m_pAsynchronousConnectionData->bUseIpV6 = m_pSavedAsynchronousConnectionData->bUseIpV6;
 					m_pAsynchronousConnectionData->bUseSSL = m_pSavedAsynchronousConnectionData->bUseSSL;
+					m_pAsynchronousConnectionData->m_pReconnectInfo = m_pSavedAsynchronousConnectionData->m_pReconnectInfo;
 					// and the other info, only if not overridden by the user
 					if(m_pAsynchronousConnectionData->szBindAddress.isEmpty())
 						m_pAsynchronousConnectionData->szBindAddress = m_pSavedAsynchronousConnectionData->szBindAddress;
@@ -489,6 +493,7 @@ void KviIrcContext::connectToCurrentServer()
 		return;
 	}
 	
+
 	prx = srv->proxyServer(g_pProxyDataBase);
 	
 	if(!prx && (srv->proxy()!=-1) && KVI_OPTION_BOOL(KviOption_boolUseProxyHost))
@@ -505,8 +510,28 @@ void KviIrcContext::connectToCurrentServer()
 	if(m_pAsynchronousConnectionData)
 	{
 		szBindAddress = m_pAsynchronousConnectionData->szBindAddress;
+		srv->m_pReconnectInfo=m_pAsynchronousConnectionData->m_pReconnectInfo;
 	}
 
+	// Find out the identity we'll be using in this connection
+	// First check the server for one
+	
+	const KviUserIdentity * pIdentity = 0;
+	
+	QString szUserIdentityId = srv->userIdentityId();
+	if(!szUserIdentityId.isEmpty())
+		pIdentity = KviUserIdentityManager::instance()->findIdentity(szUserIdentityId);
+
+	// If not found, look in the network instead
+	if(!pIdentity)
+		szUserIdentityId = net->userIdentityId();
+
+	if(!szUserIdentityId.isEmpty())
+		pIdentity = KviUserIdentityManager::instance()->findIdentity(szUserIdentityId);
+	
+	// If not found, get the default identity (this is GRANTED to be never null, eventually filled up with defaults)
+	pIdentity = KviUserIdentityManager::instance()->defaultIdentity();
+
 
 	if(m_pConnection)delete m_pConnection;
 	m_pConnection = new KviIrcConnection(
@@ -516,7 +541,8 @@ void KviIrcContext::connectToCurrentServer()
 					srv,
 					prx,
 					szBindAddress.ptr()
-				)
+				),
+				new KviUserIdentity(*pIdentity)
 			);
 
 	setState(Connecting);
@@ -542,6 +568,7 @@ void KviIrcContext::connectToCurrentServer()
 	m_pSavedAsynchronousConnectionData->bUseSSL = srv->useSSL();
 	m_pSavedAsynchronousConnectionData->szPass = srv->password();
 	m_pSavedAsynchronousConnectionData->szInitUMode = srv->m_szInitUMode;
+	m_pSavedAsynchronousConnectionData->m_pReconnectInfo=srv->m_pReconnectInfo;
 
 	// this never fails!
 	m_pConnection->start();
@@ -651,11 +678,9 @@ void KviIrcContext::connectionEstabilished()
 	}
 
 	// Add to recent server list (build the url of type irc[6]://<server>:<port>
-	KviStr tmp(KviStr::Format,"irc%s//%s:%u",
-			connection()->server()->isIpV6() ? "6:" : ":",
-			connection()->server()->m_szHostname.utf8().data(),connection()->server()->m_uPort);
-
-	g_pApp->addRecentServer(tmp.ptr());
+	QString url;
+	KviIrcUrl::join(url,connection()->server());
+	g_pApp->addRecentServer(url);
 
 	// save the last server this console used
 	//if(m_pLastIrcServer)delete m_pLastIrcServer;
@@ -667,14 +692,18 @@ void KviIrcContext::connectionTerminated()
 	if(!m_pConnection)return; // this may happen in the destructor!
 
 	KviIrcServer oldServer(*(connection()->server()));
-	QString oldNickname = connection()->userInfo()->isAway() ? connection()->userInfo()->nickNameBeforeAway() : connection()->userInfo()->nickName();
+	if(oldServer.m_pReconnectInfo) delete oldServer.m_pReconnectInfo;
+	KviIrcServerReconnectInfo* pInfo = new KviIrcServerReconnectInfo();
+	pInfo->m_szNick = connection()->userInfo()->isAway() ? connection()->userInfo()->nickNameBeforeAway() : connection()->userInfo()->nickName();
+	pInfo->m_bIsAway=connection()->userInfo()->isAway();
+	pInfo->m_szAwayReason=connection()->userInfo()->awayReason();
 
 	// we consider it unexpected when we haven't sent a QUIT message and we're connected
 	// or alternatively when a simulation of such a termination is requested (this is used to keep the queries open etc..)
 	bool bUnexpectedDisconnect = (!(connection()->stateData()->sentQuit())) && (m_eState == KviIrcContext::Connected) ||
 									connection()->stateData()->simulateUnexpectedDisconnect();
 
-	KviStr szReconnectCmd;
+	QString szChannels,szProtectedChannels,szPasswords,szCurPass,szCurChan;
 
 	if(bUnexpectedDisconnect)
 	{
@@ -685,63 +714,45 @@ void KviIrcContext::connectionTerminated()
 				// FIXME: THIS SHOULD BE A KviIrcConnection FUNCTION
 				int idx = 0;
 				KviChannel * c;
+				QString szChannels,szProtectedChannels,szPasswords,szCurPass,szCurChan;
 				// first only chans without key, in groups of 4
 				for(c = connection()->channelList()->first();c;c = connection()->channelList()->next())
 				{
-					if(c->channelKey().isEmpty())
+					szCurPass=c->channelKey();
+					szCurChan = c->windowName();
+					if(szCurPass.isEmpty())
 					{
-						idx++;
-						if(idx == 1)
-							szReconnectCmd.append("join ");
-						else
-							szReconnectCmd.append(",");
-						QString szChanName = c->windowName();
-						szChanName.replace("(","\\(");
-						szChanName.replace("\\","\\\\");
-						szReconnectCmd.append(szChanName);
-						if(idx == 4)
-						{
-							szReconnectCmd.append(";");
-							idx = 0; // 4 channels per join (this should be safe)
-						}
+						if(!szChannels.isEmpty())
+							szChannels.append(",");
+						szChannels.append(szCurChan);
+					} else {
+						if(!szProtectedChannels.isEmpty())
+							szProtectedChannels.append(",");
+						szProtectedChannels.append(szCurChan);
+						if(!szPasswords.isEmpty())
+							szPasswords.append(",");
+						szPasswords.append(szCurPass);
 					}
 				}
-				if((!szReconnectCmd.isEmpty()) && (idx != 0))szReconnectCmd.append(";");
-				// now channels with key
-				for(c = connection()->channelList()->first();c;c = connection()->channelList()->next())
+				if( (!szChannels.isEmpty()) || (!szProtectedChannels.isEmpty()) )
 				{
-					if(!c->channelKey().isEmpty())
-					{
-						szReconnectCmd.append("join ");
-						szReconnectCmd.append(c->windowName());
-						szReconnectCmd.append(" ");
-						szReconnectCmd.append(c->channelKey());
-						szReconnectCmd.append(";");
-					}
+					pInfo->m_szJoinChannels.append(szProtectedChannels);
+					if(!szProtectedChannels.isEmpty() && !szChannels.isEmpty())
+						pInfo->m_szJoinChannels.append(',');
+					pInfo->m_szJoinChannels.append(szChannels);
+					pInfo->m_szJoinChannels.append(" ");
+					pInfo->m_szJoinChannels.append(szPasswords);
 				}
 			}
 	
-			KviStr szQuery;
 	
 			if(KVI_OPTION_BOOL(KviOption_boolReopenQueriesAfterReconnect))
 			{
-				// FIXME: THIS SHOULD BE A KviIrcConnection FUNCTION
 				for(KviQuery * q = connection()->queryList()->first();q;q = connection()->queryList()->next())
 				{
-					if(szQuery.isEmpty())szQuery.append("query ");
-					else szQuery.append(",");
-					QString szQueryName = q->target();
-					szQueryName.replace("(","\\(");
-					szQueryName.replace("\\","\\\\");
-					szQuery.append(szQueryName);
+					pInfo->m_szOpenQueryes.append(q->target());
 				}
 			}
-	
-			if(szQuery.hasData())
-			{
-				if(szReconnectCmd.hasData())szReconnectCmd.append(';');
-				szReconnectCmd.append(szQuery);
-			}
 		}
 
 		if(KVI_OPTION_BOOL(KviOption_boolKeepChannelsOpenOnUnexpectedDisconnect) || KVI_OPTION_BOOL(KviOption_boolKeepChannelsOpenOnDisconnect))
@@ -785,9 +796,8 @@ void KviIrcContext::connectionTerminated()
 		d->bUseIpV6 = oldServer.isIpV6();
 		d->bUseSSL = oldServer.useSSL();
 		d->szPass = oldServer.password();
-		d->szNick = oldNickname;
 		d->szInitUMode = oldServer.m_szInitUMode;
-		d->szCommandToExecAfterConnect = szReconnectCmd;
+		d->m_pReconnectInfo = pInfo;
 		setAsynchronousConnectionData(d);
 
 		beginAsynchronousConnect(1000 * KVI_OPTION_UINT(KviOption_uintAutoReconnectDelay));
@@ -843,7 +853,7 @@ void KviIrcContext::terminateConnectionRequest(bool bForce,const QString &szQuit
 					ret.asString(buffer);
 				else
 					buffer = szQuit;
-				QCString dat = console()->encodeText(buffer);
+				KviQCString dat = console()->encodeText(buffer);
 				bWasSentQuit = false;
 				connection()->stateData()->setSentQuit();
 				connection()->sendFmtData("QUIT :%s",dat.data() ? dat.data() : ""); // here theoretically we COULD get disconnected
