@@ -65,6 +65,8 @@ KviIrcLink::KviIrcLink(KviIrcConnection * pConnection)
 	m_pTarget = pConnection->target();
 	m_pConsole = m_pConnection->console();
 	m_pSocket = 0;
+	
+	m_pLinkFilter = 0;
 
 	m_pResolver = 0;
 
@@ -78,7 +80,7 @@ KviIrcLink::KviIrcLink(KviIrcConnection * pConnection)
 KviIrcLink::~KviIrcLink()
 {
 	if(m_pResolver)delete m_pResolver;
-	if(m_pSocket)destroySocket();
+	destroySocket();
 	if(m_pReadBuffer)kvi_free(m_pReadBuffer);
 }
 
@@ -88,42 +90,50 @@ KviIrcLink::~KviIrcLink()
 // KviIrcSocket management
 //
 
-void KviIrcLink::socketDestroyed()
+void KviIrcLink::linkFilterDestroyed()
 {
-	// ops.. the link has been destroyed without permission :D
+	// ops.. the link filter has been destroyed without permission :D
 	// this should NEVER happen (?)
-	__ASSERT(false);
 	
-	m_pSocket = 0;
+	m_pLinkFilter = 0;
 	m_pConsole->output(KVI_OUT_SYSTEMWARNING,
-		__tr2qs("Ops... for some reason the link object has been destroyed"));
-	createSocket(QString::null); // we need a new one
+		__tr2qs("Ops... for some reason the link filter object has been destroyed"));
+
 }
 
 void KviIrcLink::destroySocket()
 {
-	if(!m_pSocket)return;
-	// disconnect , in particular kill the destroyed() signal
-	disconnect(m_pSocket,0,this,0);
-	// the module extension server links must be destroyed in the module that provided it
-	if(m_pSocket->inherits("KviMexLinkFilter"))((KviMexLinkFilter *)m_pSocket)->die();
-	else delete m_pSocket; // we can simply delete the builtin objects
-	m_pSocket = 0;
+	if(m_pLinkFilter)
+	{
+		QObject::disconnect(m_pLinkFilter,0,this,0);
+		// the module extension server links must be destroyed in the module that provided it
+		m_pLinkFilter->die();
+		m_pLinkFilter = 0;
+	}
+
+	if(m_pSocket)
+	{
+		delete m_pSocket;
+		m_pSocket = 0;
+	}
 }
 
 void KviIrcLink::createSocket(const QString &szLinkFilterName)
 {
-	if(m_pSocket)destroySocket();
+	destroySocket(); // make sure we do not leak memory
 
-	if(szLinkFilterName.isEmpty())goto alloc_builtin_socket;
-	if(KviQString::equalCI(szLinkFilterName,"irc"))goto alloc_builtin_socket;
+	m_pSocket = new KviIrcSocket(this);
 
-	m_pSocket = (KviIrcSocket *)g_pModuleExtensionManager->allocateExtension("linkfilter",
+	if(szLinkFilterName.isEmpty())return;
+	
+	if(KviQString::equalCI(szLinkFilterName,"irc"))return;
+
+	m_pLinkFilter = (KviMexLinkFilter *)g_pModuleExtensionManager->allocateExtension("linkfilter",
 								szLinkFilterName.utf8().data(),m_pConsole,0,this,szLinkFilterName.utf8().data());
 
-	if(m_pSocket)
+	if(m_pLinkFilter)
 	{
-		connect(m_pSocket,SIGNAL(destroyed()),this,SLOT(socketDestroyed()));
+		connect(m_pLinkFilter,SIGNAL(destroyed()),this,SLOT(linkFilterDestroyed()));
 		m_pConsole->output(KVI_OUT_SYSTEMMESSAGE,
 			__tr2qs("Using filtered IRC protocol: Link filter is \"%Q\""),&szLinkFilterName);
 		return;
@@ -131,9 +141,6 @@ void KviIrcLink::createSocket(const QString &szLinkFilterName)
 
 	m_pConsole->output(KVI_OUT_SYSTEMWARNING,
 			__tr2qs("Failed to set up the link filter \"%Q\", will try with plain IRC"),&szLinkFilterName);
-
-alloc_builtin_socket:
-	m_pSocket = new KviIrcSocket(this);
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -207,8 +214,14 @@ void KviIrcLink::resolverTerminated()
 // Incoming data processing
 //
 
-void KviIrcLink::processData(char * buffer,int)
+void KviIrcLink::processData(char * buffer,int len)
 {
+	if(m_pLinkFilter)
+	{
+		m_pLinkFilter->processData(buffer,len);
+		return;
+	}
+
 	register char *p=buffer;
 	char *beginOfCurData = buffer;
 	int   bufLen = 0;
@@ -317,6 +330,11 @@ bool KviIrcLink::sendPacket(KviDataBuffer * pData)
         pData = 0;
 		return false;
 	}
+
+	// if we have a filter, let it do its job
+	if(m_pLinkFilter)
+		return m_pLinkFilter->sendPacket(pData);
+
 	return m_pSocket->sendPacket(pData);
 }
 
