@@ -45,6 +45,7 @@
 #include "kvi_qstring.h"
 #include "kvi_lagmeter.h"
 #include "kvi_kvs_eventtriggers.h"
+#include "kvi_qcstring.h"
 
 #include <qstringlist.h>
 
@@ -149,9 +150,6 @@ bool KviNotifyListManager::handleWatchReply(KviIrcMessage *)
 	return false;
 }
 
-// kvi_app.cpp
-extern KviRegisteredUserDataBase * g_pRegisteredUserDataBase;
-
 void KviNotifyListManager::notifyOnLine(const QString &nick,const QString &user,const QString &host,const QString &szReason,bool bJoin)
 {
 	if(bJoin)
@@ -168,8 +166,8 @@ void KviNotifyListManager::notifyOnLine(const QString &nick,const QString &user,
 	else
 		KviQString::sprintf(szWho,"\r!n\r%Q\r",&nick);
 	
-	QDict<KviRegisteredUser> * d = g_pRegisteredUserDataBase->userDict();
-	QDictIterator<KviRegisteredUser> it(*d);
+	KviPointerHashTable<QString,KviRegisteredUser> * d = g_pRegisteredUserDataBase->userDict();
+	KviPointerHashTableIterator<QString,KviRegisteredUser> it(*d);
 	QString szNotify;
 	
 	while(KviRegisteredUser * u = it.current())
@@ -228,8 +226,8 @@ void KviNotifyListManager::notifyOffLine(const QString &nick,const QString &user
 	
 		QString szMsg;
 		
-		QDict<KviRegisteredUser> * d = g_pRegisteredUserDataBase->userDict();
-		QDictIterator<KviRegisteredUser> it(*d);
+		KviPointerHashTable<QString,KviRegisteredUser> * d = g_pRegisteredUserDataBase->userDict();
+		KviPointerHashTableIterator<QString,KviRegisteredUser> it(*d);
 		QString szNotify;
 		
 		while(KviRegisteredUser * u = it.current())
@@ -321,15 +319,15 @@ void KviNotifyListManager::notifyOffLine(const QString &nick,const QString &user
 KviIsOnNotifyListManager::KviIsOnNotifyListManager(KviIrcConnection * pConnection)
 : KviNotifyListManager(pConnection)
 {
-	m_pRegUserDict = new QDict<QString>(17,false); // case insensitive , copy keys
+	m_pRegUserDict = new KviPointerHashTable<QString,QString>(17,false); // case insensitive , copy keys
 	m_pRegUserDict->setAutoDelete(true);
-	m_pNotifyList  = new KviPtrList<QString>;
+	m_pNotifyList  = new KviPointerList<QString>;
 	m_pNotifyList->setAutoDelete(true);
-	m_pIsOnList = new KviPtrList<QString>;
+	m_pIsOnList = new KviPointerList<QString>;
 	m_pIsOnList->setAutoDelete(true);
-	m_pOnlineList = new KviPtrList<QString>;
+	m_pOnlineList = new KviPointerList<QString>;
 	m_pOnlineList->setAutoDelete(true);
-	m_pUserhostList = new KviPtrList<QString>;
+	m_pUserhostList = new KviPointerList<QString>;
 	m_pUserhostList->setAutoDelete(true);
 	m_pDelayedNotifyTimer = new QTimer();
 	connect(m_pDelayedNotifyTimer,SIGNAL(timeout()),this,SLOT(newNotifySession()));
@@ -378,8 +376,8 @@ void KviIsOnNotifyListManager::buildRegUserDict()
 {
 	m_pRegUserDict->clear();
 
-	const QDict<KviRegisteredUser> * d = g_pRegisteredUserDataBase->userDict();
-	QDictIterator<KviRegisteredUser> it(*d);
+	const KviPointerHashTable<QString,KviRegisteredUser> * d = g_pRegisteredUserDataBase->userDict();
+	KviPointerHashTableIterator<QString,KviRegisteredUser> it(*d);
 	while(KviRegisteredUser * u = it.current())
 	{
 		QString notify;
@@ -437,7 +435,7 @@ void KviIsOnNotifyListManager::newNotifySession()
 void KviIsOnNotifyListManager::buildNotifyList()
 {
 	m_pNotifyList->clear();
-	QDictIterator<QString> it(*m_pRegUserDict);
+	KviPointerHashTableIterator<QString,QString> it(*m_pRegUserDict);
 	while(it.current())
 	{
 		m_pNotifyList->append(new QString(it.currentKey()));
@@ -491,7 +489,7 @@ void KviIsOnNotifyListManager::sendIsOn()
 {
 	if(_OUTPUT_PARANOIC)
 		m_pConsole->output(KVI_OUT_SYSTEMMESSAGE,__tr2qs("Notify list: Checking for: %Q"),&m_szIsOnString);
-	QCString szDec = m_pConnection->encodeText(m_szIsOnString);
+	KviQCString szDec = m_pConnection->encodeText(m_szIsOnString);
 	m_pConnection->sendFmtData("ISON %s",szDec.data());
 	if(m_pConnection->lagMeter())
 		m_pConnection->lagMeter()->lagCheckRegister("@notify_ison",40); // not that reliable
@@ -508,7 +506,7 @@ bool KviIsOnNotifyListManager::handleIsOn(KviIrcMessage *msg)
 	// Check if it is our ISON
 	// all the nicks must be on the IsOnList
 
-	KviPtrList<QString> tmplist;
+	KviPointerList<QString> tmplist;
 	tmplist.setAutoDelete(false);
 
 	KviStr nk;
@@ -586,7 +584,7 @@ bool KviIsOnNotifyListManager::handleIsOn(KviIrcMessage *msg)
 
 	KviIrcUserDataBase * db = console()->connection()->userDataBase();
 
-	KviPtrList<QString> l;
+	KviPointerList<QString> l;
 	l.setAutoDelete(false);
 
 	for(s = m_pOnlineList->first();s;s = m_pOnlineList->next())
@@ -604,7 +602,7 @@ bool KviIsOnNotifyListManager::handleIsOn(KviIrcMessage *msg)
 					// mmmh...we have more than one ref , so the user is at least in one query or channel
 					// look him up on channels , if we find his entry , we can be sure that he is
 					// still the right user
-					KviPtrList<KviChannel> * chlist = m_pConsole->connection()->channelList();
+					KviPointerList<KviChannel> * chlist = m_pConsole->connection()->channelList();
 					for(KviChannel * ch = chlist->first();ch;ch = chlist->next())
 					{
 						if(KviUserListEntry * le = ch->findEntry(*s))
@@ -761,7 +759,7 @@ void KviIsOnNotifyListManager::sendUserhost()
 {
 	if(_OUTPUT_PARANOIC)
 		m_pConsole->output(KVI_OUT_SYSTEMMESSAGE,__tr2qs("Notify list: Checking userhost for: %Q"),&m_szUserhostString);
-	QCString ccc = m_pConnection->encodeText(m_szUserhostString);
+	KviQCString ccc = m_pConnection->encodeText(m_szUserhostString);
 	m_pConnection->sendFmtData("USERHOST %s",ccc.data());
 	if(m_pConnection->lagMeter())
 		m_pConnection->lagMeter()->lagCheckRegister("@notify_userhost",50);
@@ -774,7 +772,7 @@ bool KviIsOnNotifyListManager::handleUserhost(KviIrcMessage *msg)
 {
 	if(!m_bExpectingUserhost)return false;
 	// first check for consistency: all the replies must be on the USERHOST list
-	KviPtrList<KviIrcMask> tmplist;
+	KviPointerList<KviIrcMask> tmplist;
 	tmplist.setAutoDelete(true);
 
 	KviStr nk;
@@ -907,7 +905,7 @@ void KviIsOnNotifyListManager::stop()
 KviStupidNotifyListManager::KviStupidNotifyListManager(KviIrcConnection * pConnection)
 : KviNotifyListManager(pConnection)
 {
-	m_pNickList = new KviPtrList<QString>;
+	m_pNickList = new KviPointerList<QString>;
 	m_pNickList->setAutoDelete(true);
 	m_iRestartTimer = 0;
 }
@@ -958,7 +956,7 @@ void KviStupidNotifyListManager::sendIsOn()
 	}
 	if(_OUTPUT_PARANOIC)
 		m_pConsole->output(KVI_OUT_SYSTEMMESSAGE,__tr2qs("Notify list: Checking for:%Q"),&m_szLastIsOnMsg);
-	QCString dat = m_pConnection->encodeText(m_szLastIsOnMsg);
+	KviQCString dat = m_pConnection->encodeText(m_szLastIsOnMsg);
 	m_pConnection->sendFmtData("ISON%s",dat.data());
 
 	if(m_pConnection->lagMeter())
@@ -1052,8 +1050,8 @@ void KviStupidNotifyListManager::stop()
 
 void KviStupidNotifyListManager::buildNickList()
 {
-	const QDict<KviRegisteredUser> * d = g_pRegisteredUserDataBase->userDict();
-	QDictIterator<KviRegisteredUser> it(*d);
+	const KviPointerHashTable<QString,KviRegisteredUser> * d = g_pRegisteredUserDataBase->userDict();
+	KviPointerHashTableIterator<QString,KviRegisteredUser> it(*d);
 	m_pNickList->clear();
 	while(it.current())
 	{
@@ -1075,7 +1073,7 @@ void KviStupidNotifyListManager::buildNickList()
 KviWatchNotifyListManager::KviWatchNotifyListManager(KviIrcConnection * pConnection)
 : KviNotifyListManager(pConnection)
 {
-	m_pRegUserDict = new QDict<QString>(17,false);
+	m_pRegUserDict = new KviPointerHashTable<QString,QString>(17,false);
 	m_pRegUserDict->setAutoDelete(true);
 }
 
@@ -1088,8 +1086,8 @@ void KviWatchNotifyListManager::buildRegUserDict()
 {
 	m_pRegUserDict->clear();
 
-	const QDict<KviRegisteredUser> * d = g_pRegisteredUserDataBase->userDict();
-	QDictIterator<KviRegisteredUser> it(*d);
+	const KviPointerHashTable<QString,KviRegisteredUser> * d = g_pRegisteredUserDataBase->userDict();
+	KviPointerHashTableIterator<QString,KviRegisteredUser> it(*d);
 	while(KviRegisteredUser * u = it.current())
 	{
 		QString notify;
@@ -1114,7 +1112,7 @@ void KviWatchNotifyListManager::start()
 
 	QString watchStr;
 
-	QDictIterator<QString> it(*m_pRegUserDict);
+	KviPointerHashTableIterator<QString,QString> it(*m_pRegUserDict);
 	while(it.current())
 	{
 		QString nk = it.currentKey();
@@ -1122,7 +1120,7 @@ void KviWatchNotifyListManager::start()
 		{
 			if((watchStr.length() + nk.length() + 2) > 501)
 			{
-				QCString dat = m_pConnection->encodeText(watchStr);
+				KviQCString dat = m_pConnection->encodeText(watchStr);
 				m_pConnection->sendFmtData("WATCH%s",dat.data());
 				if(_OUTPUT_VERBOSE)
 					m_pConsole->output(KVI_OUT_SYSTEMMESSAGE,__tr2qs("Notify list: Adding watch entries for%Q"),&watchStr);
@@ -1135,7 +1133,7 @@ void KviWatchNotifyListManager::start()
 
 	if(!watchStr.isEmpty())
 	{
-		QCString dat = m_pConnection->encodeText(watchStr);
+		KviQCString dat = m_pConnection->encodeText(watchStr);
 		m_pConnection->sendFmtData("WATCH%s",dat.data());
 		if(_OUTPUT_VERBOSE)
 			m_pConsole->output(KVI_OUT_SYSTEMMESSAGE,__tr2qs("Notify list: Adding watch entries for%Q"),&watchStr);
