@@ -41,6 +41,7 @@
 #include "kvi_splash.h"
 #include "kvi_frame.h"
 #include "kvi_internalcmd.h"
+#include "kvi_theme.h"
 #include <qmessagebox.h>
 #include <qregexp.h>
 //#include "kvi_textencoding.h"
@@ -49,13 +50,16 @@
 #include <qdom.h>
 //!xml parser
 
+#include <zlib.h>
+#include <qtextcodec.h>
+
 #include "kvi_fileutils.h"
 
 #include <qdir.h>
 #include <qstringlist.h>
 
 // kvi_app.cpp
-extern KVIRC_API bool g_bIdentDaemonRunning;
+extern KVIRC_API int g_iIdentDaemonRunningUsers;
 
 
 #define RECT_OPTION(_txt,_val,_flags) KviRectOption(KVI_RECT_OPTIONS_PREFIX _txt, _val , _flags)
@@ -235,7 +239,7 @@ KviBoolOption g_boolOptionsTable[KVI_NUM_BOOL_OPTIONS]=
 	BOOL_OPTION("HighlightOnlyNormalMsgQueryToo",false,KviOption_sectFlagFrame),
 	BOOL_OPTION("HighlightOnlyNormalMsgNickinChanToo",false,KviOption_sectFlagFrame),
 	BOOL_OPTION("HighlightOnlyAtCustomHighlightLevel",false,KviOption_sectFlagFrame),
-	BOOL_OPTION("MdiManagerInSdiMode",false,KviOption_sectFlagFrame),
+	BOOL_OPTION("MdiManagerInSdiMode",true,KviOption_sectFlagFrame),
 	BOOL_OPTION("DccBrokenBouncerHack",false,KviOption_sectFlagDcc),
 	BOOL_OPTION("ExternalMessagesToActiveWindow",true,KviOption_sectFlagConnection),
 	BOOL_OPTION("IgnoreChannelAvatarRequestsWhenNoAvatarSet",true,KviOption_sectFlagAvatar),
@@ -270,7 +274,7 @@ KviBoolOption g_boolOptionsTable[KVI_NUM_BOOL_OPTIONS]=
 	BOOL_OPTION("ScriptErrorsToDebugWindow",false,KviOption_sectFlagFrame),
 	BOOL_OPTION("ShowMinimizedDebugWindow",true,KviOption_sectFlagFrame),
 	BOOL_OPTION("ShowExtendedInfoInQueryLabel",true,KviOption_resetUpdateGui),
-	BOOL_OPTION("UseUserListColorsAsNickColors",false,KviOption_sectFlagIrcView),
+	BOOL_OPTION("UseUserListColorsAsNickColors",true,KviOption_sectFlagIrcView | KviOption_groupTheme),
 	BOOL_OPTION("GzipLogs",false,KviOption_sectFlagLogging),
 	BOOL_OPTION("MinimizeInTray",false,KviOption_resetUpdateGui),
 	BOOL_OPTION("DisableNotifierFlashing",false,KviOption_sectFlagFrame),
@@ -289,7 +293,20 @@ KviBoolOption g_boolOptionsTable[KVI_NUM_BOOL_OPTIONS]=
 	BOOL_OPTION("HideWindowToolButtons",true,KviOption_sectFlagFrame),
 	BOOL_OPTION("HideInputToolButtons",true,KviOption_sectFlagFrame),
 	BOOL_OPTION("StripControlCodesInLogs",false,KviOption_sectFlagLogging),
-	BOOL_OPTION("DisableTrayIconFlashing",false,KviOption_sectFlagFrame)
+	BOOL_OPTION("EnableTrayIconFlashing",true,KviOption_sectFlagFrame),
+	BOOL_OPTION("UseFlatClassicTaskbarButtons",false,KviOption_sectFlagTaskBar | KviOption_resetUpdateGui | KviOption_groupTheme),
+	BOOL_OPTION("ShowTreeTaskbarHeader",false,KviOption_sectFlagTaskBar | KviOption_resetUpdateGui | KviOption_groupTheme),
+	BOOL_OPTION("UseLevelBasedTrayNotification",false,KviOption_sectFlagFrame),
+	BOOL_OPTION("MuteAllSounds",false,KviOption_sectFlagFrame),
+	BOOL_OPTION("CreateMinimizedChannels",false,KviOption_sectFlagFrame),
+	BOOL_OPTION("ShowNetworkNameForConsoleTaskBarEntry",true,KviOption_sectFlagFrame | KviOption_resetUpdateGui),
+	BOOL_OPTION("DrawGenderIcons",true,KviOption_sectFlagFrame | KviOption_resetUpdateGui | KviOption_groupTheme),
+	BOOL_OPTION("PrependGenderInfoToRealname",true,KviOption_sectFlagConnection),
+	BOOL_OPTION("UseIdentServiceOnlyOnConnect",true,KviOption_sectFlagConnection | KviOption_resetRestartIdentd),
+	BOOL_OPTION("UseSystemUrlHandlers",true,KviOption_sectFlagUrl),
+	BOOL_OPTION("ScaleAvatarsOnLoad",true,KviOption_sectFlagAvatar),
+	BOOL_OPTION("DisableNotifierFadein",false,KviOption_sectFlagFrame),
+	BOOL_OPTION("UseAntiAliasing",true,KviOption_sectFlagGui | KviOption_resetUpdateGui),
 };
 
 #define STRING_OPTION(_txt,_val,_flags) KviStringOption(KVI_STRING_OPTIONS_PREFIX _txt,_val,_flags)
@@ -297,7 +314,7 @@ KviBoolOption g_boolOptionsTable[KVI_NUM_BOOL_OPTIONS]=
 // FIXME: #warning "Remove the unused string options here!"
 
 #ifdef COMPILE_ON_WINDOWS
-	#define RUN_THE_BROWSER "run cmd.exe /c start $0"
+	#define RUN_THE_BROWSER "run \"cmd.exe /c start \\\"\\\" \\\"$0\\\"\""
 #else
 	#ifdef COMPILE_KDE_SUPPORT
 		#define RUN_THE_BROWSER "run kfmclient openURL $0"
@@ -345,15 +362,15 @@ KviStringOption g_stringOptionsTable[KVI_NUM_STRING_OPTIONS]=
 	STRING_OPTION("CustomAwayNick", KVI_DEFAULT_AWAY_NICK,KviOption_sectFlagConnection),
 	STRING_OPTION("DefaultDccFakeAddress","",KviOption_sectFlagDcc),
 	STRING_OPTION("CtcpPageReply",KVI_DEFAULT_CTCP_PAGE_REPLY,KviOption_sectFlagCtcp),
-	STRING_OPTION("SSLCertificatePath","",KviOption_sectFlagConnection),
+	STRING_OPTION("SSLCertificatePath","",KviOption_sectFlagConnection | KviOption_encodePath),
 	STRING_OPTION("SSLCertificatePass","",KviOption_sectFlagConnection),
-	STRING_OPTION("SSLPrivateKeyPath","",KviOption_sectFlagConnection),
+	STRING_OPTION("SSLPrivateKeyPath","",KviOption_sectFlagConnection | KviOption_encodePath),
 	STRING_OPTION("SSLPrivateKeyPass","",KviOption_sectFlagConnection),
 	STRING_OPTION("SoundSystem","unknown",KviOption_sectFlagFrame),
 	STRING_OPTION("DefaultUserMode", "", KviOption_sectFlagUser),
-	STRING_OPTION("LastImageDialogPath","",KviOption_sectFlagUser),
-	STRING_OPTION("IconThemeSubdir","",KviOption_sectFlagUser | KviOption_groupTheme | KviOption_resetReloadImages),
-	STRING_OPTION("IncomingPath","",KviOption_sectFlagUser),
+	STRING_OPTION("LastImageDialogPath","",KviOption_sectFlagUser | KviOption_encodePath),
+	STRING_OPTION("IconThemeSubdir","",KviOption_sectFlagUser | KviOption_groupTheme | KviOption_resetReloadImages | KviOption_encodePath),
+	STRING_OPTION("IncomingPath","",KviOption_sectFlagUser | KviOption_encodePath),
 	STRING_OPTION("MyAvatar","",KviOption_sectFlagUser),
 	STRING_OPTION("DefaultTextEncoding","",KviOption_sectFlagFrame),
 	STRING_OPTION("WinampTextEncoding","",KviOption_sectFlagFrame),
@@ -367,7 +384,8 @@ KviStringOption g_stringOptionsTable[KVI_NUM_STRING_OPTIONS]=
 	STRING_OPTION("OnHighlightedMessageSound","",KviOption_sectFlagFrame),
 	STRING_OPTION("OnMeKickedSound","",KviOption_sectFlagFrame),
 	STRING_OPTION("OnQueryMessageSound","",KviOption_sectFlagFrame),
-	STRING_OPTION("IrcViewTimestampFormat","[hh:mm:ss]",KviOption_sectFlagIrcView)
+	STRING_OPTION("IrcViewTimestampFormat","[hh:mm:ss]",KviOption_sectFlagIrcView),
+	STRING_OPTION("PreferredTorrentClient","auto",KviOption_sectFlagFrame)
 };
 
 #define STRINGLIST_OPTION(_txt,_flags) \
@@ -385,7 +403,8 @@ KviStringListOption g_stringlistOptionsTable[KVI_NUM_STRINGLIST_OPTIONS]=
 	STRINGLIST_OPTION("RecentServers",KviOption_sectFlagRecent),
 	STRINGLIST_OPTION("RecentNicknames",KviOption_sectFlagRecent),
 	STRINGLIST_OPTION("ModuleExtensionToolbars",KviOption_sectFlagFrame),
-	STRINGLIST_OPTION("ImageSearchPaths",KviOption_sectFlagFrame),
+	STRINGLIST_OPTION("ImageSearchPaths",KviOption_sectFlagFrame | KviOption_encodePath),
+	STRINGLIST_OPTION("RecentIrcUrls",KviOption_sectFlagRecent)
 };
 
 #define MIRC_COLOR_OPTION(_num,_red,_green,_blue) \
@@ -566,7 +585,7 @@ KviUIntOption g_uintOptionsTable[KVI_NUM_UINT_OPTIONS]=
 	UINT_OPTION("DccMinPort",30000,KviOption_sectFlagDcc),
 	UINT_OPTION("DccMaxPort",31000,KviOption_sectFlagDcc),
 	UINT_OPTION("SoundOfferTimeoutInSecs",60,KviOption_sectFlagConnection),
-	UINT_OPTION("MaximumRequestedAvatarSize",102400,KviOption_sectFlagAvatar),
+	UINT_OPTION("MaximumRequestedAvatarSize",256000,KviOption_sectFlagAvatar),
 	UINT_OPTION("TreeTaskBarMaximumWidth",200,KviOption_sectFlagTaskBar | KviOption_resetUpdateTaskBar),
 	UINT_OPTION("PasteDelay",2000,KviOption_sectFlagInput),
 	UINT_OPTION("MaxDccSendTransfers",10,KviOption_sectFlagDcc),
@@ -595,7 +614,14 @@ KviUIntOption g_uintOptionsTable[KVI_NUM_UINT_OPTIONS]=
 	UINT_OPTION("ToolBarAppletPixmapAlign",0,KviOption_sectFlagFrame | KviOption_groupTheme),
 	UINT_OPTION("TreeTaskBarPixmapAlign",0,KviOption_sectFlagFrame | KviOption_groupTheme),
 	UINT_OPTION("InputPixmapAlign",0,KviOption_sectFlagFrame | KviOption_groupTheme),
-	UINT_OPTION("AutoFlushLogs",30,KviOption_sectFlagFrame )
+	UINT_OPTION("AutoFlushLogs",30,KviOption_sectFlagFrame ),
+	UINT_OPTION("MinTrayLowLevelMessage",1,KviOption_sectFlagFrame ),
+	UINT_OPTION("MinTrayHighLevelMessage",4,KviOption_sectFlagFrame ),
+	UINT_OPTION("IdentdOutputMode",KviIdentdOutputMode::Quiet,KviOption_sectFlagConnection ),
+	UINT_OPTION("ScaleAvatarsOnLoadHeight",600,KviOption_sectFlagAvatar ),
+	UINT_OPTION("ScaleAvatarsOnLoadWidth",800,KviOption_sectFlagAvatar ),
+	UINT_OPTION("NotifierActiveTransparency",90,KviOption_sectFlagFrame ),
+	UINT_OPTION("NotifierInactiveTransparency",40,KviOption_sectFlagFrame )
 };
 
 #define FONT_OPTION(_name,_face,_size,_flags) \
@@ -791,7 +817,13 @@ KviMsgTypeOption g_msgtypeOptionsTable[KVI_NUM_MSGTYPE_OPTIONS]=
 	MSGTYPE_OPTION("MeChanUnOwner",__tr_no_lookup("Own chan owner status unset"),KVI_SMALLICON_MECHANUNOWNER,KVI_MSGTYPE_LEVEL_5),
 	MSGTYPE_OPTION_SPEC("ServerError",__tr_no_lookup("Server error"),KVI_SMALLICON_SERVERERROR,KVI_RED,KVI_TRANSPARENT,KVI_MSGTYPE_LEVEL_5),
 	MSGTYPE_OPTION_SPEC("Help",__tr_no_lookup("Help"),KVI_SMALLICON_HELP,KVI_DARKGREEN,KVI_TRANSPARENT,KVI_MSGTYPE_LEVEL_1),
-	MSGTYPE_OPTION("TextEncoding",__tr_no_lookup("Text Encoding Server message"),KVI_SMALLICON_TEXTENCODING,KVI_MSGTYPE_LEVEL_1)
+	MSGTYPE_OPTION("TextEncoding",__tr_no_lookup("Text Encoding Server message"),KVI_SMALLICON_TEXTENCODING,KVI_MSGTYPE_LEVEL_1),
+	// TODO: add icon and check what level means
+	// Pragma: the message level is a warning level that is rendered in the taskbar
+	//         messages with higher level are rendered with more visible color (i.e. red)
+	//         messages with very high level might flash the tray and end up in the notifier
+	//         level 1 or 2 for standard torrent messages is ok
+	MSGTYPE_OPTION("BitTorrent",__tr_no_lookup("BitTorrent message"),KVI_SMALLICON_MULTIMEDIA,KVI_MSGTYPE_LEVEL_2)
 };
 
 static const char * options_section_table[KVI_NUM_OPTION_SECT_FLAGS] =
@@ -822,7 +854,7 @@ void KviApp::loadOptions()
 	{
 		KviConfig cfg(buffer.ptr(),KviConfig::Read);
 
-		int prg = 8;
+		int prg = 12;
 		int i;
 
 		#define READ_OPTIONS(_num,_table,_readFnc) \
@@ -845,6 +877,18 @@ void KviApp::loadOptions()
 		READ_OPTIONS(KVI_NUM_STRINGLIST_OPTIONS,g_stringlistOptionsTable,readStringListEntry)
 		READ_OPTIONS(KVI_NUM_MIRCCOLOR_OPTIONS,g_mirccolorOptionsTable,readColorEntry)
 		READ_OPTIONS(KVI_NUM_ICCOLOR_OPTIONS,g_iccolorOptionsTable,readColorEntry)
+		
+		for(i=0;i<KVI_NUM_STRING_OPTIONS;i++) 
+		{ 
+			if(g_stringOptionsTable[i].flags & KviOption_encodePath)
+				KviStringConversion::decodePath(g_stringOptionsTable[i].option);
+		} 
+
+		for(i=0;i<KVI_NUM_STRINGLIST_OPTIONS;i++) 
+		{ 
+			if(g_stringlistOptionsTable[i].flags & KviOption_encodePath)
+				KviStringConversion::decodePath(g_stringlistOptionsTable[i].option);
+		}
 
 		#undef READ_OPTIONS
 	} // else already have the defaults
@@ -870,144 +914,39 @@ void KviApp::saveOptions()
 
 	WRITE_OPTIONS(KVI_NUM_RECT_OPTIONS,g_rectOptionsTable)
 	WRITE_OPTIONS(KVI_NUM_BOOL_OPTIONS,g_boolOptionsTable)
+		for(i=0;i<KVI_NUM_STRING_OPTIONS;i++) 
+		{ 
+			if(g_stringOptionsTable[i].flags & KviOption_encodePath)
+				KviStringConversion::encodePath(g_stringOptionsTable[i].option);
+		}
 	WRITE_OPTIONS(KVI_NUM_STRING_OPTIONS,g_stringOptionsTable)
+		for(i=0;i<KVI_NUM_STRING_OPTIONS;i++) 
+		{ 
+			if(g_stringOptionsTable[i].flags & KviOption_encodePath)
+				KviStringConversion::decodePath(g_stringOptionsTable[i].option);
+		}
 	WRITE_OPTIONS(KVI_NUM_COLOR_OPTIONS,g_colorOptionsTable)
 	WRITE_OPTIONS(KVI_NUM_PIXMAP_OPTIONS,g_pixmapOptionsTable)
 	WRITE_OPTIONS(KVI_NUM_UINT_OPTIONS,g_uintOptionsTable)
 	WRITE_OPTIONS(KVI_NUM_FONT_OPTIONS,g_fontOptionsTable)
 	WRITE_OPTIONS(KVI_NUM_MSGTYPE_OPTIONS,g_msgtypeOptionsTable)
+	for(i=0;i<KVI_NUM_STRINGLIST_OPTIONS;i++) 
+		{ 
+			if(g_stringlistOptionsTable[i].flags & KviOption_encodePath)
+				KviStringConversion::encodePath(g_stringlistOptionsTable[i].option);
+		}
 	WRITE_OPTIONS(KVI_NUM_STRINGLIST_OPTIONS,g_stringlistOptionsTable)
+	for(i=0;i<KVI_NUM_STRINGLIST_OPTIONS;i++) 
+	{ 
+		if(g_stringlistOptionsTable[i].flags & KviOption_encodePath)
+			KviStringConversion::decodePath(g_stringlistOptionsTable[i].option);
+	}
 	WRITE_OPTIONS(KVI_NUM_MIRCCOLOR_OPTIONS,g_mirccolorOptionsTable)
 	WRITE_OPTIONS(KVI_NUM_ICCOLOR_OPTIONS,g_iccolorOptionsTable)
 
 	#undef WRITE_OPTIONS
 }
 
-/*
-void KviApp::loadThemeOptions(KviConfig * cfg)
-{
-	int i;
-
-	#define READ_OPTIONS(_num,_table,_readFnc) \
-	for(i=0;i<_num;i++) \
-	{ \
-		if(_table[i].flags & KviOption_groupTheme) \
-			_table[i].option = cfg->_readFnc(_table[i].name,_table[i].option); \
-	} \
-
-	READ_OPTIONS(KVI_NUM_RECT_OPTIONS,g_rectOptionsTable,readRectEntry)
-	READ_OPTIONS(KVI_NUM_BOOL_OPTIONS,g_boolOptionsTable,readBoolEntry)
-	READ_OPTIONS(KVI_NUM_STRING_OPTIONS,g_stringOptionsTable,readEntry)
-	READ_OPTIONS(KVI_NUM_COLOR_OPTIONS,g_colorOptionsTable,readColorEntry)
-	READ_OPTIONS(KVI_NUM_PIXMAP_OPTIONS,g_pixmapOptionsTable,readPixmapEntry)
-	READ_OPTIONS(KVI_NUM_UINT_OPTIONS,g_uintOptionsTable,readUIntEntry)
-	READ_OPTIONS(KVI_NUM_FONT_OPTIONS,g_fontOptionsTable,readFontEntry)
-	READ_OPTIONS(KVI_NUM_MSGTYPE_OPTIONS,g_msgtypeOptionsTable,readMsgTypeEntry)
-	READ_OPTIONS(KVI_NUM_STRINGLIST_OPTIONS,g_stringlistOptionsTable,readStringListEntry)
-	READ_OPTIONS(KVI_NUM_MIRCCOLOR_OPTIONS,g_mirccolorOptionsTable,readColorEntry)
-	READ_OPTIONS(KVI_NUM_ICCOLOR_OPTIONS,g_iccolorOptionsTable,readColorEntry)
-
-	#undef READ_OPTIONS
-}
-*/
-
-bool KviApp::loadThemeInfo(const QString &themeDir,KviThemeInfo &inf)
-{
-	KviStr szD = themeDir;
-	szD.append(KVI_PATH_SEPARATOR_CHAR);
-	szD.append("themeinfo.kvc");
-
-	if(!KviFileUtils::fileExists(szD.ptr()))return false;
-
-	KviConfig cfg(szD.ptr(),KviConfig::Read);
-
-	cfg.setGroup("ThemeInfo");
-
-	inf.szAbsoluteDirectory = themeDir;
-	inf.szName = cfg.readQStringEntry("Name","");
-	inf.szVersion = cfg.readQStringEntry("Version","");
-	inf.szAuthor = cfg.readQStringEntry("Author","");
-	inf.szDescription = cfg.readQStringEntry("Description","");
-	inf.szDate = cfg.readQStringEntry("Date","");
-	inf.szKvircVersion = cfg.readQStringEntry("KvircVersion","");
-
-	QString tmp = cfg.readQStringEntry("ThemeEngineVersion","");
-
-	szD = themeDir;
-	szD.append(KVI_PATH_SEPARATOR_CHAR);
-	szD.append("themedata.kvc");
-
-	if(!KviFileUtils::fileExists(szD.ptr()))return false;
-
-	return !(inf.szName.isEmpty() || inf.szKvircVersion.isEmpty() || tmp.isEmpty());
-}
-
-#define XML_READ_ATTR(_tag,_buff) \
-	list=pElement->elementsByTagName(_tag);\
-	if(list.count()>0) \
-		_buff=list.item(0).toElement().text();
-
-void KviApp::loadXmlTheme(QDomElement *pElement)
-{
-	KviThemeInfo info;
-	char * buf;
-	QDomNodeList list;
-	QFile file;
-	
-	info.szName=pElement->attribute("Name","Name");
-	info.szVersion=pElement->attribute("Version","0.0.0");
-	
-	XML_READ_ATTR("Author",info.szAuthor);
-	XML_READ_ATTR("Description",info.szDescription);
-	XML_READ_ATTR("Date",info.szDate);
-	XML_READ_ATTR("KvircVersion",info.szKvircVersion);
-	
-	info.szSubdirectory = info.szName + QString("-") + info.szVersion;
-	info.szSubdirectory.replace(QRegExp("[ \\\\/:][ \\\\/:]*"),"_");
-	
-	getLocalKvircDirectory(info.szAbsoluteDirectory,KviApp::Themes,info.szSubdirectory,true);
-	if(!KviFileUtils::makeDir(info.szAbsoluteDirectory))
-	{
-		QMessageBox::critical(0,__tr2qs("Load Theme - KVIrc"),__tr2qs("Unable to create theme directory."),
-			QMessageBox::Ok,QMessageBox::NoButton,QMessageBox::NoButton);
-		return;
-	}
-	KviQString::ensureLastCharIs(info.szAbsoluteDirectory,KVI_PATH_SEPARATOR_CHAR);
-	
-	list=pElement->elementsByTagName("FileSystem");
-	if(list.count()>0)
-	{
-		QDomElement element=list.item(0).toElement();
-		for( QDomNode n = element.firstChild(); !n.isNull(); n = n.nextSibling() )
-		{
-				if(n.nodeName()=="File" && n.isElement())
-				{
-					QDomElement tmp=n.toElement();
-					QString szName=tmp.attribute("name");
-					KviStr szValue=tmp.text();
-					
-					int len = szValue.base64ToBuffer(&buf);
-					file.setName(info.szAbsoluteDirectory+QFileInfo(szName).fileName());
-					if ( !file.open( IO_WriteOnly ) )
-						break;
-					
-					file.writeBlock(buf,len);
-					file.close();
-				}
-		}
-	}
-	KviConfig inf(info.szAbsoluteDirectory+"themeinfo.kvc",KviConfig::Write);
-
-	inf.setGroup("ThemeInfo");
-
-	inf.writeEntry("Version",info.szVersion);
-	inf.writeEntry("Name",info.szName);
-	inf.writeEntry("Author",info.szAuthor);
-	inf.writeEntry("Description",info.szDescription);
-	inf.writeEntry("Date",info.szDate);
-	inf.writeEntry("KvircVersion",info.szKvircVersion);
-	inf.writeEntry("ThemeEngineVersion","1.0.0");
-}
 
 #undef WRITE_OPTIONS
 
@@ -1017,361 +956,251 @@ void KviApp::loadXmlTheme(QDomElement *pElement)
 		if(_table[i].flags & KviOption_groupTheme) \
 			cfg.writeEntry(_table[i].name,_table[i].option); \
 	}
-	
-#define WRITE_MSGCOLORS_OPTIONS \
-	if(opt.bIncludeMsgColors) \
-	{\
-		for(i=0;i<KVI_NUM_MSGTYPE_OPTIONS;i++) \
-		{ \
-			cfg.writeEntry(g_msgtypeOptionsTable[i].name,g_msgtypeOptionsTable[i].option); \
-		}\
-	}
 
-#define SET_XML_THEME_OPTION(_option,_value) \
-	option = doc.createElement( _option ); \
-	cdata=doc.createTextNode(_value);\
-	option.appendChild(cdata);\
-	info.appendChild(option);\
-
-#define XML_APPEND_FILE(_name,_file) \
-	reader.setName(_file); \
-		if ( reader.open( IO_ReadOnly ) ) \
-		{ \
-			data = reader.readAll(); \
-			reader.close(); \
-			decoder.bufferToBase64((char*)(data.data()),data.size()); \
-			option = doc.createElement( "File" ); \
-			option.setAttribute("name",(_name)); \
-			cdata=doc.createTextNode(decoder.ptr()); \
-			option.appendChild(cdata); \
-			filesys.appendChild(option); \
-		}
-void KviApp::saveXmlTheme(KviThemeInfo &opt,const QString& filename)
+namespace KviTheme
 {
-	QDomDocument doc;
-
-	//XML storing
-	QDomElement info,root,option;
-	QDomText cdata;
-	
-	//file storing;
-	QFile reader;
-	QByteArray data;
-	KviStr decoder;
-	
-	doc.appendChild(doc.createProcessingInstruction("xml","version=\"1.0\" encoding=\"UTF-8\""));
-	
-	root = doc.createElement( "Package" );
-	doc.appendChild( root );
-	
-	info = doc.createElement( "Theme" );
-	root.appendChild( info );
-	root=info;
-	
-	info = doc.createElement( "ThemeInfo" );
-	root.appendChild( info );
-	
-	root.appendChild( info );
-	root.setAttribute("Name",opt.szName);
-	root.setAttribute("Version",opt.szVersion);
-
-	SET_XML_THEME_OPTION("Author",opt.szAuthor);
-	SET_XML_THEME_OPTION("Description",opt.szDescription);
-	SET_XML_THEME_OPTION("Date",opt.szDate);
-	SET_XML_THEME_OPTION("KvircVersion",opt.szKvircVersion);
-	SET_XML_THEME_OPTION("ThemeEngineVersion","1.0.0");
-	
-	QDomElement filesys = doc.createElement( "FileSystem" );
-	root.appendChild( filesys );
-	
-	QString szOptionsFile,szPixFile;
-	getLocalKvircDirectory(szOptionsFile,Tmp,"themedata.kvc",TRUE);
-	KviConfig cfg(szOptionsFile,KviConfig::Write);
-	
-	cfg.setGroup("ThemeData");
-
-	int i;
-
-	WRITE_OPTIONS(KVI_NUM_RECT_OPTIONS,g_rectOptionsTable)
-	WRITE_OPTIONS(KVI_NUM_BOOL_OPTIONS,g_boolOptionsTable)
-	WRITE_OPTIONS(KVI_NUM_STRING_OPTIONS,g_stringOptionsTable)
-	WRITE_OPTIONS(KVI_NUM_COLOR_OPTIONS,g_colorOptionsTable)
- 	WRITE_OPTIONS(KVI_NUM_UINT_OPTIONS,g_uintOptionsTable)
-	WRITE_OPTIONS(KVI_NUM_FONT_OPTIONS,g_fontOptionsTable)
-	WRITE_MSGCOLORS_OPTIONS
-	WRITE_OPTIONS(KVI_NUM_STRINGLIST_OPTIONS,g_stringlistOptionsTable)
-	WRITE_OPTIONS(KVI_NUM_MIRCCOLOR_OPTIONS,g_mirccolorOptionsTable)
-	WRITE_OPTIONS(KVI_NUM_ICCOLOR_OPTIONS,g_iccolorOptionsTable)
-	
-	for(i=0;i<KVI_NUM_PIXMAP_OPTIONS;i++)
+	// utility functions for the KviTheme namespace (kvi_theme.h)
+	// that are implemented here for convenience (in saving the options)
+	bool save(KviThemeInfo &options)
 	{
-		if(g_pixmapOptionsTable[i].flags & KviOption_groupTheme)
+		QString szD = options.absoluteDirectory();
+	
+		if(szD.isEmpty())
 		{
-			if(g_pixmapOptionsTable[i].option.pixmap())
+			options.setLastError(__tr2qs("Missing absolute directory for the theme information"));
+			return false;
+		}
+	
+		if(!KviFileUtils::directoryExists(szD))
+		{
+			if(!KviFileUtils::makeDir(szD))
 			{
-				QString szPixName = g_pixmapOptionsTable[i].name;
-				szPixName += ".png";
-				getLocalKvircDirectory(szPixFile,Tmp,szPixName,TRUE);
-				
-				if(g_pixmapOptionsTable[i].option.pixmap()->save(szPixFile,"PNG"))
-				{
-					cfg.writeEntry(g_pixmapOptionsTable[i].name,szPixName);
-					
-					XML_APPEND_FILE(szPixName,szPixFile);
-					KviFileUtils::removeFile(szPixFile);
-					
-				} else {
-					debug("failed to save %s",szPixFile.utf8().data());
-					cfg.writeEntry(g_pixmapOptionsTable[i].name,"");
-				}
-			} else {
-				cfg.writeEntry(g_pixmapOptionsTable[i].name,"");
+				options.setLastError(__tr2qs("Failed to create the theme directory"));
+				return false;
 			}
 		}
-	}
 	
-	QString szPixPath=KVI_OPTION_STRING(KviOption_stringIconThemeSubdir);
-	QString szMainPicsPath;
-
-	g_pApp->getGlobalKvircDirectory(szMainPicsPath,KviApp::Pics);
-
-	QDir d(szMainPicsPath);
-	QStringList sl = d.entryList("kvi_bigicon_*.png",QDir::Files)+d.entryList("kvi_smallicon_*.png",QDir::Files);
-
-	for(QStringList::Iterator it=sl.begin();it != sl.end();it++)
-	{
-		KviCachedPixmap * p = g_pIconManager->getPixmapWithCache(*it);
-		if(p)
+		szD.append(KVI_PATH_SEPARATOR_CHAR);
+		szD.append(KVI_THEMEINFO_FILE_NAME);
+	
+		if(!options.save(szD))
 		{
-			if(p->path().find(szMainPicsPath)!=0)
-				XML_APPEND_FILE(*it,p->path());
+			return false;
 		}
-	}
 	
+		szD = options.absoluteDirectory();
+		szD.append(KVI_PATH_SEPARATOR_CHAR);
+		szD.append(KVI_THEMEDATA_FILE_NAME);
 	
-	cfg.writeEntry("stringIconThemeSubdir",opt.szSubdirectory);
-	cfg.sync();
+		KviConfig cfg(szD,KviConfig::Write);
 	
+		cfg.setGroup(KVI_THEMEDATA_CONFIG_GROUP);
 	
-	XML_APPEND_FILE("themedata.kvc",szOptionsFile);
-	KviFileUtils::removeFile(szOptionsFile);
+		int i;
 	
-	QString xml = doc.toString(5);
-	QFile file( filename );
+		WRITE_OPTIONS(KVI_NUM_RECT_OPTIONS,g_rectOptionsTable)
+		WRITE_OPTIONS(KVI_NUM_BOOL_OPTIONS,g_boolOptionsTable)
+		WRITE_OPTIONS(KVI_NUM_STRING_OPTIONS,g_stringOptionsTable)
+		WRITE_OPTIONS(KVI_NUM_COLOR_OPTIONS,g_colorOptionsTable)
+	 	WRITE_OPTIONS(KVI_NUM_UINT_OPTIONS,g_uintOptionsTable)
+		WRITE_OPTIONS(KVI_NUM_FONT_OPTIONS,g_fontOptionsTable)
+		WRITE_OPTIONS(KVI_NUM_MSGTYPE_OPTIONS,g_msgtypeOptionsTable)
+		WRITE_OPTIONS(KVI_NUM_STRINGLIST_OPTIONS,g_stringlistOptionsTable)
+		WRITE_OPTIONS(KVI_NUM_MIRCCOLOR_OPTIONS,g_mirccolorOptionsTable)
+		WRITE_OPTIONS(KVI_NUM_ICCOLOR_OPTIONS,g_iccolorOptionsTable)
 	
-	if ( !file.open( IO_WriteOnly ) )
-		return;
+		#undef WRITE_OPTIONS
 	
-	file.writeBlock(xml.utf8().data(),xml.utf8().length());
-	file.close();
-}
-#undef SET_XML_THEME_OPTION
-#undef XML_APPEND_FILE
-
-void KviApp::saveTheme(KviThemeInfo &opt)
-{
-	QString szD = opt.szAbsoluteDirectory;
-	szD.append(KVI_PATH_SEPARATOR_CHAR);
-	szD.append("themeinfo.kvc");
-
-	KviConfig inf(szD,KviConfig::Write);
-
-	inf.clear();
-
-	inf.setGroup("ThemeInfo");
-
-	inf.writeEntry("Version",opt.szVersion);
-	inf.writeEntry("Name",opt.szName);
-	inf.writeEntry("Author",opt.szAuthor);
-	inf.writeEntry("Description",opt.szDescription);
-	inf.writeEntry("Date",opt.szDate);
-	inf.writeEntry("KvircVersion",opt.szKvircVersion);
-	inf.writeEntry("ThemeEngineVersion","1.0.0");
-
-
-	szD = opt.szAbsoluteDirectory;
-	szD.append(KVI_PATH_SEPARATOR_CHAR);
-	szD.append("themedata.kvc");
-
-	KviConfig cfg(szD,KviConfig::Write);
-
-	cfg.setGroup("ThemeData");
-
-	int i;
-
-	WRITE_OPTIONS(KVI_NUM_RECT_OPTIONS,g_rectOptionsTable)
-	WRITE_OPTIONS(KVI_NUM_BOOL_OPTIONS,g_boolOptionsTable)
-	WRITE_OPTIONS(KVI_NUM_STRING_OPTIONS,g_stringOptionsTable)
-	WRITE_OPTIONS(KVI_NUM_COLOR_OPTIONS,g_colorOptionsTable)
- 	WRITE_OPTIONS(KVI_NUM_UINT_OPTIONS,g_uintOptionsTable)
-	WRITE_OPTIONS(KVI_NUM_FONT_OPTIONS,g_fontOptionsTable)
-	WRITE_MSGCOLORS_OPTIONS
-	WRITE_OPTIONS(KVI_NUM_STRINGLIST_OPTIONS,g_stringlistOptionsTable)
-	WRITE_OPTIONS(KVI_NUM_MIRCCOLOR_OPTIONS,g_mirccolorOptionsTable)
-	WRITE_OPTIONS(KVI_NUM_ICCOLOR_OPTIONS,g_iccolorOptionsTable)
-
-	#undef WRITE_OPTIONS
-
-	// the pixmap options need special processing
-	for(i=0;i<KVI_NUM_PIXMAP_OPTIONS;i++)
-	{
-		if(g_pixmapOptionsTable[i].flags & KviOption_groupTheme)
+		// the pixmap options need special processing
+		for(i=0;i<KVI_NUM_PIXMAP_OPTIONS;i++)
 		{
-			if(g_pixmapOptionsTable[i].option.pixmap())
+			if(g_pixmapOptionsTable[i].flags & KviOption_groupTheme)
 			{
-				QString szPixPath = opt.szAbsoluteDirectory;
+				if(g_pixmapOptionsTable[i].option.pixmap())
+				{
+					QString szPixPath = options.absoluteDirectory();
+					szPixPath.append(KVI_PATH_SEPARATOR_CHAR);
+					QString szPixName = g_pixmapOptionsTable[i].name;
+					szPixName += ".png";
+					szPixPath += szPixName;
+	
+					if(g_pixmapOptionsTable[i].option.pixmap()->save(szPixPath,"PNG"))
+					{
+						cfg.writeEntry(g_pixmapOptionsTable[i].name,szPixName);
+					} else {
+						// we ignore this error for now
+						debug("failed to save %s",szPixPath.utf8().data());
+						cfg.writeEntry(g_pixmapOptionsTable[i].name,"");
+					}
+				} else {
+					cfg.writeEntry(g_pixmapOptionsTable[i].name,"");
+				}
+			}
+		}
+	
+		cfg.writeEntry("stringIconThemeSubdir",options.subdirectory());
+	
+		// find all the "kvi_bigicon" images that we can find in the main pics directory
+		QString szPicsPath;
+	
+		g_pApp->getGlobalKvircDirectory(szPicsPath,KviApp::Pics);
+		QDir d(szPicsPath);
+		QStringList sl = d.entryList("kvi_bigicon_*.png",QDir::Files);
+	
+		for(QStringList::Iterator it=sl.begin();it != sl.end();it++)
+		{
+			KviCachedPixmap * p = g_pIconManager->getPixmapWithCache(*it);
+			if(p)
+			{
+				QString szPixPath = options.absoluteDirectory();
 				szPixPath.append(KVI_PATH_SEPARATOR_CHAR);
-				QString szPixName = g_pixmapOptionsTable[i].name;
-				szPixName += ".png";
-				szPixPath += szPixName;
-
-				if(g_pixmapOptionsTable[i].option.pixmap()->save(szPixPath,"PNG"))
+				szPixPath += *it;
+	
+				if(!KviFileUtils::copyFile(p->path(),szPixPath))
 				{
-					cfg.writeEntry(g_pixmapOptionsTable[i].name,szPixName);
-				} else {
-					debug("failed to save %s",szPixPath.utf8().data());
-					cfg.writeEntry(g_pixmapOptionsTable[i].name,"");
+					options.setLastError(__tr2qs("Failed to save one of the theme images"));
+					return false;
 				}
-			} else {
-				cfg.writeEntry(g_pixmapOptionsTable[i].name,"");
 			}
 		}
-	}
-
-	cfg.writeEntry("stringIconThemeSubdir",opt.szSubdirectory);
-
-	// find all the "kvi_bigicon" and "kvi_smallicon" images that we can find in the main pics directory
-	QString szMainPicsPath;
-
-	g_pApp->getGlobalKvircDirectory(szMainPicsPath,KviApp::Pics);
-
-	QDir d(szMainPicsPath);
-	QStringList sl = d.entryList("kvi_bigicon_*.png",QDir::Files);
-	QStringList sl2 = d.entryList("kvi_smallicon_*.png",QDir::Files);
-
-	// do not allow themeing the LAST kvi_smallicon_*.png
-	//WHY?
-	if(KVI_NUM_SMALL_ICONS % 16)
-	{
-		int iLastSmallIconCounter = (KVI_NUM_SMALL_ICONS - 1) / 16;
-		QString szLastImageName;
-		KviQString::sprintf(szLastImageName,"kvi_smallicon_%d%d.png",
-			iLastSmallIconCounter / 10,iLastSmallIconCounter % 10);
-		sl2.remove(szLastImageName);
-	}
-
-	sl += sl2;
-
-	for(QStringList::Iterator it=sl.begin();it != sl.end();it++)
-	{
-		KviCachedPixmap * p = g_pIconManager->getPixmapWithCache(*it);
-		if(p)
-		{
-			QString szPixPath = opt.szAbsoluteDirectory;
-			szPixPath.append(KVI_PATH_SEPARATOR_CHAR);
-			szPixPath += *it;
-
-			KviFileUtils::copyFile(p->path(),szPixPath);
-		}
-	}
-}
-
-void KviApp::loadTheme(const QString &themeDir)
-{
-	// reset the current theme subdir
-	KVI_OPTION_STRING(KviOption_stringIconThemeSubdir) = "";
 	
-	// reset the splash screen pointer
-	QString szPointerFile;
-	getLocalKvircDirectory(szPointerFile,Themes,"current-splash");
-	KviFileUtils::removeFile(szPointerFile);
+	
+		szD = options.absoluteDirectory();
+		szD.append(KVI_PATH_SEPARATOR_CHAR);
+		szD.append(KVI_SMALLICONS_SUBDIRECTORY);
+	
+		if(!KviFileUtils::makeDir(szD))
+		{
+			options.setLastError(__tr2qs("Failed to create the theme subdirectory"));
+			return false;
+		}
+	
+		// We actually need to *save* the small icons since
+		// we have a compatibility mode that can load them from
+		// the old format kvi_smallicon_XY.png multiimage libraries.
+	
+		for(int j=0;j<KVI_NUM_SMALL_ICONS;j++)
+		{
+			QPixmap * pix = g_pIconManager->getSmallIcon(j);
+	
+			QString szPixPath = options.absoluteDirectory();
+			szPixPath.append(KVI_PATH_SEPARATOR_CHAR);
+			szPixPath.append(KVI_SMALLICONS_SUBDIRECTORY);
+			szPixPath.append(KVI_PATH_SEPARATOR_CHAR);
+			szPixPath.append("kcs_");
+			szPixPath.append(g_pIconManager->getSmallIconName(j));
+			szPixPath.append(".png");
+			
+			if(!pix->save(szPixPath,"PNG",90))
+			{
+				options.setLastError(__tr2qs("Failed to save one of the theme images"));
+				return false;
+			}
+		}
+	
+		return true;
+	}
+	
+	bool load(const QString &themeDir,KviThemeInfo &buffer)
+	{
+		if(!buffer.loadFromDirectory(themeDir))
+			return false; // makes sure that themedata exists too
+	
+		// reset the current theme subdir
+		KVI_OPTION_STRING(KviOption_stringIconThemeSubdir) = "";
+		
+		// reset the splash screen pointer
+		QString szPointerFile;
+		g_pApp->getLocalKvircDirectory(szPointerFile,KviApp::Themes,"current-splash");
+		KviFileUtils::removeFile(szPointerFile);
 
-	QString szD = themeDir;
-	KviQString::ensureLastCharIs(szD,KVI_PATH_SEPARATOR_CHAR);
-	szD.append("themedata.kvc");
-
-	KviConfig cfg(szD,KviConfig::Read);
-
-	cfg.setGroup("ThemeData");
-
-	int i;
-
-	int iResetFlags = 0;
-
-
-	#undef READ_OPTIONS
-
-	#define READ_OPTIONS(_num,_table,_readFnc) \
-	for(i=0;i<_num;i++) \
-	{ \
-		if(_table[i].flags & KviOption_groupTheme) \
+		QString szD = themeDir;
+		KviQString::ensureLastCharIs(szD,KVI_PATH_SEPARATOR_CHAR);
+		szD.append(KVI_THEMEDATA_FILE_NAME);
+	
+		KviConfig cfg(szD,KviConfig::Read);
+	
+		cfg.setGroup(KVI_THEMEDATA_CONFIG_GROUP);
+	
+		int i;
+		int iResetFlags = 0;
+	
+		#undef READ_OPTIONS
+	
+		#define READ_OPTIONS(_num,_table,_readFnc) \
+		for(i=0;i<_num;i++) \
+		{ \
+			if(_table[i].flags & KviOption_groupTheme) \
+			{ \
+				if(cfg.hasKey(_table[i].name)) \
+				{ \
+					iResetFlags |= (_table[i].flags & KviOption_resetMask); \
+					_table[i].option = cfg._readFnc(_table[i].name,_table[i].option); \
+				} \
+			} \
+		}
+		
+		#define READ_ALL_OPTIONS(_num,_table,_readFnc) \
+		for(i=0;i<_num;i++) \
 		{ \
 			if(cfg.hasKey(_table[i].name)) \
 			{ \
 				iResetFlags |= (_table[i].flags & KviOption_resetMask); \
 				_table[i].option = cfg._readFnc(_table[i].name,_table[i].option); \
 			} \
-		} \
-	}
+		}
 	
-	#define READ_ALL_OPTIONS(_num,_table,_readFnc) \
-	for(i=0;i<_num;i++) \
-	{ \
-		if(cfg.hasKey(_table[i].name)) \
-		{ \
-			iResetFlags |= (_table[i].flags & KviOption_resetMask); \
-			_table[i].option = cfg._readFnc(_table[i].name,_table[i].option); \
-		} \
-	}
-
-	READ_OPTIONS(KVI_NUM_RECT_OPTIONS,g_rectOptionsTable,readRectEntry)
-	READ_OPTIONS(KVI_NUM_BOOL_OPTIONS,g_boolOptionsTable,readBoolEntry)
-	READ_OPTIONS(KVI_NUM_STRING_OPTIONS,g_stringOptionsTable,readQStringEntry)
-	READ_OPTIONS(KVI_NUM_COLOR_OPTIONS,g_colorOptionsTable,readColorEntry)
-	READ_OPTIONS(KVI_NUM_UINT_OPTIONS,g_uintOptionsTable,readUIntEntry)
-	READ_OPTIONS(KVI_NUM_FONT_OPTIONS,g_fontOptionsTable,readFontEntry)
-	READ_ALL_OPTIONS(KVI_NUM_MSGTYPE_OPTIONS,g_msgtypeOptionsTable,readMsgTypeEntry)
-	READ_OPTIONS(KVI_NUM_STRINGLIST_OPTIONS,g_stringlistOptionsTable,readStringListEntry)
-	READ_OPTIONS(KVI_NUM_MIRCCOLOR_OPTIONS,g_mirccolorOptionsTable,readColorEntry)
-	READ_OPTIONS(KVI_NUM_ICCOLOR_OPTIONS,g_iccolorOptionsTable,readColorEntry)
-
-	#undef READ_OPTIONS
-	#undef READ_ALL_OPTIONS
-	KVI_OPTION_STRING(KviOption_stringIconThemeSubdir).stripWhiteSpace();
-
-
-	// the pixmap options need special processing
-	for(i=0;i<KVI_NUM_PIXMAP_OPTIONS;i++)
-	{
-		if(g_pixmapOptionsTable[i].flags & KviOption_groupTheme)
+		READ_OPTIONS(KVI_NUM_RECT_OPTIONS,g_rectOptionsTable,readRectEntry)
+		READ_OPTIONS(KVI_NUM_BOOL_OPTIONS,g_boolOptionsTable,readBoolEntry)
+		READ_OPTIONS(KVI_NUM_STRING_OPTIONS,g_stringOptionsTable,readQStringEntry)
+		READ_OPTIONS(KVI_NUM_COLOR_OPTIONS,g_colorOptionsTable,readColorEntry)
+		READ_OPTIONS(KVI_NUM_UINT_OPTIONS,g_uintOptionsTable,readUIntEntry)
+		READ_OPTIONS(KVI_NUM_FONT_OPTIONS,g_fontOptionsTable,readFontEntry)
+		READ_ALL_OPTIONS(KVI_NUM_MSGTYPE_OPTIONS,g_msgtypeOptionsTable,readMsgTypeEntry)
+		READ_OPTIONS(KVI_NUM_STRINGLIST_OPTIONS,g_stringlistOptionsTable,readStringListEntry)
+		READ_OPTIONS(KVI_NUM_MIRCCOLOR_OPTIONS,g_mirccolorOptionsTable,readColorEntry)
+		READ_OPTIONS(KVI_NUM_ICCOLOR_OPTIONS,g_iccolorOptionsTable,readColorEntry)
+	
+		#undef READ_OPTIONS
+		#undef READ_ALL_OPTIONS
+		KVI_OPTION_STRING(KviOption_stringIconThemeSubdir).stripWhiteSpace();
+	
+	
+		// the pixmap options need special processing
+		for(i=0;i<KVI_NUM_PIXMAP_OPTIONS;i++)
 		{
-			if(cfg.hasKey(g_pixmapOptionsTable[i].name))
+			if(g_pixmapOptionsTable[i].flags & KviOption_groupTheme)
 			{
-				QString szVal = cfg.readQStringEntry(g_pixmapOptionsTable[i].name,"");
-				szVal.stripWhiteSpace();
-				KviStr szBuffer;
-				if(!szVal.isEmpty())
+				if(cfg.hasKey(g_pixmapOptionsTable[i].name))
 				{
-					findImage(szBuffer,szVal);
-				} else {
-					szBuffer = szVal;
+					QString szVal = cfg.readQStringEntry(g_pixmapOptionsTable[i].name,"");
+					szVal.stripWhiteSpace();
+					QString szBuffer;
+					if(!szVal.isEmpty())
+					{
+						g_pApp->findImage(szBuffer,szVal);
+					} else {
+						szBuffer = szVal;
+					}
+	
+					KviStringConversion::fromString(szBuffer,g_pixmapOptionsTable[i].option);
+	
+					// reset anyway
+					iResetFlags |= g_pixmapOptionsTable[i].flags & KviOption_resetMask;
 				}
-
-				KviStringConversion::fromString(szBuffer.ptr(),g_pixmapOptionsTable[i].option);
-
-				// reset anyway
-				iResetFlags |= g_pixmapOptionsTable[i].flags & KviOption_resetMask;
 			}
 		}
+	
+		// create the splash screen pointer if this theme has some pixmaps in it
+		if(!KVI_OPTION_STRING(KviOption_stringIconThemeSubdir).isEmpty())
+			KviFileUtils::writeFile(szPointerFile,KVI_OPTION_STRING(KviOption_stringIconThemeSubdir));
+	
+		// force reloading of images anyway
+		g_pApp->optionResetUpdate(iResetFlags | KviOption_resetReloadImages);
+
+		return true;
 	}
-
-	// create the splash screen pointer if this theme has some pixmaps in it
-	if(!KVI_OPTION_STRING(KviOption_stringIconThemeSubdir).isEmpty())
-		KviFileUtils::writeFile(szPointerFile,KVI_OPTION_STRING(KviOption_stringIconThemeSubdir));
-
-	// force reloading of images anyway
-	optionResetUpdate(iResetFlags | KviOption_resetReloadImages);
-}
+};
 
 void KviApp::listAvailableOptions(KviWindow *wnd)
 {
@@ -1455,9 +1284,10 @@ void KviApp::optionResetUpdate(int flags)
 
 	if(flags & KviOption_resetRestartIdentd)
 	{
-		if(g_bIdentDaemonRunning)
+		if(g_iIdentDaemonRunningUsers)
 			g_pFrame->executeInternalCommand(KVI_INTERNALCOMMAND_IDENT_STOP);
-		if(g_boolOptionsTable[KviOption_boolUseIdentService].option)
+
+		if(KVI_OPTION_BOOL(KviOption_boolUseIdentService) && !KVI_OPTION_BOOL(KviOption_boolUseIdentServiceOnlyOnConnect))
 			g_pFrame->executeInternalCommand(KVI_INTERNALCOMMAND_IDENT_START);
 	}
 
@@ -1480,6 +1310,11 @@ void KviApp::optionResetUpdate(int flags)
 	{
 		g_pApp->restartLagMeters();
 	}
+	
+	if(flags & KviOption_resetRecentChannels)
+	{
+		g_pApp->buildRecentChannels();
+	}
 }
 
 bool KviApp::setOptionValue(const char * optName,const QString &value)
@@ -1512,16 +1347,18 @@ bool KviApp::setOptionValue(const char * optName,const QString &value)
 	SET_OPTION_VALUE(KVI_NUM_FONT_OPTIONS,g_fontOptionsTable,KVI_FONT_OPTIONS_PREFIX,KVI_FONT_OPTIONS_PREFIX_LEN)
 	SET_OPTION_VALUE(KVI_NUM_MSGTYPE_OPTIONS,g_msgtypeOptionsTable,KVI_MSGTYPE_OPTIONS_PREFIX,KVI_MSGTYPE_OPTIONS_PREFIX_LEN)
 
+	if(kvi_strEqualCI(optName,"stringlistRecentChannels"))
+		buildRecentChannels();
 	// The pixmap options have special treating
 	if(kvi_strEqualCIN(optName,KVI_PIXMAP_OPTIONS_PREFIX,KVI_PIXMAP_OPTIONS_PREFIX_LEN))
 	{
 		// We lookup the image path (so we allow also relative paths for this option type)
-		KviStr szVal = value;
+		QString szVal = value;
 		szVal.stripWhiteSpace();
-		KviStr szBuffer;
-		if(szVal.hasData())
+		QString szBuffer;
+		if(!szVal.isEmpty())
 		{
-			findImage(szBuffer,szVal.ptr());
+			findImage(szBuffer,szVal);
 		} else {
 			szBuffer = szVal;
 		}
@@ -1529,8 +1366,8 @@ bool KviApp::setOptionValue(const char * optName,const QString &value)
 		for(int i=0;i < KVI_NUM_PIXMAP_OPTIONS;i++)
 		{
 			if(kvi_strEqualCI(optName,g_pixmapOptionsTable[i].name))
-			{
-				if(!KviStringConversion::fromString(szBuffer.ptr(),g_pixmapOptionsTable[i].option))return false;
+			{	
+				if(!KviStringConversion::fromString(szBuffer,g_pixmapOptionsTable[i].option))return false;
 				optionResetUpdate(g_pixmapOptionsTable[i].flags);
 				return true;
 			}
