@@ -299,9 +299,23 @@ DECLARE_OPTION_STRUCT(KviStringListOption,QStringList)
 #define KviOption_boolHideWindowToolButtons 205			/* interface */
 #define KviOption_boolHideInputToolButtons 206			/* interface */
 #define KviOption_boolStripControlCodesInLogs 207			/* log */
-#define KviOption_boolDisableTrayIconFlashing 208
+#define KviOption_boolEnableTrayIconFlashing 208
+#define KviOption_boolUseFlatClassicTaskbarButtons 209
+#define KviOption_boolShowTreeTaskbarHeader 210
+#define KviOption_boolUseLevelBasedTrayNotification 211
+#define KviOption_boolMuteAllSounds 212
+#define KviOption_boolCreateMinimizedChannels 213
+#define KviOption_boolShowNetworkNameForConsoleTaskBarEntry 214
+#define KviOption_boolDrawGenderIcons 215
+#define KviOption_boolPrependGenderInfoToRealname 216
+#define KviOption_boolUseIdentServiceOnlyOnConnect 217      /* connection::ident */
+#define KviOption_boolUseSystemUrlHandlers 218 /* Windoze only*/
+#define KviOption_boolScaleAvatarsOnLoad 219
+#define KviOption_boolDisableNotifierFadein 220 /* interface::notifier */
+#define KviOption_boolUseAntiAliasing 221 /* qt4 only! */
 
-#define KVI_NUM_BOOL_OPTIONS 209
+
+#define KVI_NUM_BOOL_OPTIONS 222
 
 
 
@@ -367,8 +381,9 @@ DECLARE_OPTION_STRUCT(KviStringListOption,QStringList)
 #define KviOption_stringOnMeKickedSound 53				/* sounds */
 #define KviOption_stringOnQueryMessageSound 54				/* sounds */
 #define KviOption_stringIrcViewTimestampFormat 55			
+#define KviOption_stringPreferredTorrentClient 56          /* still missing in options ! */
 
-#define KVI_NUM_STRING_OPTIONS 56
+#define KVI_NUM_STRING_OPTIONS 57
 
 
 
@@ -382,8 +397,9 @@ DECLARE_OPTION_STRUCT(KviStringListOption,QStringList)
 #define KviOption_stringlistRecentNicknames 4                       /* internal */
 #define KviOption_stringlistModuleExtensionToolbars 5               /* internal */
 #define KviOption_stringlistImageSearchPaths 6                      /* ??? */
+#define KviOption_stringlistRecentIrcUrls 7                      /* internal */
 
-#define KVI_NUM_STRINGLIST_OPTIONS 7
+#define KVI_NUM_STRINGLIST_OPTIONS 8
 
 
 
@@ -536,9 +552,23 @@ DECLARE_OPTION_STRUCT(KviStringListOption,QStringList)
 #define KviOption_uintTreeTaskBarPixmapAlign 55
 #define KviOption_uintInputPixmapAlign 56
 #define KviOption_uintAutoFlushLogs 57
+#define KviOption_uintMinTrayLowLevelMessage 58
+#define KviOption_uintMinTrayHighLevelMessage 59
+#define KviOption_uintIdentdOutputMode 60
+#define KviOption_uintScaleAvatarsOnLoadHeight 61
+#define KviOption_uintScaleAvatarsOnLoadWidth 62
+#define KviOption_uintNotifierActiveTransparency 63
+#define KviOption_uintNotifierInactiveTransparency 64
 
-#define KVI_NUM_UINT_OPTIONS 58
+#define KVI_NUM_UINT_OPTIONS 65
 
+namespace KviIdentdOutputMode {
+	enum Mode {
+		Quiet = 0,
+		ToConsole = 1,
+		ToActiveWindow = 2
+	};
+}
 
 
 #define KVI_FONT_OPTIONS_PREFIX "font"
@@ -570,7 +600,7 @@ DECLARE_OPTION_STRUCT(KviStringListOption,QStringList)
 #define KVI_MSGTYPE_OPTIONS_PREFIX "msgtype"
 #define KVI_MSGTYPE_OPTIONS_PREFIX_LEN 7
 
-#define KVI_NUM_MSGTYPE_OPTIONS 136
+#define KVI_NUM_MSGTYPE_OPTIONS 137
 
 
 
@@ -621,6 +651,25 @@ extern KVIRC_API KviStringListOption g_stringlistOptionsTable[KVI_NUM_STRINGLIST
 #define _OUTPUT_QUIET (KVI_OPTION_UINT(KviOption_uintOutputVerbosityLevel) <= KVI_VERBOSITY_LEVEL_QUIET)
 #define _OUTPUT_MUTE (KVI_OPTION_UINT(KviOption_uintOutputVerbosityLevel) <= KVI_VERBOSITY_LEVEL_MUTE)
 
+#ifdef COMPILE_USE_QT4
+	#define START_TABLE_BOLD_ROW "<tr><td style=\"background-color: rgb(0,0,0); font-weight: bold; color: rgb(200,200,255); text-indent: 5px;\"><nobr>"
+	#define END_TABLE_BOLD_ROW "</nobr></td></tr>"
+
+	#define START_TABLE_NORMAL_ROW "<tr><td>"
+
+	#define SET_ANTI_ALIASING(p) \
+	(p).setRenderHint(QPainter::Antialiasing, KVI_OPTION_BOOL(KviOption_boolUseAntiAliasing)); \
+	(p).setRenderHint(QPainter::TextAntialiasing, KVI_OPTION_BOOL(KviOption_boolUseAntiAliasing));
+#else
+	#define START_TABLE_BOLD_ROW "<tr><td bgcolor=\"#303030\">" \
+							"<font color=\"#FFFFFF\"><nobr><b>"
+	#define END_TABLE_BOLD_ROW "</b></nobr></font></td></tr>"
+
+	#define START_TABLE_NORMAL_ROW "<tr><td bgcolor=\"#F0F0F0\">"
+
+	#define SET_ANTI_ALIASING(p)
+#endif
+
 
 #if defined(_KVI_OPTIONS_CPP_) || defined(_WANT_OPTION_FLAGS_)
 
@@ -664,6 +713,7 @@ extern KVIRC_API KviStringListOption g_stringlistOptionsTable[KVI_NUM_STRINGLIST
 	#define KviOption_groupMask (255 << 8)
 
 
+
 	// actions to take when an option is set
 	#define KviOption_resetNone 0
 	//#define KviOption_resetUpdateCaption (1 << 16) UNUSED!
@@ -675,10 +725,12 @@ extern KVIRC_API KviStringListOption g_stringlistOptionsTable[KVI_NUM_STRINGLIST
 	#define KviOption_resetRestartIdentd (1 << 22)
 	#define KviOption_resetReloadImages (1 << 23)
 	#define KviOption_resetRestartLagMeter (1 << 24)
+	#define KviOption_resetRecentChannels (1 << 25)
 
 	#define KviOption_resetMask (~(KviOption_sectMask | KviOption_groupMask))
-
-
+	
+	//for file pathes
+	#define KviOption_encodePath (1 << 25)
 
 #endif
 
