@@ -68,15 +68,15 @@ KviKvsArray::~KviKvsArray()
 
 static int kvs_array_reverse_compare_func(const void * v1,const void * v2)
 {
-	if((KviKvsVariant *)v1)return -((KviKvsVariant *)v1)->compare((KviKvsVariant *)v2);
-	if((KviKvsVariant *)v2)return (((KviKvsVariant *)v2)->compare((KviKvsVariant *)v1));
+	if(*((KviKvsVariant **)v1))return (*((KviKvsVariant **)v1))->compare(*((KviKvsVariant **)v2));
+	if(*((KviKvsVariant **)v2))return -(*((KviKvsVariant **)v2))->compare(*((KviKvsVariant **)v1));
 	return 0;
 }
 
 static int kvs_array_compare_func(const void * v1,const void * v2)
 {
-	if((KviKvsVariant *)v1)return ((KviKvsVariant *)v1)->compare((KviKvsVariant *)v2);
-	if((KviKvsVariant *)v2)return -(((KviKvsVariant *)v2)->compare((KviKvsVariant *)v1));
+	if(*((KviKvsVariant **)v1))return -(*((KviKvsVariant **)v1))->compare(*((KviKvsVariant **)v2));
+	if(*((KviKvsVariant **)v2))return (*((KviKvsVariant **)v2))->compare(*((KviKvsVariant **)v1));
 	return 0;
 }
 
@@ -191,6 +191,27 @@ KviKvsVariant * KviKvsArray::getAt(kvs_uint_t uIdx)
 	return m_pData[uIdx];
 }
 
+void KviKvsArray::serialize(QString& result)
+{
+	QString tmpBuffer;
+	result="[";
+	kvs_uint_t u = 0;
+	bool bNeedComma = false;
+	while(u < m_uSize)
+	{
+		if(bNeedComma)result.append(',');
+		else bNeedComma = true;
+		if(m_pData[u]) {
+			m_pData[u]->serialize(tmpBuffer);
+			result.append(tmpBuffer);
+		} else {
+			result.append("null");
+		}
+		u++;
+	}
+	result.append(']');
+}
+
 void KviKvsArray::appendAsString(QString &szBuffer)
 {
 	kvs_uint_t u = 0;
