@@ -43,7 +43,7 @@
 #include "kvi_locale.h"
 
 #include <qregexp.h>
-#include <qtooltip.h>
+#include "kvi_tal_tooltip.h"
 
 namespace KviKvsCoreCallbackCommands
 {
@@ -62,7 +62,7 @@ namespace KviKvsCoreCallbackCommands
 		@switches:
 			!sw: --ipv6 | -i
 			Causes the command to run in IPv6 mode
-			!sw: --any | -i
+			!sw: --any | -a
 			Causes the command to run in unspecified mode and lookup both IPv4 and IPv6 addresses
 		@description:
 			Starts a DNS lookup for the <dnsquery> and reports the
@@ -349,7 +349,7 @@ namespace KviKvsCoreCallbackCommands
 
 		KVSCCC_REQUIRE_CONNECTION
 
-		QCString szN = KVSCCC_pConnection->encodeText(szNick);
+		KviQCString szN = KVSCCC_pConnection->encodeText(szNick);
 
 		KviAsyncWhoisInfo * info = new KviAsyncWhoisInfo();
 		info->pCallback = new KviKvsScript(*KVSCCC_pCallback);
@@ -455,11 +455,11 @@ namespace KviKvsCoreCallbackCommands
 			pButton->show();
 		}
 
-		QToolTip::remove(pButton);
+		KviTalToolTip::remove(pButton);
 		if(!szLabel.isEmpty())
 		{
 			pButton->setButtonText(szLabel);
-			QToolTip::add(pButton,szLabel);
+			KviTalToolTip::add(pButton,szLabel);
 		}
 
 		pButton->setButtonCode(new KviKvsScript(*KVSCCC_pCallback));
