@@ -50,10 +50,11 @@ namespace KviKvsCoreFunctions
 		_REGFNC("ascii",unicode)
 		_REGFNC("asciiToHex",asciiToHex)
 		_REGFNC("asciiToBase64",asciiToBase64)
-		_REGFNC("avatar",avatar)
 		_REGFNC("away",away)
 		_REGFNC("b",b)
 		_REGFNC("base64ToAscii",base64ToAscii)
+		_REGFNC("bool",boolean)
+		_REGFNC("boolean",boolean)
 		_REGFNC("channel",channel)
 		_REGFNC("char",charCKEYWORDWORKAROUND)
 		_REGFNC("classDefined",classDefined)
@@ -75,14 +76,10 @@ namespace KviKvsCoreFunctions
 		_REGFNC("ic",context);
 		_REGFNC("icon",icon);
 		_REGFNC("iconName",iconName);
-		_REGFNC("int",intCKEYWORDWORKAROUND)
-		_REGFNC("isAnyConsoleConnected",isAnyConsoleConnected)
+		_REGFNC("int",integer)
+		_REGFNC("integer",integer)
 		_REGFNC("isEmpty",isEmpty)
 		_REGFNC("isEventEnabled",isEventEnabled)
-		_REGFNC("isMeOp",isMeOp)
-		_REGFNC("isMeHalfOp",isMeHalfOp)
-		_REGFNC("isMeUserOp",isMeUserOp)
-		_REGFNC("isMeVoice",isMeVoice)
 		_REGFNC("isMainWindowActive",isMainWindowActive)
 		_REGFNC("isMainWindowMinimized",isMainWindowMinimized)
 		_REGFNC("isNumeric",isNumeric)
@@ -91,6 +88,7 @@ namespace KviKvsCoreFunctions
 		_REGFNC("isWellKnown",isWellKnown)
 		_REGFNC("k",k)
 		_REGFNC("keys",keys)
+		_REGFNC("lag",lag)
 		_REGFNC("lang",lang)
 		_REGFNC("length",length)
 		_REGFNC("lf",lf)
@@ -107,22 +105,25 @@ namespace KviKvsCoreFunctions
 		_REGFNC("r",r)
 		_REGFNC("rand",rand)
 		_REGFNC("real",real)
+		_REGFNC("receivedBytes",receivedBytes)
 		_REGFNC("rsort",rsort)
 		// s_z
 		_REGFNC("selected",selected)
+		_REGFNC("sentBytes",sentBytes)
+		_REGFNC("serialize",serialize)
 		_REGFNC("server",server)
 		_REGFNC("sort",sort)
-		_REGFNC("split",split)
+		_REGFNC("string",string)
 		_REGFNC("sw",sw)
 		_REGFNC("target",target)
 		_REGFNC("this",thisCKEYWORDWORKAROUND)
-		_REGFNC("time",timeCFUNCTIONWORKAROUND)
 		_REGFNC("tr",tr)
 		_REGFNC("true",trueCKEYWORDWORKAROUND)
 		_REGFNC("typeof",typeofCKEYWORDWORKAROUND)
 		_REGFNC("u",u)
 		_REGFNC("unicode",unicode)
 		_REGFNC("unixtime",unixtime)
+		_REGFNC("unserialize",unserialize)
 		_REGFNC("username",username)
 		_REGFNC("version",version)
 		_REGFNC("window",window)
