@@ -58,6 +58,7 @@ namespace KviKvsCoreFunctions
 	KVSCF(away);
 	KVSCF(b);
 	KVSCF(base64ToAscii);
+	KVSCF(boolean);
 	KVSCF(channel);
 	KVSCF(charCKEYWORDWORKAROUND);
 	KVSCF(classDefined);
@@ -79,7 +80,7 @@ namespace KviKvsCoreFunctions
 	KVSCF(hptimestamp);
 	KVSCF(icon);
 	KVSCF(iconName);
-	KVSCF(intCKEYWORDWORKAROUND);
+	KVSCF(integer);
 	KVSCF(isAnyConsoleConnected);
 	KVSCF(isEmpty);
 	KVSCF(isEventEnabled);
@@ -95,6 +96,7 @@ namespace KviKvsCoreFunctions
 	KVSCF(isWellKnown);
 	KVSCF(k);
 	KVSCF(keys);
+	KVSCF(lag);
 	KVSCF(lang);
 	KVSCF(length);
 	KVSCF(lf);
@@ -111,12 +113,16 @@ namespace KviKvsCoreFunctions
 	KVSCF(r);
 	KVSCF(rand);
 	KVSCF(real);
+	KVSCF(receivedBytes);
 	KVSCF(rsort);
 	// s_z
 	KVSCF(selected);
+	KVSCF(sentBytes);
+	KVSCF(serialize);
 	KVSCF(server);
 	KVSCF(sort);
 	KVSCF(split);
+	KVSCF(string);
 	KVSCF(sw);
 	KVSCF(target);
 	KVSCF(thisCKEYWORDWORKAROUND);
@@ -127,6 +133,7 @@ namespace KviKvsCoreFunctions
 	KVSCF(u);
 	KVSCF(unicode);
 	KVSCF(unixtime);
+	KVSCF(unserialize);
 	KVSCF(username);
 	KVSCF(version);
 	KVSCF(window);
