@@ -70,7 +70,7 @@ namespace KviKvsCoreFunctions
 			for communicating something REALLY urgent (and maybe
 			unrelated to a specific IRC connection) to the user.
 		@seealso:
-			[fnc]$window[/fnc],
+			[fnc]$window[/fnc]
 	*/
 
 	KVSCF(active)
@@ -111,7 +111,7 @@ namespace KviKvsCoreFunctions
 			This function has been renamed to $unicode and is present
 			only for backward compatibility.
 		@seealso:
-			[fnc]$cr[/fnc],[fnc]$lf[/fnc],[fnc]$char[/fnc]
+			[fnc]$cr[/fnc], [fnc]$lf[/fnc], [fnc]$char[/fnc]
 	*/
 
 	///////////////////////////////////////////////////////////////////////////////////////////////
@@ -134,7 +134,7 @@ namespace KviKvsCoreFunctions
 		@examples:
 			[cmd]echo[/cmd] $asciiToBase64("Hello!")
 		@seealso:
-			[fnc]$base64toascii()[/fnc]
+			[fnc]$base64toascii[/fnc]
 	*/
 
 	KVSCF(asciiToBase64)
@@ -176,7 +176,7 @@ namespace KviKvsCoreFunctions
 		@examples:
 			[cmd]echo[/cmd] $asciiToHex("Hello!")
 		@seealso:
-			[fnc]$hextoascii()[/fnc]
+			[fnc]$hextoascii[/fnc]
 	*/
 
 	KVSCF(asciiToHex)
@@ -247,52 +247,6 @@ namespace KviKvsCoreFunctions
 
 	/////////////////////////////////////////////////////////////////////////////////////////////
 
-	/*
-		@doc: avatar
-		@type:
-			function
-		@title:
-			$avatar
-		@short:
-			Obsolete: use $avatar.name
-		@syntax:
-			<string> $avatar[([<nickname:string>])]
-		@description:
-			This function is obsolete and has been replaced by [fnc]$avatar.name[/fnc]
-			and [fnc]$avatar.path[/fnc]. It is provided only for backward compatibility
-			and will be removed in a future version.
-	*/
-
-	KVSCF(avatar)
-	{
-		QString szNick;
-
-		KVSCF_PARAMETERS_BEGIN
-			KVSCF_PARAMETER("nickname",KVS_PT_STRING,KVS_PF_OPTIONAL,szNick)
-		KVSCF_PARAMETERS_END
-
-		if(KVSCF_pContext->window()->console())
-		{
-			if(KVSCF_pContext->window()->console()->isConnected())
-			{
-				KviIrcUserEntry * e = KVSCF_pContext->window()->connection()->userDataBase()->find(szNick.isEmpty() ? KVSCF_pContext->window()->connection()->currentNickName() : szNick);
-				if(e)
-				{
-					KviAvatar * a = e->avatar();
-					if(a)
-					{
-						KVSCF_pRetBuffer->setString(a->localPath());
-						return true;
-					}
-				}
-			}
-		}
-		KVSCF_pRetBuffer->setNothing();
-		return true;
-	}
-
-	/////////////////////////////////////////////////////////////////////////////////////////////
-
 	/*
 		@doc: away
 		@type:
@@ -361,7 +315,7 @@ namespace KviKvsCoreFunctions
 		@description:
 			Returns the BOLD mIRC control character (CTRL+B).[br]
 		@seealso:
-			[fnc]$k[/fnc],[fnc]$u[/fnc]
+			[fnc]$k[/fnc], [fnc]$u[/fnc]
 	*/
 
 	KVSCF(b)
@@ -385,7 +339,7 @@ namespace KviKvsCoreFunctions
 		@description:
 			Decodes a base64 encoded string.
 		@seealso:
-			[fnc]$asciiToBase64[/fnc]()
+			[fnc]$asciiToBase64[/fnc]
 	*/
 
 	KVSCF(base64ToAscii)
@@ -404,29 +358,61 @@ namespace KviKvsCoreFunctions
 	}
 
 	/////////////////////////////////////////////////////////////////////////////////////////////
-
+	
 	/*
-		@doc: calc
+		@doc: boolean
 		@type:
 			function
 		@title:
-			$calc
+			$boolean
 		@short:
-			$calc() has been replaced by $() !
+			Casts a variable to a boolean
 		@syntax:
-			$(<expression>)
+			<integer> $boolean(<data:variant>)
 		@description:
-			In KVIrc 3.0.0 , $calc() has been replaced by the $().[br]
-			This is just a shorter and faster form.[br]
-			You can use $() to evaluate any integer expression.[br]
-		@examples:
-			[example]
-				[cmd]echo[/cmd] $(1 + 2)
-				%var = 2
-				[cmd]echo[/cmd] $(10 * %val << 1)
-			[/example]
+			Forces <data> to be a boolean data type by first casting
+			to integer (see [fnc]$int[/fnc]()) and then comparing the result against zero.
+			A zero integer will result in a false value while a non-zero one
+			will result in a true value.
+			This function is similar to the C++ (bool) cast and is internally
+			aliased to [fnc]$bool[/fnc] too.
+			Note that since KVIrc does most of the casting work automatically
+			you shouldn't need to use this function.
+		@seealso:
+			[fnc]$real[/fnc]
+			[fnc]$integer[/fnc]
 	*/
 
+	/*
+		@doc: bool
+		@type:
+			function
+		@title:
+			$bool
+		@short:
+			Casts a variable to a boolean
+		@syntax:
+			<integer> $bool(<data:variant>)
+		@description:
+			This is an internal alias to [fnc]$boolean[/fnc]().
+		@seealso:
+			[fnc]$real[/fnc]
+			[fnc]$integer[/fnc]
+	*/
+
+	KVSCF(boolean)
+	{
+		KviKvsVariant * v;
+		KVSCF_PARAMETERS_BEGIN
+			KVSCF_PARAMETER("data",KVS_PT_VARIANT,0,v)
+		KVSCF_PARAMETERS_END
+
+		kvs_int_t iVal;
+		v->castToInteger(iVal);
+		KVSCF_pRetBuffer->setBoolean(iVal);
+		return true;
+	}
+
 	/////////////////////////////////////////////////////////////////////////////////////////////
 
 	/*
@@ -452,7 +438,7 @@ namespace KviKvsCoreFunctions
 		@seealso:
 			[fnc]$window[/fnc],
 			[fnc]$query[/fnc],
-			[fnc]$console[/fnc]
+			[fnc]$console[/fnc],
 			[doc:window_naming_conventions]Window naming conventions[/doc]
 	*/
 
@@ -513,7 +499,7 @@ namespace KviKvsCoreFunctions
 			If the <unicode_code> is not a valid UNICODE code (or is 0), this function returns
 			an empty string.[br]
 		@seealso:
-			[fnc]$cr[/fnc],[fnc]$lf[/fnc],[fnc]$unicode[/fnc]
+			[fnc]$cr[/fnc], [fnc]$lf[/fnc], [fnc]$unicode[/fnc]
 	*/
 
 	KVSCF(charCKEYWORDWORKAROUND)
@@ -580,7 +566,7 @@ namespace KviKvsCoreFunctions
 		@seealso:
 			[fnc]$window[/fnc],
 			[fnc]$channel[/fnc],
-			[fnc]$query[/fnc]
+			[fnc]$query[/fnc],
 			[doc:window_naming_conventions]Window naming conventions[/doc]
 	*/
 
@@ -618,7 +604,7 @@ namespace KviKvsCoreFunctions
 			$context[(<server>,<nickname>)]
 		@description:
 			Returns the [b]IRC context ID[/b] of the IRC context that uses
-			the specified <server> and <nickname>.[br] This function can
+			the specified <server> and local user's <nickname>.[br] This function can
 			find only connected IRC contexts.
 			If no context matches the server and nickname, and invalid
 			[b]IRC context ID[/b] is returned (0).[br]
@@ -635,6 +621,8 @@ namespace KviKvsCoreFunctions
 			It is a good idea to take a look at the
 			[doc:window_naming_conventions]window naming conventions[/doc].
 			This identifier is equivalent to [fnc]$ic[/fnc].[br]
+		@seealso:
+			[fnc]$window.context[/fnc]
 	*/
 
 	KVSCF(context)
@@ -672,7 +660,7 @@ namespace KviKvsCoreFunctions
 		@description:
 			Returns a carriage return character
 		@seealso:
-			[fnc]$lf[/fnc],[fnc]$ascii[/fnc],[fnc]$char[/fnc]
+			[fnc]$lf[/fnc], [fnc]$ascii[/fnc], [fnc]$char[/fnc]
 	*/
 
 	KVSCF(cr)
@@ -776,21 +764,31 @@ namespace KviKvsCoreFunctions
 		QString szFormat;
 		kvs_int_t iTime;
 		KVSCF_PARAMETERS_BEGIN
-			KVSCF_PARAMETER("format",KVS_PT_STRING,0,szFormat)
+			KVSCF_PARAMETER("format",KVS_PT_NONEMPTYSTRING,0,szFormat)
 			KVSCF_PARAMETER("unixtime",KVS_PT_INT,KVS_PF_OPTIONAL,iTime)
 		KVSCF_PARAMETERS_END
 
-		KviStr tmpFormat;
+		KviStr tmpFormat("");
+		
+		#ifdef COMPILE_ON_WINDOWS
+			QString szAllowedCharacters;
+			//windows version of strftime()
+			//kvirc crashes if other then these characters get an % character in front of them
+			szAllowedCharacters = "AaBbcdHIjMmpSUWwXxYyZz";
+		#endif
+		
 		const QChar * c = KviQString::nullTerminatedArray(szFormat);
 		if(c)
 		{
 			while(c->unicode())
 			{
-				if(!c->isLetter())tmpFormat += (char)(c->unicode());
-				else {
-					tmpFormat += '%';
-					tmpFormat += (char)(c->unicode());
-				}
+				//Check for right Characters
+				#ifdef COMPILE_ON_WINDOWS
+					if (szAllowedCharacters.find((char)(c->unicode()),0,true) >= 0)	tmpFormat += '%';
+				#else
+					if (c->isLetter()) tmpFormat += '%';
+				#endif
+				tmpFormat += (char)(c->unicode());
 				c++;
 			}
 		}
@@ -810,7 +808,7 @@ namespace KviKvsCoreFunctions
 		} else {
 			KVSCF_pContext->warning(__tr2qs("The specified format string wasn't accepted by the underlying system time formatting function"));
 		}
-
+		
 		return true;
 	}
 
@@ -919,9 +917,6 @@ namespace KviKvsCoreFunctions
 	#ifdef COMPILE_SSL_SUPPORT
 			"SSL",
 	#endif
-	#ifdef COMPILE_LOCALE_STUFF
-			"Locale",
-	#endif
 	#ifdef COMPILE_GET_INTERFACE_ADDRESS
 			"IfAddr",
 	#endif
@@ -952,13 +947,14 @@ namespace KviKvsCoreFunctions
 	#ifdef COMPILE_SCRIPTTOOLBAR
 			"ScriptToolBar",
 	#endif // COMPILE_SCRIPTTOOLBAR
-	#if QT_VERSION >= 300
+	#ifdef COMPILE_USE_QT4
+			"Qt4",
+	#else
 			"Qt3",
 	#endif
 	#ifdef COMPILE_NEW_KVS
 			"KVS",
 	#endif
-			"WizPathset",
 			0
 		};
 
