@@ -42,6 +42,7 @@
 #include "kvi_kvs_eventmanager.h"
 #include "kvi_kvs_eventhandler.h"
 #include <qregexp.h>
+#include "kvi_lagmeter.h"
 
 namespace KviKvsCoreFunctions
 {
@@ -116,7 +117,7 @@ namespace KviKvsCoreFunctions
 				[cmd]echo[/cmd] $hexToAscii(6B76697263)
 			[/example]
 		@seealso:
-			[fnc]$asciitohex()[/fnc]
+			[fnc]$asciiToHex[/fnc]
 	*/
 
 	KVSCF(hexToAscii)
@@ -129,7 +130,7 @@ namespace KviKvsCoreFunctions
 		KviStr tmp1(szHex);
 		char * buf;
 		int len = tmp1.hexToBuffer(&buf,true);
-		KVSCF_pRetBuffer->setString(QString(buf));
+		KVSCF_pRetBuffer->setString(QString(KviQCString(buf,len+1)));
 		KviStr::freeBuffer(buf);
 		return true;
 	}
@@ -166,7 +167,7 @@ namespace KviKvsCoreFunctions
 			in this interval of time KVIrc knows only the user's nickname.
 			This function will return the string "*" in this case.[br]
 		@seealso:
-			[fnc]$iswellknown[/fnc], [fnc]$username[/fnc], [cmd]awhois[/cmd]
+			[fnc]$isWellKnown[/fnc], [fnc]$username[/fnc], [cmd]awhois[/cmd]
 	*/
 
 	KVSCF(hostname)
@@ -193,7 +194,35 @@ namespace KviKvsCoreFunctions
 		KVSCF_pRetBuffer->setNothing();
 		return true;
 	}
-
+	
+	//-------------------------------------------------
+	/*
+ 	    @doc: lag
+ 	    @type:
+			function
+ 	    @title:
+ 	    		$lag
+ 	    @short:
+	 	        Returns the lag on the current server
+ 	    @syntax:
+ 		        <integer> lag
+ 	    @description:
+ 	    		This function returns the lag in the current server, in milliseconds.[br]
+	*/
+	
+	KVSCF(lag)
+	{
+	        if(!KVSCF_pContext->window()->console()) return KVSCF_pContext->errorNoIrcContext();
+ 	        if(!KVSCF_pContext->window()->console()->connection())  return KVSCF_pContext->warningNoIrcConnection();
+ 	        if(!KVSCF_pContext->window()->console()->connection()->lagMeter())
+ 	        {
+ 	            KVSCF_pContext->warning(__tr2qs("Lag meter was not enabled"));
+ 	            return false;
+ 	        }
+ 	        
+ 	        KVSCF_pRetBuffer->setInteger( KVSCF_pContext->window()->console()->connection()->lagMeter()->lag());
+ 	        return true;
+	}
 	/////////////////////////////////////////////////////////////////////////////////////////
 
 	/*
@@ -220,7 +249,7 @@ namespace KviKvsCoreFunctions
 				[cmd]echo[/cmd] $($hptimestamp - %tmp)
 			[/example]
 		@seealso:
-			[fnc]$unixtime[/fnc], [fnc]$date[/fnc], [fnc]$time[/fnc]
+			[fnc]$unixTime[/fnc], [fnc]$date[/fnc]
 	*/
 
 	KVSCF(hptimestamp)
@@ -235,23 +264,6 @@ namespace KviKvsCoreFunctions
 
 	///////////////////////////////////////////////////////////////////////////////////////////////
 
-	/*
-		@doc: ic
-		@type:
-			function
-		@title:
-			$ic
-		@short:
-			Retrieves the ID of the specified IRC context
-		@syntax:
-			$ic[(<server>,<nickname>)]
-		@description:
-			This identifier is equivalent to [fnc]$context[/fnc].
-			See the related documentation.
-	*/
-
-	///////////////////////////////////////////////////////////////////////////////////////////////
-
 	/*
 		@doc: icon
 		@type:
@@ -272,7 +284,7 @@ namespace KviKvsCoreFunctions
 				[cmd]echo[/cmd] $icon(linux)
 			[/example]
 		@seealso:
-			[fnc]$iconname[/fnc]
+			[fnc]$iconName[/fnc]
 	*/
 
 	KVSCF(icon)
@@ -317,7 +329,7 @@ namespace KviKvsCoreFunctions
 				[cmd]echo[/cmd] $iconname([fnc]$icon[/fnc](linux))
 			[/example]
 		@seealso:
-			[fnc]$iconname[/fnc]
+			[fnc]$iconName[/fnc]
 	*/
 
 	KVSCF(iconName)
@@ -340,15 +352,15 @@ namespace KviKvsCoreFunctions
 	///////////////////////////////////////////////////////////////////////////////////////////////
 
 	/*
-		@doc: int
+		@doc: integer
 		@type:
 			function
 		@title:
-			$int
+			$integer
 		@short:
 			Casts a variable to an integer
 		@syntax:
-			<integer> $int(<data:variant>)
+			<integer> $integer(<data:variant>)
 		@description:
 			Forces <data> to be an integer data type with the following
 			semantics:[br]
@@ -361,16 +373,34 @@ namespace KviKvsCoreFunctions
 				[li]If <data> is a string, its length is returned.[/li]
 				[li]If <data> is an object, 0 is returned if the reference is null (invalid) and 1 otherwise[/li]
 			[/ul]
-			This function is similar to the C (int) cast.[br]
+			This function is similar to the C (int) cast and is internally
+			aliased to [fnc]$int[/fnc]() too.
 			Note that since KVIrc does most of the casting work automatically
 			you shouldn't need to use this function.
 		@seealso:
-			[fnc]$real()[/fnc]
+			[fnc]$real[/fnc]
+			[fnc]$boolean[/fnc]
 	*/
 
-	KVSCF(intCKEYWORDWORKAROUND)
+	/*
+		@doc: int
+		@type:
+			function
+		@title:
+			$int
+		@short:
+			Casts a variable to an integer
+		@syntax:
+			<integer> $int(<data:variant>)
+		@description:
+			This is an internal alias to [fnc]$integer[/fnc]().
+		@seealso:
+			[fnc]$real[/fnc]
+			[fnc]$boolean[/fnc]
+	*/
+
+	KVSCF(integer)
 	{
-#ifdef COMPILE_NEW_KVS
 		KviKvsVariant * v;
 		KVSCF_PARAMETERS_BEGIN
 			KVSCF_PARAMETER("data",KVS_PT_VARIANT,0,v)
@@ -379,29 +409,6 @@ namespace KviKvsCoreFunctions
 		kvs_int_t iVal;
 		v->castToInteger(iVal);
 		KVSCF_pRetBuffer->setInteger(iVal);
-#endif
-		return true;
-	}
-
-	///////////////////////////////////////////////////////////////////////////////////////////////
-
-	/*
-		@doc: isanyconsoleconnected
-		@type:
-			function
-		@title:
-			$isAnyConsoleConnected
-		@short:
-			DEPRECATED: use $firstConnectedConsole
-		@syntax:
-			<bool> $isAnyConsoleConnected()
-		@description:
-			DEPRECATED: use $firstConnectedConsole
-	*/
-
-	KVSCF(isAnyConsoleConnected)
-	{
-		KVSCF_pRetBuffer->setBoolean(g_pApp->topmostConnectedConsole() ? true : false);
 		return true;
 	}
 
@@ -541,216 +548,6 @@ namespace KviKvsCoreFunctions
 		return true;
 	}
 
-	/*
-		@doc: ismehalfop
-		@type:
-			function
-		@title:
-			$isMeHalfOp
-		@short:
-			Returns 1 if the current user has halfop status
-		@syntax:
-			$ismehalfop
-			$ismehalfop(<window id>)
-		@description:
-			The form with the <window id> parameter returns '1' if the current
-			user has half-operator status on channel designated by <window id>.
-			The form without parameters is equivalent to $ismehalfop([fnc]$window[/fnc])
-			WARNING: This function is DEPRECATED: use [fnc]$chan.ismehalfop[/fnc]()
-		@seealso:
-			[fnc]$ismevoice[/fnc],
-			[fnc]$isvoice[/fnc],
-			[fnc]$isop[/fnc],
-			[fnc]$ismeop[/fnc],
-			[fnc]$ishalfop[/fnc],
-			[fnc]$isuserop[/fnc],
-			[fnc]$ismeuserop[/fnc],
-			[fnc]$window[/fnc],
-			[fnc]$channel[/fnc],
-			[doc:window_naming_conventions]Window naming conventions[/doc]
-	*/
-
-	KVSCF(isMeHalfOp)
-	{
-		QString winId;
-
-		KVSCF_PARAMETERS_BEGIN
-			KVSCF_PARAMETER("windowId",KVS_PT_STRING,KVS_PF_OPTIONAL,winId)
-		KVSCF_PARAMETERS_END
-		KviWindow * wnd;
-		if(winId.isEmpty())wnd = KVSCF_pContext->window();
-		else {
-			wnd = g_pApp->findWindow(winId.utf8().data());
-			if(!wnd)
-			{
-				KVSCF_pContext->warning(__tr2qs("Window with ID '%s' not found"),winId.utf8().data());
-				KVSCF_pRetBuffer->setNothing();
-				return true;
-			}
-		}
-		if(wnd->type() != KVI_WINDOW_TYPE_CHANNEL)
-		{
-			KVSCF_pContext->warning(__tr2qs("The specified window is not a channel"));
-			return true;
-		}
-		KVSCF_pRetBuffer->setBoolean(((KviChannel *)wnd)->isMeHalfOp());
-		return true;
-	}
-
-	///////////////////////////////////////////////////////////////////////////////////////////////
-
-	/*
-		@doc: ismeop
-		@type:
-			function
-		@title:
-			$isMeOp
-		@short:
-			Returns 1 if the current user has operator status
-		@syntax:
-			$ismeop
-			$ismeop(<window id>)
-		@description:
-			NOTE: This function is DEPRECATED: use [fnc]$chan.ismeop[/fnc]()
-		@seealso:
-	*/
-
-	KVSCF(isMeOp)
-	{
-		QString winId;
-
-		KVSCF_PARAMETERS_BEGIN
-			KVSCF_PARAMETER("windowId",KVS_PT_STRING,KVS_PF_OPTIONAL,winId)
-		KVSCF_PARAMETERS_END
-		KviWindow * wnd;
-		if(winId.isEmpty())wnd = KVSCF_pContext->window();
-		else {
-			wnd = g_pApp->findWindow(winId.utf8().data());
-			if(!wnd)
-			{
-				KVSCF_pContext->warning(__tr2qs("Window with ID '%s' not found"),winId.utf8().data());
-				KVSCF_pRetBuffer->setNothing();
-				return true;
-			}
-		}
-		if(wnd->type() != KVI_WINDOW_TYPE_CHANNEL)
-		{
-			KVSCF_pContext->warning(__tr2qs("The specified window is not a channel"));
-			return true;
-		}
-		KVSCF_pRetBuffer->setBoolean(((KviChannel *)wnd)->isMeOp());
-		return true;
-	}
-
-	///////////////////////////////////////////////////////////////////////////////////////////////
-
-	/*
-		@doc: ismeuserop
-		@type:
-			function
-		@title:
-			$isMeUserOp
-		@short:
-			Returns 1 if the current user has userop status
-		@syntax:
-			<bool> $ismeuserop
-			<bool> $ismeuserop(<window id:uint>)
-		@description:
-			The form with the <window id> parameter returns '1' if the current
-			user has user-operator status on channel designated by <window id>.
-			The form without parameters is equivalent to $ismeuserop([fnc]$window[/fnc])
-			WARNING: This function is DEPRECATED: use [fnc]$chan.ismeuserop[/fnc]()
-		@seealso:
-			[fnc]$ismevoice[/fnc], [fnc]$isvoice[/fnc], [fnc]$isop[/fnc],
-			[fnc]$ismeop[/fnc], [fnc]$ishalfop[/fnc], [fnc]$ismehalfop[/fnc],
-			[fnc]$isuserop[/fnc], [fnc]$window[/fnc], [fnc]$channel[/fnc],
-			[doc:window_naming_conventions]Window naming conventions[/doc]
-	*/
-
-	KVSCF(isMeUserOp)
-	{
-		QString winId;
-
-		KVSCF_PARAMETERS_BEGIN
-			KVSCF_PARAMETER("windowId",KVS_PT_STRING,KVS_PF_OPTIONAL,winId)
-		KVSCF_PARAMETERS_END
-		KviWindow * wnd;
-		if(winId.isEmpty())wnd = KVSCF_pContext->window();
-		else {
-			wnd = g_pApp->findWindow(winId.utf8().data());
-			if(!wnd)
-			{
-				KVSCF_pContext->warning(__tr2qs("Window with ID '%s' not found"),winId.utf8().data());
-				KVSCF_pRetBuffer->setNothing();
-				return true;
-			}
-		}
-		if(wnd->type() != KVI_WINDOW_TYPE_CHANNEL)
-		{
-			KVSCF_pContext->warning(__tr2qs("The specified window is not a channel"));
-			return true;
-		}
-		KVSCF_pRetBuffer->setBoolean(((KviChannel *)wnd)->isMeUserOp());
-		return true;
-	}
-
-	///////////////////////////////////////////////////////////////////////////////////////////////
-
-	/*
-		@doc: ismevoice
-		@type:
-			function
-		@title:
-			$isMeVoice
-		@short:
-			Returns 1 if the current user has voice status
-		@syntax:
-			$ismevoice
-			$ismevoice(<window id>)
-		@description:
-			The form with the <window id> parameter returns '1' if the current
-			user has voice status on channel designated by <window id>.
-			The form without parameters is equivalent to $ismevoice([fnc]$window[/fnc])
-		@seealso:
-			[fnc]$isvoice[/fnc],
-			[fnc]$isop[/fnc],
-			[fnc]$ismeop[/fnc],
-			[fnc]$ishalfop[/fnc],
-			[fnc]$ismehalfop[/fnc],
-			[fnc]$isuserop[/fnc],
-			[fnc]$ismeuserop[/fnc],
-			[fnc]$window[/fnc],
-			[fnc]$channel[/fnc],
-			[doc:window_naming_conventions]Window naming conventions[/doc]
-	*/
-
-	KVSCF(isMeVoice)
-	{
-		QString winId;
-
-		KVSCF_PARAMETERS_BEGIN
-			KVSCF_PARAMETER("windowId",KVS_PT_STRING,KVS_PF_OPTIONAL,winId)
-		KVSCF_PARAMETERS_END
-		KviWindow * wnd;
-		if(winId.isEmpty())wnd = KVSCF_pContext->window();
-		else {
-			wnd = g_pApp->findWindow(winId.utf8().data());
-			if(!wnd)
-			{
-				KVSCF_pContext->warning(__tr2qs("Window with ID '%s' not found"),winId.utf8().data());
-				KVSCF_pRetBuffer->setNothing();
-				return true;
-			}
-		}
-		if(wnd->type() != KVI_WINDOW_TYPE_CHANNEL)
-		{
-			KVSCF_pContext->warning(__tr2qs("The specified window is not a channel"));
-			return true;
-		}
-		KVSCF_pRetBuffer->setBoolean(((KviChannel *)wnd)->isMeVoice());
-		return true;
-	}
-
 	///////////////////////////////////////////////////////////////////////////////////////////////
 
 	/*
@@ -833,7 +630,7 @@ namespace KviKvsCoreFunctions
 		@description:
 			Returns 1 if the timer named <name> is actually running, else 0
 		@seealso:
-			[cmd]timer[/cmd],[cmd]killtimer[/cmd]
+			[cmd]timer[/cmd], [cmd]killtimer[/cmd]
 	*/
 
 	KVSCF(isTimer)
@@ -908,7 +705,7 @@ namespace KviKvsCoreFunctions
 			<string> $k(<foreground:integer>[,<background:integer>])
 			<string> $k
 		@description:
-			Returns the COLOR mIRC control character (CTRL+K).[br]
+			Returns the COLOR mIRC control character (Qt::CTRL+K).[br]
 			If <foreground> and <background> are passed, a standard mIRC
 			color escape is returned.[br]
 		@seealso:
@@ -1010,6 +807,9 @@ namespace KviKvsCoreFunctions
 		return true;
 	}
 
+
+
+
 	///////////////////////////////////////////////////////////////////////////////////////////////
 
 	/*
@@ -1075,7 +875,7 @@ namespace KviKvsCoreFunctions
 		@description:
 			Returns a line feed character
 		@seealso:
-			[fnc]$cr[/fnc],[fnc]$ascii[/fnc],[fnc]$char[/fnc]
+			[fnc]$cr[/fnc], [fnc]$ascii[/fnc], [fnc]$char[/fnc]
 	*/
 
 	KVSCF(lf)
