@@ -37,6 +37,7 @@
 #include "kvi_console.h"
 #include "kvi_ircuserdb.h"
 #include "kvi_ircmask.h"
+#include "kvi_socket.h"
 #include "kvi_app.h"
 #include "kvi_query.h"
 
@@ -360,7 +361,7 @@ namespace KviKvsCoreFunctions
 			Please note that writing $null is semantically equivalent to writing 0
 			or even [fnc]$nothing[/fnc] in place of the handle, but $null increases code readability.
 		@seealso:
-			[fnc]$new()[/fnc], [fnc]$nothing[/fnc]
+			[fnc]$new[/fnc], [fnc]$nothing[/fnc]
 	*/
 
 	KVSCF(nullCKEYWORDWORKAROUND)
@@ -384,7 +385,7 @@ namespace KviKvsCoreFunctions
 		@description:
 			Returns the RESET mIRC control character (CTRL+O).[br]
 		@seealso:
-			[fnc]$k[/fnc],[fnc]$b[/fnc],[fnc]$u[/fnc],[fnc]$r[/fnc]
+			[fnc]$k[/fnc], [fnc]$b[/fnc], [fnc]$u[/fnc], [fnc]$r[/fnc]
 	*/
 
 	KVSCF(o)
@@ -517,7 +518,7 @@ namespace KviKvsCoreFunctions
 		@description:
 			Returns the REVERSE mIRC control character (CTRL+R).[br]
 		@seealso:
-			[fnc]$k[/fnc],[fnc]$b[/fnc],[fnc]$u[/fnc],[fnc]$o[/fnc]
+			[fnc]$k[/fnc], [fnc]$b[/fnc], [fnc]$u[/fnc], [fnc]$o[/fnc]
 	*/
 
 	KVSCF(r)
@@ -597,7 +598,7 @@ namespace KviKvsCoreFunctions
 			Note that since KVIrc does most of the casting work automatically
 			you shouldn't need to use this function.
 		@seealso:
-			[fnc]$int()[/fnc]
+			[fnc]$int[/fnc]
 	*/
 
 	KVSCF(real)
@@ -618,6 +619,27 @@ namespace KviKvsCoreFunctions
 		return true;
 	}
 
+	/*
+		@doc: receivedBytes
+		@type:
+			function
+		@title:
+			$receivedBytes
+		@short:
+			Returns total received bytes
+		@syntax:
+			<uint> $receivedBytes()
+		@description:
+			Returns total received bytes
+		@seealso:
+			[fnc]$sentBytes[/fnc]
+	*/
+
+	KVSCF(receivedBytes)
+	{
+		KVSCF_pRetBuffer->setInteger(g_uIncomingTraffic);
+		return true;
+	}
 
 	/*
 		@doc: rsort
