@@ -42,6 +42,7 @@
 #include "kvi_modulemanager.h"
 #include "kvi_mirccntrl.h"
 #include "kvi_sourcesdate.h"
+#include "kvi_socket.h"
 
 #include <stdlib.h> // rand & srand
 
@@ -144,6 +145,60 @@ namespace KviKvsCoreFunctions
 		return true;
 	}
 
+
+		/*
+		@doc: sentBytes
+		@type:
+			function
+		@title:
+			$sentBytes
+		@short:
+			Returns total sent bytes
+		@syntax:
+			<uint> $sentBytes()
+		@description:
+			Returns total sent bytes
+		@seealso:
+			[fnc]$receivedBytes[/fnc]
+	*/
+
+	KVSCF(sentBytes)
+	{
+		KVSCF_pRetBuffer->setInteger(g_uOutgoingTraffic);
+		return true;
+	}
+
+	/*
+		@doc: serialize
+		@type:
+			function
+		@title:
+			<string> $serialize(<data:mixed>)
+		@short:
+			Encodes variable to JSON string
+		@syntax:
+			<string> $serialize(<data:mixed>)
+		@description:
+			Decodes JSON-encoded string
+			$serialize() returns a string containing a byte-stream representation of value that can be stored anywhere.
+		@seealso:
+			[fnc]$serialize[/fnc]
+	*/
+	KVSCF(serialize)
+	{
+		KviKvsVariant *pVar = 0;
+		QString szBuffer;
+
+		KVSCF_PARAMETERS_BEGIN
+			KVSCF_PARAMETER("data",KVS_PT_VARIANT,0,pVar)
+		KVSCF_PARAMETERS_END
+
+		if(!pVar) return false;
+		pVar->serialize(szBuffer);
+		KVSCF_pRetBuffer->setString(szBuffer);
+		return true;
+	}
+
 	/////////////////////////////////////////////////////////////////////////////////////////
 
 	/*
@@ -222,7 +277,6 @@ namespace KviKvsCoreFunctions
 
 	KVSCF(sort)
 	{
-#ifdef COMPILE_NEW_KVS
 		KviKvsArrayCast a;
 
 		KVSCF_PARAMETERS_BEGIN
@@ -237,44 +291,51 @@ namespace KviKvsCoreFunctions
 		} else {
 			KVSCF_pRetBuffer->setArray(new KviKvsArray());
 		}
-#endif
 		return true;
 	}
 
-	/////////////////////////////////////////////////////////////////////////////////////////
-
+	/////////////////////////////////////////////////////////////////////////////////////////////
+	
 	/*
-		@doc: split
+		@doc: string
 		@type:
 			function
 		@title:
-			$split
+			$string
 		@short:
-			DEPRECATED: Use $str.split instead!
+			Casts a variable to a string
+		@syntax:
+			<integer> $string(<data:variant>)
 		@description:
-			This function has been moved to the str module.
-			See [fnc]$str.split[/fnc]()
+			Forces <data> to be a string data type with the following semantics:
+			[ul]
+				[li]If <data> is a string then <data> itself is returned.[/li]
+				[li]If <data> is an integer then its decimal rappresentation is returned.[/li]
+				[li]If <data> is a real then its decimal floating-point rappresentation is returned.[/li]
+				[li]If <data> is a boolean then the string "1" is returned for a true value and the string "0" for a false value.[/li]
+				[li]If <data> is nothing (unset) then an empty string is returned[/li]
+				[li]If <data> is an array then a string with all the items converted to strings and separated by commas is returned[/li]
+				[li]If <data> is a hash then a string with all the values converted to strings and separated by commas is returned[/li]
+				[li]If <data> is a hobject then the string "object" is returned[/li]
+			[/ul]
+			Note that since KVIrc does most of the casting work automatically
+			you shouldn't need to use this function.
+		@seealso:
+			[fnc]$real[/fnc]
+			[fnc]$integer[/fnc]
 	*/
 
-	KVSCF(split)
+	KVSCF(string)
 	{
-		KviModule * m = g_pModuleManager->getModule("str");
-		if(!m)
-		{
-			KVSCF_pContext->error(__tr2qs("Module function call failed: can't load the module 'str'"));
-			return false;
-		}
+		KviKvsVariant * v;
+		KVSCF_PARAMETERS_BEGIN
+			KVSCF_PARAMETER("data",KVS_PT_VARIANT,0,v)
+		KVSCF_PARAMETERS_END
 
-		KviKvsModuleFunctionExecRoutine * proc = m->kvsFindFunction("split");
-		if(!proc)
-		{
-			KVSCF_pContext->error(__tr2qs("Module function call failed: the module 'str' doesn't export a function named 'split'"));
-			return false;
-		}
-
-		KviKvsModuleFunctionCall call(m,KVSCF_pContext,KVSCF_pParams,KVSCF_pRetBuffer);
-
-		return (*proc)(&call);
+		QString szVal;
+		v->asString(szVal);
+		KVSCF_pRetBuffer->setString(szVal);
+		return true;
 	}
 
 	/////////////////////////////////////////////////////////////////////////////////////////
@@ -288,7 +349,7 @@ namespace KviKvsCoreFunctions
 		@short:
 			Returns the value of a switch for an alias
 		@syntax:
-			<variant> $sw(<switch_name:string>)
+			<variant> $sw(<switch_name:string>[,<long_switch_name:string>])
 		@description:
 			This function is valid and useful only in aliases.
 			It allows an alias to handle switches just like any other
@@ -302,12 +363,13 @@ namespace KviKvsCoreFunctions
 		@examples:
 			[example]
 				[cmd]alias[/cmd](test){
-					if($sw(a)) [cmd]echo[/cmd] "Switch -a was passed"
+					if($sw(a,append)) [cmd]echo[/cmd] "Switch -a was passed"
 					%x = $sw(x);
 					if(%x) [cmd]echo[/cmd] "Switch -x=%x was passed"
 				}
 				test -a
 				test -x
+				test --append -x
 				test -a -x
 				test -a -x=test
 				test -a=10 -x=test
@@ -317,9 +379,11 @@ namespace KviKvsCoreFunctions
 	KVSCF(sw)
 	{
 		QString szSwitch;
+		QString szLongSwitch;
 
 		KVSCF_PARAMETERS_BEGIN
 			KVSCF_PARAMETER("switch_name",KVS_PT_STRING,0,szSwitch)
+			KVSCF_PARAMETER("long_name",KVS_PT_STRING | KVS_PF_OPTIONAL ,0,szLongSwitch)
 		KVSCF_PARAMETERS_END
 
 		KviKvsSwitchList * sl = KVSCF_pContext->aliasSwitchList();
@@ -330,9 +394,20 @@ namespace KviKvsCoreFunctions
 		}
 
 		KviKvsVariant * v;
+		
 
-		if(szSwitch.length() > 1)v = sl->find(szSwitch);
-		else v = sl->find(szSwitch[0]);
+		if(szSwitch.length() > 1)
+		{
+			if(szLongSwitch.isEmpty())
+				v = sl->find(szSwitch);
+			else
+				v = sl->find(szSwitch[0].unicode(),szLongSwitch);
+		}else {
+			if(szLongSwitch.isEmpty())
+				v = sl->find(szSwitch[0]);
+			else
+				v = sl->find(szSwitch[0].unicode(),szLongSwitch);
+		}
 
 		if(v)KVSCF_pRetBuffer->copyFrom(*v);
 		else KVSCF_pRetBuffer->setNothing();
@@ -394,7 +469,7 @@ namespace KviKvsCoreFunctions
 			wnd = KVSCF_pContext->window();
 		}
 
-		debug("CALLING $target on window %s",wnd->name());
+		//debug("CALLING $target on window %s",wnd->name());
 		QString szTa = wnd->target();
 
 
@@ -445,42 +520,6 @@ namespace KviKvsCoreFunctions
 
 	/////////////////////////////////////////////////////////////////////////////////////////
 
-	/*
-		@doc: time
-		@type:
-			function
-		@title:
-			$time
-		@short:
-			Returns a formatted date/time string
-		@syntax:
-			$time(<unixtime>)
-			$time
-		@description:
-			Returns the string representation of <unixtime> or
-			of the current time if <unixtime> is not given.[br]
-		@examples:
-			[example]
-				[cmd]echo[/cmd] $time
-			[/example]
-		@seealso:
-			[fnc]$unixtime[/fnc], [fnc]$date[/fnc], [fnc]$hptimestamp[/fnc]
-	*/
-
-	KVSCF(timeCFUNCTIONWORKAROUND)
-	{
-		kvs_int_t iTime;
-		KVSCF_PARAMETERS_BEGIN
-			KVSCF_PARAMETER("unixtime",KVS_PT_INT,KVS_PF_OPTIONAL,iTime)
-		KVSCF_PARAMETERS_END
-
-		kvi_time_t t = (kvi_time_t)iTime;
-		KVSCF_pRetBuffer->setString(QString(ctime(&t)));
-		return true;
-	}
-
-	/////////////////////////////////////////////////////////////////////////////////////////
-
 	/*
 		@doc: script_localization
 		@type:
@@ -791,7 +830,7 @@ namespace KviKvsCoreFunctions
 		@description:
 			Returns the UNDERLINE mIRC control character (CTRL+U).[br]
 		@seealso:
-			[fnc]$k[/fnc],[fnc]$b[/fnc],[fnc]$r[/fnc],[fnc]$o[/fnc]
+			[fnc]$k[/fnc], [fnc]$b[/fnc], [fnc]$r[/fnc], [fnc]$o[/fnc]
 	*/
 
 	KVSCF(u)
@@ -818,7 +857,7 @@ namespace KviKvsCoreFunctions
 			If <char> is composed of more than one character
 			then an array of UNICODE code points is returned.
 		@seealso:
-			[fnc]$cr[/fnc],[fnc]$lf[/fnc],[fnc]$char[/fnc]
+			[fnc]$cr[/fnc], [fnc]$lf[/fnc], [fnc]$char[/fnc]
 	*/
 
 	KVSCF(unicode)
@@ -856,7 +895,7 @@ namespace KviKvsCoreFunctions
 			Returns the time since the Epoch (00:00:00 UTC, January 1, 1970),
 			measured in seconds.
 		@seealso:
-			[fnc]$time[/fnc], [fnc]$date[/fnc], [fnc]$hptimestamp[/fnc]
+			[fnc]$date[/fnc], [fnc]$hpTimeStamp[/fnc]
 	*/
 
 	KVSCF(unixtime)
@@ -865,6 +904,36 @@ namespace KviKvsCoreFunctions
 		return true;
 	}
 
+	/*
+		@doc: unserialize
+		@type:
+			function
+		@title:
+			<mixed> $unserialize(<data:string>)
+		@short:
+			Decodes JSON-encoded string
+		@syntax:
+			<mixed> $unserialize(<data:string>)
+		@description:
+			Decodes JSON-encoded string
+		@seealso:
+			[fnc]$serialize[/fnc]
+	*/
+
+	KVSCF(unserialize)
+	{
+		QString szData;
+
+		KVSCF_PARAMETERS_BEGIN
+			KVSCF_PARAMETER("data",KVS_PT_NONEMPTYSTRING,0,szData)
+		KVSCF_PARAMETERS_END
+
+		KviKvsVariant *pVar = KviKvsVariant::unserialize(szData);
+		if(pVar)
+			KVSCF_pRetBuffer->copyFrom(pVar);
+		return true;
+	}
+
 	/////////////////////////////////////////////////////////////////////////////////////////
 
 	/*
@@ -897,7 +966,7 @@ namespace KviKvsCoreFunctions
 			in this interval of time KVIrc knows only the user's nickname.
 			This function will return the string "*" in this case.[br]
 		@seealso:
-			[fnc]$iswellknown[/fnc], [$fnc]$hostname[/fnc], [cmd]awhois[/cmd]
+			[fnc]$isWellKnown[/fnc], [$fnc]$hostname[/fnc], [cmd]awhois[/cmd]
 	*/
 
 	KVSCF(username)
@@ -986,7 +1055,7 @@ namespace KviKvsCoreFunctions
 			Retrieve the id of a specified window.
 		@syntax:
 			<string> $window
-			<string> $window(<caption_text:hash>)
+			<string> $window([<caption_text:hash>[,<context_id:uint>]])
 		@description:
 			Returns the [b]window id[/b] of the first window that
 			has the specified <caption text>.[br]
@@ -994,6 +1063,7 @@ namespace KviKvsCoreFunctions
 			window id is returned (0).[br]
 			If no <caption text> is specified , this function returns the id
 			of the current window.[br]
+			<context_id> restricts search in only one irc context.
 		@examples:
  			[example]
  				[cmd]echo[/cmd] This is the window with id $window
@@ -1007,28 +1077,32 @@ namespace KviKvsCoreFunctions
 
  	KVSCF(window)
  	{
-#ifdef COMPILE_NEW_KVS
 		//#warning "FIXME: the window identifiers could be numbers!"
 		QString szCaption;
+		kvs_int_t iContextId; // kvs_int_t is 64bit while int is 32 (and thus KVSCF_PARAMETER() crashes)
 
 		KVSCF_PARAMETERS_BEGIN
 			KVSCF_PARAMETER("caption_text",KVS_PT_STRING,KVS_PF_OPTIONAL,szCaption)
+			KVSCF_PARAMETER("context_id",KVS_PT_INTEGER,KVS_PF_OPTIONAL,iContextId)
 		KVSCF_PARAMETERS_END
 
+		if(KVSCF_pParams->count() < 2)
+			iContextId = -1;
+
 		KviWindow * pWnd;
 		if(szCaption.isEmpty())
 		{
 			pWnd = KVSCF_pContext->window();
 		} else {
-			pWnd = g_pApp->findWindowByCaption(szCaption);
+			pWnd = g_pApp->findWindowByCaption(szCaption,iContextId);
 			if(!pWnd)
 			{
-				KVSCF_pContext->warning(__tr2qs("Window with caption %Q not found"),&szCaption);
+				//follow the documented behaviour
+				KVSCF_pRetBuffer->setInteger(0);
 				return true;
 			}
 		}
-		KVSCF_pRetBuffer->setString(pWnd->id());
-#endif
+		KVSCF_pRetBuffer->setInteger(pWnd->numericId());
 		return true;
 	}
 };
