@@ -46,12 +46,20 @@
 #ifndef COMPILE_NO_X_BELL
 	#include "kvi_xlib.h" // XBell : THIS SHOULD BE INCLUDED AS LAST!
 	#include <unistd.h>   // for usleep();
+
+	#ifdef COMPILE_USE_QT4
+		#include <qx11info_x11.h>
+		#define get_xdisplay QX11Info::display
+	#else
+		#define get_xdisplay qt_xdisplay
+	#endif
+
 #endif
 
-#include <qtooltip.h>
+#include "kvi_tal_tooltip.h"
 
 // kvi_app.cpp
-extern QAsciiDict<KviWindow> * g_pGlobalWindowDict;
+extern KviPointerHashTable<const char *,KviWindow> * g_pGlobalWindowDict;
 
 namespace KviKvsCoreSimpleCommands
 {
@@ -116,7 +124,7 @@ namespace KviKvsCoreSimpleCommands
 	
 		if(KVSCSC_pSwitches->find('a',"all-networks"))
 		{
-			QAsciiDictIterator<KviWindow> it(*g_pGlobalWindowDict);
+			KviPointerHashTableIterator<const char *,KviWindow> it(*g_pGlobalWindowDict);
 			while(KviWindow * wnd = it.current())
 			{
 				if(wnd->type()==KVI_WINDOW_TYPE_CONSOLE)
@@ -130,7 +138,7 @@ namespace KviKvsCoreSimpleCommands
 				++it;
 			}
 		} else  {
-			QCString szR = KVSCSC_pConnection->encodeText(szReason);
+			KviQCString szR = KVSCSC_pConnection->encodeText(szReason);
 			if(!(KVSCSC_pConnection->sendFmtData("AWAY :%s",szR.data())))
 				return KVSCSC_pContext->warningNoIrcConnection();
 		}
@@ -170,7 +178,7 @@ namespace KviKvsCoreSimpleCommands
 		
 		if(KVSCSC_pSwitches->find('a',"all-networks"))
 		{
-			QAsciiDictIterator<KviWindow> it(*g_pGlobalWindowDict);
+			KviPointerHashTableIterator<const char *,KviWindow> it(*g_pGlobalWindowDict);
 			while(KviWindow * wnd = it.current())
 			{
 				if(wnd->type()==KVI_WINDOW_TYPE_CONSOLE)
@@ -215,7 +223,11 @@ namespace KviKvsCoreSimpleCommands
 			ban Maxim,Gizmo!*@*,*!root@*
 			[/example]
 		@seealso:
-			[cmd]op[/cmd],[cmd]deop[/cmd],[cmd]voice[/cmd],[cmd]devoice[/cmd],[cmd]unban[/cmd]
+			[cmd]op[/cmd],
+			[cmd]deop[/cmd],
+			[cmd]voice[/cmd],
+			[cmd]devoice[/cmd],
+			[cmd]unban[/cmd]
 	*/
 
 	KVSCSC(ban)
@@ -309,10 +321,12 @@ namespace KviKvsCoreSimpleCommands
 #else
 	#ifndef COMPILE_NO_X_BELL
 
+
+
 		XKeyboardState st;
 		XKeyboardControl ctl;
 
-		XGetKeyboardControl(qt_xdisplay(),&st);
+		XGetKeyboardControl(get_xdisplay(),&st);
 
 		unsigned long mask = KBBellPercent;
 		ctl.bell_percent = uVolume;
@@ -326,9 +340,9 @@ namespace KviKvsCoreSimpleCommands
 			ctl.bell_duration = duration;
 			mask             |= KBBellDuration;
 		}
-		XChangeKeyboardControl(qt_xdisplay(),mask,&ctl);
+		XChangeKeyboardControl(get_xdisplay(),mask,&ctl);
 
-		XBell(qt_xdisplay(),100);
+		XBell(get_xdisplay(),100);
 
 		if(bSync)
 		{
@@ -340,7 +354,7 @@ namespace KviKvsCoreSimpleCommands
 		ctl.bell_duration = st.bell_duration;
 		ctl.bell_percent = st.bell_percent;
 
-		XChangeKeyboardControl(qt_xdisplay(),mask,&ctl);
+		XChangeKeyboardControl(get_xdisplay(),mask,&ctl);
 
 	#endif //COMPILE_NO_X_BELL
 #endif
@@ -416,8 +430,8 @@ namespace KviKvsCoreSimpleCommands
 		switch(o.unicode())
 		{
 			case 't':
-				QToolTip::remove(pButton);
-				QToolTip::add(pButton,tbPar);
+				KviTalToolTip::remove(pButton);
+				KviTalToolTip::add(pButton,tbPar);
 				pButton->setButtonText(tbPar);
 			break;
 			case 'i':
@@ -509,8 +523,8 @@ namespace KviKvsCoreSimpleCommands
 			KviQString::appendFormatted(szCtcpData," %d.%d",tv.tv_sec,tv.tv_usec);
 		}
 
-		QCString szT = KVSCSC_pConnection->encodeText(szTarget);
-		QCString szD = KVSCSC_pConnection->encodeText(szCtcpData);
+		KviQCString szT = KVSCSC_pConnection->encodeText(szTarget);
+		KviQCString szD = KVSCSC_pConnection->encodeText(szCtcpData);
 	
 		if(!(KVSCSC_pConnection->sendFmtData("%s %s :%c%s%c",
 				KVSCSC_pSwitches->find('n',"notice") ? "NOTICE" : "PRIVMSG",szT.data(),0x01,szD.data(),0x01)))
@@ -658,7 +672,7 @@ namespace KviKvsCoreSimpleCommands
 			about inexisting items or inexisting popup menus.[br]
 			See [cmd]defpopup[/cmd] for more informations.[br]
 		@seealso:
-			[cmd]defpopup[/cmd],[cmd]popup[/cmd]
+			[cmd]defpopup[/cmd], [cmd]popup[/cmd]
 	*/
 	// FIXME: #warning "Separator should have the expression too ?"
 
@@ -718,7 +732,7 @@ namespace KviKvsCoreSimpleCommands
 			deop Pragma,Crocodile
 			[/example]
 		@seealso:
-			[cmd]op[/cmd],[cmd]voice[/cmd],[cmd]devoice[/cmd]
+			[cmd]op[/cmd], [cmd]voice[/cmd], [cmd]devoice[/cmd]
 	*/
 
 	KVSCSC(deop)
@@ -750,7 +764,7 @@ namespace KviKvsCoreSimpleCommands
 			devoice Pragma,Crocodile
 			[/example]
 		@seealso:
-			[cmd]op[/cmd],[cmd]deop[/cmd],[cmd]voice[/cmd]
+			[cmd]op[/cmd], [cmd]deop[/cmd], [cmd]voice[/cmd]
 	*/
 
 	KVSCSC(devoice)
