@@ -35,6 +35,12 @@
 #include "kvi_ircconnectionserverinfo.h"
 #include "kvi_locale.h"
 
+#include "kvi_out.h"
+
+#ifdef COMPILE_USE_QT4
+	#include <q3mimefactory.h>
+#endif
+
 namespace KviKvsCoreSimpleCommands
 {
 	/*
@@ -133,8 +139,12 @@ namespace KviKvsCoreSimpleCommands
 			QString szOriginal = szTopic;
 	
 			QString topik = szTopic;
+#ifdef COMPILE_USE_QT4
+			QStringList pl = Q3MimeSourceFactory::defaultFactory()->filePath();
+#else
 			QStringList pl = QMimeSourceFactory::defaultFactory()->filePath();
-	
+#endif
+
 			bool bLowCaseTried = false;
 			bool bFound = KviFileUtils::fileExists(szTopic);
 	
@@ -249,7 +259,7 @@ try_again:
 		@switches:
 			!sw: --ipv6 | -i
 			Causes the command to run in IPv6 mode
-			!sw: --any | -i
+			!sw: --any | -a
 			Causes the command to run in unspecified mode and lookup both IPv4 and IPv6 addresses
 		@description:
 			Starts a DNS lookup for the <dnsquery> (hostname) and prints
@@ -402,14 +412,14 @@ try_again:
 		}
 
 		szChans = slChans.join(",");
-		QCString szEncodedChans = KVSCSC_pConnection->encodeText(szChans);
+		KviQCString szEncodedChans = KVSCSC_pConnection->encodeText(szChans);
 
 		if(szKeys.isEmpty())
 		{
 			if(!(KVSCSC_pConnection->sendFmtData("JOIN %s",szEncodedChans.data())))
 				return KVSCSC_pContext->warningNoIrcConnection();
 		} else {
-			QCString szEncodedKeys  = KVSCSC_pConnection->encodeText(szKeys);
+			KviQCString szEncodedKeys  = KVSCSC_pConnection->encodeText(szKeys);
 			if(!(KVSCSC_pConnection->sendFmtData("JOIN %s %s",szEncodedChans.data(),szEncodedKeys.data())))
 				return KVSCSC_pContext->warningNoIrcConnection();
 		}
@@ -456,9 +466,9 @@ try_again:
 			return false;
 		}
 
-		QCString szC = KVSCSC_pConnection->encodeText(KVSCSC_pWindow->target());
-		QCString szU = KVSCSC_pConnection->encodeText(szUser);
-		QCString szR = KVSCSC_pConnection->encodeText(szReason);
+		KviQCString szC = KVSCSC_pConnection->encodeText(KVSCSC_pWindow->target());
+		KviQCString szU = KVSCSC_pConnection->encodeText(szUser);
+		KviQCString szR = KVSCSC_pConnection->encodeText(szReason);
 
 		if(szR.isEmpty())
 		{
@@ -498,12 +508,11 @@ try_again:
 			in this case the current timer will be scheduled for killing immediately
 			after it has returned control to KVIrc.
 		@seealso:
-			[cmd]timer[/cmd], [fnc]$isTimer[/fnc]
+			[cmd]timer[/cmd], [fnc]$isTimer[/fnc], [cmd]listtimers[/cmd]
 	*/
 
 	KVSCSC(killtimer)
 	{
-#ifdef COMPILE_NEW_KVS
 		QString szName;
 		KVSCSC_PARAMETERS_BEGIN
 			KVSCSC_PARAMETER("name",KVS_PT_STRING,KVS_PF_OPTIONAL,szName)
@@ -529,7 +538,6 @@ try_again:
 					KVSCSC_pContext->warning(__tr2qs("Can't kill the timer '%Q' since it is not running"),&szName);
 			}
 		}
-#endif
 		return true;
 	}
 
@@ -590,6 +598,75 @@ try_again:
 
 	///////////////////////////////////////////////////////////////////////////////////////////////////////
 
+	/*
+		@doc: listtimers
+		@title:
+			listtimers
+		@type:
+			command
+		@short:
+			Lists the active timers
+		@syntax:
+			listtimers
+		@description:
+			Lists the currently active timers
+		@seealso:
+			[cmd]timer[/cmd], [fnc]$isTimer[/fnc], [cmd]killtimer[/cmd]
+	*/
+
+	KVSCSC(listtimers)
+	{
+		KviPointerHashTable<QString,KviKvsTimer> * pTimerDict = KviKvsTimerManager::instance()->timerDict();
+
+		if(!pTimerDict)
+			return true;
+		
+		KviPointerHashTableIterator<QString,KviKvsTimer> it(*pTimerDict);
+		
+		KVSCSC_pContext->window()->outputNoFmt(KVI_OUT_VERBOSE,__tr2qs("List of active timers"));
+		
+		unsigned int uCnt = 0;
+		
+		while(KviKvsTimer * pTimer = it.current())
+		{
+			QString szName = pTimer->name();
+			QString szLifetime;
+			switch(pTimer->lifetime())
+			{
+				case KviKvsTimer::Persistent:
+					szLifetime = __tr2qs("Persistent");
+				break;
+				case KviKvsTimer::WindowLifetime:
+					szLifetime = __tr2qs("WindowLifetime");
+				break;
+				case KviKvsTimer::SingleShot:
+					szLifetime = __tr2qs("SingleShot");
+				break;
+				default:
+					szLifetime = __tr2qs("Unknown");
+				break;
+			}
+			QString szDelay;
+			szDelay.setNum(pTimer->delay());
+			QString szWindow;
+			szWindow = pTimer->window() ? pTimer->window()->id() : __tr2qs("None");
+
+			KVSCSC_pContext->window()->output(KVI_OUT_VERBOSE,
+					"Timer \"%Q\": Lifetime: %Q, Delay: %Q, Window: %Q",
+					&szName,&szLifetime,&szDelay,&szWindow
+				);
+
+			uCnt++;
+			++it;
+		}
+
+		KVSCSC_pContext->window()->output(KVI_OUT_VERBOSE,__tr2qs("Total: %u timers running"),uCnt);
+
+		return true;
+	}
+
+	///////////////////////////////////////////////////////////////////////////////////////////////////////
+
 	/*
 		@doc: lusers
 		@type:
@@ -611,5 +688,6 @@ try_again:
 	*/
 	// RFC2821 wrapper
 
+
 };
 
