@@ -40,6 +40,8 @@
 #include "kvi_channel.h"
 #include "kvi_ircurl.h"
 #include "kvi_frame.h"
+#include "kvi_modulemanager.h" 
+#include "kvi_kvs_moduleinterface.h"
 
 #include "kvi_kvs_variantlist.h"
 #include "kvi_kvs_script.h"
@@ -130,7 +132,7 @@ namespace KviKvsCoreSimpleCommands
 
 		KVSCSC_REQUIRE_CONNECTION
 
-		QCString szTxt = KVSCSC_pConnection->encodeText(szText);
+		KviQCString szTxt = KVSCSC_pConnection->encodeText(szText);
 
 		if(!szTxt.isEmpty())
 		{
@@ -217,7 +219,7 @@ namespace KviKvsCoreSimpleCommands
 
 		KVSCSC_REQUIRE_CONNECTION
 
-		QCString szData = KVSCSC_pConnection->encodeText(szNick);
+		KviQCString szData = KVSCSC_pConnection->encodeText(szNick);
 		if(!szData.data())szData = "";
 
 		if(!KVSCSC_pConnection->sendFmtData("NICK %s",szData.data()))
@@ -268,8 +270,8 @@ namespace KviKvsCoreSimpleCommands
 		KviWindow * w = KVSCSC_pConnection->findChannel(szTarget);
 		if(!w)w = KVSCSC_pConnection->findQuery(szTarget);
 
-		QCString szT = KVSCSC_pConnection->encodeText(szTarget);
-		QCString szD = w ? w->encodeText(szText) : KVSCSC_pConnection->encodeText(szText);
+		KviQCString szT = KVSCSC_pConnection->encodeText(szTarget);
+		KviQCString szD = w ? w->encodeText(szText) : KVSCSC_pConnection->encodeText(szText);
 		if(!szT.data())szT = ""; // encoding problems ?
 		if(!szD.data())szD = ""; // encoding problems ?
 
@@ -306,7 +308,7 @@ namespace KviKvsCoreSimpleCommands
 			op Pragma,Crocodile
 			[/example]
 		@seealso:
-			[cmd]deop[/cmd],[cmd]voice[/cmd],[cmd]devoice[/cmd]
+			[cmd]deop[/cmd], [cmd]voice[/cmd], [cmd]devoice[/cmd]
 	*/
 
 	KVSCSC(op)
@@ -340,14 +342,14 @@ namespace KviKvsCoreSimpleCommands
 		@examples:
 			[example]
 				openurl http://www.kvirc.net
+				openurl https://www.secure.net
+				openurl file://home/pragma/pippo.txt
 				openurl irc://irc.eu.dal.net:6667
 				openurl irc6://irc.ircd.it/#kvirc
 				openurl ircs://crypto.azzurra.org:9999
 				openurl ircs6://ngnet.azzurra.org:9999
-				openurl www.kvirc.net
 				openurl ftp://ftp.localhost.net/pub/kvirc/
-				openurl https://www.secure.net
-				openurl file://home/pragma/pippo.txt
+				openurl mailto:users@domain.extension
 			[/example]
 	*/
 
@@ -378,32 +380,39 @@ namespace KviKvsCoreSimpleCommands
 			szCommand = KVI_OPTION_STRING(KviOption_stringUrlFileCommand);
 		} else if(KviQString::equalCIN(szUrl,"irc",3))
 		{
-			KviStr command;
-			if(!parseIrcUrl(szUrl.utf8().data(),command))
+			if(KviIrcUrl::run(szUrl,KviIrcUrl::FirstFreeContext,KVSCSC_pContext->console()) & KviIrcUrl::InvalidProtocol)
 			{
 				KVSCSC_pContext->warning(__tr2qs("Invalid IRC url (%Q)"),&szUrl);
-				return true;
 			}
-			szCommand = command.ptr();
+			return true;
 		} else if(KviQString::equalCIN(szUrl,"mailto",6))
 		{
 			szCommand = KVI_OPTION_STRING(KviOption_stringUrlMailtoCommand);
 		}
-	
-		if(szCommand.isEmpty())szCommand = KVI_OPTION_STRING(KviOption_stringUrlUnknownCommand);
-	
-		if(!szCommand.isEmpty())
+#ifdef COMPILE_ON_WINDOWS
+		if(KVI_OPTION_BOOL(KviOption_boolUseSystemUrlHandlers))
 		{
-			KviKvsVariantList vList;
-			vList.append(new KviKvsVariant(szUrl));
+			ShellExecute(NULL, "open", szUrl.local8Bit().data(),
+                NULL, NULL, SW_SHOWNORMAL);
+		} else {
+#endif
+			if(szCommand.isEmpty())szCommand = KVI_OPTION_STRING(KviOption_stringUrlUnknownCommand);
+		
+			if(!szCommand.isEmpty())
+			{
+				KviKvsVariantList vList;
+				vList.append(new KviKvsVariant(szUrl));
 
-			QString szName = "openurl::handler";
-			KviKvsScript script(szName,szCommand);
+				QString szName = "openurl::handler";
+				KviKvsScript script(szName,szCommand);
 
-			if(!script.run(KVSCSC_pWindow,&vList,0,KviKvsScript::PreserveParams))
-				KVSCSC_pContext->warning(__tr2qs("The commandline for this url type seems to be broken (%Q)"),&szUrl);
-	
-		} else KVSCSC_pContext->warning(__tr2qs("No commandline specified for this type of url (%Q)"),&szUrl);
+				if(!script.run(KVSCSC_pWindow,&vList,0,KviKvsScript::PreserveParams))
+					KVSCSC_pContext->warning(__tr2qs("The commandline for this url type seems to be broken (%Q)"),&szUrl);
+		
+			} else KVSCSC_pContext->warning(__tr2qs("No commandline specified for this type of url (%Q)"),&szUrl);
+#ifdef COMPILE_ON_WINDOWS
+		}
+#endif
 
 		return true;
 	}
@@ -483,7 +492,7 @@ namespace KviKvsCoreSimpleCommands
 				option fontIrcView helvetica,24,5,1,50
 			[/example]
 		@seealso:
-			[fnc]$option[/fnc]()
+			[fnc]$option[/fnc]
 	*/
 
 	KVSCSC(option)
@@ -544,6 +553,7 @@ namespace KviKvsCoreSimpleCommands
 			If it is a relative path then KVIrc will try to look it up
 			in the path of the calling script (if any) and in the current
 			KVIrc working directory.
+			The file must be utf8-encoded (see below).
 			[parameters] is a space separated string of parameters to be
 			passed to the script. The parameter $0 will contain the
 			path of the file being parsed, the other parameters will
@@ -556,6 +566,16 @@ namespace KviKvsCoreSimpleCommands
 			some reason. If you want the command to stop with an error in
 			this case then use the -e switch.[br]
 			This command has a builtin alias called [cmd]include[/cmd].
+			[br][br]
+			Note that script files, especially the ones that you distribute,
+			MUST be encoded in utf8. Any other encoding (especially the exotic
+			ones like KOI8R or Shift-JIS) may screw things up.
+			The reason for such a constraint is simple: KVIrc has no means
+			of knowing the encoding that one or other scripter uses to
+			edit his files. Unlike other languages (like HTML, for example)
+			there is no "external" metadata that will allow for
+			encoding detection before the data is actually decoded.
+			UTF8 is the right way (tm). Use it.
 		@examples:
 			[example]
 				parse /home/pragma/myscript.kvs
@@ -580,8 +600,6 @@ namespace KviKvsCoreSimpleCommands
 
 		if(KviFileUtils::directoryExists(szFileName))
 		{
-			// FIXME: Throw away KviStr!!!
-			//KviStr szTmp;
 			QString szTmp;
 			KVSCSC_pContext->enterBlockingSection();
 			
@@ -614,7 +632,7 @@ namespace KviKvsCoreSimpleCommands
 		szFileName = infz.absFilePath();
 
 		QString szBuffer;
-		if(!KviFileUtils::loadFile(szFileName,szBuffer,true))
+		if(!KviFileUtils::loadFile(szFileName,szBuffer,true)) // <-- scripts SHOULD be shipped in utf8 format
 		{
 			if(KVSCSC_pSwitches->find('e',"fail-on-load"))
 			{
@@ -699,13 +717,13 @@ namespace KviKvsCoreSimpleCommands
 			}
 		}
 
-		QCString szEncodedChans = KVSCSC_pConnection->encodeText(szChans);
+		KviQCString szEncodedChans = KVSCSC_pConnection->encodeText(szChans);
 
 		QStringList sl = QStringList::split(",",szChans);
 	
 		if(!szMsg.isEmpty())
 		{
-			QCString szText;
+			KviQCString szText;
 			if(sl.count() == 1)
 			{
 				// single chan , use channel encoding if possible
@@ -768,45 +786,33 @@ namespace KviKvsCoreSimpleCommands
 		@syntax:
 			play <filename:string>
 		@short:
-			Plays a file
+			DEPRECATED: Use $snd.play instead!
 		@description:
-			Plays a file by using the media type matching.[br]
-			If <filename> is a relative path, KVIrc will firs make a pre-guess
-			of the media type by matching the filename (no magic check),
-			then look for the file in the save directory for the media type guessed,
-			then look in a set of standard directories (including the kvirc local
-			pics, incoming and audio directories and the home directory).[br]
-			If the <filename> is an absolute path, no lookup will be made.[br]
-			If the file can be found, a second media type guess will be performed,
-			this time eventually matching also the magic bytes.[br]
-			If the file matches a media type, the commandline of that media type
-			will be executed, passing the filename as the first parameter ($0).[br]
-		@examples:
-			[example]
-				play test.wav
-				play diagram.jpg
-			[/example]
+			This command has been moved to the snd module.
+			See [cmd]snd.play[/cmd]
 	*/
 
 	KVSCSC(play)
 	{
-		QString szFileName;
-		KVSCSC_PARAMETERS_BEGIN
-			KVSCSC_PARAMETER("filename",KVS_PT_NONEMPTYSTRING,KVS_PF_APPENDREMAINING,szFileName)
-		KVSCSC_PARAMETERS_END
+		// cool, no ?
 
-		if(KviQString::equalCIN(szFileName,"file:",5))
-			szFileName.remove(0,5);
+		KviModule * m = g_pModuleManager->getModule("snd");
+		if(!m)
+		{
+			KVSCSC_pContext->error(__tr2qs("Module command call failed: can't load the module 'snd'"));
+			return false;
+		}
 
-		KviStr filename = szFileName;
-		KviStr buffer;
-		if(g_pApp->findUserFile(buffer,filename.ptr()))filename = buffer;
-		kvi_adjustFilePath(filename);
-	
-		KviStr error;
-		if(!g_pApp->playFile(filename.ptr(),error,KVSCSC_pContext->window()))KVSCSC_pContext->warning(error.ptr());
+		KviKvsModuleSimpleCommandExecRoutine * proc = m->kvsFindSimpleCommand("play");
+		if(!proc)
+		{
+			KVSCSC_pContext->error(__tr2qs("Module command call failed: the module 'snd' doesn't export a command named 'play'"));
+			return false;
+		}
 
-		return true;
+		KviKvsModuleCommandCall call(m,KVSCSC_pContext,KVSCSC_pParams,KVSCSC_pSwitches);
+
+		return (*proc)(&call); 
 	}
 
 	//////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -839,7 +845,6 @@ namespace KviKvsCoreSimpleCommands
 	
 	KVSCSC(popup)
 	{
-#ifdef COMPILE_NEW_KVS
 		QString szPopupName;
 		KVSCSC_PARAMETERS_BEGIN
 			KVSCSC_PARAMETER("popup_name",KVS_PT_NONEMPTYSTRING,0,szPopupName)
@@ -855,7 +860,7 @@ namespace KviKvsCoreSimpleCommands
 		if(!pMenu)
 		{
 			delete pPopupParams;
-            pPopupParams = 0;
+			pPopupParams = 0;
 			KVSCSC_pContext->error(__tr2qs("Popup %Q is not defined"),&szPopupName);
 			return false;
 		}
@@ -863,7 +868,7 @@ namespace KviKvsCoreSimpleCommands
 		if(pMenu->isLocked())
 		{
 			delete pPopupParams;
-            pPopupParams = 0;
+			pPopupParams = 0;
 			KVSCSC_pContext->error(__tr2qs("A popup menu cannot be popped up twice"));
 			return false;
 		}
@@ -893,7 +898,6 @@ namespace KviKvsCoreSimpleCommands
 		}
 
 		pMenu->doPopup(pnt,KVSCSC_pContext->window(),pPopupParams);
-#endif
 		return true;
 	}
 
@@ -944,8 +948,8 @@ namespace KviKvsCoreSimpleCommands
 		if(w)w->ownMessage(szText);
 		else {
 
-			QCString szT = KVSCSC_pConnection->encodeText(szTarget);
-			QCString szD = w ? w->encodeText(szText) : KVSCSC_pConnection->encodeText(szText);
+			KviQCString szT = KVSCSC_pConnection->encodeText(szTarget);
+			KviQCString szD = w ? w->encodeText(szText) : KVSCSC_pConnection->encodeText(szText);
 			if(!szT.data())szT = ""; // encoding problems ?
 			if(!szD.data())szD = ""; // encoding problems ?
 
@@ -1042,7 +1046,7 @@ namespace KviKvsCoreSimpleCommands
 			quit
 		@syntax:
 			quit [-f] [-u] [quit-message:string]
-      		quit -q
+		quit -q
 		@short:
 			Terminates the current IRC connection or the entier application
 		@switches:
@@ -1173,7 +1177,7 @@ namespace KviKvsCoreSimpleCommands
 
 		KVSCSC_REQUIRE_CONNECTION
 
-		QCString szData = KVSCSC_pConnection->encodeText(szRawCommand);
+		KviQCString szData = KVSCSC_pConnection->encodeText(szRawCommand);
 		if(!szData.data())szData = "";
 
 		if(!KVSCSC_pConnection->sendData(szData.data()))
@@ -1221,7 +1225,6 @@ namespace KviKvsCoreSimpleCommands
 	
 	KVSCSC(rebind)
 	{
-#ifdef COMPILE_NEW_KVS
 		QString szWinId;
 		KVSCSC_PARAMETERS_BEGIN
 			KVSCSC_PARAMETER("window_id",KVS_PT_NONEMPTYSTRING,0,szWinId)
@@ -1233,7 +1236,6 @@ namespace KviKvsCoreSimpleCommands
 			if(!KVSCSC_pSwitches->find('q',"quiet"))
 				KVSCSC_pContext->warning(__tr2qs("Window with id %Q not found: no rebinding performed"),&szWinId);
 		}
-#endif
 		return true;
 	}
 
@@ -1264,7 +1266,6 @@ namespace KviKvsCoreSimpleCommands
 	
 	KVSCSC(returnCKEYWORDWORKAROUND)
 	{
-#ifdef COMPILE_NEW_KVS
 		if(KVSCSC_pParams->count() == 0)
 		{
 			KVSCSC_pContext->returnValue()->setNothing();
@@ -1279,7 +1280,6 @@ namespace KviKvsCoreSimpleCommands
 		QString all;
 		KVSCSC_pParams->allAsString(all);
 		KVSCSC_pContext->returnValue()->setString(all);
-#endif
 		return false;
 	}
 
@@ -1320,9 +1320,15 @@ namespace KviKvsCoreSimpleCommands
 			KVSCSC_PARAMETER("parameters",KVS_PT_STRINGLIST,KVS_PF_OPTIONAL,l)
 		KVSCSC_PARAMETERS_END
 
+#ifdef COMPILE_USE_QT4
+		QProcess proc;
+		proc.start(szCommand,l);
+		// FIXME: KVSCSC_pContext->warning(__tr2qs("Failed to execute command '%Q'"),&szCommand);
+#else
 		QProcess proc(szCommand);
 		for ( QStringList::Iterator it = l.begin(); it != l.end(); ++it ) proc.addArgument(*it);
 		if(!proc.start())KVSCSC_pContext->warning(__tr2qs("Failed to execute command '%Q'"),&szCommand);
+#endif
 		return true;
 	}
 };
