@@ -581,7 +581,7 @@ namespace KviKvsCoreSimpleCommands
 			This command is [doc:connection_dependant_commands]connection dependant[/doc].
 		@examples:
 			[example]
-			topic #kvirc KVIrc 3.0.0 has been released!
+			topic #kvirc KVIrc 3.4.0 has been released!
 			[/example]
 	*/
 
@@ -606,8 +606,8 @@ namespace KviKvsCoreSimpleCommands
 			}
 		}
 
-		QCString szC = KVSCSC_pConnection->encodeText(szChannel);
-		QCString szT = KVSCSC_pConnection->encodeText(szTopic);
+		KviQCString szC = KVSCSC_pConnection->encodeText(szChannel);
+		KviQCString szT = KVSCSC_pConnection->encodeText(szTopic);
 		if(szTopic.isEmpty())
 		{
 			if(!KVSCSC_pConnection->sendFmtData("TOPIC %s",szC.data()))
@@ -775,7 +775,11 @@ namespace KviKvsCoreSimpleCommands
 			unban -r=[fnc]$channel[/fnc](#kvirc,[fnc]$context[/fnc](irc.myirc.net,Pragma)) Maxim,Gizmo!*@*,*!root*@*
 			[/example]
 		@seealso:
-			[cmd]op[/cmd],[cmd]deop[/cmd],[cmd]voice[/cmd],[cmd]devoice[/cmd],[cmd]ban[/cmd]
+			[cmd]op[/cmd],
+			[cmd]deop[/cmd],
+			[cmd]voice[/cmd],
+			[cmd]devoice[/cmd],
+			[cmd]ban[/cmd]
 	*/
 
 	KVSCSC(unban)
@@ -825,7 +829,7 @@ namespace KviKvsCoreSimpleCommands
 			voice Pragma,Crocodile
 			[/example]
 		@seealso:
-			[cmd]op[/cmd],[cmd]deop[/cmd],[cmd]devoice[/cmd]
+			[cmd]op[/cmd], [cmd]deop[/cmd], [cmd]devoice[/cmd]
 	*/
 
 	KVSCSC(voice)
@@ -854,11 +858,10 @@ namespace KviKvsCoreSimpleCommands
 
 	KVSCSC(warning)
 	{
-#ifdef COMPILE_NEW_KVS
 		QString szAll;
 		KVSCSC_pParams->allAsString(szAll);
 		KVSCSC_pContext->warning("%Q",&szAll);
-#endif
+
 		return true;
 	}
 
@@ -915,17 +918,16 @@ namespace KviKvsCoreSimpleCommands
 
 	KVSCSC(whois)
 	{
-#ifdef COMPILE_NEW_KVS
 		QString szNick;
 		KVSCSC_PARAMETERS_BEGIN
 			KVSCSC_PARAMETER("nickname",KVS_PT_NONEMPTYSTRING,KVS_PF_APPENDREMAINING,szNick)
 		KVSCSC_PARAMETERS_END
 
-		QCString szData = KVSCSC_pContext->window()->encodeText(szNick);
+		KviQCString szData = KVSCSC_pContext->window()->encodeText(szNick);
 
 		if(!KVSCSC_pContext->connection())return KVSCSC_pContext->warningNoIrcConnection();
 		if(!KVSCSC_pContext->connection()->sendFmtData("WHOIS %s",szData.data()))return KVSCSC_pContext->warningNoIrcConnection();
-#endif
+
 		return true;
 	}
 
@@ -956,17 +958,16 @@ namespace KviKvsCoreSimpleCommands
 
 	KVSCSC(whowas)
 	{
-#ifdef COMPILE_NEW_KVS
 		QString szNick;
 		KVSCSC_PARAMETERS_BEGIN
 			KVSCSC_PARAMETER("nickname",KVS_PT_NONEMPTYSTRING,KVS_PF_APPENDREMAINING,szNick)
 		KVSCSC_PARAMETERS_END
 
-		QCString szData = KVSCSC_pContext->window()->encodeText(szNick);
+		KviQCString szData = KVSCSC_pContext->window()->encodeText(szNick);
 
 		if(!KVSCSC_pContext->connection())return KVSCSC_pContext->warningNoIrcConnection();
 		if(!KVSCSC_pContext->connection()->sendFmtData("WHOWAS %s",szData.data()))return KVSCSC_pContext->warningNoIrcConnection();
-#endif
+
 		return true;
 	}
 
