@@ -99,7 +99,7 @@ void KviKvsDnsManager::addDns(KviKvsDnsObject * pObject)
 {
 	if(!m_pDnsObjects)
 	{
-		m_pDnsObjects = new QPtrDict<KviKvsDnsObject>;
+		m_pDnsObjects = new KviPointerHashTable<void *,KviKvsDnsObject>;
 		m_pDnsObjects->setAutoDelete(true);
 	}
 	m_pDnsObjects->replace(pObject->dns(),pObject);
@@ -140,12 +140,12 @@ void KviKvsDnsManager::dnsLookupTerminated(KviDns * pDns)
 			o->parameterList()->prepend(new KviKvsVariant(KviError::getDescription(o->dns()->error()))); // $2
 			o->parameterList()->prepend(new KviKvsVariant((kvs_int_t)0)); // $1
 		} else {
-			KviStr * fh = o->dns()->hostnameList()->first();
-			KviStr * fi = o->dns()->ipAddressList()->first();
+			QString * fh = o->dns()->hostnameList()->first();
+			QString * fi = o->dns()->ipAddressList()->first();
 
 			// $4... is the magic data
-			o->parameterList()->prepend(new KviKvsVariant(fh ? fh->ptr() : "?.?")); // $3
-			o->parameterList()->prepend(new KviKvsVariant(fi ? fi->ptr() : "?.?.?.?")); // $2
+			o->parameterList()->prepend(new KviKvsVariant(fh ? *fh : QString("?.?"))); // $3
+			o->parameterList()->prepend(new KviKvsVariant(fi ? *fi : QString("?.?.?.?"))); // $2
 			o->parameterList()->prepend(new KviKvsVariant((kvs_int_t)1)); // $1
 		}
 		o->parameterList()->prepend(new KviKvsVariant(o->query())); // $0
@@ -153,7 +153,8 @@ void KviKvsDnsManager::dnsLookupTerminated(KviDns * pDns)
 		copy.run(o->window(),o->parameterList(),0,KviKvsScript::PreserveParams);
 
 	} else {
-		o->window()->output(KVI_OUT_HOSTLOOKUP,__tr2qs("DNS Lookup result for query \"%s\""),o->dns()->query());
+		QString szQuery = o->dns()->query();
+		o->window()->output(KVI_OUT_HOSTLOOKUP,__tr2qs("DNS Lookup result for query \"%Q\""),&szQuery);
 	
 		if(o->dns()->state() == KviDns::Failure)
 		{
@@ -161,15 +162,15 @@ void KviKvsDnsManager::dnsLookupTerminated(KviDns * pDns)
 			o->window()->output(KVI_OUT_HOSTLOOKUP,__tr2qs("Error: %Q"),&szErr);
 		} else {
 			int idx = 1;
-			for(KviStr * h = o->dns()->hostnameList()->first();h;h = o->dns()->hostnameList()->next())
+			for(QString * h = o->dns()->hostnameList()->first();h;h = o->dns()->hostnameList()->next())
 			{
-				o->window()->output(KVI_OUT_HOSTLOOKUP,__tr2qs("Hostname %d: %s"),idx,h->ptr());
+				o->window()->output(KVI_OUT_HOSTLOOKUP,__tr2qs("Hostname %d: %Q"),idx,h);
 				idx++;
 			}
 			idx = 1;
-			for(KviStr * a = o->dns()->ipAddressList()->first();a;a = o->dns()->ipAddressList()->next())
+			for(QString * a = o->dns()->ipAddressList()->first();a;a = o->dns()->ipAddressList()->next())
 			{
-				o->window()->output(KVI_OUT_HOSTLOOKUP,__tr2qs("IP address %d: %s"),idx,a->ptr());
+				o->window()->output(KVI_OUT_HOSTLOOKUP,__tr2qs("IP address %d: %Q"),idx,a);
 				idx++;
 			}
 		}
