@@ -33,7 +33,7 @@
 class KVIRC_API KviKvsEventHandler : public KviHeapObject
 {
 public:
-	enum Type { Script , Module , OldModule };
+	enum Type { Script , Module };
 protected:
 	Type m_type;
 public:
@@ -83,6 +83,8 @@ public:
 	KviKvsModuleEventHandlerRoutine * handlerRoutine(){ return m_pProc; };
 };
 
+
+/*
 #include "kvi_module.h"
 
 class KVIRC_API KviKvsOldModuleEventHandler : public KviKvsEventHandler
@@ -100,5 +102,5 @@ public:
 	void setProc(KviModuleEventParseProc p){ m_proc = p; };
 };
 
-
+*/
 #endif //!_KVI_KVS_EVENTHANDLER_H_
