@@ -128,6 +128,9 @@ unsigned int KviKvsEventManager::findAppEventIndexByName(const QString &szName)
 	for(unsigned int u = 0;u < KVI_KVS_NUM_APP_EVENTS;u++)
 	{
 		if(KviQString::equalCI(szName,m_appEventTable[u].name()))return u;
+		//Backwards compatibility >_<
+		if((u == 4) && KviQString::equalCI(szName,"OnIrcConnectionEstabilished"))
+			return u;
 	}
 	return KVI_KVS_NUM_APP_EVENTS; // <-- invalid event number
 }
@@ -137,6 +140,9 @@ KviKvsEvent * KviKvsEventManager::findAppEventByName(const QString &szName)
 	for(unsigned int u = 0;u < KVI_KVS_NUM_APP_EVENTS;u++)
 	{
 		if(KviQString::equalCI(szName,m_appEventTable[u].name()))return &(m_appEventTable[u]);
+		//Backwards compatibility >_<
+		if((u == 4) && KviQString::equalCI(szName,"OnIrcConnectionEstabilished"))
+			return &(m_appEventTable[u]);
 	}
 	return 0;
 }
@@ -153,7 +159,7 @@ bool KviKvsEventManager::addRawHandler(unsigned int uRawIdx,KviKvsEventHandler *
 	if(uRawIdx >= KVI_KVS_NUM_RAW_EVENTS)return false;
 	if(!m_rawEventTable[uRawIdx])
 	{
-		m_rawEventTable[uRawIdx] = new KviPtrList<KviKvsEventHandler>();
+		m_rawEventTable[uRawIdx] = new KviPointerList<KviKvsEventHandler>();
 		m_rawEventTable[uRawIdx]->setAutoDelete(true);
 	}
 	m_rawEventTable[uRawIdx]->append(h);
@@ -238,7 +244,9 @@ bool KviKvsEventManager::removeModuleAppHandler(unsigned int uEvIdx,KviKvsModule
 				m_appEventTable[uEvIdx].removeHandler(h);
 				return true;
 			}
+		}
 		// COMPAT
+		/*
 		} else if(h->type() == KviKvsEventHandler::OldModule)
 		{
 			if(((KviKvsOldModuleEventHandler *)h)->module() == i)
@@ -247,6 +255,7 @@ bool KviKvsEventManager::removeModuleAppHandler(unsigned int uEvIdx,KviKvsModule
 				return true;
 			}
 		}
+		*/
 		// END COMPAT
 	}
 	return false;
@@ -259,7 +268,7 @@ void KviKvsEventManager::removeAllModuleAppHandlers(KviKvsModuleInterface *pIfac
 	{
 		if(!m_appEventTable[i].handlers())continue;
 	
-		KviPtrList<KviKvsEventHandler> l;
+		KviPointerList<KviKvsEventHandler> l;
 		l.setAutoDelete(false);
 		for(h = m_appEventTable[i].handlers()->first();h;h = m_appEventTable[i].handlers()->next())
 		{
@@ -269,7 +278,9 @@ void KviKvsEventManager::removeAllModuleAppHandlers(KviKvsModuleInterface *pIfac
 				{
 					l.append(h);
 				}
+			}
 			// COMPAT
+			/*
 			} else if(h->type() == KviKvsEventHandler::OldModule)
 			{
 				if(((KviKvsOldModuleEventHandler *)h)->module() == pIface)
@@ -277,6 +288,7 @@ void KviKvsEventManager::removeAllModuleAppHandlers(KviKvsModuleInterface *pIfac
 					l.append(h);
 				}
 			}
+			*/
 			// END COMPAT
 	
 		}
@@ -291,7 +303,7 @@ void KviKvsEventManager::removeAllModuleRawHandlers(KviKvsModuleInterface *pIfac
 	{
 		if(!m_rawEventTable[i])continue;
 
-		KviPtrList<KviKvsEventHandler> l;
+		KviPointerList<KviKvsEventHandler> l;
 		l.setAutoDelete(false);
 		for(h = m_rawEventTable[i]->first();h;h = m_rawEventTable[i]->next())
 		{
@@ -301,7 +313,9 @@ void KviKvsEventManager::removeAllModuleRawHandlers(KviKvsModuleInterface *pIfac
 				{
 					l.append(h);
 				}
+			}
 			// COMPAT
+			/*
 			} else if(h->type() == KviKvsEventHandler::OldModule)
 			{
 				if(((KviKvsOldModuleEventHandler *)h)->module() == pIface)
@@ -309,6 +323,7 @@ void KviKvsEventManager::removeAllModuleRawHandlers(KviKvsModuleInterface *pIfac
 					l.append(h);
 				}
 			}
+			*/
 			// END COMPAT
 
 		}
@@ -374,7 +389,9 @@ bool KviKvsEventManager::removeModuleRawHandler(unsigned int uRawIdx,KviKvsModul
 				}
 				return true;
 			}
+		}
 		// COMPAT
+		/*
 		} else if(h->type() == KviKvsEventHandler::OldModule)
 		{
 			if(((KviKvsOldModuleEventHandler *)h)->module() == i)
@@ -388,6 +405,7 @@ bool KviKvsEventManager::removeModuleRawHandler(unsigned int uRawIdx,KviKvsModul
 				return true;
 			}
 		}
+		*/
 		// END COMPAT
 
 	}
@@ -414,7 +432,7 @@ void KviKvsEventManager::removeAllScriptRawHandlers()
 	{
 		if(m_rawEventTable[i])
 		{
-			KviPtrList<KviKvsEventHandler> dl;
+			KviPointerList<KviKvsEventHandler> dl;
 			dl.setAutoDelete(false);
 			KviKvsEventHandler * e;
 			for(e = m_rawEventTable[i]->first();e;e = m_rawEventTable[i]->next())
@@ -459,7 +477,7 @@ void KviKvsEventManager::clear()
 	clearAppEvents();
 }
 
-bool KviKvsEventManager::triggerHandlers(KviPtrList<KviKvsEventHandler> * pHandlers,KviWindow *pWnd,KviKvsVariantList *pParams)
+bool KviKvsEventManager::triggerHandlers(KviPointerList<KviKvsEventHandler> * pHandlers,KviWindow *pWnd,KviKvsVariantList *pParams)
 {
 	if(!pHandlers)return false;
 
@@ -499,9 +517,6 @@ bool KviKvsEventManager::triggerHandlers(KviPtrList<KviKvsEventHandler> * pHandl
 				if(!(*proc)(&call))bGotHalt = true;
 			}
 			break;
-			case KviKvsEventHandler::OldModule:
-				/* FIXME: Is this needed at all ? */
-			break;
 		}
 	}
 	return bGotHalt;
@@ -524,7 +539,7 @@ void KviKvsEventManager::loadRawEvents(const QString &szFileName)
 			unsigned int nHandlers = cfg.readUIntEntry("NHandlers",0);
 			if(nHandlers)
 			{
-				m_rawEventTable[i] = new KviPtrList<KviKvsEventHandler>();
+				m_rawEventTable[i] = new KviPointerList<KviKvsEventHandler>();
 				m_rawEventTable[i]->setAutoDelete(true);
 				for(unsigned int index = 0;index < nHandlers;index++)
 				{
@@ -585,9 +600,13 @@ void KviKvsEventManager::loadAppEvents(const QString &szFileName)
 	int i;
 	for(i=0;i<KVI_KVS_NUM_APP_EVENTS;i++)
 	{
-		if(cfg.hasGroup(m_appEventTable[i].name()))
+		QString szEventName(m_appEventTable[i].name());
+		// Backwards compatibility >_<
+		if((i == 4) && !cfg.hasGroup(szEventName))
+			szEventName = "OnIrcConnectionEstabilished";
+		if(cfg.hasGroup(szEventName))
 		{
-			cfg.setGroup(m_appEventTable[i].name());
+			cfg.setGroup(szEventName);
 			unsigned int nHandlers = cfg.readUIntEntry("NHandlers",0);
 			if(nHandlers)
 			{
@@ -616,12 +635,20 @@ void KviKvsEventManager::saveAppEvents(const QString &szFileName)
 	KviConfig cfg(szFileName,KviConfig::Write);
 	cfg.clear();
 	int i;
+	bool bCompat = FALSE;
 
 	for(i=0;i<KVI_KVS_NUM_APP_EVENTS;i++)
 	{
 		if(m_appEventTable[i].hasHandlers())
 		{
-			cfg.setGroup(m_appEventTable[i].name());
+			QString szEventName(m_appEventTable[i].name());
+			// Backwards compatibility >_<
+			if((i == 4) && cfg.hasGroup(szEventName))
+			{
+				szEventName = "OnIRCConnectionEstabilished";
+				bCompat = TRUE;
+			}
+			cfg.setGroup(szEventName);
 			int index = 0;
 			for(KviKvsEventHandler* s = m_appEventTable[i].handlers()->first();s; s = m_appEventTable[i].handlers()->next())
 			{
@@ -638,6 +665,10 @@ void KviKvsEventManager::saveAppEvents(const QString &szFileName)
 				}
 			}
 			cfg.writeEntry("NHandlers",index);
+
+			// Backwards compatibility >_<
+			if((i == 4) && !bCompat)
+				i--;
 		}
 	}
 }
