@@ -27,7 +27,7 @@
 #include "kvi_settings.h"
 
 #include "kvi_kvs_event.h"
-#include "kvi_list.h"
+#include "kvi_pointerlist.h"
 #include "kvi_kvs_eventtable.h"
 
 class KviWindow;
@@ -46,7 +46,7 @@ protected:
 	static KviKvsEventManager * m_pInstance;
 
 	static KviKvsEvent               m_appEventTable[KVI_KVS_NUM_APP_EVENTS];
-	KviPtrList<KviKvsEventHandler> * m_rawEventTable[KVI_KVS_NUM_RAW_EVENTS];
+	KviPointerList<KviKvsEventHandler> * m_rawEventTable[KVI_KVS_NUM_RAW_EVENTS];
 public:
 	static KviKvsEventManager * instance(){ return m_pInstance; };
 	static void init(); // called by KviKvs::init()
@@ -55,10 +55,10 @@ public:
 	KviKvsEvent * appEvent(unsigned int uEvIdx){ return &(m_appEventTable[uEvIdx]); };
 
 	bool hasAppHandlers(unsigned int uEvIdx){ return m_appEventTable[uEvIdx].hasHandlers(); };
-	KviPtrList<KviKvsEventHandler> * appHandlers(unsigned int uEvIdx){ return m_appEventTable[uEvIdx].handlers(); };
+	KviPointerList<KviKvsEventHandler> * appHandlers(unsigned int uEvIdx){ return m_appEventTable[uEvIdx].handlers(); };
 	
 	bool hasRawHandlers(unsigned int uEvIdx){ return m_rawEventTable[uEvIdx]; };
-	KviPtrList<KviKvsEventHandler> * rawHandlers(unsigned int uEvIdx){ return m_rawEventTable[uEvIdx]; };
+	KviPointerList<KviKvsEventHandler> * rawHandlers(unsigned int uEvIdx){ return m_rawEventTable[uEvIdx]; };
 
 	KviKvsEvent * findAppEventByName(const QString &szName);
 	unsigned int findAppEventIndexByName(const QString &szName);
@@ -88,7 +88,7 @@ public:
 
 	// returns true if further processing should be stopped
 	// none of these functions takes params ownership, so be sure to delete them !
-	bool triggerHandlers(KviPtrList<KviKvsEventHandler> * pHandlers,KviWindow *pWnd,KviKvsVariantList *pParams);
+	bool triggerHandlers(KviPointerList<KviKvsEventHandler> * pHandlers,KviWindow *pWnd,KviKvsVariantList *pParams);
 	bool trigger(unsigned int uEvIdx,KviWindow * pWnd,KviKvsVariantList * pParams)
 		{ return triggerHandlers(m_appEventTable[uEvIdx].handlers(),pWnd,pParams); };
 	bool triggerRaw(unsigned int uEvIdx,KviWindow *pWnd,KviKvsVariantList * pParams)
