@@ -43,10 +43,10 @@ KviKvsEvent KviKvsEventManager::m_appEventTable[KVI_NUM_SCRIPT_EVENTS]=
 		@parameters:
 			None
 		@window:
-			Console of the first irc context
+			Console of the first IRC context
 		@description:
 			This event is triggered on KVIrc startup.
-			It is bound to the console of the first created irc context.
+			It is bound to the console of the first created IRC context.
 			This is a little tricky, since this event is triggered
 			before the related [event:onirccontextcreated]OnIRCContextCreated[/event] event.
 			This is to make OnApplicationStartup be the absolutely first
@@ -68,10 +68,10 @@ KviKvsEvent KviKvsEventManager::m_appEventTable[KVI_NUM_SCRIPT_EVENTS]=
 		@parameters:
 			None
 		@window:
-			Console of the last irc context
+			Console of the last IRC context
 		@description:
 			This event is triggered on KVIrc shutdown.
-			It is bound to the console of the last existing irc context.
+			It is bound to the console of the last existing IRC context.
 			This is a little tricky, since this event is triggered
 		    immediately after the on [event:onirccontextdestroyed]OnIRCContextDestroyed[/event] event,
 			so in theory the console should be already destroyed.
@@ -89,14 +89,14 @@ KviKvsEvent KviKvsEventManager::m_appEventTable[KVI_NUM_SCRIPT_EVENTS]=
 		@title:
 			OnIRCContextCreated
 		@short:
-			Triggered when a new irc context is created
+			Triggered when a new IRC context is created
 		@parameters:
 			None
 		@window:
-			Console of the created irc context
+			Console of the created IRC context
 		@description:
-			This event is triggered when a new irc context is created.
-			It is bound to the console of the related irc context,
+			This event is triggered when a new IRC context is created.
+			It is bound to the console of the related IRC context,
 			that is the first window that is created.
 		@seealso:
 			[event:onirccontextdestroyed]OnIRCContextDestroyed[/event]
@@ -109,14 +109,14 @@ KviKvsEvent KviKvsEventManager::m_appEventTable[KVI_NUM_SCRIPT_EVENTS]=
 		@title:
 			OnIRCContextDestroyed
 		@short:
-			Triggered when an irc context is destroyed
+			Triggered when an IRC context is destroyed
 		@parameters:
 			None
 		@window:
-			Console of the destroyed irc context
+			Console of the destroyed IRC context
 		@description:
-			This event is triggered when an irc context is being destroyed.
-			It is bound to the console of the related irc context,
+			This event is triggered when an IRC context is being destroyed.
+			It is bound to the console of the related IRC context,
 			that is the last window of the context that is destroyed.
 		@seealso:
 			[event:onirccontextcreated]OnIRCContextCreated[/event]
@@ -127,15 +127,15 @@ KviKvsEvent KviKvsEventManager::m_appEventTable[KVI_NUM_SCRIPT_EVENTS]=
 		@type:
 			event
 		@title:
-			OnIRCConnectionEstabilished
+			OnIRCConnectionEstablished
 		@short:
-			Triggered when a new irc connection has been established
+			Triggered when a new IRC connection has been established
 		@parameters:
 			None
 		@window:
-			Console of the related irc context
+			Console of the related IRC context
 		@description:
-			This event is triggered immediately after an irc connection
+			This event is triggered immediately after an IRC connection
 			has been established. No data has been sent to the server yet
 			and you have not logged in: it is not a good idea
 			attempting to send data to the server (READ: [b]This is NOT
@@ -149,7 +149,7 @@ KviKvsEvent KviKvsEventManager::m_appEventTable[KVI_NUM_SCRIPT_EVENTS]=
 		@seealso:
 			[event:onircconnectionterminated]OnIRCConnectionTerminated[/event]
 	*/
-	EVENT("OnIRCConnectionEstabilished",""),
+	EVENT("OnIRCConnectionEstablished",""),
 	/*
 		@doc: onircconnectionterminated
 		@type:
@@ -157,20 +157,20 @@ KviKvsEvent KviKvsEventManager::m_appEventTable[KVI_NUM_SCRIPT_EVENTS]=
 		@title:
 			OnIRCConnectionTerminated
 		@short:
-			Triggered when an irc connection has been terminated
+			Triggered when an IRC connection has been terminated
 		@parameters:
 			None
 		@window:
-			Console of the related irc context
+			Console of the related IRC context
 		@description:
-			This event is triggered immediately after an irc connection
+			This event is triggered immediately after an IRC connection
 			has been terminated. The socket is already closed, so you
 			can't send data to the server. You can still read
 			the connection parameters like the server name or
 			network name. By calling [cmd]halt[/cmd] in this
 			event you will stop the "Connection terminated..." output.
 		@seealso:
-			[event:onircconnectionestablished]OnIRCConnectionEstabilished[/event]
+			[event:onircconnectionestablished]OnIRCConnectionEstablished[/event]
 	*/
 	EVENT("OnIRCConnectionTerminated",""),
 	/*
@@ -184,7 +184,7 @@ KviKvsEvent KviKvsEventManager::m_appEventTable[KVI_NUM_SCRIPT_EVENTS]=
 		@parameters:
 			None
 		@window:
-			Console of the related irc context
+			Console of the related IRC context
 		@description:
 			This event is triggered immediately after the login
 			operations have been terminated. From now on you are
@@ -194,7 +194,7 @@ KviKvsEvent KviKvsEventManager::m_appEventTable[KVI_NUM_SCRIPT_EVENTS]=
 			By calling [cmd]halt[/cmd] in this event you will
 			stop the "Login operations complete..." output.
 		@seealso:
-			[event:onircconnectionestablished]OnIRCConnectionEstabilished[/event]
+			[event:onircconnectionestablished]OnIRCConnectionEstablished[/event]
 			[event:onircconnectionterminated]OnIRCConnectionTerminated[/event]
 	*/
 	EVENT("OnIRC",""),
@@ -379,17 +379,16 @@ KviKvsEvent KviKvsEventManager::m_appEventTable[KVI_NUM_SCRIPT_EVENTS]=
 		@title:
 			OnURL
 		@short:
-			Triggered when an url appears in one of the output windows
+			Triggered when an URL appears in one of the output windows
 		@parameters:
 			$0 = URL
 		@window:
 			The window that the URL appeared in
 		@description:
-			This event is triggered every time that an url is going to appear
-			in a KVIrc window output widget. You can not stop it nor modify it.
-			This event is good for implementing an url catcher.[br]
-			WARNING: If you attempt to "echo $0" inside this event kvirc will hang:
-			I can do nothing about it...this is infinite recursion....
+			This event is triggered every time that an URL is going to appear
+			in a KVIrc window output widget. You cannot stop it or modify it.
+			This event is good for implementing an URL catcher.[br]
+			WARNING: If you attempt to "echo $0" inside this event, you will cause an infinite loop.
 	*/
 	EVENT("OnURL","$0 = URL"),
 	/*
@@ -1536,7 +1535,7 @@ channel
         @description:
             Triggered when someone has changed his nickname.
 			The change has already been processed by the server, but not by the
-			local KVirc database.
+			local KVIrc database.
         @seealso:
             [event:onmenickchange]OnMeNickChange[/event]
     */
@@ -1557,7 +1556,7 @@ channel
         @description:
             Triggered when the local user is going to change his nickname.
 			The change has already been processed by the server, but not by the
-			local KVirc database.
+			local KVIrc database.
         @seealso:
             [event:onnickchange]OnNickChange[/event]
     */
@@ -1581,9 +1580,9 @@ channel
             Console window
         @description:
             A CTCP request has been received.[br]
-			If you call [cmd]halt[/cmd] in this event , you will stop the further
-			processing of the CTCP (thus you can disable some of the kvirc features).
-			Be sure to know what you're doing.
+			If you call [cmd]halt[/cmd] in this event, you will stop the further
+			processing of the CTCP (thus, you can disable some of the KVIrc features).
+			Be careful when using this.
         @seealso:
             [event:onctcpreply]OnCTCPReply[/event]
     */
@@ -1607,9 +1606,9 @@ channel
             Console window
         @description:
             A CTCP reply has been received.[br]
-			If you call [cmd]halt[/cmd] in this event , you will stop the further
-			processing of the CTCP (thus you can disable some of the kvirc features).
-			Be sure to know what you're doing.
+			If you call [cmd]halt[/cmd] in this event, you will stop the further
+			processing of the CTCP (thus, you can disable some of the KVIrc features).
+			Be careful when using this.
         @seealso:
             [event:onctcpreply]OnCTCPReply[/event]
     */
@@ -1915,7 +1914,7 @@ channel
 		@short:
 			A dcc chat window has been just created
 		@parameters:
-			$0 = DCC Session Id
+			$0 = DCC session ID
 		@window:
 			DCC Chat
 		@description:
@@ -1929,7 +1928,7 @@ channel
 		@seealso:
 			[event:ondccchatterminated]OnDCCChatTerminated[/event]
 	*/
-	EVENT("OnDCCChatWindowCreated", "$0 = DCC session id"),
+	EVENT("OnDCCChatWindowCreated", "$0 = DCC session ID"),
 	/*
 		@doc: ondccchatconnectioninprogress
 		@type:
@@ -1939,7 +1938,7 @@ channel
 		@short:
 			A DCC Chat connection has just been started
 		@parameters:
-			$0 = DCC Session Id
+			$0 = DCC session ID 
 		@window:
 			DCC Chat
 		@description:
@@ -1951,7 +1950,7 @@ channel
 			are known from the moment that this event triggers.
 		@seealso:
 	*/
-	EVENT("OnDCCChatConnectionInProgress","$0 = DCC session id"),
+	EVENT("OnDCCChatConnectionInProgress","$0 = DCC session ID"),
 	/*
 		@doc: ondccchatconnected
 		@type:
@@ -1961,7 +1960,7 @@ channel
 		@short:
 			A DCC Chat connection has been established
 		@parameters:
-			$0 = DCC Session Id
+			$0 = DCC session ID
 		@window:
 			DCC Chat
 		@description:
@@ -1971,7 +1970,7 @@ channel
 			window and the data transfer.
 		@seealso:
 	*/
-	EVENT("OnDCCChatConnected","$0 = DCC session id"),
+	EVENT("OnDCCChatConnected","$0 = DCC session ID"),
 	/*
 		@doc: ondccchatmessage
 		@type:
@@ -1982,7 +1981,7 @@ channel
 			A DCC Chat message has just been received
 		@parameters:
 			$0 = message text
-			$1 = DCC Session Id
+			$1 = DCC session ID
 		@window:
 			DCC Chat
 		@description:
@@ -1992,7 +1991,7 @@ channel
 			window and the data transfer.
 		@seealso:
 	*/
-	EVENT("OnDCCChatMessage","$0 = text\n$1 = DCC session id"),
+	EVENT("OnDCCChatMessage","$0 = text\n$1 = DCC session ID"),
 	/*
 		@doc: ondccchaterror
 		@type:
@@ -2003,7 +2002,7 @@ channel
 			A DCC Chat error has just been triggered
 		@parameters:
 			$0 = error message
-			$1 = DCC Session Id
+			$1 = DCC session ID
 		@window:
 			DCC Chat
 		@description:
@@ -2018,7 +2017,7 @@ channel
 			an error.
 		@seealso:
 	*/
-	EVENT("OnDCCChatError","$0 = error message,$1 = DCC session id"),
+	EVENT("OnDCCChatError","$0 = error message,$1 = DCC session ID"),
 	/*
 		@doc: ondccchatdisconnected
 		@type:
@@ -2028,7 +2027,7 @@ channel
 		@short:
 			A DCC Chat has been just disconnected
 		@parameters:
-			$0 = DCC Session Id
+			$0 = DCC session ID
 		@window:
 			DCC Chat
 		@description:
@@ -2038,7 +2037,7 @@ channel
 			window and the data transfer.
 		@seealso:
 	*/
-	EVENT("OnDCCChatDisconnected","$0 = DCC session id"),
+	EVENT("OnDCCChatDisconnected","$0 = DCC session ID"),
 	/*
 		@doc: ondccchatwindowclosing
 		@type:
@@ -2048,7 +2047,7 @@ channel
 		@short:
 			A DCC Chat is going to be closed
 		@parameters:
-			$0 = DCC Session Id
+			$0 = DCC session ID
 		@window:
 			DCC Chat
 		@description:
@@ -2058,7 +2057,7 @@ channel
 			window and the data transfer.
 		@seealso:
 	*/
-	EVENT("OnDCCChatWindowClosing","$0 = DCC session id"),
+	EVENT("OnDCCChatWindowClosing","$0 = DCC session ID"),
 	/*
 		@doc: onaccelkeypressed
 		@type:
@@ -2076,7 +2075,7 @@ channel
 			The key sequence that the user has pressed is passed in $0 as a
 			human readable string.[br]
 			The keys that actually work with KVIrc are:[br]
-			F2 to F12, F1 to F12 with SHIFT key pressed, 0 to 9 with CTRL Key pressed.[br]
+			F2 to F12, F1 to F12 with SHIFT key pressed, 0 to 9 with CTRL key pressed.[br]
 			This means that you can set up 33 "quick" aliases...that's really more than
 			an user can remember.[br]
 			If you need more keys , mail me , I'll see what I can do :)[br]
@@ -2110,11 +2109,11 @@ channel
 			Since the CTCP ACTION messages generally have different format of output
 			then for your convenience $6 contains 1 if the message was caused by a
 			CTCP ACTION and 0 otherwise.[br]
-			If you call [cmd]halt[/cmd] in this event the message output will be stopped at all
-			(thus KVIrc assumes that YOU have provided the necessary output and feedback to the user).[br]
-			A common error here is to call halt and re-echo the unmodified output: [b]this
-			will probably cause another OnHiglight event to be triggered and thus an infinite loop![/b].
-			[cmd]echoprivmsg[/cmd] [b]-n[/b] is the command you probably need.
+			If you call [cmd]halt[/cmd] in this event the message output will be completely disabled
+			(thus, KVIrc assumes that YOU have provided the necessary output and feedback to the user).[br]
+			A common error here is to call halt and re-echo the unmodified output; [b]this
+			can cause another OnHighlight event to be triggered and create an infinite loop![/b].
+			[cmd]echoprivmsg[/cmd] [b]-n[/b] is the command you probably want. 
     */
 	EVENT("OnHighlight", "$0 = source nick\n$1 = source username\n$2 = source hostname\n$3 = message\n$4 = highlight word"),
 	/*
@@ -2139,17 +2138,17 @@ channel
 		@type:
 			event
 		@title:
-			OnNotifyOnLine
+			OnNotifyOnline
 		@short:
 			An user in the notify list is on-line
 		@parameters:
 			$0 = nickname
 		@window:
-			Console or active window of the irc context
+			Console or active window of the IRC context
 		@description:
 			This event is triggered when one of the users in your [doc:notify_list]notify[/doc] lists
 			is detected to be ON-Line.[br]
-			The event is triggered in the console window or the active window of the irc context depending
+			The event is triggered in the console window or the active window of the IRC context depending
 			on the user options.[br]
 			(Note: If you call [cmd]halt[/cmd] in this event , you will stop the "Nick is on irc" output,
 			but this is rather a bad idea since KVIrc gives a lot of additional informations to the
@@ -2157,30 +2156,30 @@ channel
 			This is a good place to play a sound or attract the user attention in some other way.[br]
 
 	*/
-	EVENT("OnNotifyOnLine","$0 = nickname"),
+	EVENT("OnNotifyOnline","$0 = nickname"),
 	/*
 		@doc: onnotifyoffline
 		@type:
 			event
 		@title:
-			OnNotifyOffLine
+			OnNotifyOffline
 		@short:
 			An user in the notify list went off-line
 		@parameters:
 			$0 = nickname
 		@window:
-			Console or active window of the irc context
+			Console or active window of the IRC context
 		@description:
 			This event is triggered when one of the users in your [doc:notify_list]notify[/doc] lists
 			has just left IRC.[br]
-			The event is triggered in the console window or the active window of the irc context depending
+			The event is triggered in the console window or the active window of the IRC context depending
 			on the user options.[br]
 			(Note: If you call [cmd]halt[/cmd] in this event , you will stop the "Nick has left irc" output,
 			but this is rather a bad idea since KVIrc gives a lot of additional informations to the
 			user with some notify-methods).[br]
 			This is a good place to play a sound or attract the user attention in some other way.[br]
 	*/
-	EVENT("OnNotifyOffLine","$0 = nickname"),
+	EVENT("OnNotifyOffline","$0 = nickname"),
 	/*
 		@doc: onpong
 		@type:
@@ -2537,7 +2536,7 @@ channel
 			Triggered when a new remote target has been added to a query window.
 			This is the event to catch when you want to perform some specific actions
 			when someone queries you.
-			KVIrc supports multiple target queries and thus this event is triggered also
+			KVIrc supports multiple target queries and thus, this event is triggered also
 			when a new query target is added by using [cmd]addtarget[/cmd].[br]
 	*/
 	EVENT("OnQueryTargetAdded","$0 = nick\n$1 = username (may be *)\n$2 = hostname (may be *)"),
@@ -2580,7 +2579,7 @@ channel
 		@short:
 			A new DCC session has just been created
 		@parameters:
-			$0 = DCC session id
+			$0 = DCC session ID
 		@window:
 			console
 		@description:
@@ -2588,7 +2587,7 @@ channel
 			You can retrieve the session information by calling the [module:dcc]dcc[/module].*
 			module functions.
 	*/
-	EVENT("OnDCCSessionCreated","$0 = DCC session id"),
+	EVENT("OnDCCSessionCreated","$0 = DCC session ID"),
 	/*
 		@doc: ondccsessiondestroyed
 		@type:
@@ -2598,15 +2597,15 @@ channel
 		@short:
 			A new DCC session has just been destroyed
 		@parameters:
-			$0 = DCC session id
+			$0 = DCC session ID
 		@window:
 			console
 		@description:
 			Triggered when a new DCC session has just been destroyed.
 			You can retrieve the session information by calling the [module:dcc]dcc[/module].*
-			module functions and by passing the DCC session id parameter.
+			module functions and by passing the DCC session ID parameter.
 	*/
-	EVENT("OnDCCSessionDestroyed","$0 = DCC session id"),
+	EVENT("OnDCCSessionDestroyed","$0 = DCC session ID"),
 	/*
 		@doc: ontextinput
 		@type:
@@ -2645,7 +2644,7 @@ channel
 		@short:
 			Triggered when the DCC chat text view is right-clicked
 		@parameters:
-			$0 = DCC Session Id
+			$0 = DCC session ID
 		@window:
 			DCC Chat window
 		@description:
@@ -2653,13 +2652,13 @@ channel
 			text view with the right mouse button. It is a good place
 			to activate a [cmd]popup[/cmd] menu :)
 			You can retrieve the session information by calling the [module:dcc]dcc[/module].*
-			module functions and by passing the DCC session id parameter.
+			module functions and by passing the DCC session ID parameter.
 		@seealso:
 			[event:onconsolepuprequest]OnConsolePopupRequest[/event],
 			[event:onchannelpopuprequest]OnChannelPopupRequest[/event],
 			[event:onquerypopuprequest]OnQueryPopupRequest[/event]
 	*/
-	EVENT("OnDCCChatPopupRequest","$0 = DCC session id"),
+	EVENT("OnDCCChatPopupRequest","$0 = DCC session ID"),
 	/*
 		@doc: ondccfiletransferconnectioninprogress
 		@type:
@@ -2669,25 +2668,25 @@ channel
 		@short:
 			Triggered when a DCC File transfer is waiting for a connection
 		@parameters:
-			$0 = DCC Session Id
+			$0 = DCC session ID
 		@window:
 			unspecified
 		@description:
 			Triggered when a DCC File transfer has been set up and
-			it is waiting for the connection to be estabilished.[br]
+			is waiting for the connection to be established.[br]
 			Note that the real data transfer is not started until
 			[event:ondccfiletransferbegin]OnDCCFileTransferBegin[/event] is triggered
 			but from this moment on you will be notified of success
 			or failure by the means of [event:ondccfiletransfersuccess]OnDCCFileTransferSuccess[/event]
 			or [event:ondccfiletransferfailed]OnDCCFileTransferFailed[/event].[br]
 			You can retrieve the session information by calling the [module:dcc]dcc[/module].*
-			module functions and by passing the DCC session id parameter.
+			module functions and by passing the DCC session ID parameter.
 		@seealso:
 			[event:ondccfiletransferfailed]OnDCCFileTransferFailed[/event],
 			[event:ondccfiletransfersuccess]OnDCCFileTransferSuccess[/event],
 			[event:ondccfiletransferbegin]OnDCCFileTransferBegin[/event]
 	*/
-	EVENT("OnDCCFileTransferConnectionInProgress","$0 = DCC session id"),
+	EVENT("OnDCCFileTransferConnectionInProgress","$0 = DCC session ID"),
 	/*
 		@doc: ondccfiletransferbegin
 		@type:
@@ -2697,20 +2696,20 @@ channel
 		@short:
 			Triggered when a DCC File transfer begins
 		@parameters:
-			$0 = DCC Session Id
+			$0 = DCC session ID
 		@window:
 			unspecified
 		@description:
-			Triggered when the DCC file transfer connection is estabilished
+			Triggered when a DCC file transfer connection is established
 			and the real data transfer starts.[br]
 			You can retrieve the session information by calling the [module:dcc]dcc[/module].*
-			module functions and by passing the DCC session id parameter.
+			module functions and by passing the DCC session ID parameter.
 		@seealso:
 			[event:ondccfiletransferconnectioninprogress]OnDCCFileTransferConnectionInProgress[/event],
 			[event:ondccfiletransfersuccess]OnDCCFileTransferSuccess[/event],
 			[event:ondccfiletransferfailed]OnDCCFileTransferFailed[/event]
 	*/
-	EVENT("OnDCCFileTransferBegin","$0 = DCC session id"),
+	EVENT("OnDCCFileTransferBegin","$0 = DCC session ID"),
 	/*
 		@doc: ondccfiletransfersuccess
 		@type:
@@ -2721,20 +2720,20 @@ channel
 			Triggered when a DCC File transfer succeeds
 		@parameters:
 			$0 = bytes transferred
-			$1 = DCC Session Id
+			$1 = DCC session ID
 		@window:
 			unspecified
 		@description:
 			Triggered when a DCC File transfer terminates succesfully.[br]
 			$0 contains the number of bytes transferred in the session.[br]
 			You can retrieve the session information by calling the [module:dcc]dcc[/module].*
-			module functions and by passing the DCC session id parameter.
+			module functions and by passing the DCC session ID parameter.
 		@seealso:
 			[event:ondccfiletransferconnectioninprogress]OnDCCFileTransferConnectionInProgress[/event],
 			[event:ondccfiletransferfailed]OnDCCFileTransferFailed[/event],
 			[event:ondccfiletransferbegin]OnDCCFileTransferBegin[/event]
 	*/
-	EVENT("OnDCCFileTransferSuccess","$0 = bytes transferred\n$1 = DCC session id"),
+	EVENT("OnDCCFileTransferSuccess","$0 = bytes transferred\n$1 = DCC session ID"),
 	/*
 		@doc: ondccfiletransferfailed
 		@type:
@@ -2744,9 +2743,9 @@ channel
 		@short:
 			Triggered when a DCC File transfer fails
 		@parameters:
-			$0 = Failure reason message
+			$0 = failure reason message
 			$1 = bytes transferred
-			$2 = DCC Session Id
+			$2 = DCC session ID
 		@window:
 			unspecified
 		@description:
@@ -2754,13 +2753,13 @@ channel
 			explaining the reason of the failure.[br]
 			$1 contains the number of bytes transferred in the session, eventually 0.[br]
 			You can retrieve the session information by calling the [module:dcc]dcc[/module].*
-			module functions and by passing the DCC session id parameter.
+			module functions and by passing the DCC session ID parameter.
 		@seealso:
 			[event:ondccfiletransferconnectioninprogress]OnDCCFileTransferConnectionInProgress[/event],
 			[event:ondccfiletransfersuccess]OnDCCFileTransferSuccess[/event],
 			[event:ondccfiletransferbegin]OnDCCFileTransferBegin[/event]
 	*/
-	EVENT("OnDCCFileTransferFailed","$0 = Failure reason\n$1 = bytes transferred\n$2 = DCC session id"),
+	EVENT("OnDCCFileTransferFailed","$0 = failure reason\n$1 = bytes transferred\n$2 = DCC session ID"),
 	/*
 		@doc: onwallops
 		@type:
@@ -3090,6 +3089,59 @@ channel
 			Triggered when user clicks on server name in any window
 			It will be triggered only at the left mouse button click
 	*/
-	EVENT("OnServerLinkClick","$0 = server name")
+	EVENT("OnServerLinkClick","$0 = server name"),
+		/*
+		@doc: OnIgnoredMessage
+		@type:
+			event
+		@title:
+			OnIgnoredMessage
+		@short:
+			Triggered when a message is ignored.
+		@parameters:
+			$0 = source nick
+			$1 = source username
+			$2 = source host
+			$3 = message target
+			$4 = message
+		@window:
+			any
+		@description:
+			Triggered when a message is ignored.
+	*/
+	EVENT("OnIgnoredMessage","$0 = source nick\n$1 = source username\n$2 = source host\n$3 = message target\n$4 = message"),
+	/*
+		@doc: OnNickServAuth
+		@type:
+			event
+		@title:
+			OnNickServAuth
+		@short:
+			Triggered when ircd sets a registered user mode.
+		@parameters:
+		@window:
+			any
+		@description:
+			Triggered when ircd sets a registered user mode.
+	*/
+        EVENT("OnNickServAuth",""),
+        /*
+                @doc: onmeaction
+                @type:
+                        event
+                @title:
+                        OnMeAction
+                @short:
+                        User issued a CTCP ACTION
+                @parameters:
+                        $0 = action message text
+                @window:
+                        Channels and query windows
+                @description:
+                        This event is triggered when user issues a CTCP ACTION.[br]
+                        (The CTCP ACTION is usually triggered by the /me command).[br]
+        */
+
+        EVENT("OnMeAction","$0 = action message text")
 };
 
