@@ -199,8 +199,13 @@
 #define KviEvent_OnUrlLinkClick 134
 #define KviEvent_OnChannelLinkClick 135
 #define KviEvent_OnServerLinkClick 136
+#define KviEvent_OnIgnoredMessage 137
 
-#define KVI_KVS_NUM_APP_EVENTS 137
+#define KviEvent_OnNickServAuth 138
+
+#define KviEvent_OnMeAction 139
+
+#define KVI_KVS_NUM_APP_EVENTS 140
 // compat
 #define KVI_NUM_SCRIPT_EVENTS KVI_KVS_NUM_APP_EVENTS
 
