@@ -28,15 +28,15 @@
 
 KviKvsHash::KviKvsHash()
 {
-	m_pDict = new QDict<KviKvsVariant>(17,false);
+	m_pDict = new KviPointerHashTable<QString,KviKvsVariant>(17,false);
 	m_pDict->setAutoDelete(true);
 }
 
 KviKvsHash::KviKvsHash(const KviKvsHash &h)
 {
-	m_pDict = new QDict<KviKvsVariant>();
+	m_pDict = new KviPointerHashTable<QString,KviKvsVariant>();
 	m_pDict->setAutoDelete(true);
-	QDictIterator<KviKvsVariant> it(*(h.m_pDict));
+	KviPointerHashTableIterator<QString,KviKvsVariant> it(*(h.m_pDict));
 	while(it.current())
 	{
 		m_pDict->replace(it.currentKey(),new KviKvsVariant(*(it.current())));
@@ -51,7 +51,7 @@ KviKvsHash::~KviKvsHash()
 
 void KviKvsHash::appendAsString(QString &szBuffer) const
 {
-	QDictIterator<KviKvsVariant> it(*m_pDict);
+	KviPointerHashTableIterator<QString,KviKvsVariant> it(*m_pDict);
 	bool bNeedComma = false;
 	while(KviKvsVariant * s = it.current())
 	{
@@ -62,6 +62,30 @@ void KviKvsHash::appendAsString(QString &szBuffer) const
 	}
 }
 
+void KviKvsHash::serialize(QString& result)
+{
+	QString tmpBuffer;
+	result="{";
+	KviPointerHashTableIterator<QString,KviKvsVariant> it(*m_pDict);
+	bool bNeedComma = false;
+	while(KviKvsVariant * s = it.current())
+	{
+		if(bNeedComma)result.append(',');
+		else bNeedComma = true;
+		
+		tmpBuffer = it.currentKey();
+		KviKvsVariant::serializeString(tmpBuffer);
+		result.append(tmpBuffer);
+
+		result.append(":");
+		s->serialize(tmpBuffer);
+		result.append(tmpBuffer);
+
+		++it;
+	}
+	result.append('}');
+}
+
 KviKvsVariant * KviKvsHash::get(const QString &szKey)
 {
 	KviKvsVariant * v = m_pDict->find(szKey);
