@@ -600,7 +600,7 @@ KviKvsObject::KviKvsObject(KviKvsObjectClass * pClass,KviKvsObject * pParent,con
 
 	m_pClass             = pClass;
 
-	m_pChildList         = new KviPtrList<KviKvsObject>;
+	m_pChildList         = new KviPointerList<KviKvsObject>;
 	m_pChildList->setAutoDelete(false);
 
 	m_pDataContainer     = new KviKvsHash();
@@ -635,10 +635,11 @@ KviKvsObject::~KviKvsObject()
 	while(m_pChildList->first())delete m_pChildList->first();
 	delete m_pChildList;
 
+#if 0
 	// Disconnect all the signals
 	if(m_pSignalDict)
 	{
-		QDictIterator<KviKvsObjectConnectionList> it(*m_pSignalDict);
+		KviPointerHashTableIterator<QString,KviKvsObjectConnectionList> it(*m_pSignalDict);
 
 		while(it.current())
 		{
@@ -664,6 +665,28 @@ KviKvsObject::~KviKvsObject()
 			//++cit;// NO!... we point to the next now!
 		}
 	}
+#else
+	// Disconnect all the signals
+	for(;;)
+	{
+		if(!m_pSignalDict)break;
+		KviPointerHashTableEntry<QString,KviKvsObjectConnectionList> * pSignalList = m_pSignalDict->firstEntry();
+		if(!pSignalList)break;
+		KviKvsObjectConnection * pConnection = pSignalList->data()->first();
+		if(!pConnection)break;
+		disconnectSignal(pSignalList->key(),pConnection);
+	}
+
+	// Disconnect all the slots
+	for(;;)
+	{
+		if(!m_pConnectionList)break;
+		KviKvsObjectConnection * pConnection = m_pConnectionList->first();
+		if(!pConnection)break;
+		QString szSignalCopy = pConnection->szSignal; // we need this since pConnection is deleted inside disconnectSignal() and pConnection->szSignal dies too (but is referenced after the connection delete)
+		pConnection->pSourceObject->disconnectSignal(szSignalCopy,pConnection);
+	}
+#endif
 
 	KviKvsKernel::instance()->objectController()->unregisterObject(this);
 
@@ -715,7 +738,7 @@ bool KviKvsObject::connectSignal(const QString &sigName,KviKvsObject * pTarget,c
 
 	if(!m_pSignalDict)
 	{
-		m_pSignalDict = new QDict<KviKvsObjectConnectionList>(7,false);
+		m_pSignalDict = new KviPointerHashTable<QString,KviKvsObjectConnectionList>(7,false);
 		m_pSignalDict->setAutoDelete(true);
 	}
 
@@ -821,7 +844,7 @@ int KviKvsObject::emitSignal(const QString &sigName,KviKvsObjectFunctionCall * p
 	KviKvsVariant retVal;
 
 	// The objects we're going to disconnect
-	KviPtrList<KviKvsObjectConnection> * pDis = 0;
+	KviPointerList<KviKvsObjectConnection> * pDis = 0;
 
 	kvs_int_t emitted = 0;
 
@@ -832,7 +855,7 @@ int KviKvsObject::emitSignal(const QString &sigName,KviKvsObjectFunctionCall * p
 		// save it , since s may be destroyed in the call!
 		KviKvsObject * pTarget = s->pTargetObject;
 
-		emitted ++;
+		emitted++;
 
 		kvs_hobject_t hTarget = pTarget->handle();
 		kvs_hobject_t hOld = pTarget->signalSender();
@@ -855,7 +878,7 @@ int KviKvsObject::emitSignal(const QString &sigName,KviKvsObjectFunctionCall * p
 
 				if(!pDis)
 				{
-					pDis = new KviPtrList<KviKvsObjectConnection>;
+					pDis = new KviPointerList<KviKvsObjectConnection>;
 					pDis->setAutoDelete(false);
 				}
 				pDis->append(s);
@@ -994,7 +1017,10 @@ bool KviKvsObject::function_killTimer(KviKvsObjectFunctionCall * c)
 
 bool KviKvsObject::function_killTimers(KviKvsObjectFunctionCall * c)
 {
+	// FIXME: QT4 does not seem to have QObject::killTimers()
+#ifndef COMPILE_USE_QT4
 	killTimers();
+#endif
 	return true;
 }
 
@@ -1016,27 +1042,42 @@ bool KviKvsObject::function_listProperties(KviKvsObjectFunctionCall * c)
 	kvs_int_t cnt = 0;
 	if(m_pObject)
 	{
-		QMetaObject *o = m_pObject->metaObject();
+		const QMetaObject *o = m_pObject->metaObject();
 		if(!bArray)
 			w->output(KVI_OUT_SYSTEMMESSAGE,__tr2qs("Properties for Qt class %s"),o->className());
+#ifndef COMPILE_USE_QT4
 		while(o)
 		{
+#endif
 			kvs_int_t idx = 0;
-			const QMetaProperty *p = o->property(idx);
+			#ifdef COMPILE_USE_QT4
+				QMetaProperty prop = o->property(idx);
+				const QMetaProperty *p = &prop;
+			#else
+				const QMetaProperty *p = o->property(idx);
+			#endif
+
 			while(p)
 			{
 				QString szOut;
 				QString szName = p->name();
+				#ifdef COMPILE_USE_QT4
+					QString szType = p->typeName();
+				#else
 				QString szType = p->type();
+				#endif
 				if(bArray)
 					KviQString::sprintf(szOut,"%Q, %Q",&szName,&szType);
 				else {
 					KviQString::sprintf(szOut,__tr2qs("Property: %c%Q%c, type %Q"),KVI_TEXT_BOLD,&szName,KVI_TEXT_BOLD,&szType);
 					szOut.prepend(" ");
 				}
+				
 				if(p->isEnumType())
 				{
 					szOut += ", enum(";
+#ifndef COMPILE_USE_QT4
+					// FIXME: Qt 4.x needs QMetaEnum for this loop
 					QStrList le = p->enumKeys();
 					int i = 0;
 					for(char *c2 = le.first(); c2; c2 = le.next())
@@ -1047,20 +1088,42 @@ bool KviKvsObject::function_listProperties(KviKvsObjectFunctionCall * c)
 							szOut.append(", ");
 						szOut.append(c2);
 					}
+#endif
 					szOut += ")";
 				}
+				
+
+#ifdef COMPILE_USE_QT4
+				// FIXME: QT4 Need to read better the docs and check the changes: there seem to be too many
+				//        for me to fix now. Actually I need to get the whole executable working...
+				if(p->isWritable())szOut += ", writable";
+#else
 				if(p->isSetType())szOut += ", set";
 				if(p->writable())szOut += ", writable";
+#endif
 				if(bArray)
 					a->set(cnt,new KviKvsVariant(szOut));
 				else
 					w->outputNoFmt(KVI_OUT_SYSTEMMESSAGE,szOut);
+#ifdef COMPILE_USE_QT4
+				idx++;
+				if (idx<o->propertyCount()){
+						prop = o->property(idx);
+						p = &prop;
+				}
+				else p=0;
+#else
 				p = o->property(idx);
 				idx++;
+#endif
+				
 				cnt++;
 			}
+#ifndef COMPILE_USE_QT4	
 			o = o->superClass();
 		}
+#endif
+
 	}
 
 	if(bArray)
@@ -1090,13 +1153,22 @@ bool KviKvsObject::function_setProperty(KviKvsObjectFunctionCall * c)
 		return true;
 	}
 
+#ifdef COMPILE_USE_QT4
+	int idx = m_pObject->metaObject()->indexOfProperty(szName);
+#else
 	int idx = m_pObject->metaObject()->findProperty(szName,true);
+#endif
 	if(idx < 0)
 	{
 		c->warning(__tr2qs("No Qt property named \"%Q\" for object named \"%Q\" of class %Q"),&szName,&m_szName,&(m_pClass->name()));
 		return true;
 	}
+#ifdef COMPILE_USE_QT4
+	QMetaProperty prop = m_pObject->metaObject()->property(idx);
+	const QMetaProperty * p = &prop;
+#else
 	const QMetaProperty * p = m_pObject->metaObject()->property(idx,true);
+#endif
 	if(!p)
 	{
 		c->warning(__tr2qs("Can't find property named \"%Q\" for object named \"%Q\" of class %Q: the property is indexed but it doesn't really exist"),&szName,&m_szName,&(m_pClass->name()));
@@ -1114,7 +1186,11 @@ bool KviKvsObject::function_setProperty(KviKvsObjectFunctionCall * c)
 	{
 		QString szKey;
 		v->asString(szKey);
+#ifdef COMPILE_USE_QT4
+		int val = p->enumerator().keyToValue(szKey);
+#else
 		int val = p->keyToValue(szKey);
+#endif
 		QVariant var(val);
 		m_pObject->setProperty(szName,var);
 		return true;
@@ -1198,6 +1274,8 @@ bool KviKvsObject::function_setProperty(KviKvsObjectFunctionCall * c)
 			m_pObject->setProperty(szName,QVariant(QRect(iX,iY,iW,iH)));
 		}
 		break;
+#ifndef COMPILE_USE_QT4
+		// FIXME: QT4 ????
 		case QVariant::Color:
 		{
 			if(!v->isArray())WRONG_TYPE("array(integer,integer,integer)")
@@ -1276,6 +1354,7 @@ bool KviKvsObject::function_setProperty(KviKvsObjectFunctionCall * c)
 			}
 		}
 		break;
+#endif
 		default:
 			c->warning(__tr2qs("Property \"%Q\" for object named \"%Q\" of class %Q has an unsupported data type"),&szName,&m_szName,&(m_pClass->name()));
 			c->returnValue()->setNothing();
@@ -1305,7 +1384,11 @@ bool KviKvsObject::function_property(KviKvsObjectFunctionCall * c)
 		return true;
 	}
 
+#ifdef COMPILE_USE_QT4
+	int idx = m_pObject->metaObject()->indexOfProperty(szName);
+#else
 	int idx = m_pObject->metaObject()->findProperty(szName,true);
+#endif
 	if(idx < 0)
 	{
 		if (bNoerror) c->returnValue()->setString("No Qt properties");
@@ -1316,7 +1399,12 @@ bool KviKvsObject::function_property(KviKvsObjectFunctionCall * c)
 		}
 		return true;
 	}
+#ifdef COMPILE_USE_QT4
+	QMetaProperty prop = m_pObject->metaObject()->property(idx);
+	const QMetaProperty * p = &prop;
+#else
 	const QMetaProperty * p = m_pObject->metaObject()->property(idx,true);
+#endif
 	if(!p)
 	{
 		c->warning(__tr2qs("Can't find property named \"%Q\" for object named \"%Q\" of class %Q: the property is indexed but it doesn't really exist"),&szName,&m_szName,&(m_pClass->name()));
@@ -1334,7 +1422,11 @@ bool KviKvsObject::function_property(KviKvsObjectFunctionCall * c)
 
 	if(p->isEnumType())
 	{
+#ifdef COMPILE_USE_QT4
+		c->returnValue()->setString(p->enumerator().valueToKey(v.toInt()));
+#else
 		c->returnValue()->setString(p->valueToKey(v.toInt()));
+#endif
 		return true;
 	}
 
@@ -1384,6 +1476,8 @@ bool KviKvsObject::function_property(KviKvsObjectFunctionCall * c)
 			c->returnValue()->setArray(a);
 		}
 		break;
+#ifndef COMPILE_USE_QT4
+		// FIXME: QT4 ?
 		case QVariant::Color:
 		{
 			QColor clr = v.toColor();
@@ -1411,6 +1505,7 @@ bool KviKvsObject::function_property(KviKvsObjectFunctionCall * c)
 			c->returnValue()->setString(szFlags);
 		}
 		break;
+#endif
 		default:
 			if (bNoerror) c->returnValue()->setString("Unsupported_data_type");
 			else
@@ -1425,7 +1520,7 @@ bool KviKvsObject::function_property(KviKvsObjectFunctionCall * c)
 
 void KviKvsObject::killAllChildrenWithClass(KviKvsObjectClass *cl)
 {
-	KviPtrList<KviKvsObject> l;
+	KviPointerList<KviKvsObject> l;
 	l.setAutoDelete(true);
 	for(KviKvsObject * o=m_pChildList->first();o;o=m_pChildList->next())
 	{
@@ -1436,6 +1531,18 @@ void KviKvsObject::killAllChildrenWithClass(KviKvsObjectClass *cl)
 	}
 }
 
+bool KviKvsObject::inheritsClass(KviKvsObjectClass * pClass)
+{
+	if(pClass == m_pClass)return true;
+	KviKvsObjectClass * cl = m_pClass->m_pParentClass;
+	while(cl)
+	{
+		if(cl == pClass)return true;
+		else cl = cl->m_pParentClass;
+	}
+	return false;
+}
+
 KviKvsObjectClass * KviKvsObject::getClass(const QString & classOverride)
 {
 	if(classOverride.isEmpty())return m_pClass;
@@ -1596,7 +1703,7 @@ void KviKvsObject::registerPrivateImplementation(const QString &szFunctionName,c
 	} else {
 		if(!m_pFunctionHandlers)
 		{
-			m_pFunctionHandlers = new QDict<KviKvsObjectFunctionHandler>(7,false);
+			m_pFunctionHandlers = new KviPointerHashTable<QString,KviKvsObjectFunctionHandler>(7,false);
 			m_pFunctionHandlers->setAutoDelete(true);
 		}
 
