@@ -185,7 +185,7 @@ KviKvsTreeNodeCommand * KviKvsParser::parseSpecialCommandUnset()
 
 	const QChar * pCmdBegin = KVSP_curCharPointer;
 
-	KviPtrList<KviKvsTreeNodeVariable> * pVarList = new KviPtrList<KviKvsTreeNodeVariable>;
+	KviPointerList<KviKvsTreeNodeVariable> * pVarList = new KviPointerList<KviKvsTreeNodeVariable>;
 	pVarList->setAutoDelete(true);
 	
 	while(KVSP_curCharUnicode == '%')
@@ -242,13 +242,9 @@ KviKvsTreeNodeCommand * KviKvsParser::parseSpecialCommandGlobal()
 			it refers to the global kvirc instance for the scope of the script.
 			Global variables are shared between scripts and keep their
 			value until they are explicitly unset or kvirc quits.
-			Please note that the commands typed in from the commandline
-			already assume that all the variables are global: this command
-			has no effect in that case.[br]
-			The versions of KVIrc prior to 3.0.0 recognized global variables
-			by the initial uppercase letter. This method is incoherent with the
-			rest of the language and is deprecated (even if it is still supported
-			for backward compatibility).
+			This command can be used to override the default behaviour of
+			declaring global variables by starting them with an uppercase letter
+			and declaring local variables by starting them with a lowercase one.
 		@examples:
 			global %a,%b,%c;
 	*/
@@ -264,7 +260,7 @@ KviKvsTreeNodeCommand * KviKvsParser::parseSpecialCommandGlobal()
 
 		if(!m_pGlobals)
 		{
-			m_pGlobals = new QDict<QString>(17,false);
+			m_pGlobals = new KviPointerHashTable<QString,QString>(17,false);
 			m_pGlobals->setAutoDelete(true);
 		}
 		m_pGlobals->replace(szIdentifier,new QString());
@@ -1294,7 +1290,7 @@ KviKvsTreeNodeCommand * KviKvsParser::parseSpecialCommandSwitch()
 			The <value> is evaluated and is compared against the result of <expression>.
 			The comparison is case insensitive (if the values are strings).[br]
 			If <value> is equal to <expression> then <command> is executed.
-			<command> is a single instruction or an instruction block enclosed in braces.
+			Please note that <command> must be either a single instruction or an instruction block [b]enclosed in braces[/b].
 			If <command> contains a [cmd]break[/cmd] statement inside or if [cmd]break[/cmd]
 			is specified just after the <command> then the execution of the switch is terminated
 			otherwise the nex label is evaluated.[br]
@@ -1578,7 +1574,7 @@ KviKvsTreeNodeSpecialCommandDefpopupLabelPopup * KviKvsParser::parseSpecialComma
 		QString szLabel(pLabelBegin,KVSP_curCharPointer - pLabelBegin);
 		QString szLabelLow = szLabel.lower();
 
-		KviPtrList<QString> * pParameters = 0;
+		KviPointerList<QString> * pParameters = 0;
 		
 		QString szCondition;
 
@@ -1967,6 +1963,8 @@ KviKvsTreeNodeCommand * KviKvsParser::parseSpecialCommandHelp()
 	// a CoreSimpleCommand but parses the parameters as constants
 	
 	// we handle a single big parameter, with whitespace stripped
+	// This is because we want the identifiers to be preserved
+	// as unevaluated (i.e $function).
 
 	skipSpaces();
 
