@@ -324,7 +324,10 @@ void KviKvsPopupMenuItemLabel::fill(KviKvsPopupMenu * pMenu,KviKvsPopupMenuTopLe
 	}
 	m_pLabel = new QLabel(szText,pMenu);
 	QObject::connect(m_pLabel,SIGNAL(destroyed()),m_pSignalRelay,SLOT(labelDestroyed()));
+#ifndef COMPILE_USE_QT4
+	// FIXME: QT4 Seems to not allow widgets as QMenu items
 	pMenu->insertItem(m_pLabel);
+#endif
 	m_pLabel->setFrameStyle(QFrame::StyledPanel | QFrame::Raised);
 	if(pPix)m_pLabel->setPixmap(*pPix);
 }
@@ -525,14 +528,14 @@ KviKvsPopupMenuTopLevelData::~KviKvsPopupMenuTopLevelData()
 
 
 KviKvsPopupMenu::KviKvsPopupMenu(const QString &szName)
-:QPopupMenu(0,szName)
+:KviTalPopupMenu(0,szName)
 {
 	m_szName = szName;
-	m_pItemList = new KviPtrList<KviKvsPopupMenuItem>;
+	m_pItemList = new KviPointerList<KviKvsPopupMenuItem>;
 	m_pItemList->setAutoDelete(true);
-	m_pPrologues = new KviPtrList<KviKvsScript>;
+	m_pPrologues = new KviPointerList<KviKvsScript>;
 	m_pPrologues->setAutoDelete(true);
-	m_pEpilogues = new KviPtrList<KviKvsScript>;
+	m_pEpilogues = new KviPointerList<KviKvsScript>;
 	m_pEpilogues->setAutoDelete(true);
 	m_pParentPopup = 0;
 	m_pTopLevelData = 0;
@@ -721,7 +724,7 @@ void KviKvsPopupMenu::doPopup(const QPoint & pnt,KviWindow * wnd,KviKvsVariantLi
 	clearMenuContents();
 	m_pTempTopLevelData = new KviKvsPopupMenuTopLevelData(pParams,wnd);
 	m_pTempTopLevelData->setTestMode(bTestMode);
-	QPopupMenu::popup(pnt);
+	KviTalPopupMenu::popup(pnt);
 }
 
 void KviKvsPopupMenu::clearMenuContents()
