@@ -125,10 +125,8 @@ bool KviKvsScript::locked() const
 
 void KviKvsScript::dump(const char * prefix)
 {
-#ifdef COMPILE_NEW_KVS
 	if(m_pData->m_pTree)m_pData->m_pTree->dump(prefix);
 	else debug("%s KviKvsScript : no tree to dump",prefix);
-#endif
 }
 
 void KviKvsScript::detach()
