@@ -38,3 +38,9 @@ KviKvsTreeNodeIndirectData::~KviKvsTreeNodeIndirectData()
 	delete m_pSource;
 }
 
+
+bool KviKvsTreeNodeIndirectData::canEvaluateInObjectScope()
+{
+	return m_pSource->canEvaluateInObjectScope();
+}
+
