@@ -26,9 +26,18 @@
 
 #include "kvi_kvs_treenode_instruction.h"
 
+void KviKvsTreeNodeInstruction::contextDescription(QString &szBuffer)
+{
+#ifdef COMPILE_NEW_KVS
+	szBuffer = "Instruction";
+#endif
+}
+
 void KviKvsTreeNodeInstruction::dump(const char * prefix)
 {
+#ifdef COMPILE_NEW_KVS
 	debug("%s Instruction",prefix);
+#endif
 }
 
 
