@@ -51,7 +51,7 @@ void KviKvsTreeNodeSwitchList::dump(const char * prefix)
 	debug("%s SwitchList",prefix);
 	if(m_pShortSwitchDict)
 	{
-		QIntDictIterator<KviKvsTreeNodeData> it(*m_pShortSwitchDict);
+		KviPointerHashTableIterator<int,KviKvsTreeNodeData> it(*m_pShortSwitchDict);
 		while(it.current())
 		{
 			QString tmp = prefix;
@@ -65,7 +65,7 @@ void KviKvsTreeNodeSwitchList::dump(const char * prefix)
 	}
 	if(m_pLongSwitchDict)
 	{
-		QDictIterator<KviKvsTreeNodeData> it(*m_pLongSwitchDict);
+		KviPointerHashTableIterator<QString,KviKvsTreeNodeData> it(*m_pLongSwitchDict);
 		while(it.current())
 		{
 			QString tmp = prefix;
@@ -82,7 +82,7 @@ void KviKvsTreeNodeSwitchList::addShort(int iShortKey,KviKvsTreeNodeData * p)
 {
 	if(!m_pShortSwitchDict)
 	{
-		m_pShortSwitchDict = new QIntDict<KviKvsTreeNodeData>(11);
+		m_pShortSwitchDict = new KviPointerHashTable<int,KviKvsTreeNodeData>(11);
 		m_pShortSwitchDict->setAutoDelete(true);
 	}
 
@@ -94,7 +94,7 @@ void KviKvsTreeNodeSwitchList::addLong(const QString &szLongKey,KviKvsTreeNodeDa
 {
 	if(!m_pLongSwitchDict)
 	{
-		m_pLongSwitchDict = new QDict<KviKvsTreeNodeData>(11);
+		m_pLongSwitchDict = new KviPointerHashTable<QString,KviKvsTreeNodeData>(11);
 		m_pLongSwitchDict->setAutoDelete(true);
 	}
 
@@ -109,7 +109,7 @@ bool KviKvsTreeNodeSwitchList::evaluate(KviKvsRunTimeContext * c,KviKvsSwitchLis
 
 	if(m_pShortSwitchDict)
 	{
-		QIntDictIterator<KviKvsTreeNodeData> it(*m_pShortSwitchDict);
+		KviPointerHashTableIterator<int,KviKvsTreeNodeData> it(*m_pShortSwitchDict);
 		while(KviKvsTreeNodeData * d = it.current())
 		{
 			KviKvsVariant * v = new KviKvsVariant();
@@ -124,7 +124,7 @@ bool KviKvsTreeNodeSwitchList::evaluate(KviKvsRunTimeContext * c,KviKvsSwitchLis
 	}
 	if(m_pLongSwitchDict)
 	{
-		QDictIterator<KviKvsTreeNodeData> it(*m_pLongSwitchDict);
+		KviPointerHashTableIterator<QString,KviKvsTreeNodeData> it(*m_pLongSwitchDict);
 		while(KviKvsTreeNodeData * d = it.current())
 		{
 			KviKvsVariant * v = new KviKvsVariant();
