@@ -29,6 +29,7 @@
 #include "kvi_kvs_hash.h"
 #include "kvi_kvs_array.h"
 
+#include <math.h>
 
 KviKvsVariant::KviKvsVariant()
 {
@@ -51,6 +52,15 @@ KviKvsVariant::KviKvsVariant(const QString &szString)
 	m_pData->m_u.pString = new QString(szString);
 }
 
+KviKvsVariant::KviKvsVariant(const char * szString)
+{
+	m_pData = new KviKvsVariantData;
+	m_pData->m_eType = KviKvsVariantData::String;
+	m_pData->m_uRefs = 1;
+	m_pData->m_u.pString = new QString(QString::fromUtf8(szString));
+}
+
+
 KviKvsVariant::KviKvsVariant(KviKvsArray * pArray)
 {
 	m_pData = new KviKvsVariantData;
@@ -403,7 +413,7 @@ void KviKvsVariant::castToArray(KviKvsArrayCast *c) const
 		break;
 		case KviKvsVariantData::Hash:
 		{
-			QDictIterator<KviKvsVariant> it(*(m_pData->m_u.pHash->dict()));
+			KviPointerHashTableIterator<QString,KviKvsVariant> it(*(m_pData->m_u.pHash->dict()));
 			KviKvsArray * a = new KviKvsArray();
 			kvs_int_t idx = 0;
 			while(KviKvsVariant * v = it.current())
@@ -441,7 +451,7 @@ void KviKvsVariant::convertToArray()
 		break;
 		case KviKvsVariantData::Hash:
 		{
-			QDictIterator<KviKvsVariant> it(*(m_pData->m_u.pHash->dict()));
+			KviPointerHashTableIterator<QString,KviKvsVariant> it(*(m_pData->m_u.pHash->dict()));
 			KviKvsArray * a = new KviKvsArray();
 			kvs_int_t idx = 0;
 			while(KviKvsVariant * v = it.current())
@@ -728,7 +738,7 @@ bool KviKvsVariant::isEqualToNothing() const
 class KviKvsVariantComparison
 {
 public:
-	static inline int compare_integer_string(KviKvsVariant * v1,KviKvsVariant * v2)
+	static inline int compare_integer_string(const KviKvsVariant * v1,const KviKvsVariant * v2)
 	{
 		if(v1->m_pData->m_u.iInteger == 0)
 		{
@@ -747,49 +757,49 @@ public:
 		return -1 * KviQString::cmpCI(szString,*(v2->m_pData->m_u.pString));
 	}
 
-	static inline int compare_integer_real(KviKvsVariant * v1,KviKvsVariant * v2)
+	static inline int compare_integer_real(const KviKvsVariant * v1,const KviKvsVariant * v2)
 	{
 		if(((kvs_real_t)v1->m_pData->m_u.iInteger) == *(v2->m_pData->m_u.pReal))return CMP_EQUAL;
 		if(((kvs_real_t)v1->m_pData->m_u.iInteger) > *(v2->m_pData->m_u.pReal))return CMP_THISGREATER;
 		return CMP_OTHERGREATER;
 	}
 
-	static inline int compare_integer_boolean(KviKvsVariant * v1,KviKvsVariant * v2)
+	static inline int compare_integer_boolean(const KviKvsVariant * v1,const KviKvsVariant * v2)
 	{
 		if(v1->m_pData->m_u.iInteger == 0)
 			return v2->m_pData->m_u.bBoolean ? CMP_OTHERGREATER : CMP_EQUAL;
 		return v2->m_pData->m_u.bBoolean ? CMP_EQUAL : CMP_THISGREATER;
 	}
 	
-	static inline int compare_integer_hash(KviKvsVariant * v1,KviKvsVariant * v2)
+	static inline int compare_integer_hash(const KviKvsVariant * v1,const KviKvsVariant * v2)
 	{
 		if(v1->m_pData->m_u.iInteger == 0)
 			return v2->m_pData->m_u.pHash->isEmpty() ? CMP_EQUAL : CMP_OTHERGREATER;
 		return CMP_THISGREATER;
 	}
 
-	static inline int compare_integer_array(KviKvsVariant * v1,KviKvsVariant * v2)
+	static inline int compare_integer_array(const KviKvsVariant * v1,const KviKvsVariant * v2)
 	{
 		if(v1->m_pData->m_u.iInteger == 0)
 			return v2->m_pData->m_u.pArray->isEmpty() ? CMP_EQUAL : CMP_OTHERGREATER;
 		return CMP_THISGREATER;
 	}
 
-	static inline int compare_integer_hobject(KviKvsVariant * v1,KviKvsVariant * v2)
+	static inline int compare_integer_hobject(const KviKvsVariant * v1,const KviKvsVariant * v2)
 	{
 		if(v1->m_pData->m_u.iInteger == 0.0)
 			return (v2->m_pData->m_u.hObject == (kvs_hobject_t)0) ? CMP_EQUAL : CMP_THISGREATER;
 		return CMP_OTHERGREATER;
 	}
 
-	static inline int compare_real_hobject(KviKvsVariant * v1,KviKvsVariant * v2)
+	static inline int compare_real_hobject(const KviKvsVariant * v1,const KviKvsVariant * v2)
 	{
 		if(*(v1->m_pData->m_u.pReal) == 0.0)
 			return (v2->m_pData->m_u.hObject == (kvs_hobject_t)0) ? CMP_EQUAL : CMP_THISGREATER;
 		return CMP_OTHERGREATER;
 	}
 
-	static inline int compare_real_string(KviKvsVariant * v1,KviKvsVariant * v2)
+	static inline int compare_real_string(const KviKvsVariant * v1,const KviKvsVariant * v2)
 	{
 		if(*(v1->m_pData->m_u.pReal) == 0.0)
 		{
@@ -808,28 +818,28 @@ public:
 		return -1 * KviQString::cmpCI(szString,*(v2->m_pData->m_u.pString));
 	}
 
-	static inline int compare_real_boolean(KviKvsVariant * v1,KviKvsVariant * v2)
+	static inline int compare_real_boolean(const KviKvsVariant * v1,const KviKvsVariant * v2)
 	{
 		if(*(v1->m_pData->m_u.pReal) == 0.0)
 			return v2->m_pData->m_u.bBoolean ? CMP_OTHERGREATER : CMP_EQUAL;
 		return v2->m_pData->m_u.bBoolean ? CMP_EQUAL : CMP_THISGREATER;
 	}
 
-	static inline int compare_real_hash(KviKvsVariant * v1,KviKvsVariant * v2)
+	static inline int compare_real_hash(const KviKvsVariant * v1,const KviKvsVariant * v2)
 	{
 		if(*(v1->m_pData->m_u.pReal) == 0)
 			return v2->m_pData->m_u.pHash->isEmpty() ? CMP_EQUAL : CMP_OTHERGREATER;
 		return CMP_THISGREATER;
 	}
 
-	static inline int compare_real_array(KviKvsVariant * v1,KviKvsVariant * v2)
+	static inline int compare_real_array(const KviKvsVariant * v1,const KviKvsVariant * v2)
 	{
 		if(*(v1->m_pData->m_u.pReal) == 0)
 			return v2->m_pData->m_u.pArray->isEmpty() ? CMP_EQUAL : CMP_OTHERGREATER;
 		return CMP_THISGREATER;
 	}
 
-	static inline int compare_string_hash(KviKvsVariant * v1,KviKvsVariant * v2)
+	static inline int compare_string_hash(const KviKvsVariant * v1,const KviKvsVariant * v2)
 	{
 		if(v1->m_pData->m_u.pString->isEmpty())
 		{
@@ -838,7 +848,7 @@ public:
 		return CMP_THISGREATER;
 	}
 
-	static inline int compare_string_array(KviKvsVariant * v1,KviKvsVariant * v2)
+	static inline int compare_string_array(const KviKvsVariant * v1,const KviKvsVariant * v2)
 	{
 		if(v1->m_pData->m_u.pString->isEmpty())
 		{
@@ -847,7 +857,7 @@ public:
 		return CMP_THISGREATER;
 	}
 	
-	static inline int compare_string_hobject(KviKvsVariant * v1,KviKvsVariant * v2)
+	static inline int compare_string_hobject(const KviKvsVariant * v1,const KviKvsVariant * v2)
 	{
 		if(v2->m_pData->m_u.hObject == (kvs_hobject_t)0)
 		{
@@ -863,7 +873,7 @@ public:
 		return CMP_THISGREATER;
 	}
 
-	static inline int compare_boolean_string(KviKvsVariant * v1,KviKvsVariant * v2)
+	static inline int compare_boolean_string(const KviKvsVariant * v1,const KviKvsVariant * v2)
 	{
 		if(v2->isEqualToNothing())
 		{
@@ -873,7 +883,7 @@ public:
 		}
 	}
 
-	static inline int compare_boolean_hash(KviKvsVariant * v1,KviKvsVariant * v2)
+	static inline int compare_boolean_hash(const KviKvsVariant * v1,const KviKvsVariant * v2)
 	{
 		if(v1->m_pData->m_u.bBoolean)
 			return v2->m_pData->m_u.pHash->isEmpty() ? CMP_THISGREATER : CMP_EQUAL;
@@ -881,7 +891,7 @@ public:
 			return v2->m_pData->m_u.pHash->isEmpty() ? CMP_EQUAL : CMP_OTHERGREATER;
 	}
 
-	static inline int compare_boolean_array(KviKvsVariant * v1,KviKvsVariant * v2)
+	static inline int compare_boolean_array(const KviKvsVariant * v1,const KviKvsVariant * v2)
 	{
 		if(v1->m_pData->m_u.bBoolean)
 			return v2->m_pData->m_u.pArray->isEmpty() ? CMP_THISGREATER : CMP_EQUAL;
@@ -889,7 +899,7 @@ public:
 			return v2->m_pData->m_u.pArray->isEmpty() ? CMP_EQUAL : CMP_OTHERGREATER;
 	}
 
-	static inline int compare_boolean_hobject(KviKvsVariant * v1,KviKvsVariant * v2)
+	static inline int compare_boolean_hobject(const KviKvsVariant * v1,const KviKvsVariant * v2)
 	{
 		if(v1->m_pData->m_u.bBoolean)
 			return v2->m_pData->m_u.hObject == ((kvs_hobject_t)0) ? CMP_THISGREATER : CMP_EQUAL;
@@ -897,21 +907,21 @@ public:
 			return v2->m_pData->m_u.hObject == ((kvs_hobject_t)0) ? CMP_EQUAL : CMP_OTHERGREATER;
 	}
 
-	static inline int compare_array_hash(KviKvsVariant * v1,KviKvsVariant * v2)
+	static inline int compare_array_hash(const KviKvsVariant * v1,const KviKvsVariant * v2)
 	{
 		if(v1->m_pData->m_u.pArray->size() > v2->m_pData->m_u.pHash->size())return CMP_THISGREATER;
 		if(v1->m_pData->m_u.pArray->size() == v2->m_pData->m_u.pHash->size())return CMP_EQUAL;
 		return CMP_OTHERGREATER;
 	}
 
-	static inline int compare_hobject_hash(KviKvsVariant * v1,KviKvsVariant * v2)
+	static inline int compare_hobject_hash(const KviKvsVariant * v1,const KviKvsVariant * v2)
 	{
 		if(v2->m_pData->m_u.pHash->isEmpty())
 			return v1->m_pData->m_u.hObject == ((kvs_hobject_t)0) ? CMP_EQUAL : CMP_OTHERGREATER;
 		return v1->m_pData->m_u.hObject == ((kvs_hobject_t)0) ? CMP_THISGREATER : CMP_EQUAL;
 	}
 
-	static inline int compare_hobject_array(KviKvsVariant * v1,KviKvsVariant * v2)
+	static inline int compare_hobject_array(const KviKvsVariant * v1,const KviKvsVariant * v2)
 	{
 		if(v2->m_pData->m_u.pArray->isEmpty())
 			return v1->m_pData->m_u.hObject == ((kvs_hobject_t)0) ? CMP_EQUAL : CMP_OTHERGREATER;
@@ -919,8 +929,461 @@ public:
 	}
 
 };
+void KviKvsVariant::serializeString(QString& buffer)
+{
+	buffer.replace('\\',"\\\\");
+	buffer.replace('\n',"\\n");
+	buffer.replace('\r',"\\r");
+	buffer.replace('\b',"\\b");
+	buffer.replace('\t',"\\t");
+	buffer.replace('\f',"\\f");
+	buffer.replace('/',"\\/");
+	buffer.replace('"',"\\\"");
+	buffer.prepend('"');
+	buffer.append('"');
+}
 
-int KviKvsVariant::compare(KviKvsVariant * pOther,bool bPreferNumeric)
+void KviKvsVariant::serialize(QString& result)
+{
+	switch(m_pData->m_eType)
+	{
+		case KviKvsVariantData::HObject:
+			//can't serialize objects yet
+		break;
+		case KviKvsVariantData::Integer:
+			result.setNum(m_pData->m_u.iInteger);
+		break;
+		case KviKvsVariantData::Real:
+			result.setNum(*(m_pData->m_u.pReal));
+		break;
+		case KviKvsVariantData::String:
+			result = *(m_pData->m_u.pString);
+			serializeString(result);
+		break;
+		case KviKvsVariantData::Boolean:
+			result = m_pData->m_u.bBoolean ? "true" : "false";
+		break;
+		case KviKvsVariantData::Hash:
+			m_pData->m_u.pHash->serialize(result);
+		break;
+		case KviKvsVariantData::Array:
+			m_pData->m_u.pArray->serialize(result);
+		break;
+		case KviKvsVariantData::Nothing:
+			result="null";
+		break;
+		default: // just make gcc happy
+		break;
+	}
+}
+
+KviKvsVariant* KviKvsVariant::unserializeTrue(const QChar** aux)
+{
+	if(KviQString::equalCIN(QString("true"),*aux,4))
+	{
+		(*aux)+=4;
+		return new KviKvsVariant(true);
+	}
+	return 0;
+}
+
+KviKvsVariant* KviKvsVariant::unserializeFalse(const QChar** aux)
+{
+	if(KviQString::equalCIN(QString("false"),*aux,5))
+	{
+		(*aux)+=5;
+		return new KviKvsVariant(false);
+	}
+	return 0;
+}
+
+KviKvsVariant* KviKvsVariant::unserializeNull(const QChar** aux)
+{
+	if(KviQString::equalCIN(QString("null"),*aux,4))
+	{
+		(*aux)+=4;
+		return new KviKvsVariant();
+	}
+	return 0;
+}
+
+KviKvsVariant* KviKvsVariant::unserializeRealOrInteger(const QChar** aux)
+{
+	QString data;
+	if((*aux)->unicode() == '-')
+	{
+		data.append('-');
+		(*aux)++;
+	}
+	if(!(*aux)->isDigit())
+	{
+		return 0;
+	}
+	while((*aux)->isDigit())
+	{
+		data.append(**aux);
+		(*aux)++;
+	}
+	if((*aux)->unicode()=='.')
+	{
+		return unserializeReal(aux,data);
+	}
+	return unserializeInteger(aux,data);
+}
+
+KviKvsVariant* KviKvsVariant::unserializeReal(const QChar** aux,QString& data)
+{
+	QString exponent;
+	(*aux)++; //skip .
+	data.append('.');
+	while((*aux)->isDigit())
+	{
+		data.append(**aux);
+		(*aux)++;
+	}
+
+	if((*aux)->unicode() == 'e' || (*aux)->unicode() == 'E')
+	{
+		(*aux)++;
+		if((*aux)->unicode() == '-')
+		{
+			exponent.append('-');
+			(*aux)++;
+		} else {
+			if((*aux)->unicode() == '+')
+			{
+				exponent.append('+');
+				(*aux)++;
+			}
+		}
+
+		while((*aux)->isDigit())
+		{
+			exponent.append(**aux);
+			(*aux)++;
+		}
+	}
+
+	
+
+	float value = data.toFloat();
+	if(!exponent.isNull())
+	{
+		value*=pow(10.0,exponent.toInt());
+	}
+	return new KviKvsVariant(value);
+}
+
+KviKvsVariant* KviKvsVariant::unserializeInteger(const QChar** aux,QString& data)
+{
+
+	QString exponent;
+
+	if((*aux)->unicode() == 'e' || (*aux)->unicode() == 'E')
+	{
+		(*aux)++;
+		if((*aux)->unicode() == '-')
+		{
+			exponent.append('-');
+			(*aux)++;
+		} else {
+			if((*aux)->unicode() == '+')
+			{
+				exponent.append('+');
+				(*aux)++;
+			}
+		}
+
+		while((*aux)->isDigit())
+		{
+			exponent.append(**aux);
+			(*aux)++;
+		}
+	}
+
+	kvs_int_t value = data.toInt();
+	if(!exponent.isNull())
+	{
+		value*=pow(10.0,exponent.toInt());
+	}
+	return new KviKvsVariant(value);
+}
+
+KviKvsVariant* KviKvsVariant::unserializeString(const QChar** aux)
+{
+	QString buffer;
+	unserializeString(aux,buffer);
+	return new KviKvsVariant(buffer);
+}
+
+void KviKvsVariant::unserializeString(const QChar** aux,QString& data)
+{
+	data="";
+	QString hex; //temp var
+	//skip leading "
+	(*aux)++;
+	while((*aux)->unicode())
+	{
+		switch((*aux)->unicode())
+		{
+		case '"':
+			//EOF
+			(*aux)++;
+			return;
+			break;
+		case '\\':
+			//Special
+			(*aux)++;
+			switch((*aux)->unicode())
+			{
+			case 't':
+				data.append('\t');
+				break;
+			case '\"':
+				data.append('\"');
+				break;
+			case '/':
+				data.append('/');
+			case 'b':
+				data.append('\b');
+			case 'f':
+				data.append('\f');
+				break;
+			case 'n':
+				data.append('\n');
+				break;
+			case 'r':
+				data.append('\r');
+				break;
+			case 'u':
+				//4 hexadecmical digits pending...
+				hex="";
+				(*aux)++;
+				for(int k=0;k<4 && (*aux)->unicode(); k++)
+				{
+					if((*aux)->isDigit() ||
+						((*aux)->unicode() >='A' && (*aux)->unicode() <='F')|| //ABCDEF
+						((*aux)->unicode() >='a' && (*aux)->unicode() <='f')) //abcdef
+					{
+						hex.append(**aux);
+						(*aux)++;
+					} else {
+						break;
+					}
+				}
+				(*aux)--;
+				data.append(QChar(hex.toUInt(0,16)));
+				break;
+			default:
+				//Fallback; incorrect escape
+				(*aux)--;
+				data.append('\\');
+			}
+			(*aux)++;
+			break;
+		default:
+			data.append(**aux);
+			(*aux)++;
+			break;
+		}
+	}
+}
+
+KviKvsVariant* KviKvsVariant::unserializeHash(const QChar** aux)
+{
+	KviKvsHash* pHash = new KviKvsHash();
+	QString szKey;
+	KviKvsVariant* pElement = 0;
+	//skip leading '{'
+	(*aux)++;
+	int i=0;
+	while(1)
+	{
+		//skip leading space
+		while((*aux)->isSpace())
+				(*aux)++;
+		//waiting for starting of string
+		if((*aux)->unicode()!='\"')
+		{
+			//strange characters
+			delete pHash;
+			return 0;
+		}
+		unserializeString(aux,szKey);
+		if(szKey.isEmpty())
+		{
+			//Strange element name
+			delete pHash;
+			return 0;
+		}
+
+		//skip leading space before ':'
+		while((*aux)->isSpace())
+				(*aux)++;
+		//waiting for name-value delimeter
+		if((*aux)->unicode()!=':')
+		{
+			//strange characters
+			delete pHash;
+			return 0;
+		}
+		(*aux)++;
+		
+
+		//getting element
+		pElement = unserialize(aux);
+		if(pElement)
+		{
+			pHash->set(szKey,pElement);
+			i++;
+			while((*aux)->isSpace())
+				(*aux)++;
+			switch((*aux)->unicode())
+			{
+			case ',':
+				//goto next
+				(*aux)++;
+				break;
+			case '}':
+				//EOF array
+				(*aux)++;
+				return new KviKvsVariant(pHash);
+				break;
+			default:
+				delete pHash;
+				return 0;
+				break;
+			}
+		} else {
+			//error
+			delete pHash;
+			return 0;
+		}
+	}
+	return 0;
+}
+
+KviKvsVariant* KviKvsVariant::unserializeArray(const QChar** aux)
+{
+	KviKvsArray* pArray = new KviKvsArray();
+	KviKvsVariant* pElement = 0;
+	(*aux)++;
+	int i=0;
+	while(1)
+	{
+		pElement = unserialize(aux);
+		if(pElement)
+		{
+			pArray->set(i,pElement);
+			i++;
+			while((*aux)->isSpace())
+				(*aux)++;
+			switch((*aux)->unicode())
+			{
+			case ',':
+				//goto next
+				(*aux)++;
+				break;
+			case ']':
+				//EOF array
+				(*aux)++;
+				return new KviKvsVariant(pArray);
+				break;
+			default:
+				delete pArray;
+				return 0;
+				break;
+			}
+		} else {
+			//error
+			delete pArray;
+			return 0;
+		}
+	}
+	return 0;
+}
+
+KviKvsVariant* KviKvsVariant::unserialize(const QChar** aux)
+{
+	KviKvsVariant* pResult = 0;
+
+	while((*aux)->isSpace())
+		(*aux)++;
+
+	switch((*aux)->unicode())
+	{
+	case 't':
+		//true
+		pResult = unserializeTrue(aux);
+		break;
+	case 'f':
+		//false
+		pResult = unserializeFalse(aux);
+		break;
+	case 'n':
+		//null
+		pResult = unserializeNull(aux);
+		break;
+	case '[':
+		//array
+		pResult = unserializeArray(aux);
+		break;
+	case '{':
+		//hash
+		pResult = unserializeHash(aux);
+		break;
+	case '"':
+		//string
+		pResult = unserializeString(aux);
+		break;
+	case '1':
+	case '2':
+	case '3':
+	case '4':
+	case '5':
+	case '6':
+	case '7':
+	case '8':
+	case '9':
+	case '0':
+	case '-':
+		//real or integer
+		pResult = unserializeRealOrInteger(aux);
+		break;
+	default:
+		//incorrect value
+		return 0;
+	}
+
+	while((*aux)->isSpace())
+		(*aux)++;
+
+	return pResult;
+}
+
+KviKvsVariant* KviKvsVariant::unserialize(const QString& data)
+{
+	KviKvsVariant* pResult = 0;
+
+#ifdef COMPILE_USE_QT4
+	const QChar * aux = (const QChar *)data.constData();
+#else
+	const QChar * aux = (const QChar *)data.ucs2();
+#endif
+	
+	pResult = unserialize(&aux);
+
+	if(aux->unicode())
+	{
+		//strange extra characters?
+		if(pResult) delete pResult;
+		pResult = 0;
+	}
+
+	return pResult;
+}
+
+int KviKvsVariant::compare(const KviKvsVariant * pOther,bool bPreferNumeric) const
 {
 	// returns -1 if this variant is greater than pOther
 	// 0 if they are considered to be equal
