@@ -96,6 +96,7 @@ public:
 	KviKvsVariant(kvs_real_t * pReal);
 	KviKvsVariant(bool bBoolean);
 	KviKvsVariant(const QString &szString);
+	KviKvsVariant(const char * szString); // without this gcc chooses the conversion (const char *)->(void *) instead of (const char *)->(QString) and obviously calls the wrong constructor
 	KviKvsVariant(QString * pString);
 	KviKvsVariant(KviKvsArray * pArray);
 	KviKvsVariant(KviKvsHash * pHash);
@@ -162,7 +163,7 @@ public:
 
 	kvs_int_t integer() const { return m_pData ? m_pData->m_u.iInteger : 0; };
 	kvs_real_t real() const { return m_pData ? *(m_pData->m_u.pReal) : 0.0; };
-	const QString & string() const { return m_pData ? *(m_pData->m_u.pString) : QString::null; };
+	const QString & string() const { return m_pData ? *(m_pData->m_u.pString) : KviQString::empty; };
 	KviKvsArray * array() const { return m_pData ? m_pData->m_u.pArray : 0; };
 	KviKvsHash * hash() const { return m_pData ? m_pData->m_u.pHash : 0; };
 	bool boolean() const { return m_pData ? m_pData->m_u.bBoolean : false; };
@@ -178,9 +179,26 @@ public:
 	// returns -1 if this variant is greater than the other, 0 if are equal, 1 if the other is greater
 	// if bPreferNumeric is true then when comparing strings a conversion to a numeric format
 	// is first attempted.
-	int compare(KviKvsVariant * pOther,bool bPreferNumeric = false);
+	int compare(const KviKvsVariant * pOther,bool bPreferNumeric = false) const;
 	
 	void operator = (const KviKvsVariant &v){ copyFrom(v); };
+
+	//JSON serialization
+	void serialize(QString& result);
+	static void serializeString(QString& buffer);
+	static KviKvsVariant* unserialize(const QString& buffer);
+private:
+	static KviKvsVariant* unserialize(const QChar** aux);
+	static KviKvsVariant* unserializeTrue(const QChar** aux);
+	static KviKvsVariant* unserializeFalse(const QChar** aux);
+	static KviKvsVariant* unserializeNull(const QChar** aux);
+	static KviKvsVariant* unserializeArray(const QChar** aux);
+	static KviKvsVariant* unserializeHash(const QChar** aux);
+	static void unserializeString(const QChar** aux,QString& buffer);
+	static KviKvsVariant* unserializeString(const QChar** aux);
+	static KviKvsVariant* unserializeRealOrInteger(const QChar** aux);
+	static KviKvsVariant* unserializeReal(const QChar** aux,QString& data);
+	static KviKvsVariant* unserializeInteger(const QChar** aux,QString& data);
 };
 
 #include "kvi_kvs_array.h"
