@@ -1,9 +1,10 @@
+//=============================================================================
 //
 //   File : kvi_mexlinkfilter.cpp
 //   Creation date : Wed Apr 11 2003 03:07 by Szymon Stefanek
 //
 //   This file is part of the KVirc irc client distribution
-//   Copyright (C) 2003 Szymon Stefanek (pragma at kvirc dot net)
+//   Copyright (C) 2003-2006 Szymon Stefanek (pragma at kvirc dot net)
 //
 //   This program is FREE software. You can redistribute it and/or
 //   modify it under the terms of the GNU General Public License
@@ -19,12 +20,13 @@
 //   along with this program. If not, write to the Free Software Foundation,
 //   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 //
+//=============================================================================
 
 #define __KVIRC__
 #include "kvi_mexlinkfilter.h"
 
-KviMexLinkFilter::KviMexLinkFilter(KviIrcLink * l,KviModuleExtensionDescriptor * d)
-: KviIrcSocket(l) , KviModuleExtension(d)
+KviMexLinkFilter::KviMexLinkFilter(KviModuleExtensionDescriptor * d)
+: QObject(), KviModuleExtension(d)
 {
 }
 
