@@ -27,14 +27,14 @@
 
 #include "kvi_settings.h"
 #include "kvi_string.h"
-#include "kvi_command.h"
+//#include "kvi_command.h"
 #include "kvi_parameterlist.h"
 #include "kvi_library.h"
-#include "kvi_list.h"
+#include "kvi_pointerlist.h"
 #include "kvi_moduleextension.h"
 #include "kvi_kvs_moduleinterface.h"
 
-#include <qasciidict.h>
+#include "kvi_pointerhashtable.h"
 
 #ifdef COMPILE_CRYPT_SUPPORT
 	#include "kvi_crypt.h"
@@ -127,20 +127,22 @@ typedef struct _KviModuleInfo
 	
 
 // old type parsing procedures
+/*
 typedef bool (*KviModuleCommandParseProc)(KviModule *,KviCommand *);
 typedef bool (*KviModuleFunctionParseProc)(KviModule *,KviCommand *,KviParameterList *,KviStr &);
 typedef bool (*KviModuleEventParseProc)(KviModule *,KviWindow *,KviParameterList *);
-
+*/
 
 
 class KVIRC_API KviModule : public KviKvsModuleInterface
 {
-	friend class QAsciiDict<KviModule>;
+	friend class KviPointerHashTable<const char *,KviModule>;
 	friend class KviModuleManager;
 	friend class KviUserParser;
 protected:
 	KviModule(kvi_library_t handle,KviModuleInfo * info,const char * name,const char * filename);
-	~KviModule();
+public:
+	~KviModule(); // must be public for KviPointerList
 private:
 	KviStr                                     m_szName;
 	KviStr                                     m_szFileName;
