@@ -43,7 +43,7 @@ KviModuleManager * g_pModuleManager = 0;
 
 KviModuleManager::KviModuleManager()
 {
-	m_pModuleDict = new QAsciiDict<KviModule>(17,false);
+	m_pModuleDict = new KviPointerHashTable<const char *,KviModule>(17,false);
 	m_pModuleDict->setAutoDelete(false);
 
 	m_pCleanupTimer = new QTimer(this);
@@ -85,7 +85,7 @@ void KviModuleManager::loadModulesByCaps(const char * caps)
 	loadModulesByCaps(caps,szDir.ptr());
 }
 
-void KviModuleManager::completeModuleNames(const QString &path,const QString &word,KviPtrList<QString> * matches)
+void KviModuleManager::completeModuleNames(const QString &path,const QString &word,KviPointerList<QString> * matches)
 {
 	QDir d(path);
 #ifdef COMPILE_ON_WINDOWS
@@ -112,7 +112,7 @@ void KviModuleManager::completeModuleNames(const QString &path,const QString &wo
 	}
 }
 
-void KviModuleManager::completeModuleNames(const QString &word,KviPtrList<QString> * matches)
+void KviModuleManager::completeModuleNames(const QString &word,KviPointerList<QString> * matches)
 {
 	QString szDir;
 	// FIXME: Should check for duplicate names here!
@@ -134,13 +134,14 @@ KviModule * KviModuleManager::getModule(const char * modName)
 	KviModule * m = m_pModuleDict->find(modName);
 	if(!m)
 	{
-		loadModule(modName);
+		if(!loadModule(modName)) return 0;
 		m = m_pModuleDict->find(modName);
 	}
 	if(m)m->updateAccessTime();
 	return m;
 }
 
+/*
 static bool default_module_cmd_load(KviModule *,KviCommand *)
 {
 	return true;
@@ -151,6 +152,7 @@ static bool default_module_cmd_unload(KviModule *m,KviCommand *)
 	g_pModuleManager->unloadModule(m->name());
 	return true;
 }
+*/
 
 bool KviModuleManager::loadModule(const char * modName)
 {
@@ -173,7 +175,8 @@ bool KviModuleManager::loadModule(const char * modName)
 	{
 		g_pApp->getGlobalKvircDirectory(tmp,KviApp::Plugins,szName);
 	}
-
+	
+	if(!KviFileUtils::fileExists(tmp)) return false;
 	kvi_library_t handle = kvi_library_open(tmp.local8Bit().data());
 	if(!handle)
 	{
@@ -307,7 +310,7 @@ bool KviModuleManager::unloadModule(KviModule * module)
 
 bool KviModuleManager::hasLockedModules()
 {
-	QAsciiDictIterator<KviModule> it(*m_pModuleDict);
+	KviPointerHashTableIterator<const char *,KviModule> it(*m_pModuleDict);
 	while(KviModule * m = it.current())
 	{
 		if(m->isLocked())return true;
@@ -319,7 +322,11 @@ bool KviModuleManager::hasLockedModules()
 
 void KviModuleManager::cleanupUnusedModules()
 {
-	QAsciiDictIterator<KviModule> it(*m_pModuleDict);
+	KviPointerHashTableIterator<const char *,KviModule> it(*m_pModuleDict);
+
+	KviPointerList<KviModule> lModulesToUnload;
+	lModulesToUnload.setAutoDelete(false);
+
 	while(it.current())
 	{
 		if(it.current()->secondsSinceLastAccess() > KVI_OPTION_UINT(KviOption_uintModuleCleanupTimeout))
@@ -327,28 +334,36 @@ void KviModuleManager::cleanupUnusedModules()
 			if(it.current()->moduleInfo()->can_unload)
 			{
 				if((it.current()->moduleInfo()->can_unload)(it.current()))
-				{
-					unloadModule(it.current());
-					continue;
-				} else {
+					lModulesToUnload.append(it.current());
+				else {
 					// the module don't want to be unloaded
 					// keep it memory for a while
 					it.current()->updateAccessTime();
 				}
 			} else {
 				if(!(it.current()->isLocked()))
-				{
-					unloadModule(it.current());
-					continue;
-				}
+					lModulesToUnload.append(it.current());
 			}
 		}
 		++it;
 	}
+	
+	for(KviModule * pModule = lModulesToUnload.first();pModule;pModule = lModulesToUnload.next())
+		unloadModule(pModule);
 }
 
 void KviModuleManager::unloadAllModules()
 {
-	QAsciiDictIterator<KviModule> it(*m_pModuleDict);
-	while(it.current())unloadModule(it.current());
+	KviPointerHashTableIterator<const char *,KviModule> it(*m_pModuleDict);
+
+	KviPointerList<KviModule> lModulesToUnload;
+	lModulesToUnload.setAutoDelete(false);
+	while(KviModule * pModule = it.current())
+	{
+		lModulesToUnload.append(pModule);
+		++it;
+	}
+
+	for(KviModule * pModule = lModulesToUnload.first();pModule;pModule = lModulesToUnload.next())
+		unloadModule(pModule);
 }
