@@ -54,6 +54,7 @@
 #include "kvi_kvs_eventtriggers.h"
 #include "kvi_kvs_script.h"
 #include "kvi_sourcesdate.h"
+#include "kvi_regusersdb.h"
 
 #include <stdlib.h>
 
@@ -463,7 +464,7 @@ void KviServerParser::encodeCtcpParameter(const char * parametr,QString &resultB
 	// This one encodes a single ctcp parameter with the simplest
 	// subset of rules and places it in the supplied buffer
 	//
-	QCString buffer;
+	KviQCString buffer;
 	register const char* param=parametr;
 	if(!param)
 	{
@@ -579,7 +580,7 @@ const char * KviServerParser::decodeCtcpEscape(const char * msg_ptr,KviStr &buff
 }
 
 
-const char * KviServerParser::decodeCtcpEscape(const char * msg_ptr,QCString &buffer)
+const char * KviServerParser::decodeCtcpEscape(const char * msg_ptr,KviQCString &buffer)
 {
 	//
 	// This one decodes an octal sequence
@@ -728,7 +729,7 @@ const char * KviServerParser::extractCtcpParameter(const char * p_msg_ptr,QStrin
 	// based CTCP message.
 	//
     
-	QCString buffer;
+	KviQCString buffer;
 	register const char* msg_ptr=p_msg_ptr;
 	int bInString = 0;
 	if(!msg_ptr) return 0;
@@ -810,6 +811,44 @@ void KviServerParser::parseCtcpRequest(KviCtcpMessage *msg)
 {
 	msg->pData = extractCtcpParameter(msg->pData,msg->szTag);
 
+	bool bDCCRequest = msg->szTag == "DCC" || msg->szTag == "XDCC" || msg->szTag == "TDCC";
+
+	bool bAction = (msg->szTag == "ACTION");
+
+	if (bDCCRequest)
+	{
+		if (KVI_OPTION_BOOL(KviOption_boolIgnoreCtcpDcc))
+		{
+			msg->msg->console()->output(KVI_OUT_IGNORE,__tr2qs("Ignoring DCC from \r!nc\r%s\r [%s@\r!h\r%s\r]"),
+				KviQString::toUtf8(msg->pSource->nick()).data(),
+				KviQString::toUtf8(msg->pSource->user()).data(),
+				KviQString::toUtf8(msg->pSource->host()).data()
+				);
+			return;
+		}
+	} else {
+		KviRegisteredUser * u = msg->msg->connection()->userDataBase()->registeredUser(msg->pSource->nick(),msg->pSource->user(),msg->pSource->host());
+		//Ignore it?
+		if(u) 
+		{
+			if( (!bAction && u->isIgnoreEnabledFor(KviRegisteredUser::Ctcp)) ||
+				(bAction && u->isIgnoreEnabledFor(IS_ME(msg->msg,msg->szTarget) ? KviRegisteredUser::Query : KviRegisteredUser::Channel)) )
+			{
+				if (KVI_OPTION_BOOL(KviOption_boolVerboseIgnore))
+				{
+					msg->msg->console()->output(KVI_OUT_IGNORE,__tr2qs("Ignoring CTCP from \r!nc\r%s\r [%s@\r!h\r%s\r]"),
+						KviQString::toUtf8(msg->pSource->nick()).data(),
+						KviQString::toUtf8(msg->pSource->user()).data(),
+						KviQString::toUtf8(msg->pSource->host()).data()
+						);
+				}
+				return;
+			}
+		}
+	}
+
+	bool bCtcpVersion = KviQString::equalCI(msg->szTag,"VERSION");
+
 	for(int i=0;m_ctcpRequestParseProcTable[i].msgName;i++)
 	{
 		if(KviQString::equalCI(msg->szTag,m_ctcpRequestParseProcTable[i].msgName))
@@ -817,14 +856,18 @@ void KviServerParser::parseCtcpRequest(KviCtcpMessage *msg)
 			if(!(m_ctcpReplyParseProcTable[i].iFlags & KVI_CTCP_MESSAGE_PARSE_TRIGGERNOEVENT))
 			{
 				QString szData = msg->msg->connection()->decodeText(msg->pData);
-				if(KVS_TRIGGER_EVENT_6_HALTED(KviEvent_OnCtcpRequest, \
-					msg->msg->console(), \
-					msg->pSource->nick(), \
-					msg->pSource->user(), \
-					msg->pSource->host(), \
-					msg->szTarget, \
-					msg->szTag, \
-					szData))return;
+				//do not allow to make faked version reply
+				if(!(bCtcpVersion && KVI_OPTION_BOOL(KviOption_boolIgnoreCtcpVersion)))
+				{
+					if(KVS_TRIGGER_EVENT_6_HALTED(KviEvent_OnCtcpRequest, \
+						msg->msg->console(), \
+						msg->pSource->nick(), \
+						msg->pSource->user(), \
+						msg->pSource->host(), \
+						msg->szTarget, \
+						msg->szTag, \
+						szData) && !bCtcpVersion)return;
+				}
 			}
 			(this->*(m_ctcpRequestParseProcTable[i].proc))(msg);
 			return;
@@ -911,7 +954,7 @@ bool KviServerParser::checkCtcpFlood(KviCtcpMessage *msg)
 
 void KviServerParser::replyCtcp(KviCtcpMessage *msg,const char * data)
 {
-	QCString szNick = msg->msg->connection()->encodeText(msg->pSource->nick());
+	KviQCString szNick = msg->msg->connection()->encodeText(msg->pSource->nick());
 	msg->msg->connection()->sendFmtData("NOTICE %s :%c%s %s%c",
 		szNick.data(),0x01,msg->msg->connection()->encodeText(msg->szTag).data(),msg->msg->connection()->encodeText(data).data(),0x01);
 }
@@ -955,7 +998,10 @@ void KviServerParser::echoCtcpRequest(KviCtcpMessage *msg)
 	if(!msg->msg->haltOutput())
 	{
 		QString req = msg->szTag;
-		if(*(msg->pData))KviQString::appendFormatted(req," %s",msg->pData);
+		if(*(msg->pData)) {
+			req.append(" ");
+			req.append(msg->pData);
+		}
 
 		KviWindow * pOut = KVI_OPTION_BOOL(KviOption_boolCtcpRequestsToActiveWindow) ? msg->msg->console()->activeWindow() : msg->msg->console();
 
@@ -974,7 +1020,6 @@ void KviServerParser::echoCtcpRequest(KviCtcpMessage *msg)
 			} else bIsChannel = true;
 		}
 
-
 		QString szRequest = pOut->decodeText(req);
 		QString szTag = pOut->decodeText(msg->szTag);
 		QString szWhat = bIsChannel ? __tr2qs("Channel CTCP") : QString("CTCP");
@@ -1098,14 +1143,20 @@ void KviServerParser::parseCtcpRequestVersion(KviCtcpMessage *msg)
 		if(!KVI_OPTION_BOOL(KviOption_boolIgnoreCtcpVersion))
 		{
 			QString szVersion;
+#ifdef COMPILE_USE_QT4
+	#define QT4_TAG " (QT4) "
+#else
+	#define QT4_TAG
+#endif
+
 #ifdef COMPILE_ON_WINDOWS
-			szVersion = "KVIrc " KVI_VERSION " '" KVI_RELEASE_NAME "' " KVI_SOURCES_DATE " - build " KVI_BUILD_DATE;
+			szVersion = "KVIrc " KVI_VERSION QT4_TAG " '" KVI_RELEASE_NAME "' " KVI_SOURCES_DATE " - build " KVI_BUILD_DATE;
 			szVersion.append(QString(" - %1").arg(KviOsInfo::version()));
 #else
-			szVersion = "KVIrc " KVI_VERSION " '" KVI_RELEASE_NAME "' " KVI_SOURCES_DATE " - build " KVI_BUILD_DATE " - " KVI_BUILD_FLAGS;
+			szVersion = "KVIrc " KVI_VERSION QT4_TAG " '" KVI_RELEASE_NAME "' " KVI_SOURCES_DATE " - build " KVI_BUILD_DATE " - " KVI_BUILD_FLAGS;
 			szVersion.append(QString(" - %1 (%2)").arg(KviOsInfo::name()).arg(KviOsInfo::release()));
 #endif
-			szVersion.append(QString(" - QT Version: %1 - %2").arg(qVersion()).arg(__tr2qs("http://www.kvirc.net/")));
+			//szVersion.append(QString(" - QT Version: %1 - %2").arg(qVersion()).arg(__tr2qs("http://www.kvirc.net/")));
 			if(!KVI_OPTION_STRING(KviOption_stringCtcpVersionPostfix).isEmpty())
 			{
 				QString sz = KVI_OPTION_STRING(KviOption_stringCtcpVersionPostfix);
@@ -1430,6 +1481,15 @@ void KviServerParser::parseCtcpRequestAvatar(KviCtcpMessage *msg)
 	// AVATAR
 	if(!KVI_OPTION_BOOL(KviOption_boolIgnoreCtcpAvatar))
 	{
+		QString szGenderTag=" ";
+		if(KVI_OPTION_STRING(KviOption_stringCtcpUserInfoGender).startsWith("m",false)){
+			szGenderTag.append("M");
+		} else if(KVI_OPTION_STRING(KviOption_stringCtcpUserInfoGender).startsWith("f",false)){
+			szGenderTag.append("F");
+		} else {
+			szGenderTag.append("?");
+		}
+
 		KviAvatar * a = msg->msg->console()->currentAvatar();
 		if(a)
 		{
@@ -1462,9 +1522,10 @@ void KviServerParser::parseCtcpRequestAvatar(KviCtcpMessage *msg)
 								KVI_OPTION_UINT(KviOption_uintAvatarOfferTimeoutInSecs),&(a->name()),&(a->localPath()),&szUserMask);
 						}
 					}
-					if(o)szReply.append(QString(" %1").arg(o->fileSize()));
+					//if(o)szReply.append(QString(" %1").arg(o->fileSize()));
 				}
 				
+				szReply.append(szGenderTag);
 				replyCtcp(msg,szReply.utf8().data());
 			}
 		} else {
@@ -1485,10 +1546,11 @@ void KviServerParser::parseCtcpRequestAvatar(KviCtcpMessage *msg)
 void KviServerParser::parseCtcpReplyAvatar(KviCtcpMessage *msg)
 {
 	QString szRemoteFile;
-	QString szSize;
+	QString szGender;
 	QString decoded=msg->msg->console()->decodeText(msg->pData);
 
 	decoded = extractCtcpParameter(decoded.utf8().data(),szRemoteFile,true);
+	decoded = extractCtcpParameter(decoded.utf8().data(),szGender,true);
 	szRemoteFile.stripWhiteSpace();
 
 	bool bPrivate = IS_ME(msg->msg,msg->szTarget);
@@ -1503,6 +1565,15 @@ void KviServerParser::parseCtcpReplyAvatar(KviCtcpMessage *msg)
 	KviQString::sprintf(nickLink,"\r!n\r%Q\r",&(msg->pSource->nick()));
 
 	KviIrcUserEntry * e = msg->msg->connection()->userDataBase()->find(msg->pSource->nick());
+	if(e){
+		if( (szGender=="m") || (szGender=="M") ) {
+			e->setGender(KviIrcUserEntry::Male);
+		} else if((szGender=="f") || (szGender=="F") ) {
+			e->setGender(KviIrcUserEntry::Female);
+		} else {
+			e->setGender(KviIrcUserEntry::Unknown);
+		}
+	}
 
 	QString szWhere = bPrivate ? __tr2qs("private") : __tr2qs("channel notification:");
 	QString szWhat = bPrivate ? __tr2qs("notification") : msg->szTarget;
@@ -1551,7 +1622,9 @@ void KviServerParser::parseCtcpReplyAvatar(KviCtcpMessage *msg)
 					QString szCommand = "http.get -w=nm ";
 					unsigned int uMaxSize = KVI_OPTION_UINT(KviOption_uintMaximumRequestedAvatarSize);
 					if(uMaxSize > 0)KviQString::appendFormatted(szCommand,"-m=%u ",uMaxSize);
-					szCommand += szRemoteFile;
+					szRemoteFile = szRemoteFile.replace(";","%3B");
+					szRemoteFile = szRemoteFile.replace("\"","%22");
+					szCommand += "\""+szRemoteFile+"\"";
 					szCommand += " \"";
 					szCommand += szLocalFilePath.ptr();
 					szCommand += "\"";
@@ -1632,9 +1705,25 @@ void KviServerParser::parseCtcpRequestDcc(KviCtcpMessage *msg)
 	p.bIpV6       = msg->msg->console()->isIpV6Connection();
 	p.pConsole    = msg->msg->console();
 
-	KviStr nickBuffer,hostBuffer;
+	KviRegisteredUser * u = msg->msg->connection()->userDataBase()->registeredUser(msg->pSource->nick(),msg->pSource->user(),msg->pSource->host());
 
-	if(KVI_OPTION_BOOL(KviOption_boolIgnoreCtcpDcc))
+	if (u)
+	{
+		if (u->isIgnoreEnabledFor(KviRegisteredUser::Dcc))
+		{
+			if (KVI_OPTION_BOOL(KviOption_boolVerboseIgnore))
+			{
+				msg->msg->console()->output(KVI_OUT_DCCREQUEST,
+					__tr2qs("Ignoring DCC %S request from \r!n\r%Q\r [%Q@\r!h\r%Q\r] (%Q %S)"),
+					&p.szType,&(msg->pSource->nick()),
+					&(msg->pSource->user()),&(msg->pSource->host()),
+					&msg->szTag,&aux);
+			}
+			return;
+		}
+	}
+
+	/*if(KVI_OPTION_BOOL(KviOption_boolIgnoreCtcpDcc))
 	{
 		if(!msg->msg->haltOutput())
 		{
@@ -1645,7 +1734,7 @@ void KviServerParser::parseCtcpRequestDcc(KviCtcpMessage *msg)
 				&msg->szTag,&aux);
 		}
 		return;
-	}
+	}*/
 
 	bool bIsFlood = checkCtcpFlood(msg);
 
@@ -1695,6 +1784,49 @@ void KviServerParser::parseCtcpRequestDcc(KviCtcpMessage *msg)
 	}
 }
 
+void KviServerParser::parseCtcpReplyUserinfo(KviCtcpMessage *msg)
+{
+	QString szRemoteFile;
+	QString szGender;
+	QString decoded=msg->msg->console()->decodeText(msg->pData);
+	
+	bool bNeedToUpdateUserlist = false;
+	KviIrcUserEntry * e = msg->msg->connection()->userDataBase()->find(msg->pSource->nick());
+	if(e)
+	{
+		int pos = decoded.find("Gender=",0,false);	
+		
+		if(pos>=0)
+		{
+			QChar c = decoded[pos+7];
+			switch(c.unicode())
+			{
+				case 'F':
+				case 'f':
+					bNeedToUpdateUserlist = true;
+					e->setGender(KviIrcUserEntry::Female);
+					break;
+				case 'M':
+				case 'm':
+					bNeedToUpdateUserlist = true;
+					e->setGender(KviIrcUserEntry::Male);
+					break;
+			}
+		}
+	}
+
+	if(bNeedToUpdateUserlist)
+	{
+		if(KviQString::equalCS(g_pActiveWindow->className(),QString("KviChannel")))
+		{
+			((KviChannel*)g_pActiveWindow)->userListView()->updateArea();
+		}
+		
+	}
+
+	echoCtcpReply(msg);
+}
+
 void KviServerParser::parseCtcpReplyGeneric(KviCtcpMessage *msg)
 {
 	echoCtcpReply(msg);
