@@ -57,6 +57,7 @@
 #include "kvi_lagmeter.h"
 #include "kvi_ircserver.h"
 #include "kvi_kvs_eventtriggers.h"
+#include "kvi_qcstring.h"
 
 #include "kvi_settings.h"
 
@@ -71,9 +72,6 @@
 //#include "kvi_iconmanager.h"
 #include <qdatetime.h>
 
-// kvi_app.cpp
-extern KviRegisteredUserDataBase * g_pRegisteredUserDataBase;
-
 extern KviNickServRuleSet * g_pNickServRuleSet;
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -182,13 +180,13 @@ void KviServerParser::parseLiteralJoin(KviIrcMessage *msg)
 	// nick!user@host JOIN :#channel\x07[o|v]
 	const QChar * pExt = KviQString::nullTerminatedArray(channel);
 	char  chExtMode = 0;
-	while(*pExt && (pExt->unicode() != 0x07))pExt++;
-	if(*pExt)
+	while(pExt->unicode() && (pExt->unicode() != 0x07))pExt++;
+	if(pExt->unicode())
 	{
 		++pExt;
-		if(*pExt)
+		if(pExt->unicode())
 		{
-			chExtMode = (*pExt);
+			chExtMode = (char)pExt->unicode();
 			channel.remove(channel.length() - 2,2); // assuming that we're at the end (we should be)
 		} // else { senseless 0x07 in channel name ?
 	}
@@ -213,15 +211,7 @@ void KviServerParser::parseLiteralJoin(KviIrcMessage *msg)
 		}
 
 		int iFlags = 0;
-		switch(chExtMode)
-		{
-			case 'o': iFlags = KVI_USERFLAG_OP;        break;
-			case 'v': iFlags = KVI_USERFLAG_VOICE;     break;
-			case 'h': iFlags = KVI_USERFLAG_HALFOP;    break;
-			case 'u': iFlags = KVI_USERFLAG_USEROP;    break;
-			case 'q': iFlags = KVI_USERFLAG_CHANOWNER; break;
-			// we ignore +a totally for now
-		}
+		iFlags = msg->connection()->serverInfo()->modeFlagFromModeChar(chExtMode);
 
 		KviUserListEntry * it = chan->join(szNick,szUser,szHost,iFlags);
 		if(iFlags)chan->updateCaption();
@@ -290,15 +280,7 @@ void KviServerParser::parseLiteralJoin(KviIrcMessage *msg)
 	} else {
 		// This must be someone else...(or desync)
 		int iFlags = 0;
-		switch(chExtMode)
-		{
-			case 'o': iFlags = KVI_USERFLAG_OP;        break;
-			case 'v': iFlags = KVI_USERFLAG_VOICE;     break;
-			case 'h': iFlags = KVI_USERFLAG_HALFOP;    break;
-			case 'u': iFlags = KVI_USERFLAG_USEROP;    break;
-			case 'q': iFlags = KVI_USERFLAG_CHANOWNER; break;
-			// we ignore +a for now
-		}
+		iFlags = msg->connection()->serverInfo()->modeFlagFromModeChar(chExtMode);
 
 		KviUserListEntry * it = chan->join(szNick,szUser,szHost,iFlags);
 
@@ -619,7 +601,7 @@ void KviServerParser::parseLiteralKick(KviIrcMessage *msg)
 			msg->setHaltOutput();
 		if(!KVI_OPTION_STRING(KviOption_stringOnMeKickedSound).isEmpty()) KviKvsScript::run("snd.play $0",0,new KviKvsVariantList(new KviKvsVariant(KVI_OPTION_STRING(KviOption_stringOnMeKickedSound))));
 
-		QString szPass = chan->channelKey().ptr();
+		QString szPass = chan->channelKey();
 
 		if(KVI_OPTION_BOOL(KviOption_boolKeepChannelOpenOnKick))
 		{
@@ -649,10 +631,10 @@ void KviServerParser::parseLiteralKick(KviIrcMessage *msg)
 		{
 			if(_OUTPUT_VERBOSE)
 				console->output(KVI_OUT_SYSTEMMESSAGE,__tr2qs("Attempting to rejoin \r!c\r%Q\r..."),&szChan);
-			QCString szC = msg->connection()->encodeText(szChan);
+			KviQCString szC = msg->connection()->encodeText(szChan);
 			if(!szPass.isEmpty())
 			{
-				QCString szP = msg->connection()->encodeText(szChan);
+				KviQCString szP = msg->connection()->encodeText(szChan);
 				msg->connection()->sendFmtData("JOIN %s %s",szC.data(),szP.data());
 			} else msg->connection()->sendFmtData("JOIN %s",szC.data());
 		}
@@ -722,10 +704,13 @@ void KviServerParser::parseLiteralKick(KviIrcMessage *msg)
 						_retmsgtype = _type; \
 					break; \
 					default: /* also case KviCryptEngine::DecryptError: */ \
+					{ \
+						QString szEngineError = cinf->pEngine->lastError(); \
 						_target->output(KVI_OUT_SYSTEMERROR, \
-							__tr2qs("The following message appears to be encrypted, but the crypto engine failed to decode it: %s"), \
-							cinf->pEngine->lastError()); \
+							__tr2qs("The following message appears to be encrypted, but the crypto engine failed to decode it: %Q"), \
+							&szEngineError); \
 						_retptr = _txt + 1; _retmsgtype=_type; \
+					} \
 					break; \
 				} \
 			} else _retptr = _txt, _retmsgtype=_type; \
@@ -745,27 +730,10 @@ void KviServerParser::parseLiteralPrivmsg(KviIrcMessage *msg)
 	msg->decodeAndSplitPrefix(szNick,szUser,szHost);
 
 	QString szTarget = msg->connection()->decodeText(msg->safeParam(0));
+	QString szMsg = msg->connection()->decodeText(msg->safeTrailing());
 
 	KviConsole * console = msg->console();
-    KviRegisteredUser * u = g_pRegisteredUserDataBase->findMatchingUser(szNick,szUser,szHost);
-	// Ignore it?
-	if(u)
-	{
-		if(KVI_OPTION_BOOL(KviOption_boolEnableIgnoreOnPrivMsg))
-		{
-			if(u->getBoolProperty("ignore"))
-			{
-				if(KVI_OPTION_BOOL(KviOption_boolVerboseIgnore))
-				{
-					QString szMsg = msg->connection()->decodeText(msg->safeTrailing());
-					console->output(KVI_OUT_IGNORE,__tr2qs("Ignoring PRIVMSG from \r!nc\r%Q\r [%Q@\r!h\r%Q\r]: %Q"),
-							&szNick,&szUser,&szHost,&szMsg);
-				}
-				return;
-			}
-		}
-	}
-
+	KviRegisteredUser * u = msg->connection()->userDataBase()->registeredUser(szNick,szUser,szHost);
     //Highlight it?
 
 	// FIXME: 	#warning "DEDICATED CTCP WINDOW ?"
@@ -796,6 +764,20 @@ void KviServerParser::parseLiteralPrivmsg(KviIrcMessage *msg)
 	// Normal PRIVMSG
 	if(IS_ME(msg,szTarget))
 	{
+		//Ignore it?
+		if (u)
+		{
+			if (u->isIgnoreEnabledFor(KviRegisteredUser::Query))
+			{
+				if(KVS_TRIGGER_EVENT_5_HALTED(KviEvent_OnIgnoredMessage,msg->console(),szNick,szUser,szHost,szTarget,szMsg)) return;
+
+				if (KVI_OPTION_BOOL(KviOption_boolVerboseIgnore))
+				{
+					console->output(KVI_OUT_IGNORE,__tr2qs("Ignoring query-PRIVMSG from \r!nc\r%Q\r [%Q@\r!h\r%Q\r]: %Q"),&szNick,&szUser,&szHost,&szMsg);
+				}
+				return;
+			}
+		}
 		// FIXME: 	#warning "PROCESS MULTIMEDIA FILE REQUESTS"
 
 		//		if(g_pOptions->m_bListenToMultimediaFileRequests)
@@ -905,7 +887,12 @@ void KviServerParser::parseLiteralPrivmsg(KviIrcMessage *msg)
 				msg->setHaltOutput();
 			
 			if(!KVI_OPTION_STRING(KviOption_stringOnQueryMessageSound).isEmpty() && query!=g_pActiveWindow)
-			 	KviKvsScript::run("snd.play $0",0,new KviKvsVariantList(new KviKvsVariant(KVI_OPTION_STRING(KviOption_stringOnQueryMessageSound))));
+			{
+				// KviKvsScript does NOT take parameters ownership
+				KviKvsVariantList soundParams(new KviKvsVariant(KVI_OPTION_STRING(KviOption_stringOnQueryMessageSound)));
+			 	//KviKvsScript::run("snd.play $0",0,&soundParams); <-- we also should provide a window for the script: it's always a good idea
+				KviKvsScript::run("snd.play $0",query,&soundParams);
+			}
 			
 			// spit out the message text
 			if(!msg->haltOutput())
@@ -944,8 +931,14 @@ void KviServerParser::parseLiteralPrivmsg(KviIrcMessage *msg)
 			if(KVS_TRIGGER_EVENT_4_HALTED(KviEvent_OnQueryMessage,console,szNick,szUser,szHost,szMsgText))
 					msg->setHaltOutput();
 			
-			if(!KVI_OPTION_STRING(KviOption_stringOnQueryMessageSound).isEmpty() && query!=g_pActiveWindow)
-			 	KviKvsScript::run("snd.play $0",0,new KviKvsVariantList(new KviKvsVariant(KVI_OPTION_STRING(KviOption_stringOnQueryMessageSound))));
+			// we don't have a query here!
+			//if(!KVI_OPTION_STRING(KviOption_stringOnQueryMessageSound).isEmpty() && query!=g_pActiveWindow)
+			if(!KVI_OPTION_STRING(KviOption_stringOnQueryMessageSound).isEmpty() && console!=g_pActiveWindow)
+			{
+				// same as above
+				KviKvsVariantList soundParams(new KviKvsVariant(KVI_OPTION_STRING(KviOption_stringOnQueryMessageSound)));
+			 	KviKvsScript::run("snd.play $0",console,&soundParams);
+			}
 			// spit the message text out
 			if(!msg->haltOutput())
 			{
@@ -972,11 +965,28 @@ void KviServerParser::parseLiteralPrivmsg(KviIrcMessage *msg)
 		}
 	} else {
 		// Channel PRIVMSG
+
 		KviChannel * chan = msg->connection()->findChannel(szTarget);
 
 		QString szOriginalTarget = szTarget;
 		QString szPrefixes;
 
+		//Ignore it?
+		if(u) 
+		{
+			if(u->isIgnoreEnabledFor(KviRegisteredUser::Channel))
+			{
+				if(KVS_TRIGGER_EVENT_5_HALTED(KviEvent_OnIgnoredMessage,msg->console(),szNick,szUser,szHost,szTarget,szMsg))
+					return;
+
+				if (KVI_OPTION_BOOL(KviOption_boolVerboseIgnore))
+				{
+					console->output(KVI_OUT_IGNORE,__tr2qs("Ignoring channel-PRIVMSG from \r!nc\r%Q\r [%Q@\r!h\r%Q\r]: %Q"),&szNick,&szUser,&szHost,&szMsg);
+				}
+				return;
+			}
+		}
+
 		if(!chan)
 		{
 			// check if the channel has some leading mode prefixes 
@@ -1004,18 +1014,6 @@ void KviServerParser::parseLiteralPrivmsg(KviIrcMessage *msg)
 
 			KviStr szBuffer; const char * txtptr; int msgtype;
 			DECRYPT_IF_NEEDED(chan,msg->safeTrailing(),KVI_OUT_CHANPRIVMSG,KVI_OUT_CHANPRIVMSGCRYPTED,szBuffer,txtptr,msgtype)
-/*
-#define GATHER_STATS
-#ifdef GATHER_STATS
-			KviStr szFName(KviStr::Format,"/usr/build/encodings/chan%s.dat",chan->name());
-			FILE * f = fopen(szFName.ptr(),"a");
-			if(f)
-			{
-				fwrite(txtptr,1,strlen(txtptr),f);
-				fclose(f);
-			}
-#endif
-*/
 
 			QString szMsgText = chan->decodeText(txtptr);
 
@@ -1069,22 +1067,6 @@ void KviServerParser::parseLiteralNotice(KviIrcMessage *msg)
 		}
 	}
 
-	// Ignore it?
-	if(KVI_OPTION_BOOL(KviOption_boolEnableIgnoreOnNotice))
-	{
-		KviRegisteredUser * u = g_pRegisteredUserDataBase->findMatchingUser(szNick,szUser,szHost);
-		if(u)
-		{
-			if(u->getBoolProperty("ignore"))
-			{
-				QString szMsgText = msg->connection()->decodeText(msg->safeTrailing());
-				if(KVI_OPTION_BOOL(KviOption_boolVerboseIgnore))
-					console->output(KVI_OUT_IGNORE,__tr2qs("Ignoring NOTICE from %Q (%Q)"),&szNick,&szMsgText);
-				return;
-			}
-		}
-	}
-
 	// FIXME: "DEDICATED CTCP WINDOW ?"
 
 	KviStr * pTrailing = msg->trailingString();
@@ -1112,6 +1094,21 @@ void KviServerParser::parseLiteralNotice(KviIrcMessage *msg)
 
 	QString szTarget = msg->connection()->decodeText(msg->safeParam(0));
 
+	KviRegisteredUser * u = msg->connection()->userDataBase()->registeredUser(szNick,szUser,szHost);
+	//Ignore it?
+	if(u)
+	{
+		if(u->isIgnoreEnabledFor(KviRegisteredUser::Notice))
+		{
+			if(KVI_OPTION_BOOL(KviOption_boolVerboseIgnore))
+			{
+				QString szMsg = msg->connection()->decodeText(msg->safeTrailing());
+				console->output(KVI_OUT_IGNORE,__tr2qs("Ignoring Notice from \r!nc\r%Q\r [%Q@\r!h\r%Q\r]: %Q"),&szNick,&szUser,&szHost,&szMsg);
+			}
+			return;
+		}
+	}
+
 	// Normal NOTICE
 	if(IS_ME(msg,szTarget))
 	{
@@ -1316,7 +1313,7 @@ void KviServerParser::parseLiteralNotice(KviIrcMessage *msg)
 					}
 				}
 
-				pOut->output(KVI_OUT_QUERYNOTICE,"[NOTICE \r!n\r%Q\r]: %Q",&szNick,&szMsgText);
+				pOut->output(KVI_OUT_QUERYNOTICE,"*\r!n\r%Q\r* %Q",&szNick,&szMsgText);
 			}
 		}
 		return;
@@ -1531,6 +1528,21 @@ void KviServerParser::parseLiteralInvite(KviIrcMessage *msg)
 	QString szTarget = msg->connection()->decodeText(msg->safeParam(0));
 	QString szChannel = msg->connection()->decodeText(msg->safeParam(1));
 
+	KviConsole * console = msg->console();
+	KviRegisteredUser * u = msg->connection()->userDataBase()->registeredUser(szNick,szUser,szHost);
+	//Ignore it?
+	if(u)
+	{
+		if(u->isIgnoreEnabledFor(KviRegisteredUser::Invite))
+		{
+			if(KVI_OPTION_BOOL(KviOption_boolVerboseIgnore))
+			{
+				console->output(KVI_OUT_IGNORE,__tr2qs("Ignoring invite from \r!nc\r%Q\r [%Q@\r!h\r%Q\r]"),&szNick,&szUser,&szHost);
+			}
+			return;
+		}
+	}
+
 	if(IS_ME(msg,szTarget))
 	{
 		if(KVS_TRIGGER_EVENT_4_HALTED(KviEvent_OnInvite,msg->console(),szNick,szUser,szHost,szChannel))
@@ -1587,6 +1599,11 @@ void KviServerParser::parseUserMode(KviIrcMessage *msg,const char * modeflptr)
 			default:
 				if(msg->connection()->changeUserMode(*modeflptr,bSet))
 				{
+					if(msg->connection()->serverInfo()->registerModeChar()==*modeflptr)
+					{
+						KviKvsVariantList vList;
+						KviKvsEventManager::instance()->trigger(KviEvent_OnNickServAuth,msg->console(),&vList);
+					}
 					// There was a mode change
 					if(KviKvsEventManager::instance()->hasAppHandlers(KviEvent_OnUserMode))
 					{
@@ -1744,22 +1761,34 @@ void KviServerParser::parseChannelMode(const QString &szNick,const QString &szUs
 
 #define CHANUSER_MODE(__modechar,__chanfunc,__evmeset,__evmeunset,__evset,__evunset,__icomeset,__icomeunset,__icoset,__icounset) \
 			case __modechar: \
-				aParam = msg->connection()->decodeText(msg->safeParam(curParam++)); \
-				chan->__chanfunc(aParam,bSet); \
-				bIsMe = IS_ME(msg,aParam); \
-				if(bIsMe) \
+				if(msg->connection()->serverInfo()->isSupportedModeFlag(__modechar)) \
 				{ \
-					if(KVS_TRIGGER_EVENT_3_HALTED(bSet ? __evmeset : __evmeunset,chan,szNick,szUser,szHost))msg->setHaltOutput(); \
-					chan->updateCaption(); \
-				} else { \
-					if(KVS_TRIGGER_EVENT_4_HALTED(bSet ? __evset : __evunset,chan,szNick,szUser,szHost,aParam))msg->setHaltOutput(); \
-				} \
-				if(!(msg->haltOutput() || KVI_OPTION_BOOL(KviOption_boolShowCompactModeChanges))) \
-				{ \
-					chan->output(bSet ? (bIsMe ? __icomeset : __icoset) : (bIsMe ? __icomeunset : __icounset), \
-						__tr2qs("%Q [%Q@%Q] has set mode %c%c \r!n\r%Q\r"), \
-						&nickBuffer,&szUser,&hostBuffer,bSet ? '+' : '-',__modechar,&aParam); \
-				} \
+					aParam = msg->connection()->decodeText(msg->safeParam(curParam++)); \
+					chan->__chanfunc(aParam,bSet); \
+					bIsMe = IS_ME(msg,aParam); \
+					if(bIsMe) \
+					{ \
+						if(KVS_TRIGGER_EVENT_3_HALTED(bSet ? __evmeset : __evmeunset,chan,szNick,szUser,szHost))msg->setHaltOutput(); \
+						chan->updateCaption(); \
+					} else { \
+						if(KVS_TRIGGER_EVENT_4_HALTED(bSet ? __evset : __evunset,chan,szNick,szUser,szHost,aParam))msg->setHaltOutput(); \
+					} \
+					if(!(msg->haltOutput() || KVI_OPTION_BOOL(KviOption_boolShowCompactModeChanges))) \
+					{ \
+						chan->output(bSet ? (bIsMe ? __icomeset : __icoset) : (bIsMe ? __icomeunset : __icounset), \
+							__tr2qs("%Q [%Q@%Q] has set mode %c%c \r!n\r%Q\r"), \
+							&nickBuffer,&szUser,&hostBuffer,bSet ? '+' : '-',__modechar,&aParam); \
+					} \
+				} else {\
+					chan->setChannelMode(__modechar,bSet);\
+					if(!(msg->haltOutput() || KVI_OPTION_BOOL(KviOption_boolShowCompactModeChanges)))\
+					{\
+						chan->output(KVI_OUT_CHANMODE,\
+							__tr2qs("%Q [%Q@%Q] has set channel \r!m%c%c\rmode %c%c\r"),\
+							&nickBuffer,&szUser,&hostBuffer,\
+							bSet ? '-' : '+',__modechar,bSet ? '+' : '-',__modechar);\
+					}\
+				}\
 			break;
 			CHANUSER_MODE('q',setChanOwner,KviEvent_OnMeChanOwner,KviEvent_OnMeDeChanOwner,KviEvent_OnChanOwner,KviEvent_OnDeChanOwner,KVI_OUT_MECHANOWNER,KVI_OUT_MEDECHANOWNER,KVI_OUT_CHANOWNER,KVI_OUT_DECHANOWNER)
 			CHANUSER_MODE('a',setChanAdmin,KviEvent_OnMeChanAdmin,KviEvent_OnMeDeChanAdmin,KviEvent_OnChanAdmin,KviEvent_OnDeChanAdmin,KVI_OUT_MECHANADMIN,KVI_OUT_MEDECHANADMIN,KVI_OUT_CHANADMIN,KVI_OUT_DECHANADMIN)
