@@ -4,7 +4,7 @@
 //   Creation date : Thu Aug 3 2000 01:30:45 by Szymon Stefanek
 //
 //   This file is part of the KVirc irc client distribution
-//   Copyright (C) 1999-2004 Szymon Stefanek (pragma at kvirc dot net)
+//   Copyright (C) 1999-2007 Szymon Stefanek (pragma at kvirc dot net)
 //
 //   This program is FREE software. You can redistribute it and/or
 //   modify it under the terms of the GNU General Public License
@@ -49,6 +49,7 @@
 #include "kvi_ircconnectiontarget.h"
 #include "kvi_time.h"
 #include "kvi_lagmeter.h"
+#include "kvi_qcstring.h"
 
 #include <qpixmap.h>
 #include <qdatetime.h>
@@ -84,7 +85,7 @@ void KviServerParser::parseNumeric001(KviIrcMessage *msg)
 	if(msg->connection()->context()->state() != KviIrcContext::Connected)
 		msg->connection()->loginComplete(msg->connection()->decodeText(msg->param(0)));
 	if(!msg->haltOutput())
-		msg->console()->output(KVI_OUT_SERVERINFO,szText);
+		msg->console()->outputNoFmt(KVI_OUT_SERVERINFO,szText);
 }
 
 void KviServerParser::parseNumeric002(KviIrcMessage *msg)
@@ -93,7 +94,7 @@ void KviServerParser::parseNumeric002(KviIrcMessage *msg)
 	// :prefix 002 target :Your host is <server name>, running version <server version>
 	if(msg->connection()->context()->state() != KviIrcContext::Connected)
 		msg->connection()->loginComplete(msg->connection()->decodeText(msg->param(0)));
-	if(!msg->haltOutput())msg->console()->output(KVI_OUT_SERVERINFO,msg->connection()->decodeText(msg->safeTrailing()));
+	if(!msg->haltOutput())msg->console()->outputNoFmt(KVI_OUT_SERVERINFO,msg->connection()->decodeText(msg->safeTrailing()));
 }
 
 void KviServerParser::parseNumeric003(KviIrcMessage *msg)
@@ -102,47 +103,7 @@ void KviServerParser::parseNumeric003(KviIrcMessage *msg)
 	// :prefix 003 target :This server was created <date>
 	if(msg->connection()->context()->state() != KviIrcContext::Connected)
 		msg->connection()->loginComplete(msg->connection()->decodeText(msg->param(0)));
-	if(!msg->haltOutput())msg->console()->output(KVI_OUT_SERVERINFO,msg->connection()->decodeText(msg->safeTrailing()));
-}
-
-const QString & getChannelModeDescription(char c)
-{
-	switch(c)
-	{
-		case 'o': return __tr2qs("Channel operators"); break;
-		case 'v': return __tr2qs("Voiced users"); break;
-		case 'h': return __tr2qs("Half-operators");
-		case 'b': return __tr2qs("Ban masks"); break;
-		case 'c': return __tr2qs("Color free (no ANSI colors)"); break;
-		case 'e': return __tr2qs("Ban exception masks"); break;
-		case 'I': return __tr2qs("Invite exception masks or forbid /INVITE"); break;
-		case 's': return __tr2qs("Secret"); break;
-		case 'p': return __tr2qs("Private"); break;
-		case 't': return __tr2qs("Topic change restricted"); break;
-		case 'i': return __tr2qs("Invite only"); break;
-		case 'n': return __tr2qs("No external messages"); break;
-		case 'a': return __tr2qs("Anonymous or protected user"); break;
-		case 'q': return __tr2qs("Quiet or channel owner"); break;
-		case 'l': return __tr2qs("Limited number of users"); break;
-		case 'k': return __tr2qs("Key"); break;
-		case 'm': return __tr2qs("Moderated"); break;
-		case 'r': return __tr2qs("Registered"); break;
-		case 'G': return __tr2qs("Censor swear words"); break;
-		case 'M': return __tr2qs("Impossible to speak and change nick if not authenticated with NickServ"); break;
-		case 'N': return __tr2qs("Impossible to change nick if not authenticated with NickServ"); break;
-		case 'R': return __tr2qs("Only registered nicks can join"); break;
-		case 'Q': return __tr2qs("No kicks able (unless U-Line)"); break;
-		case 'O': return __tr2qs("IRC-Op only channel"); break;
-		case 'A': return __tr2qs("Server/Network/Tech Admin only channel"); break;
-		case 'K': return __tr2qs("Forbid /KNOCK"); break;
-		case 'S': return __tr2qs("Strip colors"); break;
-		case 'L': return __tr2qs("Redirect on channel full"); break;
-		case 'C': return __tr2qs("Forbid channel CTCPs"); break;
-		case 'u': return __tr2qs("User-operators OR Auditorium: /NAMES and /WHO show only ops"); break;
-		case '7': return __tr2qs("Only 7-bit letters in nicknames allowed"); break;
-		case 'x': return __tr2qs("Impossible to use both 7-bit and 8-bit letters in nicknames"); break;
-		default: return __tr2qs("Unknown channel mode"); break;
-	}
+	if(!msg->haltOutput())msg->console()->outputNoFmt(KVI_OUT_SERVERINFO,msg->connection()->decodeText(msg->safeTrailing()));
 }
 
 void KviServerParser::parseNumeric004(KviIrcMessage *msg)
@@ -158,6 +119,7 @@ void KviServerParser::parseNumeric004(KviIrcMessage *msg)
 	if(uParams < 2)uParams = 2;
 
 	KviStr version   = msg->safeParam(2);
+	msg->connection()->serverInfo()->setServerVersion(msg->safeParam(2));
 	
 	KviStr umodes;
 	// skip version number (great, thanks WEBMASTER INCORPORATED -_-)
@@ -201,24 +163,13 @@ void KviServerParser::parseNumeric004(KviIrcMessage *msg)
 
 		while(*aux)
 		{
-			switch(*aux)
+			tmp = msg->connection()->serverInfo()->getUserModeDescription(*aux);
+			if(tmp.isEmpty())
 			{
-				case 'o': tmp = __tr2qs("o: IRC operator (OPER)"); break;
-				case 'O': tmp = __tr2qs("O: Local IRC operator (LOCOP)"); break;
-				case 'i': tmp = __tr2qs("i: Invisible"); break;
-				case 'w': tmp = __tr2qs("w: Recipient for WALLOPS messages"); break;
-				case 'r': tmp = __tr2qs("r: User with restricted connection (or recipient for messages about rejected bots)"); break;
- 				case 's': tmp = __tr2qs("s: Recipient for server notices"); break;
-				case 'z': tmp = __tr2qs("z: Recipient for oper wallop messages"); break;
-				case 'c': tmp = __tr2qs("c: Recipient for cconn messages"); break;
-				case 'k': tmp = __tr2qs("k: Recipient for server kill messages"); break;
-				case 'f': tmp = __tr2qs("f: Recipient for full server notices"); break;
-				case 'y': tmp = __tr2qs("y: Spy :)"); break;
-				case 'd': tmp = __tr2qs("d: Obscure 'DEBUG' flag"); break;
-				case 'n': tmp = __tr2qs("n: Recipient for nick changes"); break;
-				default: tmp = __tr2qs(": Unknown user mode"); tmp.prepend(*aux); break;
+				QString tmp2 = __tr2qs(": Unknown user mode");
+				KviQString::sprintf(tmp,"%c: %Q",*aux,&tmp2);
 			}
-
+			
 			msg->console()->outputNoFmt(KVI_OUT_SERVERINFO,tmp);
 			aux++;
 		}
@@ -227,14 +178,11 @@ void KviServerParser::parseNumeric004(KviIrcMessage *msg)
 
 		aux = chanmodes.ptr();
 
-		if(!_OUTPUT_MUTE)
+		while(*aux)
 		{
-			while(*aux)
-			{
-				KviQString::sprintf(tmp,"%c: %Q",*aux,&(getChannelModeDescription(*aux)));
-				msg->console()->outputNoFmt(KVI_OUT_SERVERINFO,tmp);
-				aux++;
-			}
+			KviQString::sprintf(tmp,"%c: %Q",*aux,&(msg->connection()->serverInfo()->getChannelModeDescription(*aux)));
+			msg->console()->outputNoFmt(KVI_OUT_SERVERINFO,tmp);
+			aux++;
 		}
 	}
 
@@ -261,6 +209,9 @@ void KviServerParser::parseNumeric005(KviIrcMessage *msg)
 	if(msg->connection()->context()->state() != KviIrcContext::Connected)
 		msg->connection()->loginComplete(msg->connection()->decodeText(msg->param(0)));
 
+	bool bUhNames = false;
+	bool bNamesx = false;
+
 	unsigned int count = msg->paramCount();
 	if(count > 2)
 	{
@@ -278,8 +229,7 @@ void KviServerParser::parseNumeric005(KviIrcMessage *msg)
 				KviStr szModePrefixes = p;
 				if(szModePrefixes.hasData() && (szModePrefixes.len() == szModeFlags.len()))
 				{
-					msg->connection()->serverInfo()->setSupportedModePrefixes(szModePrefixes.ptr());
-					msg->connection()->serverInfo()->setSupportedModeFlags(szModeFlags.ptr());
+					msg->connection()->serverInfo()->setSupportedModePrefixes(szModePrefixes.ptr(),szModeFlags.ptr());
 				}
 			} else if(kvi_strEqualCIN("CHANTYPES=",p,10))
 			{
@@ -314,12 +264,13 @@ void KviServerParser::parseNumeric005(KviIrcMessage *msg)
 			} else if(kvi_strEqualCI("CODEPAGES",p))
 			{
 				msg->connection()->serverInfo()->setSupportsCodePages(true);
-				// FIXME: we could TRY to set the codepage that the user selected here!
-				//        ... or even utf8!
 				if((!_OUTPUT_MUTE) && (!msg->haltOutput()) && KVI_OPTION_BOOL(KviOption_boolShowExtendedServerInfo))
 				{
 					msg->console()->outputNoFmt(KVI_OUT_SERVERINFO,__tr2qs("This server supports the CODEPAGE command, it will be used"));
 				}
+
+				//msg->connection()->sendFmtData("CODEPAGE %s",msg->console()->textCodec()->name());
+
 			} else if(kvi_strEqualCIN("CHANMODES=",p,10))
 			{
 				p+=10;
@@ -333,9 +284,30 @@ void KviServerParser::parseNumeric005(KviIrcMessage *msg)
 				int num=tmp.toUInt(&bok);
 				if(bok)
 					msg->connection()->serverInfo()->setMaxModeChanges(num);
-			}/* else if(kvi_strEqualCIN("CAPAB",p,5))
+			} else if(kvi_strEqualCIN("NAMESX",p,6))
 			{
-			}*/
+				p+=6;
+				bNamesx=true;
+			} else if(kvi_strEqualCIN("UHNAMES",p,7))
+			{
+				p+=7;
+				bUhNames=true;
+			}else if(kvi_strEqualCIN("CHARSET=",p,8))
+			{
+				p+=8;
+				QString tmp = p;
+				msg->connection()->serverInfo()->setSupportsCodePages(true);
+
+				if((!_OUTPUT_MUTE) && (!msg->haltOutput()) && KVI_OPTION_BOOL(KviOption_boolShowExtendedServerInfo))
+				{
+					msg->console()->outputNoFmt(KVI_OUT_SERVERINFO,__tr2qs("This server supports the CODEPAGE command, it will be used"));
+				}
+
+				/*if( tmp.contains(msg->console()->textCodec()->name(),false) || tmp.contains("*",false) )
+				{
+					msg->connection()->sendFmtData("CODEPAGE %s",msg->console()->textCodec()->name());
+				}*/
+			}
 		}
 		if((!_OUTPUT_MUTE) && (!msg->haltOutput()))
 		{
@@ -345,6 +317,9 @@ void KviServerParser::parseNumeric005(KviIrcMessage *msg)
 			while(*aux == ' ')aux++;
 			if(*aux == ':')aux++;
 			if(!msg->haltOutput())msg->console()->output(KVI_OUT_SERVERINFO,__tr2qs("This server supports: %s"),msg->connection()->decodeText(aux).utf8().data());
+			if(bNamesx || bUhNames) {
+				msg->connection()->sendFmtData("PROTOCTL %s %s",bNamesx ? "NAMESX" : "", bUhNames ? "UHNAMES" : "");
+			}
 		}
 	} else {
 		QString inf = msg->connection()->decodeText(msg->safeTrailing());
@@ -410,7 +385,7 @@ void KviServerParser::parseNumeric020(KviIrcMessage *msg)
 	{
 		QString szWText = msg->console()->decodeText(msg->safeTrailing());
 		msg->console()->output(
-			KVI_OUT_CONNECTION,__tr2qs("%c\r!s\r%s\r%c: %Q"),KVI_TEXT_BOLD,
+			KVI_OUT_CONNECTION,"%c\r!s\r%s\r%c: %Q",KVI_TEXT_BOLD,
 			msg->safePrefix(),KVI_TEXT_BOLD,&szWText);
 	}
 }
@@ -423,7 +398,7 @@ void KviServerParser::parseNumericNames(KviIrcMessage *msg)
 	// [=|*|@] is the type of the channel:
 	// = --> public  * --> private   @ --> secret
 	// ...but we ignore it
-	//QString szChan = msg->connection()->decodeText(msg->cSafeParam(2)->data()); // <-- QCString::data() is implicitly unsafe: it CAN return 0
+	//QString szChan = msg->connection()->decodeText(msg->cSafeParam(2)->data()); // <-- KviQCString::data() is implicitly unsafe: it CAN return 0
 	QString szChan = msg->connection()->decodeText(msg->safeParam(2));
 	KviChannel * chan = msg->connection()->findChannel(szChan);
 	// and run to the first nickname
@@ -445,49 +420,34 @@ void KviServerParser::parseNumericNames(KviIrcMessage *msg)
 		int iPrevFlags = chan->myFlags();
 
 		KviIrcConnectionServerInfo * pServerInfo = msg->connection()->serverInfo();
-
+		
 		while(*aux)
 		{
 			int iFlags = 0;
 			// @ = op (+o), + = voiced (+v), % = halfop (+h), - = userop (+u), ^ = protected (+a?), * = chan owner (+q), !, & = channel admin (+a?)
 			// ^  +a is a weird mode: it also breaks nicknames on some networks!
-			// not a valid first char of nickname, must be a mode prefix
+			// not a valid first char(s) of nickname, must be a mode prefix
 			
 			bool bContinue = true;
-			while(bContinue)
+
+			while(pServerInfo->isSupportedModePrefix((unsigned char)(*aux)))
 			{
-				if(pServerInfo->isSupportedModePrefix((unsigned char)(*aux)))
-				{
-					// leading umode flag
-					switch(*aux)
-					{
-						case '@': iFlags |= KVI_USERFLAG_OP; aux++;         break;
-						case '+': iFlags |= KVI_USERFLAG_VOICE; aux++;      break;
-						case '%': iFlags |= KVI_USERFLAG_HALFOP; aux++;     break;
-						case '!':
-						case '.': // PTLink +a mode
-						case '&': iFlags |= KVI_USERFLAG_CHANADMIN; aux++;  break;
-						case '-': iFlags |= KVI_USERFLAG_USEROP; aux++;     break;
-						case '~':
-						case '*': iFlags |= KVI_USERFLAG_CHANOWNER; aux++;  break;
-						// For now we ignore protected and chan owner
-						default:
-							// unhandled flag , but still a flag...
-							aux++;
-						break;
-					}
-				} else {
-					bContinue = false;
-				}
+				// leading umode flag(s)
+				iFlags |= pServerInfo->modeFlagFromPrefixChar(*aux);
+				aux++;
 			}
 			
 			char * begin = aux;
 			while(*aux && (*aux != ' '))aux++;
 			char save = *aux;
 			*aux = 0;
-			QString szNick = msg->connection()->decodeText(begin);
+			// NAMESX + UHNAMES support
+			KviIrcMask mask(msg->connection()->decodeText(begin));
 			// and make it join
-			if(!szNick.isEmpty())chan->join(szNick,QString::null,QString::null,iFlags);
+			if(!mask.nick().isEmpty())chan->join(mask.nick(),
+				mask.hasUser() ? mask.user() : QString::null,
+				mask.hasHost() ? mask.host() : QString::null,
+					iFlags);
 			*aux = ' ';
 			*aux = save;
 			// run to the next nick (or the end)
@@ -799,6 +759,7 @@ void KviServerParser::parseNumericEndOfWho(KviIrcMessage *msg)
 	KviChannel * chan = msg->connection()->findChannel(szChan);
 	if(chan)
 	{
+		chan->userListView()->updateArea();
 		kvi_time_t tNow = kvi_unixTime();
 		msg->connection()->stateData()->setLastReceivedChannelWhoReply(tNow);
 		chan->setLastReceivedWhoReply(tNow);
@@ -911,7 +872,7 @@ void KviServerParser::parseLoginNicknameProblem(KviIrcMessage *msg)
 				&szActual,msg->numeric(),&szWText,&nextNick);
 	}
 
-	QCString d = msg->connection()->encodeText(nextNick);
+	KviQCString d = msg->connection()->encodeText(nextNick);
 	msg->connection()->sendFmtData("NICK %s",d.data());
 }
 
@@ -952,6 +913,8 @@ void KviServerParser::parseNumericCantJoinChannel(KviIrcMessage *msg)
 	}
 }
 
+// Keep the source ordered: this should be named "parseOtherChannelError"
+
 void KviServerParser::otherChannelError(KviIrcMessage *msg)
 {
 	// 482: ERR_CHANOPRIVSNEEDED
@@ -969,7 +932,7 @@ void KviServerParser::otherChannelError(KviIrcMessage *msg)
 	}
 }
 
-void KviServerParser::commandSyntaxHelp(KviIrcMessage *msg)
+void KviServerParser::parseCommandSyntaxHelp(KviIrcMessage *msg)
 {
 	// 704 RPL_COMMANDSYNTAX
 	// :prefix 704 <target> <command> :text
@@ -979,11 +942,11 @@ void KviServerParser::commandSyntaxHelp(KviIrcMessage *msg)
 		QString szCommand = msg->connection()->decodeText(msg->safeParam(1));
 		QString szWText = msg->connection()->decodeText(msg->safeTrailing());
 		pOut->output(KVI_OUT_HELP,
-			"Синатксис команды %Q: %Q",&szCommand,&szWText);
+			__tr2qs("Command syntax %Q: %Q"),&szCommand,&szWText); // Pragma: wheee..... that should be in english :D
 	}
 }
 
-void KviServerParser::commandHelp(KviIrcMessage *msg)
+void KviServerParser::parseCommandHelp(KviIrcMessage *msg)
 {
 	// 705 RPL_COMMANDHELP
 	// :prefix 705 <target> <command> :text
@@ -992,12 +955,32 @@ void KviServerParser::commandHelp(KviIrcMessage *msg)
 		KviWindow * pOut = (KviWindow *)(msg->console());
 		QString szCommand = msg->connection()->decodeText(msg->safeParam(1));
 		QString szWText = msg->connection()->decodeText(msg->safeTrailing());
-		pOut->output(KVI_OUT_HELP,
-			"%Q",&szWText);
+		pOut->outputNoFmt(KVI_OUT_HELP,szWText);
 	}
 }
 
-void KviServerParser::commandEndOfHelp(KviIrcMessage *msg)
+void KviServerParser::parseChannelHelp(KviIrcMessage *msg)
+{
+	// 477 RPL_CHANNELHELP (freenode)
+	// :prefix 477 <target> <channel> :text
+	if(!msg->haltOutput())
+	{
+		QString szChan  = msg->connection()->decodeText(msg->safeParam(1));
+		QString szText = msg->connection()->decodeText(msg->safeTrailing());
+		KviWindow * pOut = msg->connection()->findChannel(szChan);
+		if(pOut)
+		{
+			pOut->output(KVI_OUT_HELP,__tr2qs("Tip: %Q"),&szText);
+		} else {
+			pOut = (KviWindow *)(msg->console());
+			pOut->output(KVI_OUT_HELP,__tr2qs("Tip for %Q: %Q"),&szChan,&szText);
+		}
+		
+	}
+}
+
+
+void KviServerParser::parseCommandEndOfHelp(KviIrcMessage *msg)
 {
 	// 704 RPL_COMMANDSYNTAX
 	// 705 RPL_COMMANDHELP
@@ -1007,7 +990,7 @@ void KviServerParser::commandEndOfHelp(KviIrcMessage *msg)
 		KviWindow * pOut = (KviWindow *)(msg->console());
 		QString szCommand = msg->connection()->decodeText(msg->safeParam(1));
 		pOut->output(KVI_OUT_HELP,
-			"Конец справки по команде %Q",&szCommand);
+			__tr2qs("End of help about %Q"),&szCommand);
 	}
 }
 
@@ -1036,6 +1019,8 @@ void KviServerParser::parseNumericNicknameProblem(KviIrcMessage *msg)
 void KviServerParser::parseNumericWhoisAway(KviIrcMessage * msg)
 {
 // FIXME: #warning "Need an icon here too: sth like KVI_OUT_WHOISSERVER, but with 'A' letter"
+	msg->connection()->stateData()->setLastReceivedWhoisReply(kvi_unixTime());
+
 	QString szNk = msg->connection()->decodeText(msg->safeParam(1));
 	KviIrcUserDataBase * db = msg->connection()->userDataBase();
 	KviIrcUserEntry * e = db->find(szNk);
@@ -1058,6 +1043,8 @@ void KviServerParser::parseNumericWhoisUser(KviIrcMessage *msg)
 {
 	// 311: RPL_WHOISUSER [I,E,U,D]
 	// :prefix 311 <target> <nick> <user> <host> * :<real_name>
+	msg->connection()->stateData()->setLastReceivedWhoisReply(kvi_unixTime());
+
 	QString szNick = msg->connection()->decodeText(msg->safeParam(1));
 	QString szUser = msg->connection()->decodeText(msg->safeParam(2));
 	QString szHost = msg->connection()->decodeText(msg->safeParam(3));
@@ -1069,6 +1056,12 @@ void KviServerParser::parseNumericWhoisUser(KviIrcMessage *msg)
 		e->setUser(szUser);
 		e->setHost(szHost);
 		e->setRealName(szReal);
+		if(e->gender()!=KviIrcUserEntry::Unknown) {
+			if(KviQString::equalCS(g_pActiveWindow->className(),QString("KviChannel")))
+			{
+				((KviChannel*)g_pActiveWindow)->userListView()->updateArea();
+			}
+		}
 		KviQuery * q = msg->connection()->findQuery(szNick);
 		if(q) q->updateLabelText();
 		if(!e->avatar())
@@ -1108,6 +1101,7 @@ void KviServerParser::parseNumericWhowasUser(KviIrcMessage * msg)
 {
 	// 314: RPL_WHOWASUSER [I,E,U,D]
 	// :prefix 314 <target> <nick> <user> <host> * :<real_name>
+
 	if(!msg->haltOutput())
 	{
 		QString szNick = msg->connection()->decodeText(msg->safeParam(1));
@@ -1133,6 +1127,8 @@ void KviServerParser::parseNumericWhoisChannels(KviIrcMessage *msg)
 	// 319: RPL_WHOISCHANNELS [I,E,U,D]
 	// :prefix 319 <target> <nick> :<channel list>
 
+	msg->connection()->stateData()->setLastReceivedWhoisReply(kvi_unixTime());
+
 	QString szNick = msg->connection()->decodeText(msg->safeParam(1));
 	QString szChans = msg->connection()->decodeText(msg->safeTrailing());
 	
@@ -1195,6 +1191,7 @@ void KviServerParser::parseNumericWhoisIdle(KviIrcMessage *msg)
 	// :prefix 317 <target> <nick> <number> <number> :seconds idle, signon time
 
 	// FIXME: #warning "and NICK LINKS"
+	msg->connection()->stateData()->setLastReceivedWhoisReply(kvi_unixTime());
 
 	QString szNick = msg->connection()->decodeText(msg->safeParam(1));
 
@@ -1250,6 +1247,7 @@ void KviServerParser::parseNumericWhoisServer(KviIrcMessage *msg)
 {
 	// 312: RPL_WHOISSERVER [I,E,U,D] (sent also in response to WHOWAS)
 	// :prefix 312 <target> <nick> <server> :<server description / last whowas date>
+	msg->connection()->stateData()->setLastReceivedWhoisReply(kvi_unixTime());
 
 	QString szNick = msg->connection()->decodeText(msg->safeParam(1));
 	QString szServ = msg->connection()->decodeText(msg->safeParam(2));
@@ -1282,6 +1280,7 @@ void KviServerParser::parseNumericWhoisAuth(KviIrcMessage *msg)
 {
 	// :prefix RPL_WHOISAUTH <target> <nick> :is authed as
 	// actually seen only on Quakenet
+	msg->connection()->stateData()->setLastReceivedWhoisReply(kvi_unixTime());
 
 	QString szNick = msg->connection()->decodeText(msg->safeParam(1));
 	QString szAuth = msg->connection()->decodeText(msg->safeParam(2));
@@ -1302,6 +1301,10 @@ void KviServerParser::parseNumericWhoisOther(KviIrcMessage *msg)
 	// :prefix * <target> <nick> :<description>
 	// used for RPL_WHOISCHANOP,RPL_WHOISADMIN,
 	// RPL_WHOISSADMIN,RPL_WHOISOPERATOR,RPL_WHOISREGNICK,RPL_WHOISSSL
+	// and all the other unrecognized codes that look really like a RPL_WHOIS*
+
+	msg->connection()->stateData()->setLastReceivedWhoisReply(kvi_unixTime());
+
 	QString szNick = msg->connection()->decodeText(msg->safeParam(1));
 	QString szOth = msg->connection()->decodeText(msg->safeTrailing());
 
@@ -1330,6 +1333,9 @@ void KviServerParser::parseNumericEndOfWhois(KviIrcMessage *msg)
 {
 	// 318: RPL_ENDOFWHOIS [I,E,U,D]
 	// :prefix 318 <target> <nick> :End of /WHOIS list
+
+	msg->connection()->stateData()->setLastReceivedWhoisReply(0);
+
 	QString szNick = msg->connection()->decodeText(msg->safeParam(1));
 
 	KviAsyncWhoisInfo * i = msg->connection()->asyncWhoisData()->lookup(szNick);
@@ -1644,7 +1650,7 @@ void KviServerParser::parseNumericBackFromAway(KviIrcMessage * msg)
 	{
 		if(_OUTPUT_PARANOIC)
 			msg->console()->output(KVI_OUT_AWAY,__tr2qs("Restoring pre-away nickname (%Q)"),&szNickBeforeAway);
-		QCString szDat = msg->connection()->encodeText(szNickBeforeAway);
+		KviQCString szDat = msg->connection()->encodeText(szNickBeforeAway);
 		msg->connection()->sendFmtData("NICK %s",szDat.data());
 	}
 
@@ -1682,7 +1688,7 @@ void KviServerParser::parseNumericAway(KviIrcMessage * msg)
 
 		if(_OUTPUT_PARANOIC)
 			msg->console()->output(KVI_OUT_AWAY,__tr2qs("Setting away nickname (%Q)"),&szNewNick);
-		QCString dat = msg->connection()->encodeText(szNewNick);
+		KviQCString dat = msg->connection()->encodeText(szNewNick);
 		msg->connection()->sendFmtData("NICK %s",dat.data());
 	}
 }
@@ -1739,16 +1745,16 @@ void KviServerParser::parseNumericStats(KviIrcMessage * msg)
 
 void KviServerParser::parseNumericServerAdminInfoTitle(KviIrcMessage * msg)
 {
-//RPL_ADMINME          256
+	//RPL_ADMINME          256
 	if(!msg->haltOutput())
 	{
 		KviWindow * pOut = (KviWindow *)(msg->console());
-			pOut->output(KVI_OUT_SERVERINFO,msg->connection()->decodeText(msg->safeTrailing()).utf8().data());
+			pOut->outputNoFmt(KVI_OUT_SERVERINFO,msg->connection()->decodeText(msg->safeTrailing()).utf8().data());
 	}
 }
 void KviServerParser::parseNumericServerAdminInfoServerName(KviIrcMessage * msg)
 {
-//RPL_ADMINLOC1        257
+	//RPL_ADMINLOC1        257
 	if(!msg->haltOutput())
 	{
 		KviWindow * pOut = (KviWindow *)(msg->console());
@@ -1759,7 +1765,7 @@ void KviServerParser::parseNumericServerAdminInfoServerName(KviIrcMessage * msg)
 
 void KviServerParser::parseNumericServerAdminInfoAdminName(KviIrcMessage * msg)
 {
-//RPL_ADMINLOC2        258
+	//RPL_ADMINLOC2        258
 	if(!msg->haltOutput())
 	{
 		KviWindow * pOut = (KviWindow *)(msg->console());
@@ -1770,7 +1776,7 @@ void KviServerParser::parseNumericServerAdminInfoAdminName(KviIrcMessage * msg)
 
 void KviServerParser::parseNumericServerAdminInfoAdminContact(KviIrcMessage * msg)
 {
-//RPL_ADMINEMAIL       259
+	//RPL_ADMINEMAIL       259
 	if(!msg->haltOutput())
 	{
 		KviWindow * pOut = (KviWindow *)(msg->console());
@@ -1781,7 +1787,7 @@ void KviServerParser::parseNumericServerAdminInfoAdminContact(KviIrcMessage * ms
 
 void KviServerParser::parseNumericCommandSyntax(KviIrcMessage * msg)
 {
-//RPL_COMMANDSYNTAX    334
+	//RPL_COMMANDSYNTAX    334
 	if(!msg->haltOutput())
 	{
 		KviWindow * pOut = (KviWindow *)(msg->console());
@@ -1791,7 +1797,7 @@ void KviServerParser::parseNumericCommandSyntax(KviIrcMessage * msg)
 
 void KviServerParser::parseNumericInviting(KviIrcMessage * msg)
 {
-//RPL_INVITING         341
+	//RPL_INVITING         341
 	if(!msg->haltOutput())
 	{
 		QString szWho = msg->connection()->decodeText(msg->safeParam(0));
@@ -1810,7 +1816,7 @@ void KviServerParser::parseNumericInviting(KviIrcMessage * msg)
 
 void KviServerParser::parseNumericInfo(KviIrcMessage * msg)
 {
-//RPL_INFO             371
+	//RPL_INFO             371
 	if(!msg->haltOutput())
 	{
 		KviWindow * pOut = (KviWindow *)(msg->console());
@@ -1821,7 +1827,7 @@ void KviServerParser::parseNumericInfo(KviIrcMessage * msg)
 
 void KviServerParser::parseNumericInfoStart(KviIrcMessage * msg)
 {
-//RPL_INFOSTART        373
+	//RPL_INFOSTART        373
 	if(!msg->haltOutput())
 	{
 		KviWindow * pOut = (KviWindow *)(msg->console());
@@ -1831,7 +1837,7 @@ void KviServerParser::parseNumericInfoStart(KviIrcMessage * msg)
 
 void KviServerParser::parseNumericInfoEnd(KviIrcMessage * msg)
 {
-//RPL_ENDOFINFO        374
+	//RPL_ENDOFINFO        374
 	if(!msg->haltOutput())
 	{
 		KviWindow * pOut = (KviWindow *)(msg->console());
@@ -1841,7 +1847,7 @@ void KviServerParser::parseNumericInfoEnd(KviIrcMessage * msg)
 
 void KviServerParser::parseNumericTime(KviIrcMessage * msg)
 {
-//RPL_TIME             391
+	//RPL_TIME             391
 	if(!msg->haltOutput())
 	{
 		KviWindow * pOut = (KviWindow *)(msg->console());
@@ -1852,7 +1858,7 @@ void KviServerParser::parseNumericTime(KviIrcMessage * msg)
 
 void KviServerParser::parseNumericNoSuchServer(KviIrcMessage * msg)
 {
-//ERR_NOSUCHSERVER     402
+	//ERR_NOSUCHSERVER     402
 	if(!msg->haltOutput())
 	{
 		KviWindow * pOut = (KviWindow *)(msg->console());
@@ -1863,7 +1869,7 @@ void KviServerParser::parseNumericNoSuchServer(KviIrcMessage * msg)
 
 void KviServerParser::parseNumericNoSuchChannel(KviIrcMessage * msg)
 {
-//ERR_NOSUCHCHANNEL    403
+	// ERR_NOSUCHCHANNEL    403
 	if(!msg->haltOutput())
 	{
 		KviWindow * pOut = (KviWindow *)(msg->console());
@@ -1874,7 +1880,7 @@ void KviServerParser::parseNumericNoSuchChannel(KviIrcMessage * msg)
 
 void KviServerParser::parseNumericCannotSendColor(KviIrcMessage * msg)
 {
-//ERR_NOCOLORSONCHAN   408
+	// ERR_NOCOLORSONCHAN   408
 	if(!msg->haltOutput())
 	{
 		QString szChan = msg->connection()->decodeText(msg->safeParam(1));
@@ -1892,7 +1898,7 @@ void KviServerParser::parseNumericCannotSendColor(KviIrcMessage * msg)
 
 void KviServerParser::parseNumericCannotSend(KviIrcMessage * msg)
 {
-//ERR_CANNOTSENDTOCHAN 404
+	// ERR_CANNOTSENDTOCHAN 404
 	if(!msg->haltOutput())
 	{
 		QString szChan = msg->connection()->decodeText(msg->safeParam(1));
@@ -1918,7 +1924,9 @@ void KviServerParser::parseNumericCodePageSet(KviIrcMessage *msg)
 	QString encoding = msg->connection()->decodeText(msg->safeParam(1));
 	if(msg->connection()->serverInfo()->supportsCodePages())
 	{
+		if(encoding=="NONE") encoding="KOI8-R"; //RusNet default codepage
 		msg->console()->output(KVI_OUT_TEXTENCODING,__tr2qs("Your encoding is now %Q"),&encoding);
+		msg->console()->setTextEncoding(encoding);
 		msg->connection()->setEncoding(encoding);
 	} else {
 		QString szMe = msg->connection()->decodeText(msg->safeParam(0));
@@ -1926,6 +1934,7 @@ void KviServerParser::parseNumericCodePageSet(KviIrcMessage *msg)
 			&& KviLocale::codecForName(encoding.utf8().data()))
 		{
 			msg->console()->output(KVI_OUT_TEXTENCODING,__tr2qs("Your encoding is now %Q"),&encoding);
+			msg->console()->setTextEncoding(encoding);
 			msg->connection()->setEncoding(encoding);
 		} else if(!msg->haltOutput()) // simply unhandled
 		{
@@ -1941,6 +1950,9 @@ void KviServerParser::parseNumericCodePageScheme(KviIrcMessage *msg)
 	// a nice extension for irc.wenet.ru
 	// 703: RPL_WHOISSCHEME
 	// :prefix 703 <mynick> <nick> <encoding> :translation scheme
+
+	msg->connection()->stateData()->setLastReceivedWhoisReply(kvi_unixTime());
+
 	if(msg->connection()->serverInfo()->supportsCodePages())
 	{
 		QString szNick = msg->connection()->decodeText(msg->safeParam(1));
@@ -1988,4 +2000,4 @@ void KviServerParser::parseNumericEndOfStats(KviIrcMessage *msg)
 		QString szText = msg->connection()->decodeText(msg->safeTrailing());
 		pOut->outputNoFmt(KVI_OUT_STATS, szText);
 	}
-}
\ No newline at end of file
+}
