@@ -73,7 +73,7 @@ KviCtcpMessageParseStruct KviServerParser::m_ctcpReplyParseProcTable[]=
 	{ "TDCC"       , PTM(parseCtcpRequestDcc)        , 0 },
 	{ "XDCC"       , PTM(parseCtcpRequestDcc)        , 0 },
 	{ "VERSION"    , PTM(parseCtcpReplyGeneric)      , 0 },
-	{ "USERINFO"   , PTM(parseCtcpReplyGeneric)      , 0 },
+	{ "USERINFO"   , PTM(parseCtcpReplyUserinfo)     , 0 },
 	{ "CLIENTINFO" , PTM(parseCtcpReplyGeneric)      , 0 },
 	{ "FINGER"     , PTM(parseCtcpReplyGeneric)      , 0 },
 	{ "TIME"       , PTM(parseCtcpReplyGeneric)      , 0 },
@@ -308,7 +308,7 @@ messageParseProc KviServerParser::m_numericParseProcTable[1000]=
 	PTM(parseNumericEndOfStats),                     // 219 RPL_ENDOFSTATS
 	0,                                               // 220
 	PTM(parseNumericUserMode)                      , // 221 RPL_UMODEIS
-	0,                                               // 222
+	PTM(parseNumericCodePageSet),                    // 222 RusNet Codepage set
 	0,                                               // 223
 	0,                                               // 224
 	0,                                               // 225
@@ -424,8 +424,8 @@ messageParseProc KviServerParser::m_numericParseProcTable[1000]=
 	0,                                               // 335
 	0,                                               // 336
 	0,                                               // 337
-	PTM(parseNumericWhoisOther),                                               // 338 RPL_WHOISACTUALLY
-	0,                                               // 339
+	PTM(parseNumericWhoisOther),                     // 338 RPL_WHOISACTUALLY
+	PTM(parseNumericWhoisOther),                     // 339
 	0,                                               // 340
 	PTM(parseNumericInviting)                      , // 351 RPL_INVITING
 	0,                                               // 342
@@ -563,7 +563,7 @@ messageParseProc KviServerParser::m_numericParseProcTable[1000]=
 	PTM(parseNumericCantJoinChannel)               , // 474 ERR_BANNEDFROMCHAN
 	PTM(parseNumericCantJoinChannel)               , // 475 ERR_BADCHANNELKEY
 	0,                                               // 476
-	0,                                               // 477
+	PTM(parseChannelHelp),                           // 477 RPL_CHANNELHELP
 	0,                                               // 478
 	0,                                               // 479
 	0,                                               // 480
@@ -789,10 +789,10 @@ messageParseProc KviServerParser::m_numericParseProcTable[1000]=
 	PTM(parseNumericCodePageSet)                   , // 700 RPL_CODEPAGESET
 	0,                                               // 701
 	0,                                               // 702
-	PTM(parseNumericCodePageScheme)                   , // 703 RPL_WHOISSCHEME
-	PTM(commandSyntaxHelp),                          // 704 RPL_COMMANDSYNTAX
-	PTM(commandHelp),                                // 705 RPL_COMMANDHELP
-	PTM(commandEndOfHelp),                           // 706 RPL_ENDOFCOMMANDHELP
+	PTM(parseNumericCodePageScheme)                , // 703 RPL_WHOISSCHEME
+	PTM(parseCommandSyntaxHelp),                     // 704 RPL_COMMANDSYNTAX
+	PTM(parseCommandHelp),                           // 705 RPL_COMMANDHELP
+	PTM(parseCommandEndOfHelp),                      // 706 RPL_ENDOFCOMMANDHELP
 	0,                                               // 707
 	0,                                               // 708
 	0,                                               // 709
