@@ -32,6 +32,7 @@
 #include "kvi_options.h"
 #include "kvi_kvs_eventmanager.h"
 #include "kvi_kvs_eventtriggers.h"
+#include "kvi_ircconnectionstatedata.h"
 
 KviServerParser * g_pServerParser = 0;
 
@@ -70,6 +71,30 @@ void KviServerParser::parseMessage(const char * message,KviIrcConnection * pConn
 			{
 				(this->*proc)(&msg);
 				if(!msg.unrecognized())return; // parsed
+			} else {
+				// we don't have a proc for this
+
+				// special handling of unknown RPL_WHOIS* messages
+				// if
+				//      - we're in the middle of a RPL_WHOIS* sequence (i.e. have received a RPL_WHOIS* message since less than 10 seconds)
+				//      - we have not received RPL_ENDOFWHOIS yet (the time of the last RPL_WHOIS* is reset to zero when a RPL_ENDOFWHOIS is received)
+				//      - this message is unrecognized and looks like a RPL_WHOIS*
+				// then pass it to the WhoisOther handler.
+				//
+				// Thnx Elephantman :)
+
+				if(msg.paramCount() >= 3) // might look like :prefix RPL_WHOIS* <target> <nick> [?] :<something>
+				{
+					kvi_time_t tNow = kvi_unixTime();
+					
+					if((tNow - pConnection->stateData()->lastReceivedWhoisReply()) < 10)
+					{
+						// we're in the middle of a RPL_WHOIS* sequence and haven't
+						// received a RPL_ENDOFWHOIS yet.
+						parseNumericWhoisOther(&msg);
+						if(!msg.unrecognized())return;
+					}
+				}
 			}
 		} else {
 			for(int i=0;m_literalParseProcTable[i].msgName;i++)
@@ -97,6 +122,7 @@ void KviServerParser::parseMessage(const char * message,KviIrcConnection * pConn
 	
 		}
 	
+		// unhandled || unrecognized
 		if(!msg.haltOutput() && !_OUTPUT_MUTE)
 		{
 			QString szWText = pConnection->decodeText(msg.allParams());
@@ -108,7 +134,6 @@ void KviServerParser::parseMessage(const char * message,KviIrcConnection * pConn
 					__tr2qs("[Server parser]: [%s][%s] %Q"),msg.prefix(),msg.command(),&szWText);
 				pConnection->console()->output(KVI_OUT_UNRECOGNIZED,
 					__tr2qs("[Server parser]: %s"),m_szLastParserError.ptr());
-	
 			} else {
 				// ignore spurious CRLF pairs (some servers send them a lot) unless we want PARANOID output
 				if((!msg.isEmpty()) || _OUTPUT_PARANOIC)
