@@ -31,9 +31,10 @@
 #include <time.h>
 
 #include <qobject.h>
-#include "kvi_list.h"
+#include "kvi_pointerlist.h"
 
 #include "kvi_qstring.h"
+#include "kvi_qcstring.h"
 #include "kvi_console.h"
 
 #include "kvi_ircmessage.h"
@@ -201,9 +202,10 @@ private:
 	void parseNumericCannotSendColor(KviIrcMessage *msg);
 	void parseNumericEndOfStats(KviIrcMessage *msg);
 	void otherChannelError(KviIrcMessage *msg);
-	void commandSyntaxHelp(KviIrcMessage *msg);
-	void commandHelp(KviIrcMessage *msg);
-	void commandEndOfHelp(KviIrcMessage *msg);
+	void parseCommandSyntaxHelp(KviIrcMessage *msg);
+	void parseCommandHelp(KviIrcMessage *msg);
+	void parseCommandEndOfHelp(KviIrcMessage *msg);
+	void parseChannelHelp(KviIrcMessage *msg);
 	
 	void parseLiteralPing(KviIrcMessage *msg);
 	void parseLiteralJoin(KviIrcMessage *msg);
@@ -244,6 +246,7 @@ private:
 	void parseCtcpRequestPage(KviCtcpMessage *msg);
 
 	void parseCtcpReplyAvatar(KviCtcpMessage *msg);
+	void parseCtcpReplyUserinfo(KviCtcpMessage *msg);
 	void parseCtcpReplyGeneric(KviCtcpMessage *msg);
 	void parseCtcpReplyPing(KviCtcpMessage *msg);
 	void parseCtcpReplyLagcheck(KviCtcpMessage *msg);
@@ -252,7 +255,7 @@ public:
 	static void encodeCtcpParameter(const char * param,KviStr &buffer,bool bSpaceBreaks = true);
 	static void encodeCtcpParameter(const char * param,QString &buffer,bool bSpaceBreaks = true);
 	static const char * decodeCtcpEscape(const char * msg_ptr,KviStr &buffer);
-	static const char * decodeCtcpEscape(const char * msg_ptr,QCString &buffer);
+	static const char * decodeCtcpEscape(const char * msg_ptr,KviQCString &buffer);
 	static const char * extractCtcpParameter(const char * msg_ptr,KviStr &buffer,bool bSpaceBreaks = true);
 	static const char * extractCtcpParameter(const char * msg_ptr,QString &buffer,bool bSpaceBreaks = true);
 };
