@@ -32,12 +32,20 @@
 
 #include <qlayout.h>
 #include <qlabel.h>
-#include <qscrollview.h>
-#include <qheader.h>
+//#include <qscrollview.h>
 #include <qpainter.h>
 #include <qpixmap.h>
-#include <qsimplerichtext.h>
-#include <qdragobject.h>
+#ifdef COMPILE_USE_QT4
+	#include <q3header.h>
+	#include <q3simplerichtext.h>
+	#include <qmime.h>
+	#include <qevent.h>
+#else
+	#include <qheader.h>
+	#include <qsimplerichtext.h>
+#endif
+
+#include "kvi_draganddrop.h"
 
 #define LVI_ICON_SIZE 32
 #define LVI_BORDER 4
@@ -45,8 +53,8 @@
 #define LVI_MINIMUM_TEXT_WIDTH 300
 #define LVI_MINIMUM_CELL_WIDTH (LVI_MINIMUM_TEXT_WIDTH + LVI_BORDER + LVI_ICON_SIZE + LVI_SPACING + LVI_BORDER)
 
-KviActionDrawerPageListViewItem::KviActionDrawerPageListViewItem(QListView * v,KviAction * a)
-: QListViewItem(v,"")
+KviActionDrawerPageListViewItem::KviActionDrawerPageListViewItem(KviTalListView * v,KviAction * a)
+: KviTalListViewItem(v,"")
 {
 	m_pListView = v;
 	setDragEnabled(true);
@@ -56,7 +64,11 @@ KviActionDrawerPageListViewItem::KviActionDrawerPageListViewItem(QListView * v,K
 		t += " <font color=\"#a0a0a0\">[" + __tr2qs("Script") + "]</font>";
 	t += "<br><font size=\"-1\">" + a->description()+ "</font>";
 	m_szKey = a->visibleName().upper();
+#ifdef COMPILE_USE_QT4
+	m_pText = new Q3SimpleRichText(t,v->font());
+#else
 	m_pText = new QSimpleRichText(t,v->font());
+#endif
 	QPixmap * p = a->bigIcon();
 	m_pIcon = p ? new QPixmap(*p) : new QPixmap(LVI_ICON_SIZE,LVI_ICON_SIZE);
 }
@@ -74,7 +86,7 @@ QString KviActionDrawerPageListViewItem::key(int,bool) const
 
 void KviActionDrawerPageListViewItem::setup()
 {
-	QListViewItem::setup();
+	KviTalListViewItem::setup();
 	int iWidth = m_pListView->visibleWidth();
 	if(iWidth < LVI_MINIMUM_CELL_WIDTH)iWidth = LVI_MINIMUM_CELL_WIDTH;
 	iWidth -= LVI_BORDER + LVI_ICON_SIZE + LVI_SPACING + LVI_BORDER;
@@ -86,7 +98,7 @@ void KviActionDrawerPageListViewItem::setup()
 
 void KviActionDrawerPageListViewItem::paintCell(QPainter * p,const QColorGroup & cg,int column,int width,int align)
 {
-	QListViewItem::paintCell(p,cg,column,width,align);
+	KviTalListViewItem::paintCell(p,cg,column,width,align);
 	//p->fillRect(QRect(0,0,width,height()),isSelected() ? cg.highlight() : cg.base());
 	p->drawPixmap(LVI_BORDER,LVI_BORDER,*m_pIcon);
 	int afterIcon = LVI_BORDER + LVI_ICON_SIZE + LVI_SPACING;
@@ -127,9 +139,9 @@ void KviActionDrawerPageListView::contentsMousePressEvent(QMouseEvent * e)
 	KviListView::contentsMousePressEvent(e);
 	KviActionDrawerPageListViewItem * i = (KviActionDrawerPageListViewItem *)itemAt(QPoint(5,contentsToViewport(e->pos()).y()));
 	if(!i)return;
-	QTextDrag * d = new QTextDrag(i->name(),this); // does this leak memory ?
-	if(i->icon())d->setPixmap(*(i->icon()),QPoint(3,3));
-	d->dragCopy();
+	KviTextDrag * dr = new KviTextDrag(i->name(),this); // does this leak memory ?
+	if(i->icon())dr->setPixmap(*(i->icon()),QPoint(3,3));
+	dr->dragCopy();
 }
 
 void KviActionDrawerPageListView::resizeEvent(QResizeEvent * e)
@@ -181,13 +193,13 @@ void KviActionDrawer::fill()
 {
 	KviActionManager::loadAllAvailableActions();
 
-	QDict<KviActionDrawerPage> pages;
+	KviPointerHashTable<QString,KviActionDrawerPage> pages;
 	pages.setAutoDelete(false);
 
-	QDict<KviAction> * d = KviActionManager::instance()->actions();
+	KviPointerHashTable<QString,KviAction> * d = KviActionManager::instance()->actions();
 	if(!d)return; // ooops
 
-	QDictIterator<KviAction> it(*d);
+	KviPointerHashTableIterator<QString,KviAction> it(*d);
 	while(KviAction * a = it.current())
 	{
 		KviActionCategory * c = a->category();
