@@ -34,19 +34,27 @@
 
 class KviActionDrawerPage;
 class QPixmap;
-class QSimpleRichText;
+#ifdef COMPILE_USE_QT4
+	class Q3SimpleRichText;
+#else
+	class QSimpleRichText;
+#endif
 class KviAction;
 
-class KVIRC_API KviActionDrawerPageListViewItem : public QListViewItem
+class KVIRC_API KviActionDrawerPageListViewItem : public KviTalListViewItem
 {
 public:
-	KviActionDrawerPageListViewItem(QListView * v,KviAction * a);
+	KviActionDrawerPageListViewItem(KviTalListView * v,KviAction * a);
 	~KviActionDrawerPageListViewItem();
 protected:
 	QString m_szName;
+#ifdef COMPILE_USE_QT4
+	Q3SimpleRichText * m_pText;
+#else
 	QSimpleRichText * m_pText;
+#endif
 	QPixmap * m_pIcon;
-	QListView * m_pListView;
+	KviTalListView * m_pListView;
 	QString m_szKey;
 public:
 	QPixmap * icon(){ return m_pIcon; };
