@@ -55,7 +55,6 @@
 #include "kvi_ircconnection.h"
 #include "kvi_ircconnectionserverinfo.h"
 #include "kvi_defaults.h"
-//#include "kvi_uparser.h"
 #include "kvi_sparser.h"
 #include "kvi_modew.h"
 #include "kvi_mirccntrl.h"
@@ -71,22 +70,21 @@
 #include <time.h>
 
 #include <qsplitter.h>
-#include <qhbox.h>
 #include <qtoolbutton.h>
 #include <qlabel.h>
-#include <qvaluelist.h>
+#include <qevent.h>
+
 #include <qpalette.h>
-#include <qpopupmenu.h>
-#include <qdict.h>
+#include "kvi_tal_popupmenu.h"
+#include "kvi_pointerhashtable.h"
 #include <qmessagebox.h>
-#include <qwidgetstack.h> 
+#include "kvi_tal_widgetstack.h" 
 
 #ifndef AVERAGE_CHANNEL_USERS
 	#define AVERAGE_CHANNEL_USERS 101
 #endif
 
-// kvi_sp_numeric.cpp
-extern const QString & getChannelModeDescription(char c);
+
 
 // FIXME: #warning "+a Anonymous channel mode!"
 // FIXME: #warning "+r channel mode (reop)"
@@ -97,31 +95,32 @@ KviChannel::KviChannel(KviFrame * lpFrm,KviConsole * lpConsole,const char * name
 : KviWindow(KVI_WINDOW_TYPE_CHANNEL,lpFrm,name,lpConsole)
 {
 	// Init some member variables
+	m_pInput               = 0;
 	m_iStateFlags          = 0;
-	m_pBanList             = new KviPtrList<KviMaskEntry>;
+	m_pBanList             = new KviPointerList<KviMaskEntry>;
 	m_pBanList->setAutoDelete(true);
-	m_pBanExceptionList    = new KviPtrList<KviMaskEntry>;
+	m_pBanExceptionList    = new KviPointerList<KviMaskEntry>;
 	m_pBanExceptionList->setAutoDelete(true);
-	m_pInviteList = new KviPtrList<KviMaskEntry>;
+	m_pInviteList = new KviPointerList<KviMaskEntry>;
 	m_pInviteList->setAutoDelete(true);
-	m_pActionHistory = new KviPtrList<KviChannelAction>;
+	m_pActionHistory = new KviPointerList<KviChannelAction>;
 	m_pActionHistory->setAutoDelete(true);
 	m_uActionHistoryHotActionCount = 0;
 
-	m_pTmpHighLighted      = new QStrList();
+	m_pTmpHighLighted      = new KviPointerHashTable<const char *,QString>();
 	m_pTmpHighLighted->setAutoDelete(true);
 
 	// Register ourselves
 	connection()->registerChannel(this);
 	// And create the widgets layout
 	// Button box
-	m_pButtonBox = new QHBox(this,"button_box");
+	m_pButtonBox = new KviTalHBox(this);
 	
-	m_pTopSplitter = new QSplitter(QSplitter::Horizontal,m_pButtonBox,"top_splitter");
+	m_pTopSplitter = new QSplitter(Qt::Horizontal,m_pButtonBox);
 
 	m_pButtonBox->setStretchFactor(m_pTopSplitter,1);
 	
-	m_pButtonContainer = new QHBox(m_pButtonBox);
+	m_pButtonContainer = new KviTalHBox(m_pButtonBox);
 	
 	// Topic widget on the left
 	m_pTopicWidget = new KviTopicWidget(m_pTopSplitter,"topic_widget");
@@ -130,17 +129,28 @@ KviChannel::KviChannel(KviFrame * lpFrm,KviConsole * lpConsole,const char * name
 		this,SLOT(topicSelected(const QString &)));
 	// mode label follows the topic widget
 	m_pModeWidget = new KviModeWidget(m_pTopSplitter,this,"mode_");
-	QToolTip::add(m_pModeWidget,__tr2qs("Channel mode"));
+	KviTalToolTip::add(m_pModeWidget,__tr2qs("Channel mode"));
 
 	createTextEncodingButton(m_pButtonContainer);
 
 	// Central splitter
-	m_pSplitter = new QSplitter(QSplitter::Horizontal,this,"main_splitter");
+	m_pSplitter = new QSplitter(Qt::Horizontal,this);
+	#ifdef COMPILE_USE_QT4
+		m_pSplitter->setObjectName(name);
+	#else
+		m_pSplitter->setName(name);
+	#endif
+	m_pSplitter->setOpaqueResize(false);
 	// Spitted vertially on the left
-	m_pVertSplitter = new QSplitter(QSplitter::Vertical,m_pSplitter,
-		"vertical_splitter");
+	m_pVertSplitter = new QSplitter(Qt::Vertical,m_pSplitter);
+	m_pVertSplitter->setOpaqueResize(false);
 	// With the IRC view over
 	m_pIrcView = new KviIrcView(m_pVertSplitter,lpFrm,this);
+	#ifdef COMPILE_USE_QT4
+		m_pIrcView->setObjectName(name);
+	#else
+		m_pIrcView->setName(name);
+	#endif
 	connect(m_pIrcView,SIGNAL(rightClicked()),this,SLOT(textViewRightClicked()));
 	// And the double view (that may be unused)
 	m_pMessageView = 0;
@@ -180,8 +190,12 @@ KviChannel::KviChannel(KviFrame * lpFrm,KviConsole * lpConsole,const char * name
 #endif
 
 	m_pHideToolsButton = new KviStyledToolButton(m_pButtonBox,"hide_container_button");
-	
+
+#ifndef  COMPILE_USE_QT4
 	m_pHideToolsButton->setUsesBigPixmap(false);
+#else
+	m_pHideToolsButton->setAutoRaise(true);
+#endif
 	m_pHideToolsButton->setFixedWidth(10);
 
 	if(g_pIconManager->getBigIcon("kvi_horizontal_left.png"))
@@ -203,12 +217,13 @@ KviChannel::KviChannel(KviFrame * lpFrm,KviConsole * lpConsole,const char * name
 	//setFocusHandler(m_pInput,this);
 	// And turn on the secondary IRC view if needed
 
-	if(KVI_OPTION_BOOL(KviOption_boolAutoLogChannels))m_pIrcView->startLogging(0);
+	if(KVI_OPTION_BOOL(KviOption_boolAutoLogChannels))m_pIrcView->startLogging();
 
 	applyOptions();
 	m_joinTime = QDateTime::currentDateTime();
 	m_tLastReceivedWhoReply = (kvi_time_t)m_joinTime.toTime_t();
 	
+
 }
 
 KviChannel::~KviChannel()
@@ -247,26 +262,19 @@ void KviChannel::textViewRightClicked()
 	KVS_TRIGGER_EVENT_0(KviEvent_OnChannelPopupRequest,this);
 }
 
-void KviChannel::getBaseLogFileName(KviStr &buffer)
-{
-	if (console()->connection())
-		buffer.sprintf("%s.%s",windowName().utf8().data(),console()->currentNetworkName().utf8().data());
-	else
-		buffer.sprintf("%s.%u",windowName().utf8().data(),console()->ircContextId());
-}
 void KviChannel::getBaseLogFileName(QString &buffer)
 {
-	QString szChan=windowName();
+	QString szChan(windowName());
 	szChan.replace(".","%2e");
 	if (console()->connection())
 	{
-		buffer=windowName();
-		buffer+=".";
-		buffer+=console()->currentNetworkName();
+		buffer=szChan;
+		buffer.append(".");
+		buffer.append(console()->currentNetworkName());
 	} else {
 		buffer=szChan;
-		buffer+=".";
-		buffer+=console()->ircContextId();
+		buffer.append(".");
+		buffer.append(console()->ircContextId());
 	}
 }
 
@@ -293,7 +301,15 @@ void KviChannel::saveProperties(KviConfig *cfg)
 	KviWindow::saveProperties(cfg);
 	cfg->writeEntry("TopSplitter",m_pTopSplitter->sizes());
 	cfg->writeEntry("Splitter",m_pSplitter->sizes());
+#ifdef COMPILE_USE_QT4
+	QList<int> tmp = m_pVertSplitter->sizes();
+	KviValueList<int> tmp2;
+	for(QList<int>::Iterator it = tmp.begin();it != tmp.end();++it)
+		tmp2.append(*it);
+	cfg->writeEntry("VertSplitter",m_pMessageView ? tmp2 : m_VertSplitterSizesList);
+#else
 	cfg->writeEntry("VertSplitter",m_pMessageView ? m_pVertSplitter->sizes() : m_VertSplitterSizesList);
+#endif
 	cfg->writeEntry("PrivateBackground",m_privateBackground);
 	cfg->writeEntry("DoubleView",m_pMessageView ? true : false);
 	if(m_pUserListView)
@@ -304,7 +320,7 @@ void KviChannel::saveProperties(KviConfig *cfg)
 void KviChannel::loadProperties(KviConfig *cfg)
 {
 	int w = width();
-	QValueList<int> def;
+	KviValueList<int> def;
 	def.append((w * 75) / 100);
 	def.append((w * 15) / 100);
 	def.append((w * 10) / 100);
@@ -397,7 +413,7 @@ void KviChannel::toggleModeEditor()
 		if(m_pModeEditorButton->isOn()) m_pModeEditorButton->setOn(false);
 		resizeEvent(0);
 	} else {
-		m_pModeEditor = new KviModeEditor(m_pSplitter,m_pModeEditorButton,"mode_editor",console(),m_szChannelMode,m_szChannelKey.ptr(),m_szChannelLimit.ptr());
+		m_pModeEditor = new KviModeEditor(m_pSplitter,m_pModeEditorButton,"mode_editor",console(),m_szChannelMode,m_szChannelKey,m_szChannelLimit.ptr());
 		connect(m_pModeEditor,SIGNAL(setMode(const char *)),this,SLOT(setMode(const char *)));
 		connect(m_pModeEditor,SIGNAL(done()),this,SLOT(modeSelectorDone()));
 		m_pModeEditor->show();
@@ -414,7 +430,7 @@ void KviChannel::modeSelectorDone()
 void KviChannel::setMode(const char * mode)
 {
 	if(!connection())return;
-	QCString tmp = connection()->encodeText(m_szName);
+	KviQCString tmp = connection()->encodeText(m_szName);
 	connection()->sendFmtData("MODE %s %s",tmp.data(),mode);
 }
 
@@ -436,7 +452,7 @@ void KviChannel::toggleInviteEditor()
 			m_pInviteList,'I',"invite_exception_editor");
 }
 
-void KviChannel::toggleEditor(KviMaskEditor ** ppEd,KviWindowToolPageButton ** ppBtn,KviPtrList<KviMaskEntry> *l,char flag,const char *edName)
+void KviChannel::toggleEditor(KviMaskEditor ** ppEd,KviWindowToolPageButton ** ppBtn,KviPointerList<KviMaskEntry> *l,char flag,const char *edName)
 {
 	if(*ppEd)
 	{
@@ -474,14 +490,14 @@ void KviChannel::toggleEditor(KviMaskEditor ** ppEd,KviWindowToolPageButton ** p
 		{
 			if(connection())
 			{
-				QCString szName = connection()->encodeText(m_szName);
+				KviQCString szName = connection()->encodeText(m_szName);
 				connection()->sendFmtData("MODE %s %c",szName.data(),flag);
 			}
 		}
 
 		*ppEd = new KviMaskEditor(m_pSplitter,*ppBtn,l,flag,edName);
-		connect(*ppEd,SIGNAL(removeMasks(KviMaskEditor *,KviPtrList<KviMaskEntry> *)),
-			this,SLOT(removeMasks(KviMaskEditor *,KviPtrList<KviMaskEntry> *)));
+		connect(*ppEd,SIGNAL(removeMasks(KviMaskEditor *,KviPointerList<KviMaskEntry> *)),
+			this,SLOT(removeMasks(KviMaskEditor *,KviPointerList<KviMaskEntry> *)));
 		//setFocusHandler(m_pInput,*ppEd); //socket it!
 		(*ppEd)->show();
 		if(!(*ppBtn))return;
@@ -489,7 +505,7 @@ void KviChannel::toggleEditor(KviMaskEditor ** ppEd,KviWindowToolPageButton ** p
 	}
 }
 
-void KviChannel::removeMasks(KviMaskEditor *ed,KviPtrList<KviMaskEntry> *l)
+void KviChannel::removeMasks(KviMaskEditor *ed,KviPointerList<KviMaskEntry> *l)
 {
 	KviStr masks;
 	KviStr flags;
@@ -504,7 +520,7 @@ void KviChannel::removeMasks(KviMaskEditor *ed,KviPtrList<KviMaskEntry> *l)
 		{
 			if(connection())
 			{
-				QCString szName = connection()->encodeText(m_szName);
+				KviQCString szName = connection()->encodeText(m_szName);
 				connection()->sendFmtData("MODE %s -%s %s",szName.data(),flags.ptr(),connection()->encodeText(QString(masks)).data());
 			}
 			flags = "";
@@ -516,7 +532,7 @@ void KviChannel::removeMasks(KviMaskEditor *ed,KviPtrList<KviMaskEntry> *l)
 	{
 		if(connection())
 		{
-			QCString szName = connection()->encodeText(m_szName);
+			KviQCString szName = connection()->encodeText(m_szName);
 			connection()->sendFmtData("MODE %s -%s %s",szName.data(),flags.ptr(),connection()->encodeText(QString(masks)).data());
 		}
 	}
@@ -529,11 +545,19 @@ QPixmap * KviChannel::myIconPtr()
 
 void KviChannel::resizeEvent(QResizeEvent *e)
 {
+#ifdef COMPILE_USE_QT4
+	int hght = m_pInput->heightHint();
+	int hght2 = m_pTopicWidget->sizeHint().height();
+	m_pButtonBox->setGeometry(0,0,width(),hght2);
+	m_pSplitter->setGeometry(0,hght2,width(),height() - (hght + hght2));
+	m_pInput->setGeometry(0,height() - hght,width(),hght);
+#else
 	int hght = m_pInput->heightHint();
 	int hght2 = m_pButtonBox->sizeHint().height();
 	m_pButtonBox->setGeometry(0,0,width(),hght2);
 	m_pSplitter->setGeometry(0,hght2,width(),height() - (hght + hght2));
 	m_pInput->setGeometry(0,height() - hght,width(),hght);
+#endif
 }
 
 QSize KviChannel::sizeHint() const
@@ -576,24 +600,20 @@ void KviChannel::setChannelLimit(const char * limit)
 
 void KviChannel::addHighlightedUser(const char * nick)
 {
-    if(!m_pUserListView->findEntry(nick))return;
-    else
-    {
-        if(m_pTmpHighLighted->find(nick) != -1)return;
-        else m_pTmpHighLighted->append(nick);
-    }
+	if(!m_pUserListView->findEntry(nick))return;
+	else
+   		m_pTmpHighLighted->replace(nick,new QString());
 }
 
 void KviChannel::removeHighlightedUser(const char * nick)
 {
-    if(m_pTmpHighLighted->find(nick) == -1)return;
-    else m_pTmpHighLighted->remove(nick);
+	m_pTmpHighLighted->remove(nick);
 }
 
 void KviChannel::getChannelModeString(QString &buffer)
 {
 	buffer = m_szChannelMode;
-	if(m_szChannelKey.hasData())buffer.append('k');
+	if(!m_szChannelKey.isEmpty())buffer.append('k');
 	if(m_szChannelLimit.hasData())buffer.append('l');
 }
 
@@ -639,7 +659,7 @@ void KviChannel::setAliveChan()
 	context()->unregisterDeadChannel(this);
 	connection()->registerChannel(this);
 	// Update log file name
-	if(m_pIrcView->isLogging())m_pIrcView->startLogging(0);
+	if(m_pIrcView->isLogging())m_pIrcView->startLogging();
 	updateIcon();
 	updateCaption();
 	m_pTopicWidget->reset(); // reset the topic (fixes bug #20 signaled by Klaus Weidenbach)
@@ -703,18 +723,15 @@ void KviChannel::getTaskBarTipText(QString &buffer)
 	static QString p9(")");
 	static QString p10("<br>");
 
-
-
 	static QString end_of_doc = "</table></body></html>";
-	static QString end_of_fontboldrow = "</b></font></td></tr>";
+	static QString end_of_fontboldrow = END_TABLE_BOLD_ROW;
 	static QString start_of_row = "<tr><td>";
 	static QString end_of_row = "</td></tr>";
 
 	buffer = "<html>" \
-				"<body bgcolor=\"#FFFFFF\">" \
-					"<table width=\"100%\">" \
-						"<tr><td bgcolor=\"#303030\">" \
-							"<font color=\"#FFFFFF\"><b>";
+				"<body>" \
+					"<table width=\"100%\">"\
+						START_TABLE_BOLD_ROW;
 
 	if(m_iStateFlags & KVI_CHANNEL_STATE_DEADCHAN)
 	{
@@ -1032,8 +1049,8 @@ void KviChannel::ownMessage(const QString &buffer)
 {
 	if(!connection())return;
 
-	QCString szName = connection()->encodeText(windowName());
-	QCString szData = encodeText(buffer);
+	KviQCString szName = connection()->encodeText(windowName());
+	KviQCString szData = encodeText(buffer);
 	const char * d = szData.data();
 	if(!d)return;
 	
@@ -1063,9 +1080,12 @@ void KviChannel::ownMessage(const QString &buffer)
 					}
 					break;
 					default: // also case KviCryptEngine::EncryptError
+					{
+						QString szEngineError = cryptSessionInfo()->pEngine->lastError();
 						output(KVI_OUT_SYSTEMERROR,
-							__tr2qs("The crypto engine was unable to encrypt the current message (%Q): %s, no data sent to the server"),
-							&buffer,cryptSessionInfo()->pEngine->lastError());
+							__tr2qs("The crypto engine was unable to encrypt the current message (%Q): %Q, no data sent to the server"),
+							&buffer,&szEngineError);
+					}
 					break;
 				}
 				userAction(connection()->currentNickName(),KVI_USERACTION_PRIVMSG);
@@ -1092,11 +1112,12 @@ void KviChannel::ownMessage(const QString &buffer)
 void KviChannel::ownAction(const QString &buffer)
 {
 	if(!connection())return;
-	QCString szName = connection()->encodeText(m_szName);
-	QCString szData = encodeText(buffer);
+	KviQCString szName = connection()->encodeText(m_szName);
+	KviQCString szData = encodeText(buffer);
 	const char * d = szData.data();
 	if(!d)return;
 	if(!connection()->sendFmtData("PRIVMSG %s :%cACTION %s%c",szName.data(),0x01,d,0x01))return;
+	if(KVS_TRIGGER_EVENT_1_HALTED(KviEvent_OnMeAction,this,QString(d)))return;
 	QString szBuffer = "\r!nc\r";
 	szBuffer += connection()->currentNickName();
 	szBuffer += "\r ";
@@ -1280,7 +1301,7 @@ void KviChannel::getChannelActivityStats(KviChannelActivityStats * s)
 	tTwoMinsAgo-= 120;
 	tNow -= 60;
 
-	QDict<int> userDict;
+	KviPointerHashTable<QString,int> userDict;
 	userDict.setAutoDelete(false);
 
 	int fake;
@@ -1341,8 +1362,8 @@ void KviChannel::userAction(KviIrcMask * user,unsigned int uActionType)
 void KviChannel::topicSelected(const QString & topic)
 {
 	if(!connection())return;
-	QCString szEncoded = encodeText(topic);
-	QCString szName = connection()->encodeText(m_szName);
+	KviQCString szEncoded = encodeText(topic);
+	KviQCString szName = connection()->encodeText(m_szName);
 	connection()->sendFmtData("TOPIC %s :%s",szName.data(),szEncoded.length() ? szEncoded.data() : "");
 }
 
@@ -1364,9 +1385,9 @@ void KviChannel::closeEvent(QCloseEvent *e)
 			
 			if(KviKvsScript::evaluate(tmp,this,0,&vRet))vRet.asString(tmp);
 
-			QCString dat = encodeText(tmp);
+			KviQCString dat = encodeText(tmp);
 			partMessageSent();
-			QCString szName = connection()->encodeText(m_szName);
+			KviQCString szName = connection()->encodeText(m_szName);
 			connection()->sendFmtData("PART %s :%s",szName.data(),dat.data() ? dat.data() : "");
 			// be sure to not reference ourselves here.. we could be disconnected!
 		} else {
@@ -1406,7 +1427,7 @@ int KviChannel::myFlags()
 void KviChannel::setMask(char flag, const QString &mask,bool bAdd,const QString &setBy,unsigned int setAt)
 {
 	if(!connection())return;
-	KviPtrList<KviMaskEntry> * list = m_pBanList;
+	KviPointerList<KviMaskEntry> * list = m_pBanList;
 	KviMaskEditor * editor = m_pBanEditor;
 	switch(flag)
 	{
@@ -1429,7 +1450,7 @@ void KviChannel::setMask(char flag, const QString &mask,bool bAdd,const QString
 	m_pUserListView->setMaskEntries(flag,(int)list->count());
 }
 
-void KviChannel::internalMask(const QString &mask,bool bAdd,const QString &setBy,unsigned int setAt,KviPtrList<KviMaskEntry> *l,KviMaskEditor **ppEd)
+void KviChannel::internalMask(const QString &mask,bool bAdd,const QString &setBy,unsigned int setAt,KviPointerList<KviMaskEntry> *l,KviMaskEditor **ppEd)
 {
 	KviMaskEntry * e = 0;
 	if(bAdd)
@@ -1440,7 +1461,7 @@ void KviChannel::internalMask(const QString &mask,bool bAdd,const QString &setBy
 		}
 		e = new KviMaskEntry;
 		e->szMask = mask;
-		e->szSetBy = setBy ? setBy : __tr2qs("(Unknown)");
+		e->szSetBy = (!setBy.isEmpty()) ? setBy : __tr2qs("(Unknown)");
 		e->uSetAt = setAt;
 		l->append(e);
 		if(*ppEd)(*ppEd)->addMask(e);
@@ -1466,15 +1487,15 @@ void KviChannel::updateModeLabel()
 	const char * aux = mod.ptr();
 	while(*aux)
 	{
-		KviQString::appendFormatted(tip,"<br>%c: %Q",*aux,&(getChannelModeDescription(*aux)));
+		KviQString::appendFormatted(tip,"<br>%c: %Q",*aux,&(m_pConsole->connection()->serverInfo()->getChannelModeDescription(*aux)));
 		++aux;
 	}
 
-	if(m_szChannelKey.hasData())
+	if(!m_szChannelKey.isEmpty())
 	{
 		if(!tmp.isEmpty())tmp.append(' ');
-		KviQString::appendFormatted(tmp,"k:%s",m_szChannelKey.ptr());
-		KviQString::appendFormatted(tip,__tr2qs("<br><b>Key:</b> %s"),m_szChannelKey.ptr());
+		KviQString::appendFormatted(tmp,"k:%s",m_szChannelKey.utf8().data());
+		KviQString::appendFormatted(tip,__tr2qs("<br><b>Key:</b> %s"),m_szChannelKey.utf8().data());
 	}
 
 	if(m_szChannelLimit.hasData())
@@ -1485,8 +1506,8 @@ void KviChannel::updateModeLabel()
 	}
 
 	m_pModeWidget->refreshModes();
-	QToolTip::remove(m_pModeWidget);
-	QToolTip::add(m_pModeWidget,tip);
+	KviTalToolTip::remove(m_pModeWidget);
+	KviTalToolTip::add(m_pModeWidget,tip);
 }
 
 /*
