@@ -26,6 +26,7 @@
 
 #include "kvi_settings.h"
 
+
 #include "kvi_console.h"
 #include "kvi_window.h"
 #include "kvi_string.h"
@@ -34,10 +35,10 @@
 #include "kvi_userlistview.h"
 #include "kvi_time.h"
 #include "kvi_modew.h"
+#include "kvi_valuelist.h"
 
-#include <qstrlist.h>
 #include <qdatetime.h>
-#include <qasciidict.h>
+#include "kvi_pointerhashtable.h"
 #include <qstringlist.h>
 
 class KviConsole;
@@ -46,6 +47,8 @@ class QToolButton;
 class KviTopicWidget;
 class KviIrcMask;
 class KviThemedLabel;
+class KviTalHBox;
+
 #ifdef COMPILE_ON_WINDOWS
 	// windows compiler wants this instead of the forward decl
 	#include "kvi_maskeditor.h"
@@ -112,7 +115,7 @@ public:
 protected:
 	QSplitter                           * m_pTopSplitter;
 	QSplitter                           * m_pVertSplitter;
-	QToolButton                         * m_pDoubleViewButton;
+	BUTTON_CLASS                        * m_pDoubleViewButton;
 	KviWindowToolPageButton             * m_pListViewButton;
 	KviWindowToolPageButton             * m_pBanEditorButton;
 	KviWindowToolPageButton             * m_pBanExceptionEditorButton;
@@ -128,36 +131,35 @@ protected:
 	KviModeWidget                       * m_pModeWidget;
 	int                                   m_iStateFlags;
 	QString                               m_szChannelMode;
-	KviStr                                m_szChannelKey;
+	QString                               m_szChannelKey;
 	KviStr                                m_szChannelLimit;
-	KviPtrList<KviMaskEntry>            * m_pBanList;
-	KviPtrList<KviMaskEntry>            * m_pBanExceptionList;
-	KviPtrList<KviMaskEntry>            * m_pInviteList;
+	KviPointerList<KviMaskEntry>            * m_pBanList;
+	KviPointerList<KviMaskEntry>            * m_pBanExceptionList;
+	KviPointerList<KviMaskEntry>            * m_pInviteList;
 	KviPixmap                             m_privateBackground;
 	QDateTime                             m_joinTime;
 	QString                               m_szNameWithUserFlag;
-	QStrList                            * m_pTmpHighLighted;
+	KviPointerHashTable<const char *,QString>               * m_pTmpHighLighted;
 	unsigned int                          m_uActionHistoryHotActionCount;
-	KviPtrList<KviChannelAction>        * m_pActionHistory;
+	KviPointerList<KviChannelAction>        * m_pActionHistory;
 	kvi_time_t                            m_tLastReceivedWhoReply;
-	QValueList<int> 		      m_VertSplitterSizesList;
-	QHBox				    * m_pButtonContainer;
+	KviValueList<int>                     m_VertSplitterSizesList;
+	KviTalHBox                          * m_pButtonContainer;
 protected:
 	bool eventFilter(QObject *, QEvent *);
 	virtual QPixmap * myIconPtr();
 	virtual void fillCaptionBuffers();
 	virtual void resizeEvent(QResizeEvent *e);
 	virtual void closeEvent(QCloseEvent *e);
-//	virtual void fillContextPopup(QPopupMenu * p);
+//	virtual void fillContextPopup(KviTalPopupMenu * p);
 	virtual void getConfigGroupName(QString &buf);
 	virtual void saveProperties(KviConfig * cfg);
 	virtual void loadProperties(KviConfig * cfg);
 	virtual void applyOptions();
-	virtual void getBaseLogFileName(KviStr &buffer);
 	virtual void getBaseLogFileName(QString &buffer);
 	virtual void triggerCreationEvents();
-	void toggleEditor(KviMaskEditor ** ppEd,KviWindowToolPageButton ** ppBtn,KviPtrList<KviMaskEntry> *l,char flag,const char *edName);
-	void internalMask(const QString &mask,bool bAdd,const QString &setBy,unsigned int setAt,KviPtrList<KviMaskEntry> *l,KviMaskEditor **ppEd);
+	void toggleEditor(KviMaskEditor ** ppEd,KviWindowToolPageButton ** ppBtn,KviPointerList<KviMaskEntry> *l,char flag,const char *edName);
+	void internalMask(const QString &mask,bool bAdd,const QString &setBy,unsigned int setAt,KviPointerList<KviMaskEntry> *l,KviMaskEditor **ppEd);
 	void checkChannelSync();
 	void showDoubleView(bool bShow);
 	void fixActionHistory();
@@ -166,9 +168,9 @@ public:
 	void getChannelActivityStats(KviChannelActivityStats * s);
 	//void getChannelActivityStatsDescription(QString &buffer);
 
-	KviPtrList<KviMaskEntry> * banList(){ return m_pBanList; };
-	KviPtrList<KviMaskEntry> * banExceptionList(){ return m_pBanExceptionList; };
-	KviPtrList<KviMaskEntry> * inviteList(){ return m_pInviteList; };
+	KviPointerList<KviMaskEntry> * banList(){ return m_pBanList; };
+	KviPointerList<KviMaskEntry> * banExceptionList(){ return m_pBanExceptionList; };
+	KviPointerList<KviMaskEntry> * inviteList(){ return m_pInviteList; };
 
 	QString * firstSelectedNickname(){ return m_pUserListView->firstSelectedNickname(); };
 	QString * nextSelectedNickname(){ return m_pUserListView->nextSelectedNickname(); };
@@ -276,11 +278,13 @@ public:
 
 	KviStr & channelLimit(){ return m_szChannelLimit; };
 	bool hasChannelLimit(){ return m_szChannelLimit.hasData(); };
-	KviStr & channelKey(){ return m_szChannelKey; };
+
+	bool hasChannelKey() { return !m_szChannelKey.isEmpty(); };
+	QString & channelKey(){ return m_szChannelKey; };
 
     void addHighlightedUser(const char * nick);
     void removeHighlightedUser(const char * nick);
-    int isHighlightedUser(const char * nick) { return (m_pTmpHighLighted->find(nick) == -1 ? 0 : 1); };
+    bool isHighlightedUser(const char * nick) { return m_pTmpHighLighted->find(nick); };
     KviIrcView * messageView() const { return m_pMessageView; };
 	virtual void lostUserFocus();
 	virtual void getTaskBarTipText(QString &buffer);
@@ -300,7 +304,7 @@ private slots:
 	void setMode(const char * mode);
 	void modeSelectorDone();
 	void textViewRightClicked();
-	void removeMasks(KviMaskEditor *ed,KviPtrList<KviMaskEntry> *l);
+	void removeMasks(KviMaskEditor *ed,KviPointerList<KviMaskEntry> *l);
 	void toggleToolButtons();
 protected:
 	virtual void preprocessMessage(QString & szMessage);
