@@ -27,6 +27,7 @@
 
 #define __KVIRC__
 
+#include "kvi_ircurl.h"
 #include "kvi_app.h"
 #include "kvi_console.h"
 #include "kvi_frame.h"
@@ -71,6 +72,7 @@
 #include "kvi_asynchronousconnectiondata.h"
 #include "kvi_ircdatastreammonitor.h"
 #include "kvi_toolwindows_container.h"
+#include "kvi_msgbox.h"
 
 #ifdef COMPILE_SSL_SUPPORT
 	#include "kvi_sslmaster.h"
@@ -83,18 +85,21 @@
 #include <qtoolbar.h>
 #include <qtoolbutton.h>
 #include <qtimer.h>
-#include <qhbox.h>
-#include <qpopupmenu.h>
+#include "kvi_tal_hbox.h"
+#include "kvi_tal_popupmenu.h"
 #include <qmessagebox.h>
 #include <qstringlist.h>
 
+#ifdef COMPILE_USE_QT4
+	#include <q3mimefactory.h>
+#endif
+
 #define __KVI_DEBUG__
 #include "kvi_debug.h"
 
 
 extern KVIRC_API KviIrcServerDataBase           * g_pIrcServerDataBase;
 extern KVIRC_API KviProxyDataBase               * g_pProxyDataBase;
-extern KVIRC_API KviRegisteredUserDataBase      * g_pRegisteredUserDataBase;
 extern KVIRC_API KviGarbageCollector            * g_pGarbageCollector;
 
 // %tmp[] = $str.grep("test",%array[])
@@ -115,13 +120,29 @@ KviConsole::KviConsole(KviFrame * lpFrm,int iFlags)
 		m_iFlags |= KVI_CONSOLE_FLAG_FIRSTINAPP;
 	}
 
-	m_pButtonBox = new QHBox(this,"button_box");
-	KviThemedLabel * l = new KviThemedLabel(m_pButtonBox,"dummy_label");
-	m_pButtonBox->setStretchFactor(l,1);
-	QToolTip::add(l,__tr2qs("What's this?"));
+	m_pButtonBox = new KviTalHBox(this);
+	m_pButtonBox->setSpacing(0);
+	m_pButtonBox->setMargin(0);
+	new QLabel(__tr2qs("Address:"),m_pButtonBox,"url_label");
+	m_pAddressEdit = new QComboBox(m_pButtonBox,"url_editor");
+	m_pAddressEdit->setAutoCompletion(true);
+	m_pAddressEdit->setDuplicatesEnabled(false);
+	m_pAddressEdit->setEditable(true);
+	m_pAddressEdit->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_URL)));
+	recentUrlsChanged();
+	m_pAddressEdit->setCurrentText("");
+	m_pAddressEdit->setInsertionPolicy(QComboBox::NoInsertion);
+	m_pAddressEdit->setMinimumHeight(24); //icon is 16px, + margins
+	m_pButtonBox->setStretchFactor(m_pAddressEdit,1);
+#ifdef COMPILE_USE_QT4
+	m_pButtonBox->setObjectName( QLatin1String( "kvi_window_button_box" ) );
+#endif
+	KviTalToolTip::add(m_pAddressEdit,__tr2qs("Current IRC URI"));
+	connect(m_pAddressEdit,SIGNAL(activated(const QString & )),this,SLOT(ircUriChanged(const QString & )));
+	connect(g_pApp,SIGNAL(recentUrlsChanged()),this,SLOT(recentUrlsChanged()));
 
 
-	m_pSplitter = new QSplitter(QSplitter::Horizontal,this,"splitter");
+	m_pSplitter = new QSplitter(Qt::Horizontal,this,"splitter");
 	m_pIrcView = new KviIrcView(m_pSplitter,lpFrm,this);
 	connect(m_pIrcView,SIGNAL(rightClicked()),this,SLOT(textViewRightClicked()));
 
@@ -132,11 +153,12 @@ KviConsole::KviConsole(KviFrame * lpFrm,int iFlags)
 	m_pNotifyViewButton = new KviWindowToolPageButton(KVI_SMALLICON_HIDELISTVIEW,KVI_SMALLICON_SHOWLISTVIEW,__tr2qs("Notify List"),buttonContainer(),true,"list_view_button");
 	connect(m_pNotifyViewButton,SIGNAL(clicked()),this,SLOT(toggleNotifyView()));
 	
-	m_pNotifyListView = new KviUserListView(m_pSplitter,m_pNotifyViewButton,0,this,19,__tr2qs("Notify List"),"notify_list_view");
+	m_pNotifyListView  = new KviUserListView(m_pSplitter,m_pNotifyViewButton,0,this,19,__tr2qs("Notify List"),"notify_list_view");
 
 	m_pInput   = new KviInput(this,m_pNotifyListView);
 
-	if(KVI_OPTION_BOOL(KviOption_boolAutoLogConsole))m_pIrcView->startLogging(0);
+	if(KVI_OPTION_BOOL(KviOption_boolAutoLogConsole))m_pIrcView->startLogging();
+
 }
 
 
@@ -145,6 +167,19 @@ int KviConsole::selectedCount()
 	return m_pNotifyListView->selectedCount();
 }
 
+void KviConsole::recentUrlsChanged(){
+	QString cur = m_pAddressEdit->currentText();
+	m_pAddressEdit->clear();
+	for ( 
+		QStringList::Iterator it = KVI_OPTION_STRINGLIST(KviOption_stringlistRecentIrcUrls).begin();
+		it != KVI_OPTION_STRINGLIST(KviOption_stringlistRecentIrcUrls).end();
+		++it
+			) {
+		m_pAddressEdit->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_URL)),*it);
+	}
+	m_pAddressEdit->setCurrentText(cur);
+}
+
 bool KviConsole::isNotConnected()
 {
 	return (context()->state() == KviIrcContext::Idle);
@@ -203,9 +238,6 @@ void KviConsole::triggerCreationEvents()
 
 		if(KVI_OPTION_BOOL(KviOption_boolShowTipAtStartup))
 			g_pFrame->executeInternalCommand(KVI_INTERNALCOMMAND_TIP_OPEN);
-
-		if(KVI_OPTION_BOOL(KviOption_boolShowServersConnectDialogOnStart))
-			g_pFrame->executeInternalCommand(KVI_INTERNALCOMMAND_SERVERSJOIN_OPEN);
 	}
 
 	if(m_iFlags & KVI_CONSOLE_FLAG_FIRSTINFRAME)
@@ -217,7 +249,7 @@ void KviConsole::triggerCreationEvents()
 }
 
 
-void KviConsole::fillContextPopup(QPopupMenu * p)
+void KviConsole::fillContextPopup(KviTalPopupMenu * p)
 {
 	int id;
 	int cc = 0;
@@ -245,7 +277,7 @@ void KviConsole::fillContextPopup(QPopupMenu * p)
 	}
 }
 
-void KviConsole::completeChannel(const QString &word,KviPtrList<QString> * matches)
+void KviConsole::completeChannel(const QString &word,KviPointerList<QString> * matches)
 {
 	// FIXME: first look in our context ?
 	/*
@@ -265,7 +297,7 @@ void KviConsole::completeChannel(const QString &word,KviPtrList<QString> * match
 	}
 }
 
-void KviConsole::completeServer(const QString &word, KviPtrList<QString> * matches)
+void KviConsole::completeServer(const QString &word, KviPointerList<QString> * matches)
 {
 	for(QStringList::Iterator it = KVI_OPTION_STRINGLIST(KviOption_stringlistRecentServers).begin(); it != KVI_OPTION_STRINGLIST(KviOption_stringlistRecentServers).end(); ++it)
 	{
@@ -311,8 +343,12 @@ void KviConsole::getUserTipText(const QString &nick,KviIrcUserEntry *e,QString &
 	}
 	if(e->avatar())
 	{
+#ifdef COMPILE_USE_QT4
+		Q3MimeSourceFactory::defaultFactory()->setPixmap("ulv_avatar",*(e->avatar()->pixmap()));
+#else
 		QMimeSourceFactory::defaultFactory()->setPixmap("ulv_avatar",*(e->avatar()->pixmap()));
-		buffer += "<tr><td><center><img src=\"ulv_avatar\"></center></td></tr>";
+#endif
+		buffer += QString("<tr><td><center><img src=\"ulv_avatar\" width=\"%1\"></center></td></tr>").arg(e->avatar()->pixmap()->width());
 	}
 
 	if(e->hasRealName())
@@ -322,6 +358,15 @@ void KviConsole::getUserTipText(const QString &nick,KviIrcUserEntry *e,QString &
 		buffer += "</b></center></td></tr>";
 	}
 
+	if(e->gender()!=KviIrcUserEntry::Unknown)
+	{
+		buffer += "<tr><td>";
+		buffer += __tr2qs("Gender:");
+		buffer += " ";
+		buffer += (e->gender()==KviIrcUserEntry::Male) ? __tr2qs("Male") : __tr2qs("Female");
+		buffer += "</td></tr>";
+	}
+
 	if(u)
 	{
 		QString mask;
@@ -377,14 +422,7 @@ void KviConsole::getUserTipText(const QString &nick,KviIrcUserEntry *e,QString &
 
 void KviConsole::toggleNotifyView()
 {
-	if(m_pNotifyListView->isVisible())
-	{
-		m_pNotifyListView->hide();
-		if(m_pNotifyViewButton->isOn())m_pNotifyViewButton->setOn(false);
-	} else {
-		m_pNotifyListView->show();
-		if(!(m_pNotifyViewButton->isOn()))m_pNotifyViewButton->setOn(true);
-	}
+	showNotifyList(!m_pNotifyListView->isVisible());
 }
 
 void KviConsole::executeInternalCommand(int index)
@@ -396,25 +434,34 @@ void KviConsole::saveProperties(KviConfig *cfg)
 {
 	KviWindow::saveProperties(cfg);
 	cfg->writeEntry("Splitter",m_pSplitter->sizes());
+	cfg->writeEntry("NotifyListViewVisible",m_pNotifyListView->isVisible());
 
 }
 
-void KviConsole::getBaseLogFileName(KviStr &buffer)
-{
-	buffer.sprintf("CONSOLE%u",ircContextId());
-}
 void KviConsole::getBaseLogFileName(QString &buffer)
 {
 	buffer=QString("CONSOLE%1").arg(ircContextId());
 }
 
+void KviConsole::showNotifyList(bool bShow)
+{
+	if(!bShow)
+	{
+		m_pNotifyListView->hide();
+		if(m_pNotifyViewButton->isOn())m_pNotifyViewButton->setOn(false);
+	} else {
+		m_pNotifyListView->show();
+		if(!(m_pNotifyViewButton->isOn()))m_pNotifyViewButton->setOn(true);
+	}
+}
+
 void KviConsole::loadProperties(KviConfig *cfg)
 {
 	int w = width();
-	QValueList<int> def;
+	KviValueList<int> def;
 	def.append((w * 85) / 100);
 	def.append((w * 15) / 100);
-	QValueList<int> cur = cfg->readIntListEntry("Splitter",def);
+	KviValueList<int> cur = cfg->readIntListEntry("Splitter",def);
 	// check the size correctness
 	if(cur.count() != 2)cur = def;
 	else {
@@ -424,6 +471,7 @@ void KviConsole::loadProperties(KviConfig *cfg)
 	}
 	m_pSplitter->setSizes(cur);
 	KviWindow::loadProperties(cfg);
+	showNotifyList(cfg->readBoolEntry("NotifyListViewVisible",false));
 }
 
 void KviConsole::textViewRightClicked()
@@ -439,14 +487,49 @@ KviWindow * KviConsole::activeWindow()
 	return this;
 }
 
+void KviConsole::ircUriChanged(const QString & text){
+	if(KviIrcUrl::run(text,KviIrcUrl::CurrentContext,this) & KviIrcUrl::InvalidProtocol)
+	{
+		KviMessageBox::warning(__tr2qs("KVIrc can accept only irc://, irc6://, ircs:// or irc6s:// URL's\n"
+				"Your URL is invalid. Check spelling and try again"));
+	}
+}
+
+void KviConsole::updateUri()
+{
+	QString uri;
+	if(connection())
+	{
+		KviIrcServer* server = connection()->target()->server();
+		if(server)
+		{
+			KviIrcUrl::join(uri,server);
+			KviChannel * last =connection()->channelList()->last();
+			for(KviChannel * c = connection()->channelList()->first();c;c = connection()->channelList()->next())
+			{
+				uri.append(c->name());
+				if(c->hasChannelKey()) {
+					uri.append("?");
+					uri.append(c->channelKey());
+				}
+				if(c!=last) uri.append(",");
+			}
+		}
+	}
+	m_pAddressEdit->setCurrentText(uri);
+}
 
 void KviConsole::connectionAttached()
 {
+	//need to update URI
+	connect(m_pContext->connection(),SIGNAL(chanListChanged()),this,SLOT(updateUri()));
+	updateUri();
 	m_pNotifyListView->setUserDataBase(connection()->userDataBase());
 }
 
 void KviConsole::connectionDetached()
 {
+	//need to update URI?
 	m_pNotifyListView->partAll();
 	m_pNotifyListView->setUserDataBase(0); // this is rather for crash tests
 }
@@ -570,9 +653,13 @@ int KviConsole::applyHighlighting(KviWindow *wnd,int type,const QString &nick,co
 		for(QStringList::Iterator it = KVI_OPTION_STRINGLIST(KviOption_stringlistHighlightWords).begin();
 				it != KVI_OPTION_STRINGLIST(KviOption_stringlistHighlightWords).end() ; ++it)
 		{
+			if((*it).isEmpty())
+				continue;
 			// FIXME : This is SLOOOOOOOOW (QString -> ascii translation!!) !!!!
 			if(szSource.find(QString(" %1 ").arg(*it),0,false) > -1)
+			{
 				return triggerOnHighlight(wnd,type,nick,user,host,szMsg,*it);
+			}
 		}
 	}
 
@@ -580,18 +667,19 @@ int KviConsole::applyHighlighting(KviWindow *wnd,int type,const QString &nick,co
 	{
 		if(((KviChannel *)wnd)->isHighlightedUser(nick))
 			return triggerOnHighlight(wnd,type,nick,user,host,szMsg,nick);
-	}
 
-
-	// FIXME: this is for userhighlighing
-	//        maybe mark the users as highlighted in the console user database
-	//        and then lookup them there ? this would be potentially a lot faster
-	KviRegisteredUser * u = g_pRegisteredUserDataBase->findMatchingUser(nick,user,host);
-
-	if(u)
-	{
-		if(u->getBoolProperty("highlight"))
-			return triggerOnHighlight(wnd,type,nick,user,host,szMsg,nick);
+		// FIXME: this is for userhighlighing
+		//        maybe mark the users as highlighted in the console user database
+		//        and then lookup them there ? this would be potentially a lot faster
+		KviRegisteredUser * u = connection()->userDataBase()->registeredUser(nick,user,host);
+	
+		// note that we're highlighting users only in channels since
+		// in a query (or DCC) highlighting the remote end is senseless.
+		if(u)
+		{
+			if(u->getBoolProperty("highlight"))
+				return triggerOnHighlight(wnd,type,nick,user,host,szMsg,nick);
+		}
 	}
 
 	return type;
@@ -693,7 +781,7 @@ void KviConsole::outputPrivmsg(KviWindow *wnd,
 	if(bIsChan && KVI_OPTION_BOOL(KviOption_boolShowChannelUserFlagInPrivmsgView))
 		((KviChannel *)wnd)->prependUserFlag(nick,szNick);
 
-	if(KVI_OPTION_BOOL(KviOption_boolColorNicks) && !KVI_OPTION_BOOL(KviOption_boolUseUserListColorsAsNickColors))
+	if(KVI_OPTION_BOOL(KviOption_boolColorNicks))
 	{
 		int sum = 0;
 		int i = nick.length();
@@ -815,7 +903,7 @@ void KviConsole::avatarChanged(KviAvatar * avatar,const QString &nick,const QStr
 		// Don't even try to do it for myself
 		if(!KviQString::equalCI(nick,connection()->userInfo()->nickName()))
 		{
-			KviRegisteredUser * u = g_pRegisteredUserDataBase->findMatchingUser(nick,user,host);
+			KviRegisteredUser * u = connection()->userDataBase()->registeredUser(nick,user,host);
 			if(u)
 			{
 				if(avatar)u->setProperty("avatar",avatar->identificationString());
@@ -859,7 +947,7 @@ void KviConsole::checkDefaultAvatar(KviIrcUserEntry *e,const QString &nick,const
 	}
 
 	// registered ?
-	KviRegisteredUser * u = g_pRegisteredUserDataBase->findMatchingUser(nick,user,host);
+	KviRegisteredUser * u = connection()->userDataBase()->registeredUser(nick,user,host);
 	if(u)
 	{
 		// the user is registered...
@@ -885,7 +973,7 @@ void KviConsole::resetAvatarForMatchingUsers(KviRegisteredUser * u)
 	QString szAvatar;
 	if(!u->getProperty("avatar",szAvatar))return;
 
-	QDictIterator<KviIrcUserEntry> it(*(connection()->userDataBase()->dict()));
+	KviPointerHashTableIterator<QString,KviIrcUserEntry> it(*(connection()->userDataBase()->dict()));
 	while(KviIrcUserEntry * e = it.current())
 	{
 		if(e->hasHost())
@@ -1076,7 +1164,7 @@ void KviConsole::fillCaptionBuffers()
 
 QPixmap * KviConsole::myIconPtr()
 {
-	return g_pIconManager->getSmallIcon(KVI_SMALLICON_CONSOLE);
+	return g_pIconManager->getSmallIcon(isConnected() ? KVI_SMALLICON_LINKS : KVI_SMALLICON_CONSOLE);
 }
 
 
@@ -1098,13 +1186,10 @@ void KviConsole::getTaskBarTipText(QString &buffer)
 	static QString html_spaceparopen(" (");
 	static QString html_spaceparclosed(")");
 
-
 	buffer = "<table width=\"100%\">" \
-						"<tr><td bgcolor=\"#303030\">" \
-							"<font color=\"#FFFFFF\"><b>";
+						START_TABLE_BOLD_ROW;
 	buffer += m_szStatusString;
-	buffer += "</b></font></td></tr>";
-
+	buffer += END_TABLE_BOLD_ROW;
 	if((context()->state() == KviIrcContext::Connected) && connection())
 	{
 		QString num;
@@ -1148,7 +1233,7 @@ void KviConsole::getTaskBarTipText(QString &buffer)
 		QDateTime dt;
 		dt.setTime_t(connection()->statistics()->connectionStartTime());
 
-		buffer += "<tr><td bgcolor=\"#F0F0F0\">";
+		buffer += START_TABLE_NORMAL_ROW;
 
 		buffer += __tr2qs("Connected since");
 		buffer += html_space;
