@@ -31,9 +31,10 @@
 #include "kvi_string.h"
 #include "kvi_irccontext.h"
 
-#include "kvi_list.h"
+#include "kvi_pointerlist.h"
 
 #include <time.h>
+#include <qcombobox.h>
 
 
 class QToolBar;
@@ -88,6 +89,7 @@ protected:
 	// UI
 	KviUserListView                  * m_pNotifyListView;
 	KviWindowToolPageButton          * m_pNotifyViewButton;
+	QComboBox						 * m_pAddressEdit;
 	QString                            m_szStatusString; // nick (flags) on server | not connected
 protected:
 	// UI
@@ -95,10 +97,9 @@ protected:
 	virtual void fillCaptionBuffers();
 	virtual void resizeEvent(QResizeEvent *e);
 	virtual void closeEvent(QCloseEvent *e);
-	virtual void getBaseLogFileName(KviStr &buffer);
 	virtual void getBaseLogFileName(QString &buffer);
 	virtual void getTaskBarTipText(QString &buffer);
-	virtual void fillContextPopup(QPopupMenu * p);
+	virtual void fillContextPopup(KviTalPopupMenu * p);
 	virtual QSize sizeHint() const;
 	virtual void applyOptions();
 	virtual void triggerCreationEvents();
@@ -113,6 +114,8 @@ protected:
 	void destroyConnection();
 	// internal helper for applyHighlighting
 	int triggerOnHighlight(KviWindow *wnd,int type,const QString &nick,const QString &user,const QString &host,const QString &szMsg,const QString &trigger);
+	
+	void showNotifyList(bool bShow);
 
 public:
 	// UI
@@ -181,8 +184,8 @@ public:
 	const QString & statusString(){ return m_szStatusString; };
 	
 	// forwarders from KviIrcConnection
-	KVI_DEPRECATED KviPtrList<KviChannel> * channelList(){ return connection() ? connection()->channelList() : 0; };
-	KVI_DEPRECATED KviPtrList<KviQuery> * queryList(){ return connection() ? connection()->queryList() : 0; };
+	KVI_DEPRECATED KviPointerList<KviChannel> * channelList(){ return connection() ? connection()->channelList() : 0; };
+	KVI_DEPRECATED KviPointerList<KviQuery> * queryList(){ return connection() ? connection()->queryList() : 0; };
 	KVI_DEPRECATED unsigned int channelCount(){ return (connection() ? connection()->channelList()->count() : 0); };
 	KVI_DEPRECATED unsigned int queryCount(){ return (connection() ? connection()->queryList()->count() : 0); };
 	
@@ -192,13 +195,16 @@ public:
 
 	KviWindow * activeWindow();
 	// User db, connection related
-	void completeChannel(const QString &word,KviPtrList<QString> * matches);
-	void completeServer(const QString &word,KviPtrList<QString> * matches);
+	void completeChannel(const QString &word,KviPointerList<QString> * matches);
+	void completeServer(const QString &word,KviPointerList<QString> * matches);
 	void connectionAttached();
 	void connectionDetached();
 public slots:
+	void updateUri();
 	void executeInternalCommand(int index);
+	void recentUrlsChanged();
 protected slots:
+	void ircUriChanged(const QString & );
 	void toggleNotifyView();
 	void textViewRightClicked();
 };
