@@ -41,21 +41,21 @@
 	#include "kvi_toolwindows_container.h"
 	
 	#include <qlayout.h>
-	#include <qasciidict.h>
+	#include "kvi_pointerhashtable.h"
 
 	// kvi_app.cpp
 	extern KVIRC_API KviCryptEngineManager * g_pCryptEngineManager;
 	extern KVIRC_API KviModuleManager      * g_pModuleManager;
 
-	KviEngineListBoxItem::KviEngineListBoxItem(QListBox * lb,KviCryptEngineDescription * d,const char * modName)
-	: QListBoxText(lb,d->szName.ptr())
+	KviEngineListBoxItem::KviEngineListBoxItem(KviTalListBox * lb,KviCryptEngineDescription * d,const char * modName)
+	: KviTalListBoxText(lb,d->szName)
 	{
 		m_szName = d->szName;
 		m_szAuthor = d->szAuthor;
 		m_szDescription = d->szDescription;
 		m_iFlags = d->iFlags;
 		m_szModuleName = modName;
-		setText(d->szName.ptr());
+		setText(d->szName);
 	}
 
 	KviEngineListBoxItem::~KviEngineListBoxItem()
@@ -66,7 +66,7 @@
 
 
 	KviCryptController::KviCryptController(QWidget * par,KviWindowToolPageButton* button,const char * name,KviWindow * wnd,KviCryptSessionInfo * cur)
-	: KviWindowToolWidget(par,button,name)
+	: KviWindowToolWidget(par,button)
 	{
 // FIXME: #warning "Load the available modules here"
 
@@ -78,7 +78,11 @@
 
 		m_pWindow = wnd;
 
+#ifdef COMPILE_USE_QT4
+		setFocusPolicy(Qt::ClickFocus);
+#else
 		setFocusPolicy(QWidget::ClickFocus);
+#endif
 
 		QGridLayout *g = new QGridLayout(this,10,4,2,2);
 
@@ -96,13 +100,17 @@
 		g->addMultiCellWidget(m_pEnableCheck,2,2,0,3);
 		connect(m_pEnableCheck,SIGNAL(toggled(bool)),this,SLOT(enableCheckToggled(bool)));
 
-		m_pListBox = new QListBox(this);
-		connect(m_pListBox,SIGNAL(highlighted(QListBoxItem *)),this,SLOT(engineHighlighted(QListBoxItem *)));
+		m_pListBox = new KviTalListBox(this);
+		connect(m_pListBox,SIGNAL(highlighted(KviTalListBoxItem *)),this,SLOT(engineHighlighted(KviTalListBoxItem *)));
 		g->addMultiCellWidget(m_pListBox,3,8,0,0);
 
 		m_pDescriptionLabel = new QLabel(this);
 		m_pDescriptionLabel->setFrameStyle(QFrame::Sunken | QFrame::StyledPanel);
-		m_pDescriptionLabel->setAlignment(AlignTop | AlignLeft);
+#ifdef COMPILE_USE_QT4
+		m_pDescriptionLabel->setAlignment(Qt::AlignTop | Qt::AlignLeft);
+#else
+		m_pDescriptionLabel->setAlignment(Qt::AlignTop | Qt::AlignLeft);
+#endif
 		g->addMultiCellWidget(m_pDescriptionLabel,3,3,1,3);
 
 		m_pAuthorLabel = new QLabel(this);
@@ -147,7 +155,7 @@
 
 		if(cur)
 		{
-			QListBoxItem * it = m_pListBox->findItem(cur->szEngineName.ptr());
+			KviTalListBoxItem * it = (KviTalListBoxItem *)m_pListBox->findItem(cur->szEngineName.ptr());
 			if(it)
 			{
 				m_pEnableCheck->setChecked(true);
@@ -176,10 +184,10 @@
 
 	void KviCryptController::fillEngineList()
 	{
-		const QAsciiDict<KviCryptEngineDescription> * a = g_pCryptEngineManager->engineDict();
+		const KviPointerHashTable<QString,KviCryptEngineDescription> * a = g_pCryptEngineManager->engineDict();
 		if(a)
 		{
-			QAsciiDictIterator<KviCryptEngineDescription> it(*a);
+			KviPointerHashTableIterator<QString,KviCryptEngineDescription> it(*a);
 			while(it.current())
 			{
 				KviStr modName = it.current()->providerHandle ? ((KviModule *)(it.current()->providerHandle))->name() : "";
@@ -191,7 +199,7 @@
 		noEnginesAvailable();
 	}
 
-	void KviCryptController::engineHighlighted(QListBoxItem *it)
+	void KviCryptController::engineHighlighted(KviTalListBoxItem *it)
 	{
 		if(it)
 		{
