@@ -1,6 +1,6 @@
 #ifndef _KVI_CRYPTCONTROLLER_H_
 #define _KVI_CRYPTCONTROLLER_H_
-
+//=============================================================================
 //
 //   File : kvi_cryptcontroller.h
 //   Creation date : Fri Nov 03 2000 14:11:03 CEST by Szymon Stefanek
@@ -22,15 +22,17 @@
 //   along with this program. If not, write to the Free Software Foundation,
 //   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 //
+//=============================================================================
 
 #include "kvi_settings.h"
 
 
 
-#ifdef COMPILE_CRYPT_SUPPORT
+// Qt4 moc bails out on this ??????
 
+#if defined(COMPILE_CRYPT_SUPPORT) || defined(Q_MOC_RUN)
 	#include <qwidget.h>
-	#include <qlistbox.h>
+	#include "kvi_tal_listbox.h"
 	#include <qpushbutton.h>
 	#include <qcheckbox.h>
 	#include <qlabel.h>
@@ -52,12 +54,11 @@
 		bool             bDoDecrypt;
 	};
 
-
-	class KVIRC_API KviEngineListBoxItem : public QListBoxText
+	class KVIRC_API KviEngineListBoxItem : public KviTalListBoxText
 	{
 		friend class KviCryptController;
 	public:
-		KviEngineListBoxItem(QListBox * lb,KviCryptEngineDescription * d,const char * modName);
+		KviEngineListBoxItem(KviTalListBox * lb,KviCryptEngineDescription * d,const char * modName);
 		~KviEngineListBoxItem();
 	public:
 		KviStr m_szName;
@@ -76,7 +77,7 @@
 		~KviCryptController();
 	protected:
 		KviWindow            * m_pWindow;
-		QListBox             * m_pListBox;
+		KviTalListBox             * m_pListBox;
 		QPushButton          * m_pOkButton;
 		KviStyledCheckBox            * m_pEnableCheck;
 		QLabel               * m_pDescriptionLabel;
@@ -93,7 +94,7 @@
 		KviCryptSessionInfo  * m_pSessionInfo;
 	private slots:
 		void enableCheckToggled(bool bChecked);
-		void engineHighlighted(QListBoxItem *it);
+		void engineHighlighted(KviTalListBoxItem *it);
 		void okClicked();
 	public:
 		KviCryptSessionInfo * getNewSessionInfo();
