@@ -54,6 +54,8 @@
 #include "kvi_customtoolbardescriptor.h"
 #include "kvi_actionmanager.h"
 #include "kvi_defaults.h"
+#include "kvi_ircview.h"
+#include "kvi_tal_popupmenu.h"
 
 #include "kvi_kvs_script.h"
 #include "kvi_kvs_eventtriggers.h"
@@ -63,14 +65,28 @@
 #include <qlineedit.h>
 #include <qmessagebox.h>
 #include <qcheckbox.h>
-#include <qaccel.h>
+
 #include <qtimer.h>
 #include <qlayout.h>
 
 #if QT_VERSION >= 300
 	#include <qfile.h>
 	#include <qtextstream.h>
-	#include <qdockarea.h>
+	#ifdef COMPILE_USE_QT4
+		#include <q3dockarea.h>
+		#define QDockArea Q3DockArea
+	#else
+		#include <qdockarea.h>
+	#endif
+#endif
+
+
+#ifdef COMPILE_USE_QT4
+	#include <qdesktopwidget.h>
+	#include <qevent.h>
+	#include <QShortcut>
+#else
+	#include <qaccel.h>
 #endif
 
 #include <time.h>
@@ -94,17 +110,17 @@ KviFrame::KviFrame()
 
 	setIcon(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_KVIRC)));
 
-	m_pWinList  = new KviPtrList<KviWindow>;
+	m_pWinList  = new KviPointerList<KviWindow>;
 	m_pWinList->setAutoDelete(false);
 
-	m_pModuleExtensionToolBarList = new KviPtrList<KviMexToolBar>;
+	m_pModuleExtensionToolBarList = new KviPointerList<KviMexToolBar>;
 	m_pModuleExtensionToolBarList->setAutoDelete(false);
 
 	m_pActiveContext = 0;
 
 	m_pDockExtension = 0;
 	
-	m_pSplitter = new QSplitter(QSplitter::Horizontal,this,"main_splitter");
+	m_pSplitter = new QSplitter(Qt::Horizontal,this,"main_splitter");
 //	m_pSplitter->setFrameShape(QFrame::NoFrame);
 	
 	setCentralWidget(m_pSplitter);
@@ -112,14 +128,29 @@ KviFrame::KviFrame()
 	setUsesBigPixmaps(KVI_OPTION_BOOL(KviOption_boolUseBigIcons));
 
 	m_pMdi      = new KviMdiManager(m_pSplitter,this,"mdi_manager");
-
 	connect(m_pMdi,SIGNAL(enteredSdiMode()),this,SLOT(enteredSdiMode()));
 	connect(m_pMdi,SIGNAL(leftSdiMode()),this,SLOT(leftSdiMode()));
 
-	m_pMenuBar   = new KviMenuBar(this,"main_menu_bar"); // This theoretically had to exists before KviMdiManager (that uses enterSdiMode)
+	// This theoretically had to exists before KviMdiManager (that uses enterSdiMode)
+	m_pMenuBar   = new KviMenuBar(this,"main_menu_bar");
+#ifdef COMPILE_USE_QT4
+	setMenuWidget(m_pMenuBar);
+#endif
+
 	if(KVI_OPTION_BOOL(KviOption_boolStatusBarVisible))
+	{
 		m_pStatusBar = new KviStatusBar(this);
-	else
+#ifdef COMPILE_USE_QT4
+		setStatusBar(m_pStatusBar);
+#endif
+		// torque: moved out of status bar constructor
+		// because module init functions exectued in load()
+		// couldn't access the status bar via g_pFrame->mainStatusBar()
+		// (assignment of m_pStatusBar happened after load() and
+		// the init function)
+		m_pStatusBar->load();
+
+	} else
 		m_pStatusBar = 0;
 
 	m_pTaskBar = 0;
@@ -139,7 +170,8 @@ KviFrame::KviFrame()
 
 	applyOptions();
 
-	m_pAccel = new QAccel(this);
+
+	m_pAccel = new KviAccel(this);
 
 	installAccelerators(this);
 
@@ -148,8 +180,6 @@ KviFrame::KviFrame()
 
 KviFrame::~KviFrame()
 {
-	g_pApp->frameDestructorCallback();
-
 	KVI_OPTION_RECT(KviOption_rectFrameGeometry) = QRect(pos().x(),pos().y(),
 			size().width(),size().height());
 
@@ -161,6 +191,16 @@ KviFrame::~KviFrame()
 
 	saveToolBarPositions();
 	saveModuleExtensionToolBars();
+
+	// Call the frame destructor callback AFTER saving the toolbar positions
+	// This is because the destructor callback kills alls the KVS objects
+	// and thus the eventual user toolbar objects too and their position
+	// wouldn't be saved if they are shown at startup.
+
+	g_pApp->frameDestructorCallback();
+
+	// Now start killing stuff
+
 	// Explicitly kill all the module extension toolbars: qt has NOT to delete them: we must call their "die" method
 	while(KviMexToolBar * t = m_pModuleExtensionToolBarList->first())t->die();
 	delete m_pModuleExtensionToolBarList;
@@ -174,11 +214,11 @@ KviFrame::~KviFrame()
 	}
 
 	// the really last thing to do : close all the windows
-	while(m_pWinList->first())closeWindow(m_pWinList->first());
+	while(m_pWinList->first())
+		closeWindow(m_pWinList->first());
 	delete m_pWinList;
 	
 	delete m_pAccel;
-	
 	g_pFrame = 0;
 }
 
@@ -214,7 +254,7 @@ void KviFrame::restoreModuleExtensionToolBars()
 		{
 			QString szMod = szEntry.left(idx);
 			szEntry.remove(0,idx + 1);
-			g_pModuleExtensionManager->allocateExtension("toolbar",szEntry,firstConsole(),0,0,szMod);
+			g_pModuleExtensionManager->allocateExtension("toolbar",KviStr(szEntry),firstConsole(),0,0,szMod);
 		}
 	}
 }
@@ -305,53 +345,63 @@ KviMexToolBar * KviFrame::moduleExtensionToolBar(int extensionId)
 		</example>
 */
 
-QAccel * KviFrame::installAccelerators(QWidget * wnd)
+KviAccel * KviFrame::installAccelerators(QWidget * wnd)
 {
-	QAccel *ac = new QAccel(wnd ? (QWidget *)wnd : (QWidget *)this);
+	QWidget * pParent = wnd ? (QWidget *)wnd : (QWidget *)this;
+#ifdef COMPILE_USE_QT4
+	new QShortcut(QKeySequence(Qt::Key_Left + Qt::ALT),pParent,SLOT(switchToPrevWindow()));
+	new QShortcut(QKeySequence(Qt::Key_Right + Qt::ALT),pParent,SLOT(switchToNextWindow()));
+	new QShortcut(QKeySequence(Qt::Key_Up + Qt::CTRL),pParent,SLOT(maximizeWindow()));
+	new QShortcut(QKeySequence(Qt::Key_Down + Qt::CTRL),pParent,SLOT(minimizeWindow()));
+	new QShortcut(QKeySequence(Qt::Key_Escape +Qt::CTRL),pParent,SLOT(minimizeWindow()));
+	new QShortcut(QKeySequence(Qt::Key_Left + Qt::ALT + Qt::SHIFT),pParent,SLOT(switchToPrevWindowInContext()));
+	new QShortcut(QKeySequence(Qt::Key_Right + Qt::ALT + Qt::SHIFT),pParent,SLOT(switchToNextWindowInContext()));
+#endif
+	KviAccel *ac = new KviAccel(pParent);
 
 	static int accel_table[] = {
-		Key_Left + ALT ,    // prev window
-		Key_Right + ALT ,   // next window
-		Key_Up + CTRL ,      // maximize window
-		Key_Down + CTRL ,    // minimize window
-		Key_Escape +CTRL,         // minimize window
-		Key_Left + ALT + SHIFT ,  // prev window in context
-		Key_Right + ALT + SHIFT,  // next window in context
-		Key_F4 + CTRL ,     // close current window
-		Key_1 + CTRL ,       // script accels...
-		Key_2 + CTRL ,
-		Key_3 + CTRL ,
-		Key_4 + CTRL ,
-		Key_5 + CTRL ,
-		Key_6 + CTRL ,
-		Key_7 + CTRL ,
-		Key_8 + CTRL ,
-		Key_9 + CTRL ,
-		Key_0 + CTRL ,
-		Key_F1 , // reserved for context sensitive help
-		Key_F2 ,
-		Key_F3 ,
-		Key_F4 ,
-		Key_F5 ,
-		Key_F6 ,
-		Key_F7 ,
-		Key_F8 ,
-		Key_F9 ,
-		Key_F10 ,
-		Key_F11 ,
-		Key_F12 ,
-/*		Key_F1 + SHIFT ,       // window select...
-		Key_F2 + SHIFT ,
-		Key_F3 + SHIFT ,
-		Key_F4 + SHIFT ,
-		Key_F5 + SHIFT ,
-		Key_F6 + SHIFT ,
-		Key_F7 + SHIFT ,
-		Key_F8 + SHIFT ,
-		Key_F9 + SHIFT ,
-		Key_F10 + SHIFT ,
-		Key_F11 + SHIFT ,
-		Key_F12 + SHIFT ,*/
+		Qt::Key_Left + Qt::ALT ,    // prev window
+		Qt::Key_Right + Qt::ALT ,   // next window
+		Qt::Key_Up + Qt::CTRL ,      // maximize window
+		Qt::Key_Down + Qt::CTRL ,    // minimize window
+		Qt::Key_Escape +Qt::CTRL,         // minimize window
+		Qt::Key_Left + Qt::ALT + Qt::SHIFT ,  // prev window in context
+		Qt::Key_Right + Qt::ALT + Qt::SHIFT,  // next window in context
+		Qt::Key_F4 + Qt::CTRL ,     // close current window
+		Qt::Key_1 + Qt::CTRL ,       // script accels...
+		Qt::Key_2 + Qt::CTRL ,
+		Qt::Key_3 + Qt::CTRL ,
+		Qt::Key_4 + Qt::CTRL ,
+		Qt::Key_5 + Qt::CTRL ,
+		Qt::Key_6 + Qt::CTRL ,
+		Qt::Key_7 + Qt::CTRL ,
+		Qt::Key_8 + Qt::CTRL ,
+		Qt::Key_9 + Qt::CTRL ,
+		Qt::Key_0 + Qt::CTRL ,
+		Qt::Key_F1 , // reserved for context sensitive help
+		Qt::Key_F2 ,
+		Qt::Key_F3 ,
+		Qt::Key_F4 ,
+		Qt::Key_F5 ,
+		Qt::Key_F6 ,
+		Qt::Key_F7 ,
+		Qt::Key_F8 ,
+		Qt::Key_F9 ,
+		Qt::Key_F10 ,
+		Qt::Key_F11 ,
+		Qt::Key_F12 ,
+/*		Qt::Key_F1 + Qt::SHIFT ,       // window select...
+		Qt::Key_F2 + Qt::SHIFT ,
+		Qt::Key_F3 + Qt::SHIFT ,
+		Qt::Key_F4 + Qt::SHIFT ,
+		Qt::Key_F5 + Qt::SHIFT ,
+		Qt::Key_F6 + Qt::SHIFT ,
+		Qt::Key_F7 + Qt::SHIFT ,
+		Qt::Key_F8 + Qt::SHIFT ,
+		Qt::Key_F9 + Qt::SHIFT ,
+		Qt::Key_F10 + Qt::SHIFT ,
+		Qt::Key_F11 + Qt::SHIFT ,
+		Qt::Key_F12 + Qt::SHIFT ,*/
 		0
 	};
 
@@ -369,66 +419,67 @@ QAccel * KviFrame::installAccelerators(QWidget * wnd)
 
 void KviFrame::accelActivated(int id)
 {
-	QAccel * acc = (QAccel *)sender();
+	KviAccel * acc = (KviAccel *)sender();
 
 	int keys = (int)(acc->key(id));
 	KviTaskBarItem *item = 0;
+	debug("accel");
 	switch(keys)
 	{
-		case (Key_Left+ALT): switchToPrevWindow(); break;
-		case (Key_Right+ALT): switchToNextWindow(); break;
-		case (Key_Up+CTRL): maximizeWindow(); break;
-		case (Key_Escape+CTRL):
-		case (Key_Down+CTRL): minimizeWindow(); break;
-		case (Key_Left+ALT+SHIFT): switchToPrevWindowInContext(); break;
-		case (Key_Right+ALT+SHIFT): switchToNextWindowInContext(); break;
-		case (Key_F4+CTRL):	if(g_pActiveWindow)g_pActiveWindow->close(); break;
-		case (Key_F1): g_pApp->contextSensitiveHelp(); break;
-/*		case(Key_F1 + SHIFT):
+		case (Qt::Key_Left+Qt::ALT): switchToPrevWindow(); break;
+		case (Qt::Key_Right+Qt::ALT): switchToNextWindow(); break;
+		case (Qt::Key_Up+Qt::CTRL): maximizeWindow(); break;
+		case (Qt::Key_Escape+Qt::CTRL):
+		case (Qt::Key_Down+Qt::CTRL): minimizeWindow(); break;
+		case (Qt::Key_Left+Qt::ALT+Qt::SHIFT): switchToPrevWindowInContext(); break;
+		case (Qt::Key_Right+Qt::ALT+Qt::SHIFT): switchToNextWindowInContext(); break;
+		case (Qt::Key_F4+Qt::CTRL):	if(g_pActiveWindow)g_pActiveWindow->close(); break;
+		case (Qt::Key_F1): g_pApp->contextSensitiveHelp(); break;
+/*		case(Qt::Key_F1 + SHIFT):
 			item = m_pTaskBar->item(0);
 			if(item) setActiveWindow(item->window());
 			break;
-		case(Key_F2 + SHIFT):
+		case(Qt::Key_F2 + SHIFT):
 			item = m_pTaskBar->item(1);
 			if(item) setActiveWindow(item->window());
 			break;
-		case(Key_F3 + SHIFT):
+		case(Qt::Key_F3 + SHIFT):
 			item = m_pTaskBar->item(2);
 			if(item) setActiveWindow(item->window());
 			break;
-		case(Key_F4 + SHIFT):
+		case(Qt::Key_F4 + SHIFT):
 			item = m_pTaskBar->item(3);
 			if(item) setActiveWindow(item->window());
 			break;
-		case(Key_F5 + SHIFT):
+		case(Qt::Key_F5 + SHIFT):
 			item = m_pTaskBar->item(4);
 			if(item) setActiveWindow(item->window());
 			break;
-		case(Key_F6 + SHIFT):
+		case(Qt::Key_F6 + SHIFT):
 			item = m_pTaskBar->item(5);
 			if(item) setActiveWindow(item->window());
 			break;
-		case(Key_F7 + SHIFT):
+		case(Qt::Key_F7 + SHIFT):
 			item = m_pTaskBar->item(6);
 			if(item) setActiveWindow(item->window());
 			break;
-		case(Key_F8 + SHIFT):
+		case(Qt::Key_F8 + SHIFT):
 			item = m_pTaskBar->item(7);
 			if(item) setActiveWindow(item->window());
 			break;
-		case(Key_F9 + SHIFT):
+		case(Qt::Key_F9 + SHIFT):
 			item = m_pTaskBar->item(8);
 			if(item) setActiveWindow(item->window());
 			break;
-		case(Key_F10 + SHIFT):
+		case(Qt::Key_F10 + SHIFT):
 			item = m_pTaskBar->item(9);
 			if(item) setActiveWindow(item->window());
 			break;
-		case(Key_F11 + SHIFT):
+		case(Qt::Key_F11 + SHIFT):
 			item = m_pTaskBar->item(10);
 			if(item) setActiveWindow(item->window());
 			break;
-		case(Key_F12 + SHIFT):
+		case(Qt::Key_F12 + SHIFT):
 			item = m_pTaskBar->item(11);
 			if(item) setActiveWindow(item->window());
 			break;*/
@@ -641,11 +692,12 @@ void KviFrame::addWindow(KviWindow *wnd,bool bShow)
 	
 default_docking:
 	{
-		KviMdiChild * lpC = dockWindow(wnd,false,true); //cascade it
+		KviMdiChild * lpC = dockWindow(wnd,false); //cascade it
 		wnd->triggerCreationEvents();
 		if(bShow)
 		{
 			m_pMdi->showAndActivate(lpC);
+			if(KVI_OPTION_BOOL(KviOption_boolMdiManagerInSdiMode)) wnd->maximize();
 			// Handle the special case of this top level widget not being the active one.
 			// In this situation the child will not get the focusInEvent
 			// and thus will not call out childWindowActivated() method
@@ -830,7 +882,10 @@ void KviFrame::childWindowActivated(KviWindow *wnd)
 	m_pTaskBar->setActiveItem(wnd->taskBarItem());
 
 	//wnd->gainedActiveWindowStatus(); // <-- atm unused
-
+	
+	if(g_pActiveWindow->view())
+		g_pActiveWindow->view()->clearUnreaded();
+	
 	emit activeWindowChanged();
 	if(bActiveContextChanged)emit activeContextChanged();
 
@@ -892,10 +947,11 @@ void KviFrame::updateCaption()
 
 void KviFrame::closeEvent(QCloseEvent *e)
 {
-	e->ignore();
 
 	if(KVI_OPTION_BOOL(KviOption_boolCloseInTray))
 	{
+		e->ignore();
+
 		if(!dockExtension())
 		{
 		    executeInternalCommand(KVI_INTERNALCOMMAND_DOCKWIDGET_SHOW);
@@ -906,52 +962,54 @@ void KviFrame::closeEvent(QCloseEvent *e)
 			dockExtension()->setPrevWindowState(windowState());
 			QTimer::singleShot( 0, this, SLOT(hide()) );
 		}
+		return;
 	}
-	else
+
+	if(KVI_OPTION_BOOL(KviOption_boolConfirmCloseWhenThereAreConnections))
 	{
-	
-		if(KVI_OPTION_BOOL(KviOption_boolConfirmCloseWhenThereAreConnections))
-		{
-			// check for running connections
-			
-			bool bGotRunningConnection = false;
-			for(KviWindow * w = m_pWinList->first();w;w = m_pWinList->next())
-			{
-				if(w->type() == KVI_WINDOW_TYPE_CONSOLE)
-				{
-					if(((KviConsole *)w)->connectionInProgress())
-					{
-						bGotRunningConnection = true;
-						break;
-					}
-				}
-			}
-			
-			if(bGotRunningConnection)
-			{
-				QString txt = "<p>";
-				txt += __tr2qs("There are active connections, are you sure you wish to ");
-				txt += __tr2qs("quit KVIrc?");
-				txt += "</p>";
+		// check for running connections
 		
-				switch(QMessageBox::warning(this,__tr2qs("Confirmation - KVIrc"),txt,__tr2qs("&Yes"),__tr2qs("&Always"),__tr2qs("&No"),2,2))
+		bool bGotRunningConnection = false;
+		for(KviWindow * w = m_pWinList->first();w;w = m_pWinList->next())
+		{
+			if(w->type() == KVI_WINDOW_TYPE_CONSOLE)
+			{
+				if(((KviConsole *)w)->connectionInProgress())
 				{
-					case 0:
-						// ok to close
-					break;
-					case 1:
-						// ok to close but don't ask again
-						KVI_OPTION_BOOL(KviOption_boolConfirmCloseWhenThereAreConnections) = false;
-					break;
-					case 2:
-						return;
+					bGotRunningConnection = true;
 					break;
 				}
 			}
 		}
-
-	g_pApp->destroyFrame();
+		
+		if(bGotRunningConnection)
+		{
+			QString txt = "<p>";
+			txt += __tr2qs("There are active connections, are you sure you wish to ");
+			txt += __tr2qs("quit KVIrc?");
+			txt += "</p>";
+	
+			switch(QMessageBox::warning(this,__tr2qs("Confirmation - KVIrc"),txt,__tr2qs("&Yes"),__tr2qs("&Always"),__tr2qs("&No"),2,2))
+			{
+				case 0:
+					// ok to close
+				break;
+				case 1:
+					// ok to close but don't ask again
+					KVI_OPTION_BOOL(KviOption_boolConfirmCloseWhenThereAreConnections) = false;
+				break;
+				case 2:
+					e->ignore();
+					return;
+				break;
+			}
+		}
 	}
+
+	e->accept();
+
+	if(g_pApp)
+		g_pApp->destroyFrame();
 }
 
 void KviFrame::resizeEvent(QResizeEvent *e)
@@ -1003,12 +1061,18 @@ void KviFrame::toggleStatusBar()
 		//if(statusBar())delete statusBar(); // kill any existing status bar (QT BUG)
 
 		m_pStatusBar = new KviStatusBar(this);
+		m_pStatusBar->load();
+#ifdef COMPILE_USE_QT4
+		setStatusBar(m_pStatusBar);
+#endif
 		m_pStatusBar->show();
+#ifndef COMPILE_USE_QT4
 		setUpLayout();
+#endif //!COMPILE_USE_QT4
 	}
 }
 
-void KviFrame::fillToolBarsPopup(QPopupMenu * p)
+void KviFrame::fillToolBarsPopup(KviTalPopupMenu * p)
 {
 	p->clear();
 
@@ -1033,7 +1097,7 @@ void KviFrame::fillToolBarsPopup(QPopupMenu * p)
 	}
 
 	// FIXME: Should this display "Hide %1" when the toolbar is already visible ?
-	QDictIterator<KviCustomToolBarDescriptor> it2(*(KviCustomToolBarManager::instance()->descriptors()));
+	KviPointerHashTableIterator<QString,KviCustomToolBarDescriptor> it2(*(KviCustomToolBarManager::instance()->descriptors()));
 	if(it2.current())
 	{
 		if(cnt > 0)p->insertSeparator();
@@ -1079,8 +1143,8 @@ void KviFrame::toolbarsPopupSelected(int id)
 {
 	const QObject * o = sender();
 	if(!o)return;
-	if(!o->inherits("QPopupMenu"))return;
-	const QPopupMenu * p = (const QPopupMenu *)o;
+	if(!o->inherits("KviTalPopupMenu"))return;
+	const KviTalPopupMenu * p = (const KviTalPopupMenu *)o;
 	int idext = p->itemParameter(id);
 	
 	KviCustomToolBarDescriptor * dd = KviCustomToolBarManager::instance()->findDescriptorByInternalId(idext);
@@ -1106,7 +1170,11 @@ bool KviFrame::focusNextPrevChild(bool next)
 	QWidget * w = focusWidget();
 	if(w)
 	{
+#ifdef COMPILE_USE_QT4
+		if(w->focusPolicy() == Qt::StrongFocus)return false;
+#else
 		if(w->focusPolicy() == QWidget::StrongFocus)return false;
+#endif
 		//QVariant v = w->property("KviProperty_FocusOwner");
 		//if(v.isValid())return false; // Do NOT change the focus widget!
 		
@@ -1129,6 +1197,7 @@ bool KviFrame::focusNextPrevChild(bool next)
 // Toolbar positioning stuff
 ////////////////////////////////////////////////////////////////////////////////////////////////////
 
+
 void KviFrame::saveToolBarPositions()
 {
 	QString szTemp;
@@ -1137,13 +1206,16 @@ void KviFrame::saveToolBarPositions()
 	QFile f(szTemp);
 	if(f.open(IO_WriteOnly | IO_Truncate))
 	{
+#ifdef COMPILE_USE_QT4
+		f.write(saveState(1));
+#else //!COMPILE_USE_QT4
 		QTextStream ts(&f);
 		ts << *this;
 		f.close();
+#endif //!COMPILE_USE_QT4
 	}
 }
 
-
 void KviFrame::restoreToolBarPositions()
 {
 	QString szTemp;
@@ -1155,15 +1227,26 @@ void KviFrame::restoreToolBarPositions()
 	
 	if(f.open(IO_ReadOnly))
 	{
+#ifdef COMPILE_USE_QT4
+		if(!restoreState(f.readAll(),1))
+			debug("Error while restoring toolbars position");
+#else //!COMPILE_USE_QT4
 		QTextStream ts(&f);
 		ts >> *this;
 		f.close();
+#endif //!COMPILE_USE_QT4
 	} else {
 		bNeedDefaults = true;
 	}
 
 	if(m_pTaskBar->inherits("KviTreeTaskBar"))
 	{
+#ifdef COMPILE_USE_QT4
+		// ensure that it is not too wide
+		m_pTaskBar->setMaximumWidth(600);
+		if(m_pTaskBar->width() > 600)
+			m_pTaskBar->setFixedWidth(250);
+#else //!COMPILE_USE_QT4
 		QDockArea * a = m_pTaskBar->area();
 		if((a == topDock()) || (a == bottomDock()))
 		{
@@ -1178,24 +1261,7 @@ void KviFrame::restoreToolBarPositions()
 		// ensure that it is not too wide
 		if(m_pTaskBar->width() > 600)
 			m_pTaskBar->setFixedExtentWidth(250);
-		/*
-		if(m_pTaskBar->width() > 500)
-		{
-			a = m_pTaskBar->area();
-			QRect r = a->rect();
-			a->resize(500,a->height());
-			QPoint p = m_pTaskBar->mapToGlobal(QPoint(0,0));
-			QRect r = m_pTaskBar->rect();
-			r.setWidth(180);
-			bool bSwapOrientation = false;
-			if(m_pTaskBar->orientation() != Vertical)bSwapOrientation = true;
-			debug("MOVING TO POINT %d,%d RECT %d,%d,%d,%d",
-				p.x(),p.y(),r.x(),r.y(),r.width(),r.height());
-			a->removeDockWindow(m_pTaskBar,true,false);
-			a->moveDockWindow(m_pTaskBar,p,r,bSwapOrientation);
-		}
-		*/
-
+#endif //!COMPILE_USE_QT4
 	} /*else if(m_pTaskBar->inherits("KviClassicTaskBar"))
 	{
 		QDockArea * a = m_pTaskBar->area();
@@ -1207,9 +1273,11 @@ void KviFrame::restoreToolBarPositions()
 			bottomDock()->lineUp(true);
 		}
 	}*/
-	
+
+#ifndef COMPILE_USE_QT4
 	if(bNeedDefaults)
 		lineUpDockWindows(false);
+#endif //!COMPILE_USE_QT4
 }
 
 
@@ -1218,15 +1286,27 @@ void KviFrame::createTaskBar()
 	if(KVI_OPTION_BOOL(KviOption_boolUseTreeWindowListTaskBar))
 	{
 		m_pTaskBar = new KviTreeTaskBar();
+#ifdef COMPILE_USE_QT4
+		m_pTaskBar->setAllowedAreas(Qt::LeftDockWidgetArea | Qt::RightDockWidgetArea);
+		addDockWidget(Qt::LeftDockWidgetArea,m_pTaskBar);
+#else //!COMPILE_USE_QT4
 		setDockEnabled(m_pTaskBar,Qt::DockTop,false);
 		setDockEnabled(m_pTaskBar,Qt::DockBottom,false);
+#endif //!COMPILE_USE_QT4
 	} else {
 		m_pTaskBar = new KviClassicTaskBar();
+#ifdef COMPILE_USE_QT4
+		m_pTaskBar->setAllowedAreas(Qt::AllDockWidgetAreas);
+		addDockWidget(Qt::BottomDockWidgetArea,m_pTaskBar);
+#else //!COMPILE_USE_QT4
 		setDockEnabled(m_pTaskBar,Qt::DockTop,true);
 		setDockEnabled(m_pTaskBar,Qt::DockBottom,true);
+#endif //!COMPILE_USE_QT4
 	}
+#ifndef COMPILE_USE_QT4
 	setDockEnabled(m_pTaskBar,Qt::DockLeft,true);
 	setDockEnabled(m_pTaskBar,Qt::DockRight,true);
+#endif //!COMPILE_USE_QT4
 }
 
 void KviFrame::recreateTaskBar()
@@ -1239,7 +1319,9 @@ void KviFrame::recreateTaskBar()
 	{
 		w->destroyTaskBarItem();
 	}
+#ifndef COMPILE_USE_QT4
 	removeDockWindow(m_pTaskBar);
+#endif //!COMPILE_USE_QT4
 	delete m_pTaskBar;
 	createTaskBar();
 	for(w = m_pWinList->first();w;w = m_pWinList->next())
@@ -1247,7 +1329,8 @@ void KviFrame::recreateTaskBar()
 		w->createTaskBarItem();
 	}
 	restoreToolBarPositions();
-	
+
+
 	/*
 	QString szNewClass = m_pTaskBar->className();
 	if(szOldClass != szNewClass)
