@@ -35,7 +35,7 @@
 
 #include "kvi_tal_mainwindow.h"
 #include "kvi_qstring.h"
-#include "kvi_list.h"
+#include "kvi_pointerlist.h"
 
 class KviMenuBar;
 class KviMdiManager;
@@ -45,14 +45,16 @@ class KviConsole;
 class KviTaskBarBase;
 class QSplitter;
 class KviConfig;
-class QAccel;
 class KviMexToolBar;
 class KviIrcContext;
 class KviIrcConnection;
 class KviStatusBar;
+class KviTalPopupMenu;
+
+#include "kvi_accel.h" // we need this :/
 
 #ifdef COMPILE_ON_WINDOWS
-	// MSCV has problems with KviPtrList<KviWindow> otherwise
+	// MSCV has problems with KviPointerList<KviWindow> otherwise
 	#include "kvi_window.h"
 #endif
 
@@ -60,11 +62,11 @@ class KviStatusBar;
 // this should be probably moved out of here
 class KVIRC_API KviDockExtension
 {
-public:
-	KviDockExtension():m_uStoredWindowState(Qt::WState_Maximized){};
-	virtual ~KviDockExtension(){};
 protected:
 	unsigned int m_uStoredWindowState;
+public:
+	KviDockExtension() : m_uStoredWindowState(0){};
+	virtual ~KviDockExtension(){};
 public:
 	void setPrevWindowState(unsigned int state) { m_uStoredWindowState = state; };
 	unsigned int getPrevWindowState() { return m_uStoredWindowState; };
@@ -97,15 +99,15 @@ protected:
 	QSplitter                             * m_pSplitter;                     // the frame is splitted vertically and thus can host widgets
 	KviMenuBar                            * m_pMenuBar;                      // the main menu bar
 	KviMdiManager                         * m_pMdi;                          // the mdi manager widget (child of the splitter)
-	KviPtrList<KviMexToolBar>             * m_pModuleExtensionToolBarList;   // the module extension toolbars
+	KviPointerList<KviMexToolBar>         * m_pModuleExtensionToolBarList;   // the module extension toolbars
 	KviTaskBarBase                        * m_pTaskBar;                      // the taskbar
 	KviStatusBar                          * m_pStatusBar;
 	// the mdi workspace child windows
-	KviPtrList<KviWindow>                 * m_pWinList;                      // the main list of windows
+	KviPointerList<KviWindow>             * m_pWinList;                      // the main list of windows
 	KviIrcContext                         * m_pActiveContext;                // the context of the m_pActiveWindow
 	// other
 	KviDockExtension                      * m_pDockExtension;                // the frame's dock extension: this should be prolly moved ?
-	QAccel                                * m_pAccel;                        // the global accelelrator
+	KviAccel                              * m_pAccel;                        // the global accelelrator
 public:
 	// the mdi manager: handles mdi children
 	KviMdiManager * mdiManager(){ return m_pMdi; };
@@ -122,7 +124,7 @@ public:
 	KviIrcConnection * activeConnection();
 	// The list of the windows belonging to this frame
 	// Note that the windows may be also undocked, but they are still owned by the frame
-	KviPtrList<KviWindow> * windowList() { return m_pWinList; };
+	KviPointerList<KviWindow> * windowList() { return m_pWinList; };
 	// Sets the specified window to be the active one
 	// Raises it and focuses it
 	void setActiveWindow(KviWindow *wnd);
@@ -164,7 +166,7 @@ public:
 	KviMexToolBar * moduleExtensionToolBar(int extensionId);
 	// Helper to fill the toolbars popup
 	// it is used by KviToolBar and KviMenuBar
-	void fillToolBarsPopup(QPopupMenu * p);
+	void fillToolBarsPopup(KviTalPopupMenu * p);
 	int registerAccelerator(const QString &szKeySequence,QObject * recv,const char * slot);
 	void unregisterAccelerator(int id);
 
@@ -213,11 +215,13 @@ protected:
 	virtual void moveEvent(QMoveEvent *e);
 	virtual bool focusNextPrevChild(bool next);
 	virtual void windowActivationChange(bool bOldActive);
-	
+
 	void updatePseudoTransparency();
+
+	KviAccel * installAccelerators(QWidget * wnd);
 	
-	QAccel * installAccelerators(QWidget * wnd);
-	
+	virtual void hideEvent ( QHideEvent * e);
+protected slots:
 	void switchToNextWindow();
 	void switchToPrevWindow();
 	void switchToNextWindowInContext();
@@ -225,9 +229,7 @@ protected:
 	
 	void maximizeWindow();
 	void minimizeWindow();
-	
-	virtual void hideEvent ( QHideEvent * e);
-protected slots:
+
 	void accelActivated(int id);
 	void enteredSdiMode();
 	void leftSdiMode();
