@@ -41,12 +41,12 @@
 
 #include "kvi_app.h"
 
-int KviImageDialogItem::height(const QListBox *lb) const
+int KviImageDialogItem::height(const KviTalListBox *lb) const
 {
 	return pixmap()->height() + 12 + lb->fontMetrics().lineSpacing();
 }
 
-int KviImageDialogItem::width(const QListBox *lb) const
+int KviImageDialogItem::width(const KviTalListBox *lb) const
 {
 	int w;
 	if(text().isEmpty())w = 24;
@@ -117,7 +117,7 @@ KviImageDialog::KviImageDialog(QWidget * par,
 
 	g->addMultiCellWidget(m_pTypeComboBox,0,0,0,2);
 
-	m_pTypeList = new QValueList<int>;
+	m_pTypeList = new KviValueList<int>;
 
 	QString bi = __tr2qs("Builtin images");
 
@@ -146,9 +146,9 @@ KviImageDialog::KviImageDialog(QWidget * par,
 	g->addMultiCellWidget(l,1,1,0,2);
 
 
-	m_pListBox = new QListBox(this);
-	m_pListBox->setColumnMode(QListBox::FitToWidth);
-	m_pListBox->setRowMode(QListBox::Variable);
+	m_pListBox = new KviTalListBox(this);
+	m_pListBox->setColumnMode(KviTalListBox::FitToWidth);
+	m_pListBox->setRowMode(KviTalListBox::Variable);
 
 	m_pTip = new KviDynamicToolTip(m_pListBox->viewport());
 
@@ -166,7 +166,7 @@ KviImageDialog::KviImageDialog(QWidget * par,
 	g->setColStretch(0,1);
 
 	connect(m_pTypeComboBox,SIGNAL(activated(int)),this,SLOT(jobTypeSelected(int)));
-	connect(m_pListBox,SIGNAL(doubleClicked(QListBoxItem *)),this,SLOT(itemDoubleClicked(QListBoxItem *)));
+	connect(m_pListBox,SIGNAL(doubleClicked(KviTalListBoxItem *)),this,SLOT(itemDoubleClicked(KviTalListBoxItem *)));
 	connect(m_pTip,SIGNAL(tipRequest(KviDynamicToolTip *,const QPoint &)),this,SLOT(tipRequest(KviDynamicToolTip *,const QPoint &)));
 
 	m_pTypeComboBox->setCurrentItem(idx);
@@ -235,10 +235,14 @@ void KviImageDialog::heartbeat()
 			if(max > KVI_NUM_SMALL_ICONS)max = KVI_NUM_SMALL_ICONS;
 			while(m_iJobIndexHelper < max)
 			{
-				QString id;
-				id.setNum(m_iJobIndexHelper);
+				QString id = g_pIconManager->getSmallIconName(m_iJobIndexHelper);
 				KviImageDialogItem * it;
-				it = new KviImageDialogItem(m_pListBox,*(g_pIconManager->getSmallIcon(m_iJobIndexHelper)),id,id);
+				QString tip;
+				KviQString::sprintf(tip,__tr2qs("Builtin $icon(%Q) [index %d]"),&id,m_iJobIndexHelper);
+				QString image_id = "$icon(";
+				image_id += id;
+				image_id += ")";
+				it = new KviImageDialogItem(m_pListBox,*(g_pIconManager->getSmallIcon(m_iJobIndexHelper)),id,image_id,tip);
 				m_iJobIndexHelper++;
 			}
 		}
@@ -277,7 +281,11 @@ void KviImageDialog::heartbeat()
 						QImage i(szPath);
 						if(i.isNull())continue;
 						QPixmap pix;
+#ifdef COMPILE_USE_QT4
+						if((i.width() > 80) || (i.height() > 80))pix = i.scaled(80,80,Qt::KeepAspectRatio);
+#else
 						if((i.width() > 80) || (i.height() > 80))pix = i.scale(80,80,QImage::ScaleMin);
+#endif
 						else pix = i;
 
 						QString tip = szFile;
@@ -310,9 +318,9 @@ void KviImageDialog::heartbeat()
 
 void KviImageDialog::okClicked()
 {
-	QListBoxItem * it = 0;
+	KviTalListBoxItem * it = 0;
 	int idx = m_pListBox->currentItem();
-	if(idx != -1)it = m_pListBox->item(idx);
+	if(idx != -1)it = (KviTalListBoxItem *)m_pListBox->item(idx);
 	if(!it)return;
 	itemDoubleClicked(it);
 }
@@ -329,7 +337,7 @@ void KviImageDialog::closeEvent(QCloseEvent * e)
 	QDialog::closeEvent(e);
 }
 
-void KviImageDialog::itemDoubleClicked(QListBoxItem * it)
+void KviImageDialog::itemDoubleClicked(KviTalListBoxItem * it)
 {
 	if(!it)return;
 	KviImageDialogItem * i = (KviImageDialogItem *)it;
@@ -337,14 +345,21 @@ void KviImageDialog::itemDoubleClicked(QListBoxItem * it)
 	{
 		startJob(KID_TYPE_FULL_PATH,i->imageId());
 	} else {
-		g_pApp->mapImageFile(m_szSelectedImage,i->imageId());
-		accept();
+		QString szImageId = i->imageId();
+		if(szImageId.length() > 0)
+		{
+			if(szImageId.at(0) == QChar('$'))
+				m_szSelectedImage = szImageId; // it's $icon(something)
+			else
+				g_pApp->mapImageFile(m_szSelectedImage,i->imageId()); // it's a file and we need to map it to our filesystem view
+			accept();
+		}
 	}
 }
 
 void KviImageDialog::tipRequest(KviDynamicToolTip *,const QPoint &pnt)
 {
-	QListBoxItem * it = m_pListBox->itemAt(pnt);
+	KviTalListBoxItem * it = (KviTalListBoxItem *)m_pListBox->itemAt(pnt);
 	if(!it)return;
 	QRect r = m_pListBox->itemRect(it);
 	KviImageDialogItem * i = (KviImageDialogItem *)it;
