@@ -4,7 +4,7 @@
 //   Creation date : Sun Jan 3 1999 23:11:50 by Szymon Stefanek
 //
 //   This file is part of the KVirc irc client distribution
-//   Copyright (C) 1999-2004 Szymon Stefanek (pragma at kvirc dot net)
+//   Copyright (C) 1999-2007 Szymon Stefanek (pragma at kvirc dot net)
 //
 //   This program is FREE software. You can redistribute it and/or
 //   modify it under the terms of the GNU General Public License
@@ -35,7 +35,7 @@
 #include "kvi_colorwin.h"
 #include "kvi_texticonwin.h"
 #include "kvi_window.h"
-//#include "kvi_uparser.h"
+
 #include "kvi_locale.h"
 #include "kvi_mirccntrl.h"
 #include "kvi_userlistview.h"
@@ -53,23 +53,25 @@
 #include "kvi_doublebuffer.h"
 #include "kvi_styled_controls.h"
 #include "kvi_texticonmanager.h"
+#include "kvi_draganddrop.h"
 
 #include <qlabel.h>
 #include <ctype.h>
 #include <stdlib.h>
 #include <qfiledialog.h>
-#include <qpopupmenu.h>
+#include "kvi_tal_popupmenu.h"
 #include <qpainter.h>
 #include <qclipboard.h>
-#include <qdragobject.h>
 #include <qstringlist.h>
-#include "kvi_list.h"
+#include "kvi_pointerlist.h"
 #include <qapplication.h>
 #include <qclipboard.h>
 #include <qmessagebox.h>
-#include <qhbox.h>
+#include "kvi_tal_hbox.h"
 #include <qlayout.h> 
 #include <qstyle.h>
+#include <qevent.h>
+
 
 #ifndef ACCEL_KEY
 #define ACCEL_KEY(k) "\t" + QString(QKeySequence( Qt::CTRL | Qt::Key_ ## k ))
@@ -94,7 +96,9 @@
 extern KviColorWindow    * g_pColorWindow;
 extern KviTextIconWindow * g_pTextIconWindow;
 extern KviHistoryWindow  * g_pHistoryWindow;
-extern QPopupMenu        * g_pInputPopup;
+extern KviTalPopupMenu        * g_pInputPopup;
+
+static QFontMetrics             * g_pLastFontMetrics = 0;
 
 
 #ifdef COMPILE_PSEUDO_TRANSPARENCY
@@ -111,7 +115,7 @@ extern KviInputHistory * g_pInputHistory;
 
 KviInputHistory::KviInputHistory()
 {
-	m_pStringList = new KviPtrList<QString>;
+	m_pStringList = new KviPointerList<QString>;
 	m_pStringList->setAutoDelete(true);
 }
 
@@ -168,6 +172,7 @@ void KviInputHistory::save(const char * filename)
 //=============== KviInputEditor ==============//
 
 static int g_iInputFontCharWidth[256];
+static bool g_bInputFontMetricsDirty = true;
 
 
 KviInputEditor::KviInputEditor(QWidget * par,KviWindow *wnd,KviUserListView * view)
@@ -196,33 +201,45 @@ KviInputEditor::KviInputEditor(QWidget * par,KviWindow *wnd,KviUserListView * vi
 	m_bUpdatesEnabled      = true;
 	m_pKviWindow           = wnd;
 	m_pUserListView        = view;
-	m_pHistory             = new KviPtrList<QString>;
+	m_pHistory             = new KviPointerList<QString>;
 	m_pHistory->setAutoDelete(true);
 	m_bReadOnly = FALSE;
 	
 	setInputMethodEnabled(true);
-	setBackgroundMode(NoBackground);
-	setFocusPolicy(StrongFocus);
+
+#ifdef COMPILE_USE_QT4
+	setAutoFillBackground(false);
+	setFocusPolicy(Qt::StrongFocus);
+#else
+	setBackgroundMode(Qt::NoBackground);
+	setFocusPolicy(QWidget::StrongFocus);
+#endif
 	setAcceptDrops(true);
 	setFrameStyle( LineEditPanel );
 	setFrameShadow( Plain );
-	recalcFontMetrics();
 	
-	m_pIconMenu = new QPopupMenu();
+	m_pIconMenu = new KviTalPopupMenu();
 	connect(m_pIconMenu,SIGNAL(activated(int)),this,SLOT(iconPopupActivated(int)));
+
+#ifdef COMPILE_USE_QT4
+	setCursor(Qt::IBeamCursor);
+#else
+	setCursor(IbeamCursor);
+#endif
 }
 
 KviInputEditor::~KviInputEditor()
 {
+	if(g_pLastFontMetrics) delete g_pLastFontMetrics;
+	g_pLastFontMetrics = 0;
 	if(m_pIconMenu)delete m_pIconMenu;
 	delete m_pHistory;
 	if(m_iCursorTimer)killTimer(m_iCursorTimer);
 	killDragTimer();
 }
 
-void KviInputEditor::recalcFontMetrics()
+void KviInputEditor::recalcFontMetrics(QFontMetrics * pFm)
 {
-	// FIXME: this should be shared between all input widgets and calculated only once per "apply options" session
 	QFontMetrics fm(KVI_OPTION_FONT(KviOption_fontInput));
 	unsigned short i;
 	for(i=1;i<32;i++)
@@ -235,17 +252,18 @@ void KviInputEditor::recalcFontMetrics()
 	{
 		g_iInputFontCharWidth[i] = fm.width(QChar(i));
 	}
+	g_bInputFontMetricsDirty = false;
 }
 
 void KviInputEditor::applyOptions()
 {
+	g_bInputFontMetricsDirty = true;
 	update();
-	recalcFontMetrics();
 }
 
 void KviInputEditor::dragEnterEvent(QDragEnterEvent *e)
 {
-	if(QUriDrag::canDecode(e))
+	if(KviUriDrag::canDecode(e))
 	{
 		e->accept(true);
 // FIXME: #warning "FIX THIS COMMENTED STUFF"
@@ -258,7 +276,7 @@ void KviInputEditor::dragEnterEvent(QDragEnterEvent *e)
 void KviInputEditor::dropEvent(QDropEvent *e)
 {
 	QStringList list;
-	if(QUriDrag::decodeLocalFiles(e,list))
+	if(KviUriDrag::decodeLocalFiles(e,list))
 	{
 		//debug("Local files decoded");
 		if(!list.isEmpty())
@@ -296,14 +314,32 @@ QSize KviInputEditor::sizeHint() const
 	int h = QMAX(fm.lineSpacing(), 14) + 2*2; /* innerMargin */
 	int w = fm.width( 'x' ) * 17; // "some"
 	int m = frameWidth() * 2;
+#ifdef COMPILE_USE_QT4
+	QStyleOption opt;
+	opt.initFrom(this);
+	return (style()->sizeFromContents(QStyle::CT_LineEdit,&opt,
+				     QSize( w + m, h + m ).
+				     expandedTo(QApplication::globalStrut()),this));
+#else
 	return (style().sizeFromContents(QStyle::CT_LineEdit, this,
 				     QSize( w + m, h + m ).
 				     expandedTo(QApplication::globalStrut())));
+#endif
 }
 
 #define KVI_INPUT_DEF_BACK 100
 #define KVI_INPUT_DEF_FORE 101
 
+#ifdef COMPILE_USE_QT4
+void KviInputEditor::paintEvent(QPaintEvent *e)
+{
+	QPainter p(this);
+	SET_ANTI_ALIASING(p);
+	drawFrame(&p);
+	drawContents(&p);
+}
+#endif
+
 void KviInputEditor::drawContents(QPainter *p)
 {
 	if(!isVisible())return;
@@ -316,6 +352,18 @@ void KviInputEditor::drawContents(QPainter *p)
 	QPixmap * pDoubleBufferPixmap = doublebuffer.pixmap();
 
 	QPainter pa(pDoubleBufferPixmap);
+	SET_ANTI_ALIASING(pa);
+
+	pa.setFont(KVI_OPTION_FONT(KviOption_fontInput));
+
+	QFontMetrics fm(pa.fontMetrics());
+	
+	if(!g_pLastFontMetrics) 
+		g_pLastFontMetrics = new QFontMetrics(pa.fontMetrics());
+	
+	if(g_bInputFontMetricsDirty)
+		recalcFontMetrics(&fm);
+
 
 #ifdef COMPILE_PSEUDO_TRANSPARENCY
 	if(g_pShadedChildGlobalDesktopBackground)
@@ -324,22 +372,15 @@ void KviInputEditor::drawContents(QPainter *p)
 		pa.drawTiledPixmap(0,0,widgetWidth,widgetHeight,*g_pShadedChildGlobalDesktopBackground,pnt.x(),pnt.y());
 	} else {
 #endif
+		QPixmap *pix=KVI_OPTION_PIXMAP(KviOption_pixmapInputBackground).pixmap();
+		
 		pa.fillRect(0,0,widgetWidth,widgetHeight,KVI_OPTION_COLOR(KviOption_colorInputBackground));
+		if(pix)
+			KviPixmapUtils::drawPixmapWithPainter(&pa,pix,KVI_OPTION_UINT(KviOption_uintInputPixmapAlign),rect,widgetWidth,widgetHeight);
 #ifdef COMPILE_PSEUDO_TRANSPARENCY
 	}
 #endif
-	QPixmap *pix=KVI_OPTION_PIXMAP(KviOption_pixmapInputBackground).pixmap();
-	
-	if(pix)
-	{
-		KviPixmapUtils::drawPixmapWithPainter(&pa,pix,(Qt::AlignmentFlags)(KVI_OPTION_UINT(KviOption_uintInputPixmapAlign)),QRect(0,0,widgetWidth,widgetHeight),widgetWidth,widgetHeight);
-	} 
 
-	
-	
-	pa.setFont(KVI_OPTION_FONT(KviOption_fontInput));
-
-	QFontMetrics fm(pa.fontMetrics());
 
 	int curXPos      = KVI_INPUT_MARGIN;
 	int maxXPos      = widgetWidth-2*KVI_INPUT_MARGIN;
@@ -365,6 +406,50 @@ void KviInputEditor::drawContents(QPainter *p)
 		m_iSelectionBegin = -1;
 	}
 
+	if((m_iSelectionBegin != -1) && (m_iSelectionEnd >= m_iFirstVisibleChar))
+	{
+		int iSelStart = m_iSelectionBegin;
+
+    // TODO Refactor: write a function to combine this with the code determining iIMStart and iIMSelectionStart
+		if(iSelStart < m_iFirstVisibleChar)iSelStart = m_iFirstVisibleChar;
+		int xLeft = xPositionFromCharIndex(fm,iSelStart,TRUE);
+		int xRight = xPositionFromCharIndex(fm,m_iSelectionEnd + 1,TRUE);
+
+//		pa.setRasterOp(Qt::NotROP);
+		pa.fillRect(xLeft,frameWidth(),xRight - xLeft,widgetWidth,KVI_OPTION_COLOR(KviOption_colorInputSelectionBackground));
+//		pa.setRasterOp(Qt::CopyROP);
+	}
+
+	// When m_bIMComposing is true, the text between m_iIMStart and m_iIMStart+m_iIMLength should be highlighted to show that this is the active
+	// preedit area for the input method, and the text outside cannot be edited while
+	// composing. Maybe this can be implemented similarly as painting the selection?
+	// Also notice that inside the preedit, there can also be a selection, given by
+	// m_iSelectionBegin and m_iSelectionLength, and the widget needs to highlight that
+	// while in IM composition mode
+	if(m_bIMComposing && m_iIMLength > 0)
+	{
+		// TODO Write a function to combine IM selection drawing code. maybe the preedit area too.
+		int iIMSelectionStart = m_iIMSelectionBegin;
+		if(iIMSelectionStart < m_iFirstVisibleChar) iIMSelectionStart = m_iFirstVisibleChar;
+		int xIMSelectionLeft = xPositionFromCharIndex(fm,iIMSelectionStart,TRUE);
+		int xIMSelectionRight = xPositionFromCharIndex(fm,iIMSelectionStart + m_iIMSelectionLength,TRUE);
+//		pa.setRasterOp(Qt::NotROP);
+		pa.fillRect(xIMSelectionLeft,0,xIMSelectionRight - xIMSelectionLeft, widgetWidth,KVI_OPTION_COLOR(KviOption_colorInputSelectionBackground));
+//		pa.setRasterOp(Qt::CopyROP);
+ 
+		// highlight the IM selection
+		int iIMStart = m_iIMStart;
+		if(m_iIMStart < m_iFirstVisibleChar) m_iIMStart = m_iFirstVisibleChar;
+		int xIMLeft = xPositionFromCharIndex(fm,iIMStart,TRUE);
+		int xIMRight = xPositionFromCharIndex(fm,iIMStart + m_iIMLength,TRUE);
+
+		// underline the IM preedit
+		// Maybe should be put in drawTextBlock, similar to drawing underlined text
+		pa.drawLine(xIMLeft, bottom, xIMRight, bottom);
+	}
+
+	pa.setClipping(false);
+
 	while((charIdx < ((int)(m_szTextBuffer.length()))) && (curXPos < maxXPos))
 	{
 		extractNextBlock(charIdx,fm,curXPos,maxXPos);
@@ -379,63 +464,60 @@ void KviInputEditor::drawContents(QPainter *p)
 
 			pa.drawText(curXPos + 2,textBaseline,s,1);
 
-			pa.drawLine(curXPos,top,curXPos+m_iBlockWidth-1,top);
-			pa.drawLine(curXPos,top,curXPos,bottom);
-			pa.drawLine(curXPos,bottom,curXPos+m_iBlockWidth,bottom);
-			pa.drawLine(curXPos+m_iBlockWidth-1,top,curXPos+m_iBlockWidth-1,bottom);
+			pa.drawRect(curXPos,top,m_iBlockWidth-1,bottom);
 		} else {
-			drawTextBlock(&pa,fm,curXPos,textBaseline,charIdx,m_iBlockLen,m_iBlockWidth);
+			if(m_iSelectionBegin!=-1)
+			{
+				int iBlockEnd=charIdx+m_iBlockLen;
+				//block is selected (maybe partially)
+				if( iBlockEnd>m_iSelectionBegin && charIdx<=m_iSelectionEnd )
+				{
+					int iSubStart,iSubLen;
+					//in common it consists of 3 parts: unselected-selected-unselected
+					//some of thst parts can be empty (for example block is fully selected)
+					
+					//first part start is always equal to the block start
+					iSubStart=charIdx;
+					iSubLen = m_iSelectionBegin>charIdx ? m_iSelectionBegin-charIdx : 0;
+					
+				
+					if(iSubLen)
+					{
+						drawTextBlock(&pa,fm,curXPos,textBaseline,iSubStart,iSubLen,FALSE);
+						curXPos += m_iBlockWidth;
+						m_iBlockWidth=0;
+					}
+					
+					//second one
+					iSubStart+=iSubLen;
+					iSubLen=m_iSelectionEnd<iBlockEnd ? m_iSelectionEnd-iSubStart+1 : iBlockEnd-iSubStart;
+					
+					
+					if(iSubLen)
+					{
+						drawTextBlock(&pa,fm,curXPos,textBaseline,iSubStart,iSubLen,TRUE);
+						curXPos += m_iBlockWidth;
+						m_iBlockWidth=0;
+					}
+					
+					if( m_iSelectionEnd<(iBlockEnd-1))
+					{
+						iSubStart+=iSubLen;
+						iSubLen=iBlockEnd-iSubStart;
+						drawTextBlock(&pa,fm,curXPos,textBaseline,iSubStart,iSubLen,FALSE);
+					}
+				} else {
+					drawTextBlock(&pa,fm,curXPos,textBaseline,charIdx,m_iBlockLen);
+				}
+			} else {
+				drawTextBlock(&pa,fm,curXPos,textBaseline,charIdx,m_iBlockLen);
+			}
 		}
 
 		curXPos += m_iBlockWidth;
 		charIdx += m_iBlockLen;
 	}
-
-
-	if((m_iSelectionBegin != -1) && (m_iSelectionEnd >= m_iFirstVisibleChar))
-	{
-		int iSelStart = m_iSelectionBegin;
-
-    // TODO Refactor: write a function to combine this with the code determining iIMStart and iIMSelectionStart
-		if(iSelStart < m_iFirstVisibleChar)iSelStart = m_iFirstVisibleChar;
-		int xLeft = xPositionFromCharIndex(iSelStart);
-		int xRight = xPositionFromCharIndex(m_iSelectionEnd + 1);
-
-		pa.setRasterOp(Qt::NotROP);
-		pa.fillRect(xLeft,KVI_INPUT_BORDER,xRight - xLeft,widgetWidth,Qt::black);
-		pa.setRasterOp(Qt::CopyROP);
-	}
-
-	// When m_bIMComposing is true, the text between m_iIMStart and m_iIMStart+m_iIMLength should be highlighted to show that this is the active
-	// preedit area for the input method, and the text outside cannot be edited while
-	// composing. Maybe this can be implemented similarly as painting the selection?
-	// Also notice that inside the preedit, there can also be a selection, given by
-	// m_iSelectionBegin and m_iSelectionLength, and the widget needs to highlight that
-	// while in IM composition mode
-	if(m_bIMComposing && m_iIMLength > 0)
-	{
-		// TODO Write a function to combine IM selection drawing code. maybe the preedit area too.
-		int iIMSelectionStart = m_iIMSelectionBegin;
-		if(iIMSelectionStart < m_iFirstVisibleChar) iIMSelectionStart = m_iFirstVisibleChar;
-		int xIMSelectionLeft = xPositionFromCharIndex(iIMSelectionStart);
-		int xIMSelectionRight = xPositionFromCharIndex(iIMSelectionStart + m_iIMSelectionLength);
-		pa.setRasterOp(Qt::NotROP);
-		pa.fillRect(xIMSelectionLeft,0,xIMSelectionRight - xIMSelectionLeft, widgetWidth,Qt::black);
-		pa.setRasterOp(Qt::CopyROP);
- 
-		// highlight the IM selection
-		int iIMStart = m_iIMStart;
-		if(m_iIMStart < m_iFirstVisibleChar) m_iIMStart = m_iFirstVisibleChar;
-		int xIMLeft = xPositionFromCharIndex(iIMStart);
-		int xIMRight = xPositionFromCharIndex(iIMStart + m_iIMLength);
-
-		// underline the IM preedit
-		// Maybe should be put in drawTextBlock, similar to drawing underlined text
-		pa.drawLine(xIMLeft, bottom, xIMRight, bottom);
-	}
-
-	pa.setClipping(false);
-
+	
 	//Now the cursor
 
 	m_iLastCursorXPosition = KVI_INPUT_MARGIN;
@@ -444,11 +526,15 @@ void KviInputEditor::drawContents(QPainter *p)
 	while(m_iBlockLen < m_iCursorPosition)
 	{
 		QChar c = m_szTextBuffer.at(m_iBlockLen);
+#ifdef COMPILE_USE_QT4
+		m_iLastCursorXPosition+= c.unicode() < 32 ? fm.width(getSubstituteChar(c.unicode())) + 3 : fm.width(c);
+#else
 		m_iLastCursorXPosition+= (c.unicode() < 256) ? g_iInputFontCharWidth[c.unicode()] : fm.width(c);
+#endif
 		m_iBlockLen++;
 	}
 
-//	m_iLastCursorXPosition = xPositionFromCharIndex(m_iCursorPosition);
+	//m_iLastCursorXPosition = cur1XPos;
 
 	if(m_bCursorOn)
 	{
@@ -458,18 +544,25 @@ void KviInputEditor::drawContents(QPainter *p)
 		pa.setPen(KVI_OPTION_COLOR(KviOption_colorInputForeground));
 	}
 
+#ifdef COMPILE_USE_QT4
+	// The other version of drawPixmap seems to be buggy
+	p->drawPixmap(rect.x(),rect.y(),rect.width(),rect.height(),*pDoubleBufferPixmap,0,0,widgetWidth,widgetHeight);
+#else
 	p->drawPixmap(rect.x(),rect.y(),*pDoubleBufferPixmap,0,0,widgetWidth,widgetHeight);
-
+#endif
 }
 
-void KviInputEditor::drawTextBlock(QPainter * pa,QFontMetrics & fm,int curXPos,int textBaseline,int charIdx,int len,int wdth)
+void KviInputEditor::drawTextBlock(QPainter * pa,QFontMetrics & fm,int curXPos,int textBaseline,int charIdx,int len,bool bSelected)
 {
+	QString tmp = m_szTextBuffer.mid(charIdx,len);
+	m_iBlockWidth = fm.width(tmp);
+	
 	QRect rect = contentsRect();
 	int widgetHeight      = rect.height();
 	
 	if(m_iCurFore == KVI_INPUT_DEF_FORE)
 	{
-		pa->setPen(KVI_OPTION_COLOR(KviOption_colorInputForeground));
+		pa->setPen( bSelected ? KVI_OPTION_COLOR(KviOption_colorInputSelectionForeground) : KVI_OPTION_COLOR(KviOption_colorInputForeground));
 	} else {
 		if(((unsigned char)m_iCurFore) > 16)
 		{
@@ -483,21 +576,20 @@ void KviInputEditor::drawTextBlock(QPainter * pa,QFontMetrics & fm,int curXPos,i
 	{
 		if(((unsigned char)m_iCurBack) > 16)
 		{
-			pa->fillRect(curXPos,(widgetHeight-fm.height())/2,wdth,fm.height(),KVI_OPTION_COLOR(KviOption_colorInputForeground));
+			pa->fillRect(curXPos,(widgetHeight-fm.height())/2,m_iBlockWidth,fm.height(),KVI_OPTION_COLOR(KviOption_colorInputForeground));
 		} else {
-			pa->fillRect(curXPos,(widgetHeight-fm.height())/2,wdth,fm.height(),KVI_OPTION_MIRCCOLOR((unsigned char)m_iCurBack));
+			pa->fillRect(curXPos,(widgetHeight-fm.height())/2,m_iBlockWidth,fm.height(),KVI_OPTION_MIRCCOLOR((unsigned char)m_iCurBack));
 		}
 	}
 
-	QString tmp = m_szTextBuffer.mid(charIdx,len);
-
 	pa->drawText(curXPos,textBaseline,tmp);
 
 	if(m_bCurBold)pa->drawText(curXPos+1,textBaseline,tmp);
 	if(m_bCurUnderline)
 	{
-		pa->drawLine(curXPos,textBaseline + fm.descent(),curXPos+wdth,textBaseline + fm.descent());
+		pa->drawLine(curXPos,textBaseline + fm.descent(),curXPos+m_iBlockWidth,textBaseline + fm.descent());
 	}
+	
 }
 
 QChar KviInputEditor::getSubstituteChar(unsigned short control_code)
@@ -556,7 +648,11 @@ void KviInputEditor::extractNextBlock(int idx,QFontMetrics & fm,int curXPos,int
 				(c != QChar(KVI_TEXT_ICON))))
 			{
 				m_iBlockLen++;
+#ifdef COMPILE_USE_QT4
+				int xxx = c.unicode() < 32 ? fm.width(getSubstituteChar(c.unicode())) + 3 : fm.width(c);;
+#else
 				int xxx = (c.unicode() < 256 ? g_iInputFontCharWidth[c.unicode()] : fm.width(c));
+#endif
 				m_iBlockWidth +=xxx;
 				curXPos       +=xxx;
 				idx++;
@@ -675,12 +771,12 @@ void KviInputEditor::runUpToTheFirstVisibleChar()
 
 void KviInputEditor::mousePressEvent(QMouseEvent *e)
 {
-	if(e->button() & LeftButton)
+	if(e->button() & Qt::LeftButton)
 	{
 		m_iCursorPosition = charIndexFromXPosition(e->pos().x());
 		//move the cursor to
 		int anchorX =  xPositionFromCharIndex(m_iCursorPosition);
-		if(anchorX > (width()-KVI_INPUT_BORDER))m_iFirstVisibleChar++;
+		if(anchorX > (width()-frameWidth()))m_iFirstVisibleChar++;
 		m_iSelectionAnchorChar = m_iCursorPosition;
 		selectOneChar(-1);
 		//grabMouse(QCursor(crossCursor));
@@ -688,7 +784,7 @@ void KviInputEditor::mousePressEvent(QMouseEvent *e)
 		killDragTimer();
 		m_iDragTimer = startTimer(KVI_INPUT_DRAG_TIMEOUT);
 
-	} else if(e->button() & RightButton)
+	} else if(e->button() & Qt::RightButton)
 	{
         int type = g_pActiveWindow->type();
 
@@ -701,8 +797,12 @@ void KviInputEditor::mousePressEvent(QMouseEvent *e)
 		if(c)
 		{
 			szClip = c->text(QClipboard::Clipboard);
-	
+			
+#ifdef COMPILE_USE_QT4
+			int occ = szClip.count(QChar('\n'));
+#else
 			int occ = szClip.contains(QChar('\n'));
+#endif
 	
 			if(!szClip.isEmpty())
 			{
@@ -733,8 +833,12 @@ void KviInputEditor::mousePressEvent(QMouseEvent *e)
 				QLabel * l = new QLabel(label,g_pInputPopup);
 				l->setFrameStyle(QFrame::Raised | QFrame::StyledPanel);
 				l->setMargin(5);
-	
+				// FIXME: This does NOT work under Qt 4.x (they seem to consider it as bad UI design)
+#ifndef COMPILE_USE_QT4
 				g_pInputPopup->insertItem(l);
+#else
+				delete l;
+#endif
 			}
 		}
 		
@@ -768,8 +872,8 @@ void KviInputEditor::mousePressEvent(QMouseEvent *e)
 		g_pInputPopup->insertSeparator();
 		m_pIconMenu->clear();
 		
-		QDict<KviTextIcon> * d = g_pTextIconManager->textIconDict();
-		QDictIterator<KviTextIcon> it(*d);
+		KviPointerHashTable<QString,KviTextIcon> * d = g_pTextIconManager->textIconDict();
+		KviPointerHashTableIterator<QString,KviTextIcon> it(*d);
 		QStringList strList;
 		while(KviTextIcon * i = it.current())
 		{
@@ -859,8 +963,7 @@ void KviInputEditor::moveCursorTo(int idx,bool bRepaint)
 
 void KviInputEditor::removeSelected()
 {
-	if(!hasSelection()) return;
-//	debug("%s %s %i %s",__FILE__,__FUNCTION__,__LINE__,m_szTextBuffer.utf8().data());
+	if(!hasSelection())return;
 	m_szTextBuffer.remove(m_iSelectionBegin,(m_iSelectionEnd-m_iSelectionBegin)+1);
 	moveCursorTo(m_iSelectionBegin,false);
 	selectOneChar(-1);
@@ -1139,7 +1242,10 @@ void KviInputEditor::focusInEvent(QFocusEvent *)
 		update();
 	}
 	// XIM handling...
+#ifndef COMPILE_USE_QT4
+	// THIS SEEMS TO BE GONE IN Qt4.x ? (even if the documentation states that it *should* be there)
 	setMicroFocusHint(1,1,width() - 2,height() - 2,true,0);
+#endif
 }
 
 void KviInputEditor::focusOutEvent(QFocusEvent *)
@@ -1204,12 +1310,24 @@ void KviInputEditor::imComposeEvent(QIMEvent *e)
 {
 	// replace the old pre-edit string with e->text()
 	m_bUpdatesEnabled = false;
+#ifdef COMPILE_USE_QT4
+	// Qt 4.x ??????????
+	m_iIMLength = replaceSegment(m_iIMStart, m_iIMLength, e->commitString());
+
+	// update selection inside the pre-edit
+	m_iIMSelectionBegin = m_iIMStart + e->replacementStart();
+	m_iIMSelectionLength = e->replacementLength();
+	moveCursorTo(m_iIMSelectionBegin);
+
+#else
 	m_iIMLength = replaceSegment(m_iIMStart, m_iIMLength, e->text());
 
 	// update selection inside the pre-edit
 	m_iIMSelectionBegin = m_iIMStart + e->cursorPos();
 	m_iIMSelectionLength = e->selectionLength();
 	moveCursorTo(m_iIMSelectionBegin);
+#endif
+
 
 	// repaint
 	m_bUpdatesEnabled = true;
@@ -1223,7 +1341,12 @@ void KviInputEditor::imEndEvent(QIMEvent *e)
 {
 	// replace the preedit area with the IM result text
 	m_bUpdatesEnabled = false;
+#ifdef COMPILE_USE_QT4
+	// Qt 4.x ??????????
+	m_iIMLength = replaceSegment(m_iIMStart, m_iIMLength, e->commitString());
+#else
 	m_iIMLength = replaceSegment(m_iIMStart, m_iIMLength, e->text());
+#endif
 
 	// move cursor to after the IM result text
 	moveCursorTo(m_iIMStart + m_iIMLength);
@@ -1249,16 +1372,18 @@ void KviInputEditor::keyPressEvent(QKeyEvent *e)
 		return;
 	}
 	// completion thingies
+
 	if(!m_bReadOnly)
 	{
 		if((e->key() == Qt::Key_Tab) || (e->key() == Qt::Key_BackTab))
 		{
-			completion(e->state() & ShiftButton);
+			completion(e->state() & Qt::ShiftButton);
 			return;
 		} else {
 			m_bLastCompletionFinished=1;
 		}
 	}
+
 	
 	if(e->key() == Qt::Key_Escape)
 	{
@@ -1266,12 +1391,27 @@ void KviInputEditor::keyPressEvent(QKeyEvent *e)
 		return;
 	}
 
+	if((e->state() & Qt::AltButton) || (e->state() & Qt::ControlButton))
+	{
+		switch(e->key())
+		{
+			case Qt::Key_Backspace:
+				if(m_pInputParent->inherits("KviInput"))
+				{
+					((KviInput*)(m_pInputParent))->multiLinePaste(m_szTextBuffer);
+					clear();
+					return;
+				}
+				break;
+		}
+	}
+
 //Make CtrlKey and CommandKey ("Apple") behave equally on MacOSX.
 //This way typical X11 and Apple shortcuts can be used simultanously within the input line.
 #ifndef Q_OS_MACX
-	if(e->state() & ControlButton)
+	if(e->state() & Qt::ControlButton)
 #else
-	if((e->state() & ControlButton) || (e->state() & MetaButton))
+	if((e->state() & Qt::ControlButton) || (e->state() & Qt::MetaButton))
 #endif
 	{
 		switch(e->key())
@@ -1283,13 +1423,13 @@ void KviInputEditor::keyPressEvent(QKeyEvent *e)
 					while(m_iCursorPosition < ((int)(m_szTextBuffer.length())))
 					{
 						if(!m_szTextBuffer.at(m_iCursorPosition).isSpace())break;
-						internalCursorRight(e->state() & ShiftButton);
+						internalCursorRight(e->state() & Qt::ShiftButton);
 					}
 					// skip nonwhitespace
 					while(m_iCursorPosition < ((int)(m_szTextBuffer.length())))
 					{
 						if(m_szTextBuffer.at(m_iCursorPosition).isSpace())break;
-						internalCursorRight(e->state() & ShiftButton);
+						internalCursorRight(e->state() & Qt::ShiftButton);
 					}
 					repaintWithCursorOn();
 				}
@@ -1301,13 +1441,13 @@ void KviInputEditor::keyPressEvent(QKeyEvent *e)
 					while(m_iCursorPosition > 0)
 					{
 						if(!m_szTextBuffer.at(m_iCursorPosition - 1).isSpace())break;
-						internalCursorLeft(e->state() & ShiftButton);
+						internalCursorLeft(e->state() & Qt::ShiftButton);
 					}
 					// skip nonwhitespace
 					while(m_iCursorPosition > 0)
 					{
 						if(m_szTextBuffer.at(m_iCursorPosition - 1).isSpace())break;
-						internalCursorLeft(e->state() & ShiftButton);
+						internalCursorLeft(e->state() & Qt::ShiftButton);
 					}
 					repaintWithCursorOn();
 				}
@@ -1364,11 +1504,27 @@ void KviInputEditor::keyPressEvent(QKeyEvent *e)
 			case Qt::Key_V:
 				if(!m_bReadOnly) pasteClipboardWithConfirmation();
 			break;
-			case Qt::Key_Backspace:
-				if(m_pInputParent->inherits("KviInput"))
+			//case Qt::Key_Backspace:
+			case Qt::Key_W:
+				if(m_iCursorPosition > 0 && !m_bReadOnly && !hasSelection())
 				{
-					((KviInput*)(m_pInputParent))->multiLinePaste(m_szTextBuffer);
-					clear();
+					// skip whitespace
+					while(m_iCursorPosition > 0)
+					{
+						if(!m_szTextBuffer.at(m_iCursorPosition - 1).isSpace())break;
+						m_szTextBuffer.remove(m_iCursorPosition-1,1);
+						m_iCursorPosition--;
+						if(m_iFirstVisibleChar > m_iCursorPosition)m_iFirstVisibleChar--;
+					}
+					// skip nonwhitespace
+					while(m_iCursorPosition > 0)
+					{
+						if(m_szTextBuffer.at(m_iCursorPosition - 1).isSpace())break;
+						m_szTextBuffer.remove(m_iCursorPosition-1,1);
+						m_iCursorPosition--;
+						if(m_iFirstVisibleChar > m_iCursorPosition)m_iFirstVisibleChar--;
+					}
+					repaintWithCursorOn();
 				}
 			break;
 			case Qt::Key_PageUp:
@@ -1408,7 +1564,7 @@ void KviInputEditor::keyPressEvent(QKeyEvent *e)
 				
 					m_iCurHistoryIdx = -1;
 				}
-			break;
+				break;	
 			default:
 				if(!m_bReadOnly) insertText(e->text());
 			break;
@@ -1416,9 +1572,9 @@ void KviInputEditor::keyPressEvent(QKeyEvent *e)
 		return;
 	}
 
-	if((e->state() & AltButton) && (e->state() & Keypad))
+	if((e->state() & Qt::AltButton) && (e->state() & Qt::Keypad))
 	{
-		// Qt::Key_Meta seems to substitute Key_Alt on some keyboards
+		// Qt::Key_Meta seems to substitute Qt::Key_Alt on some keyboards
 		if((e->key() == Qt::Key_Alt) || (e->key() == Qt::Key_Meta))
 		{
 			m_szAltKeyCode = "";
@@ -1428,12 +1584,15 @@ void KviInputEditor::keyPressEvent(QKeyEvent *e)
 			m_szAltKeyCode += e->ascii();
 			return;
 		}
+
 		//debug("%c",e->ascii());
-		if(!m_bReadOnly) insertText(e->text());
+		if(!m_bReadOnly) {
+			insertText(e->text());
+		}
 		return;
 	}
 
-	if(e->state() & ShiftButton)
+	if(e->state() & Qt::ShiftButton)
 	{
 		switch(e->key())
 		{
@@ -1459,14 +1618,14 @@ void KviInputEditor::keyPressEvent(QKeyEvent *e)
 		case Qt::Key_Right:
 			if(m_iCursorPosition < ((int)(m_szTextBuffer.length())))
 			{
-				internalCursorRight(e->state() & ShiftButton);
+				internalCursorRight(e->state() & Qt::ShiftButton);
 				repaintWithCursorOn();
 			}
 			break;
 		case Qt::Key_Left:
 			if(m_iCursorPosition > 0)
 			{
-				internalCursorLeft(e->state() & ShiftButton);
+				internalCursorLeft(e->state() & Qt::ShiftButton);
 				repaintWithCursorOn();
 			}
 			break;
@@ -1503,7 +1662,7 @@ void KviInputEditor::keyPressEvent(QKeyEvent *e)
 		case Qt::Key_Home:
 			if(m_iCursorPosition > 0)
 			{
-				if(e->state() & ShiftButton)
+				if(e->state() & Qt::ShiftButton)
 				{
 					if((m_iSelectionBegin == -1)&&(m_iSelectionEnd == -1))m_iSelectionEnd = m_iCursorPosition - 1;
 					m_iSelectionBegin = 0;
@@ -1514,7 +1673,7 @@ void KviInputEditor::keyPressEvent(QKeyEvent *e)
 			}
 			break;
 		case Qt::Key_End://we should call it even the cursor is at the end for deselecting
-			if(e->state() & ShiftButton)
+			if(e->state() & Qt::ShiftButton)
 			{
 				if((m_iSelectionBegin == -1)&&(m_iSelectionEnd == -1))m_iSelectionBegin = m_iCursorPosition;
 				m_iSelectionEnd = m_szTextBuffer.length()-1;
@@ -1657,7 +1816,7 @@ void KviInputEditor::completion(bool bShift)
 			return;
 		}
 	}
-	KviPtrList<QString> tmp;
+	KviPointerList<QString> tmp;
 	tmp.setAutoDelete(true);
 
 	bool bIsCommand = false;
@@ -1712,14 +1871,17 @@ void KviInputEditor::completion(bool bShift)
 				m_pKviWindow->console()->completeServer(word,&tmp);
 	} else {
 		// empty word will end up here
-		if(KVI_OPTION_BOOL(KviOption_boolBashLikeNickCompletion))
+		if(m_pUserListView)
 		{
-			m_pUserListView->completeNickBashLike(word,&tmp,bShift);
-			bIsNick = true;
-		} else {
-			standardNickCompletion(bShift,word,bFirstWordInLine);
-			repaintWithCursorOn();
-			return;
+			if(KVI_OPTION_BOOL(KviOption_boolBashLikeNickCompletion))
+			{
+				m_pUserListView->completeNickBashLike(word,&tmp,bShift);
+				bIsNick = true;
+			} else {
+				standardNickCompletion(bShift,word,bFirstWordInLine);
+				repaintWithCursorOn();
+				return;
+			}
 		}
 	}
 
@@ -1879,7 +2041,7 @@ void KviInputEditor::standardNickCompletion(bool bAddMask,QString &word,bool bFi
 
 void KviInputEditor::end()
 {
-	m_iLastCursorXPosition = KVI_INPUT_BORDER;
+	m_iLastCursorXPosition = frameWidth();
 	m_iCursorPosition = 0;
 	m_iFirstVisibleChar = 0;
 	while(m_iCursorPosition < ((int)(m_szTextBuffer.length())))
@@ -1925,11 +2087,19 @@ void KviInputEditor::moveRightFirstVisibleCharToShowCursor()
 
 	QChar c = m_szTextBuffer.at(m_iCursorPosition);
 
+#ifdef COMPILE_USE_QT4
+	m_iLastCursorXPosition += c.unicode() < 32 ? fm.width(getSubstituteChar(c.unicode())) + 3 : fm.width(c);;
+#else
 	m_iLastCursorXPosition += (c.unicode() < 256) ? g_iInputFontCharWidth[c.unicode()] : fm.width(c);
-	while(m_iLastCursorXPosition >= width()-KVI_INPUT_BORDER)
+#endif
+	while(m_iLastCursorXPosition >= contentsRect().width()-2*KVI_INPUT_MARGIN)
 	{
 		c = m_szTextBuffer.at(m_iFirstVisibleChar);
+#ifdef COMPILE_USE_QT4
+		m_iLastCursorXPosition -= c.unicode() < 32 ? fm.width(getSubstituteChar(c.unicode())) + 3 : fm.width(c);;
+#else
 		m_iLastCursorXPosition -= (c.unicode() < 256) ? g_iInputFontCharWidth[c.unicode()] : fm.width(c);
+#endif
 		m_iFirstVisibleChar++;
 	}
 }
@@ -1952,7 +2122,7 @@ void KviInputEditor::selectOneChar(int pos)
 
 int KviInputEditor::charIndexFromXPosition(int xPos)
 {
-	int curXPos = KVI_INPUT_BORDER;
+	int curXPos = frameWidth()+KVI_INPUT_MARGIN;
 	int curChar = m_iFirstVisibleChar;
 	int bufLen  = m_szTextBuffer.length();
 
@@ -1960,7 +2130,11 @@ int KviInputEditor::charIndexFromXPosition(int xPos)
 	while(curChar < bufLen)
 	{
 		QChar c = m_szTextBuffer.at(curChar);
+#ifdef COMPILE_USE_QT4
+		int widthCh = c.unicode() < 32 ? fm.width(getSubstituteChar(c.unicode())) + 3 : fm.width(c);;
+#else
 		int widthCh = (c.unicode() < 256) ? g_iInputFontCharWidth[c.unicode()] : fm.width(c);
+#endif
 		if(xPos < (curXPos+(widthCh/2)))return curChar;
 		else if(xPos < (curXPos+widthCh))return (curChar+1);
 		{
@@ -1971,16 +2145,39 @@ int KviInputEditor::charIndexFromXPosition(int xPos)
 	return curChar;
 }
 
-int KviInputEditor::xPositionFromCharIndex(int chIdx)
+int  KviInputEditor::xPositionFromCharIndex(QFontMetrics& fm,int chIdx,bool bContentsCoords)
 {
 	// FIXME: this could use fm.width(m_szTextBuffer,chIdx)
-	int curXPos = KVI_INPUT_BORDER;
+	int curXPos = bContentsCoords ? KVI_INPUT_MARGIN : frameWidth()+KVI_INPUT_MARGIN;
 	int curChar = m_iFirstVisibleChar;
-	QFontMetrics fm(KVI_OPTION_FONT(KviOption_fontInput));
 	while(curChar < chIdx)
 	{
 		QChar c = m_szTextBuffer.at(curChar);
+#ifdef COMPILE_USE_QT4
+		curXPos += c.unicode() < 32 ? fm.width(getSubstituteChar(c.unicode())) + 3 : fm.width(c);;
+#else
 		curXPos += (c.unicode() < 256) ? g_iInputFontCharWidth[c.unicode()] : fm.width(c);
+#endif
+		curChar++;
+	}
+	return curXPos;
+}
+
+int KviInputEditor::xPositionFromCharIndex(int chIdx,bool bContentsCoords)
+{
+	// FIXME: this could use fm.width(m_szTextBuffer,chIdx)
+	int curXPos = bContentsCoords ? KVI_INPUT_MARGIN : frameWidth()+KVI_INPUT_MARGIN;
+	int curChar = m_iFirstVisibleChar;
+	//debug("%i",g_pLastFontMetrics);
+	if(!g_pLastFontMetrics) g_pLastFontMetrics = new QFontMetrics(KVI_OPTION_FONT(KviOption_fontInput));
+	while(curChar < chIdx)
+	{
+		QChar c = m_szTextBuffer.at(curChar);
+#ifdef COMPILE_USE_QT4
+		curXPos += c.unicode() < 32 ? g_pLastFontMetrics->width(getSubstituteChar(c.unicode())) + 3 : g_pLastFontMetrics->width(c);
+#else
+		curXPos += (c.unicode() < 256) ? g_iInputFontCharWidth[c.unicode()] : g_pLastFontMetrics->width(c);
+#endif
 		curChar++;
 	}
 	return curXPos;
@@ -2118,10 +2315,13 @@ int KviInputEditor::xPositionFromCharIndex(int chIdx)
 KviInput::KviInput(KviWindow *par,KviUserListView * view)
 : QWidget(par,"input")
 {
-
 	QBoxLayout* pLayout=new QHBoxLayout(this);
-	pLayout->setAutoAdd( TRUE );
+	pLayout->setAutoAdd(true);
 	pLayout->setDirection(QBoxLayout::RightToLeft);
+
+	pLayout->setMargin(0);
+	pLayout->setSpacing(0);
+
 	m_pWindow = par;
 	m_pMultiLineEditor = 0;
 	
@@ -2135,8 +2335,15 @@ KviInput::KviInput(KviWindow *par,KviUserListView * view)
 	
 	connect(m_pHideToolsButton,SIGNAL(clicked()),this,SLOT(toggleToolButtons()));
 	
-	m_pButtonContainer=new QHBox(this,"input_buttons_box");
-	
+	m_pButtonContainer=new KviTalHBox(this);
+	m_pButtonContainer->setSpacing(0);
+
+#ifdef COMPILE_USE_QT4
+	m_pButtonContainer->setSizePolicy(QSizePolicy(QSizePolicy::Minimum,QSizePolicy::Preferred));
+//	if(m_pButtonContainer->layout())
+//		m_pButtonContainer->layout()->setSizeConstraint(QLayout::SetMinimumSize);
+#endif
+
 	m_pHistoryButton = new KviStyledToolButton(m_pButtonContainer,"historybutton");
 	m_pHistoryButton->setUsesBigPixmap(false);
 	//m_pHistoryButton->setUpdatesEnabled(TRUE); ???
@@ -2145,14 +2352,14 @@ KviInput::KviInput(KviWindow *par,KviUserListView * view)
 	{
 		is1.setPixmap(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_TIME)),QIconSet::Small);
 		m_pHistoryButton->setIconSet(is1);
-		QToolTip::add(m_pHistoryButton,__tr2qs("Show History<br>&lt;Ctrl+PageUp&gt;"));
+		KviTalToolTip::add(m_pHistoryButton,__tr2qs("Show History<br>&lt;Ctrl+PageUp&gt;"));
 		connect(m_pHistoryButton,SIGNAL(clicked()),this,SLOT(historyButtonClicked()));
 	}
 	else
 	{
 		is1.setPixmap(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_QUITSPLIT)),QIconSet::Small);
 		m_pHistoryButton->setIconSet(is1);
-		QToolTip::add(m_pHistoryButton,__tr2qs("Input History Disabled"));
+		KviTalToolTip::add(m_pHistoryButton,__tr2qs("Input History Disabled"));
 	}
 
 	m_pIconButton = new KviStyledToolButton(m_pButtonContainer,"iconbutton");
@@ -2160,7 +2367,7 @@ KviInput::KviInput(KviWindow *par,KviUserListView * view)
 	QIconSet is3;
 	is3.setPixmap(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_BIGGRIN)),QIconSet::Small);
 	m_pIconButton->setIconSet(is3);
-	QToolTip::add(m_pIconButton,__tr2qs("Show Icons Popup<br>&lt;Ctrl+I&gt;<br>See also /help texticons"));
+	KviTalToolTip::add(m_pIconButton,__tr2qs("Show Icons Popup<br>&lt;Ctrl+I&gt;<br>See also /help texticons"));
 
 	connect(m_pIconButton,SIGNAL(clicked()),this,SLOT(iconButtonClicked()));
 
@@ -2172,7 +2379,7 @@ KviInput::KviInput(KviWindow *par,KviUserListView * view)
 	is0.setPixmap(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_SAYSMILE)),QIconSet::Small,QIconSet::Normal,QIconSet::On);
 	is0.setPixmap(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_SAYKVS)),QIconSet::Small,QIconSet::Normal,QIconSet::Off);
 	m_pCommandlineModeButton->setIconSet(is0);
-	QToolTip::add(m_pCommandlineModeButton,__tr2qs("User friendly commandline mode<br>See also /help commandline"));
+	KviTalToolTip::add(m_pCommandlineModeButton,__tr2qs("User friendly commandline mode<br>See also /help commandline"));
 	if(KVI_OPTION_BOOL(KviOption_boolCommandlineInUserFriendlyModeByDefault))
 		m_pCommandlineModeButton->setOn(true);
 
@@ -2184,13 +2391,32 @@ KviInput::KviInput(KviWindow *par,KviUserListView * view)
 	is2.setPixmap(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_TERMINAL)),QIconSet::Small,QIconSet::Normal,QIconSet::On);
 	is2.setPixmap(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_TERMINAL)),QIconSet::Small,QIconSet::Normal,QIconSet::Off);
 	m_pMultiEditorButton->setIconSet(is2);
-	QToolTip::add(m_pMultiEditorButton,__tr2qs("Multi-line Editor<br>&lt;Ctrl+Backspace&gt;"));
+	QString szTip = __tr2qs("Multi-line Editor<br>&lt;Alt+Backspace&gt;");
+	szTip += " - &lt;Ctrl+Backspace&gt;";
+	KviTalToolTip::add(m_pMultiEditorButton,szTip);
 
 	connect(m_pMultiEditorButton,SIGNAL(toggled(bool)),this,SLOT(multilineEditorButtonToggled(bool)));
 	
 	m_pInputEditor = new KviInputEditor(this,par,view);
 	connect(m_pInputEditor,SIGNAL(enterPressed()),this,SLOT(inputEditorEnterPressed()));
+#ifdef COMPILE_USE_QT4
+	m_pInputEditor->setSizePolicy(QSizePolicy(QSizePolicy::Expanding,QSizePolicy::Ignored));
+#else
 	m_pInputEditor->setSizePolicy(QSizePolicy(QSizePolicy::Ignored,QSizePolicy::Ignored));
+#endif
+	
+
+#ifdef COMPILE_USE_QT4
+	m_pMultiEditorButton->setAutoRaise(true);
+	m_pCommandlineModeButton->setAutoRaise(true);
+	m_pIconButton->setAutoRaise(true);
+	m_pHistoryButton->setAutoRaise(true);
+	m_pHideToolsButton->setAutoRaise(true);
+#endif
+
+	pLayout->setStretchFactor(m_pInputEditor,100000);
+	pLayout->setStretchFactor(m_pButtonContainer,0);
+	pLayout->setStretchFactor(m_pHideToolsButton,0);
 }
 
 KviInput::~KviInput()
@@ -2230,7 +2456,19 @@ void KviInput::inputEditorEnterPressed()
 void KviInput::keyPressEvent(QKeyEvent *e)
 {
 	//debug("KviInput::keyPressEvent(key:%d,state:%d,text:%s)",e->key(),e->state(),e->text().isEmpty() ? "empty" : e->text().utf8().data());
-	if(e->state() & ControlButton)
+
+	if((e->state() & Qt::ControlButton) || (e->state() & Qt::AltButton) || (e->state() & Qt::MetaButton))
+	{
+		switch(e->key())
+		{
+			case Qt::Key_Backspace:
+				//if(m_pMultiLineEditor)
+				multilineEditorButtonToggled(!m_pMultiLineEditor);
+			break;
+		}
+	}
+
+	if(e->state() & Qt::ControlButton)
 	{
 		switch(e->key())
 		{
@@ -2248,7 +2486,11 @@ void KviInput::keyPressEvent(QKeyEvent *e)
 						{
 							if(szText[0] != '/')
 							{
+#ifdef COMPILE_USE_QT4
+								int nLines = szText.count('\n') + 1;
+#else
 								int nLines = szText.contains('\n') + 1;
+#endif
 								if(nLines > 15)
 								{
 									int nRet = QMessageBox::question(
@@ -2284,9 +2526,6 @@ void KviInput::keyPressEvent(QKeyEvent *e)
 				}
 			}
 			break;
-			case Qt::Key_Backspace:
-				multilineEditorButtonToggled(!m_pMultiLineEditor);
-			break;
 			case Qt::Key_PageUp:
 				historyButtonClicked();
 			break;
@@ -2314,7 +2553,10 @@ void KviInput::multilineEditorButtonToggled(bool bOn)
 	} else {
 		if(!bOn)return;
 		m_pMultiLineEditor = KviScriptEditor::createInstance(this);
-		m_pMultiLineEditor->setFindText(__tr2qs("<Ctrl+Return>; submits, <Ctrl+Backspace>; hides this editor"));
+		QString szText = __tr2qs("<Ctrl+Return>; submits, <Alt+Backspace>; hides this editor");
+		// compatibility entry to avoid breaking translation just before a release... :)
+		szText.replace("Alt+Backspace","Ctrl+Backspace");
+		m_pMultiLineEditor->setFindText(szText);
 		m_pMultiLineEditor->setFindLineeditReadOnly(true);
 		m_pInputEditor->hide();
 		m_pMultiLineEditor->show();
@@ -2395,12 +2637,15 @@ void KviInput::insertText(const QString& text)
 
 void KviInput::applyOptions()
 {
+	if(g_pLastFontMetrics) delete g_pLastFontMetrics;
+	g_pLastFontMetrics = 0;
+
 	if(KVI_OPTION_BOOL(KviOption_boolDisableInputHistory))//G&N mar 2005
 	{
 		QIconSet is1;
 		is1.setPixmap(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_QUITSPLIT)),QIconSet::Small);
 		m_pHistoryButton->setIconSet(is1);
-		QToolTip::add(m_pHistoryButton,__tr2qs("Input History Disabled"));
+		KviTalToolTip::add(m_pHistoryButton,__tr2qs("Input History Disabled"));
 		m_pHistoryButton->disconnect(SIGNAL(clicked()));
 	}
 
@@ -2409,7 +2654,7 @@ void KviInput::applyOptions()
 		QIconSet is1;
 		is1.setPixmap(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_TIME)),QIconSet::Small);
 		m_pHistoryButton->setIconSet(is1);
-		QToolTip::add(m_pHistoryButton,__tr2qs("Show History<br>&lt;Ctrl+PageUp&gt;"));
+		KviTalToolTip::add(m_pHistoryButton,__tr2qs("Show History<br>&lt;Ctrl+PageUp&gt;"));
 		connect(m_pHistoryButton,SIGNAL(clicked()),this,SLOT(historyButtonClicked()));
 	}
 
