@@ -7,7 +7,7 @@
 //   Creation date : Sun Jan 3 1999 23:04:10 by Szymon Stefanek
 //
 //   This file is part of the KVirc irc client distribution
-//   Copyright (C) 1999-2002 Szymon Stefanek (pragma at kvirc dot net)
+//   Copyright (C) 1999-2007 Szymon Stefanek (pragma at kvirc dot net)
 //
 //   This program is FREE software. You can redistribute it and/or
 //   modify it under the terms of the GNU General Public License
@@ -29,9 +29,9 @@
 
 
 #include <qwidget.h>
-#include <qhbox.h>
+#include "kvi_tal_hbox.h"
 #include <qpixmap.h>
-#include "kvi_list.h"
+#include "kvi_pointerlist.h"
 
 #include "kvi_string.h"
 
@@ -41,7 +41,8 @@
 class KviUserListView;
 class KviWindow;
 class KviInput;
-class QHBox;
+class KviTalHBox;
+class QFontMetrics;
 
 // Default maximum buffer size.
 #define KVI_INPUT_MAX_BUFFER_SIZE 400
@@ -62,14 +63,17 @@ public:
 	KviInputHistory();
 	~KviInputHistory();
 protected:
-	KviPtrList<QString> * m_pStringList;
+	KviPointerList<QString> * m_pStringList;
 public:
 	void add(QString * s);
-	KviPtrList<QString> * list(){ return m_pStringList; };
+	KviPointerList<QString> * list(){ return m_pStringList; };
 	void save(const char * filename);
 	void load(const char * filename);
 };
 
+#ifdef COMPILE_USE_QT4
+	#define QIMEvent QInputMethodEvent
+#endif
 
 class KVIRC_API KviInputEditor : public QFrame
 {
@@ -117,7 +121,7 @@ protected:
 	int                      m_iSelectionAnchorChar;
 
 	// History stuff
-	KviPtrList<QString>    * m_pHistory;
+	KviPointerList<QString>    * m_pHistory;
 	int                      m_iCurHistoryIdx;
 
 	KviStr                   m_szSaveTextBuffer;
@@ -135,7 +139,7 @@ protected:
 	KviStr                   m_szAltKeyCode;
 	KviWindow              * m_pKviWindow;
 	QWidget                * m_pInputParent;
-	QPopupMenu             * m_pIconMenu;
+	KviTalPopupMenu             * m_pIconMenu;
 	bool			 m_bReadOnly;
 public:
 	int  heightHint() const;
@@ -154,13 +158,14 @@ private:
 	void getWordBeforeCursor(QString &buffer,bool * bIsFirstWordInLine);
 	void runUpToTheFirstVisibleChar();
 	void extractNextBlock(int idx,QFontMetrics & fm,int curXPos,int maxXPos);
-	void drawTextBlock(QPainter *pa,QFontMetrics & fm,int curXPos,int textBaseline,int idx,int len,int wdth);
+	void drawTextBlock(QPainter *pa,QFontMetrics & fm,int curXPos,int textBaseline,int idx,int len,bool bSelected=FALSE);
 	QChar getSubstituteChar(unsigned short control_code);
 	void moveRightFirstVisibleCharToShowCursor();
 	void repaintWithCursorOn();
 	void selectOneChar(int pos);
 	int  charIndexFromXPosition(int xPos);
-	int  xPositionFromCharIndex(int chIdx);
+	int  xPositionFromCharIndex(QFontMetrics& fm,int chIdx,bool bContentsCoords=FALSE);
+	int  xPositionFromCharIndex(int chIdx,bool bContentsCoords=FALSE);
 	void killDragTimer();
 	void handleDragSelection();
 	void end();
@@ -170,7 +175,7 @@ private:
 	void returnPressed(bool bRepaint = true);
 	void completion(bool bShift);
 	void standardNickCompletion(bool bAddMask,QString &word,bool bFirstWordInLine);
-	void recalcFontMetrics();
+	void recalcFontMetrics(QFontMetrics * pFm);
 	void internalCursorRight(bool bShift);
 	void internalCursorLeft(bool bShift);
 public slots:
@@ -188,7 +193,7 @@ public slots:
 	void clear();
 signals:
 	void escapePressed();
-    void enterPressed();
+	void enterPressed();
 protected:
 	virtual void drawContents(QPainter *);
 	//virtual void resizeEvent(QResizeEvent *);
@@ -204,6 +209,9 @@ protected:
 	virtual void imStartEvent(QIMEvent *e);
 	virtual void imComposeEvent(QIMEvent *e);
 	virtual void imEndEvent(QIMEvent *e);
+#ifdef COMPILE_USE_QT4
+	virtual void paintEvent(QPaintEvent *e);
+#endif
 };
 
 class KviScriptEditor;
@@ -218,7 +226,7 @@ public:
 	KviWindow       * m_pWindow;
 	KviInputEditor  * m_pInputEditor;
 	KviScriptEditor * m_pMultiLineEditor;
-	QHBox		* m_pButtonContainer;
+	KviTalHBox		* m_pButtonContainer;
 	QToolButton     * m_pMultiEditorButton;
 	QToolButton     * m_pHistoryButton;
 	QToolButton     * m_pIconButton;
@@ -238,6 +246,8 @@ public slots:
 public:
 	virtual void setFocus();
 	void multiLinePaste(const QString &text);
+	bool isUserFriendly() { return m_pCommandlineModeButton->isOn(); };
+	void setUserFriendly(bool bSet) { m_pCommandlineModeButton->setOn(bSet); };
 	int heightHint() const;
 	void setText(const QString &text);
 	void insertChar(char c);
