@@ -35,8 +35,7 @@
 #include "kvi_dynamictooltip.h"
 #include "kvi_ircurl.h"
 #include "kvi_internalcmd.h"
-#include "kvi_uparser.h"
-#include "kvi_list.h"
+#include "kvi_pointerlist.h"
 #include "kvi_ircconnection.h"
 #include "kvi_ircconnectionuserinfo.h"
 #include "kvi_irccontext.h"
@@ -44,29 +43,36 @@
 
 #include <qstyle.h>
 #include <qpainter.h>
-#include <qpopupmenu.h>
+#include "kvi_tal_popupmenu.h"
 #include <qlayout.h>
 
+#ifdef COMPILE_USE_QT4
+	#include <qevent.h>
+#endif
 
 #ifdef COMPILE_PSEUDO_TRANSPARENCY
 	extern QPixmap * g_pShadedChildGlobalDesktopBackground;
 #endif
 
 static QPixmap                                  * g_pIccMemBuffer               = 0;
-static KviPtrList<KviToolBarGraphicalApplet>    * g_pToolBarGraphicalAppletList = 0;
+static KviPointerList<KviToolBarGraphicalApplet>    * g_pToolBarGraphicalAppletList = 0;
 
 KviToolBarGraphicalApplet::KviToolBarGraphicalApplet(QWidget * par,const char * name)
 : QToolButton(par,name)
 {
 	if(!g_pToolBarGraphicalAppletList)
 	{
-		g_pToolBarGraphicalAppletList = new KviPtrList<KviToolBarGraphicalApplet>();
+		g_pToolBarGraphicalAppletList = new KviPointerList<KviToolBarGraphicalApplet>();
 		g_pToolBarGraphicalAppletList->setAutoDelete(false);
 		g_pIccMemBuffer = new QPixmap(1,1);
 	}
 	
 	g_pToolBarGraphicalAppletList->append(this);
+#ifdef COMPILE_USE_QT4
+	setAutoFillBackground(false);
+#else
 	setBackgroundMode(QWidget::NoBackground);
+#endif
 
 	setMouseTracking(true);
 	m_bResizeMode = false;
@@ -114,7 +120,7 @@ toolbar.define(default)
 
 void KviToolBarGraphicalApplet::mouseMoveEvent(QMouseEvent * e)
 {
-	if(e->state() & LeftButton)
+	if(e->state() & Qt::LeftButton)
 	{
 		if(m_bResizeMode)
 		{
@@ -127,15 +133,15 @@ void KviToolBarGraphicalApplet::mouseMoveEvent(QMouseEvent * e)
 		}
 	} else {
 		if(e->pos().x() > width() - 4)
-			setCursor(sizeHorCursor);
+			setCursor(Qt::sizeHorCursor);
 		else
-			setCursor(arrowCursor);
+			setCursor(Qt::arrowCursor);
 	}
 }
 
 void KviToolBarGraphicalApplet::mousePressEvent(QMouseEvent * e)
 {
-	if(e->button() & LeftButton)
+	if(e->button() & Qt::LeftButton)
 	{
 		m_bResizeMode = (e->pos().x() > (width() - 4));
 	}
@@ -209,7 +215,12 @@ void KviToolBarGraphicalApplet::paintEvent(QPaintEvent *e)
 	pa.drawLine(1,height() - 1,width() - 1,height() - 1);
 	pa.drawLine(width() - 1,1,width() - 1,height());
 
+#ifdef COMPILE_USE_QT4
+	QPainter qt4SucksBecauseItNeedsAnAdditionalQPainter(this);
+	qt4SucksBecauseItNeedsAnAdditionalQPainter.drawPixmap(e->rect().left(),e->rect().top(),e->rect().width(),e->rect().height(),*g_pIccMemBuffer,e->rect().left(),e->rect().top(),e->rect().width(),e->rect().height());
+#else
 	bitBlt(this,e->rect().left(),e->rect().top(),g_pIccMemBuffer,e->rect().left(),e->rect().top(),e->rect().width(),e->rect().height(),Qt::CopyROP);
+#endif
 }
 
 void KviToolBarGraphicalApplet::drawContents(QPainter *)
