@@ -26,7 +26,7 @@
 
 #include "kvi_settings.h"
 #include "kvi_string.h"
-#include "kvi_list.h"
+#include "kvi_pointerlist.h"
 
 #include <qwidget.h>
 #include <qpixmap.h>      // needed
@@ -36,7 +36,7 @@ class QLineEdit;
 class QFile;
 class QToolButton;
 class QFontMetrics;
-class QPopupMenu;
+class KviTalPopupMenu;
 
 class KviWindow;
 class KviFrame;
@@ -55,6 +55,8 @@ class KVIRC_API KviIrcView : public QWidget
 {
 	Q_OBJECT
 	Q_PROPERTY(int TransparencyCapable READ dummyRead)
+	// we cannot #ifdef due to a bug in moc
+	Q_PROPERTY(bool usePaintOnScreen READ getPaintOnScreen WRITE setPaintOnScreen)
 public:
 	friend class KviIrcViewToolTip;
 	friend class KviIrcViewToolWidget;
@@ -63,8 +65,17 @@ public:
 	~KviIrcView();
 public:
 	int dummyRead() const { return 0; };
+#ifdef COMPILE_USE_QT4
+	bool getPaintOnScreen() const { return testAttribute(Qt::WA_PaintOnScreen);};
+	void setPaintOnScreen(bool bFlag){setAttribute(Qt::WA_PaintOnScreen,bFlag);} ;
+#else
+	// hack to fix moc bug on win qt4
+	bool getPaintOnScreen() const { return 0;};
+	void setPaintOnScreen(bool bFlag){} ;
+#endif
 private:
-	int		 	    m_iFlushTimer;
+//	QDate                       m_lastLogDay;
+	int		 	                m_iFlushTimer;
 	KviIrcViewLine            * m_pFirstLine;
 	KviIrcViewLine            * m_pCurLine;    // Bottom line in the view
 	KviIrcViewLine            * m_pLastLine;
@@ -72,7 +83,7 @@ private:
 	unsigned int                m_uLineMarkLineIndex;
 
 	// Highliting of links
-	KviIrcViewWrappedBlock       * m_pLastLinkUnderMouse;
+	KviIrcViewWrappedBlock    * m_pLastLinkUnderMouse;
 	int                         m_iLastLinkRectTop;
 	int                         m_iLastLinkRectHeight;
 
@@ -84,7 +95,7 @@ private:
 	QPixmap                   * m_pPrivateBackgroundPixmap;
 	QScrollBar                * m_pScrollBar;
 	QToolButton               * m_pToolsButton;
-	QPopupMenu                * m_pToolsPopup;
+	KviTalPopupMenu           * m_pToolsPopup;
 
 	KviIrcViewToolWidget      * m_pToolWidget;
 
@@ -118,7 +129,7 @@ private:
 
 	bool                        m_bSkipScrollBarRepaint;
 	int                         m_iSelectTimer;
-	int			    m_iMouseTimer;
+	int                         m_iMouseTimer;
 	//int                         m_iTipTimer;
 	QString                     m_szLastSelection;
 	QString                     m_szLastSelectionLine;
@@ -129,16 +140,22 @@ private:
 	bool                        m_bAcceptDrops;
 	int                         m_iUnprocessedPaintEventRequests;
 	bool                        m_bPostedPaintEventPending;
-	KviPtrList<KviIrcViewLine> * m_pMessagesStoppedWhileSelecting;
+	KviPointerList<KviIrcViewLine> * m_pMessagesStoppedWhileSelecting;
 	KviIrcView                * m_pMasterView;
-	QFontMetrics              * m_pFm;
+	QFontMetrics              * m_pFm;               // assume this valid only inside a paint event (may be 0 in other circumstances)
 	
-	QMouseEvent		  *  m_pLastEvent;
+	QMouseEvent              *  m_pLastEvent;
 	
 	KviIrcViewToolTip         * m_pToolTip;
+	bool m_bHaveUnreadedHighlightedMessages;
+	bool m_bHaveUnreadedMessages;
 public:
+	void checkLogDate();
+	void clearUnreaded();
 	void applyOptions();
 	void enableDnd(bool bEnable);
+	bool haveUnreadedMessages() { return m_bHaveUnreadedMessages; };
+	bool haveUnreadedHighlightedMessages() { return m_bHaveUnreadedHighlightedMessages; };
 	enum AppendTextFlags { NoRepaint = 1, NoTimestamp = 2, SetLineMark = 4 };
 	void appendText(int msg_type,const kvi_wchar_t *data_ptr,int iFlags = 0);
 	void clearLineMark(bool bRepaint=false);
@@ -160,7 +177,7 @@ public:
 	//==============================================================================================
 	// Logging
 	// Stops previous logging session too...
-	bool startLogging(const char *filename,bool bPrependCurBuffer = false);
+	bool startLogging(const QString& fname = QString::null,bool bPrependCurBuffer = false);
 	void stopLogging();
 	bool isLogging(){ return (m_pLogFile != 0); };
 	void getLogFileName(KviStr &buffer);
@@ -200,14 +217,13 @@ signals:
 private:
 	void setCursorLine(KviIrcViewLine * l);
 	KviIrcViewLine * getVisibleLineAt(int xPos,int yPos);
-//	void findClosestPositionInText(int xCursorPos,int yCursorPos,KviIrcViewPositionInText &pos);
 	void getLinkEscapeCommand(QString &buffer,const QString &escape_cmd,const QString &escape_label);
 	void appendLine(KviIrcViewLine *ptr,bool bRepaint);
 	void postUpdateEvent();
 	void fastScroll(int lines = 1);
 	const kvi_wchar_t * getTextLine(int msg_type,const kvi_wchar_t * data_ptr,KviIrcViewLine *line_ptr,bool bEnableTimeStamp = true);
 	void calculateLineWraps(KviIrcViewLine *ptr,int maxWidth);
-	void recalcFontVariables(const QFont &font);
+	void recalcFontVariables(const QFontMetrics &fm,const QFontInfo &fi);
 	bool checkSelectionBlock(KviIrcViewLine * line,int left,int bottom,int bufIndex);
 	void calculateSelectionBounds();
 	KviIrcViewWrappedBlock * getLinkUnderMouse(int xPos,int yPos,QRect * pRect = 0,QString * linkCmd = 0,QString * linkText = 0);
@@ -227,6 +243,7 @@ protected:
 	virtual void wheelEvent(QWheelEvent *e);
 	virtual void keyPressEvent(QKeyEvent *e);
 	void maybeTip(const QPoint &pnt);
+	virtual void leaveEvent ( QEvent * );
 protected slots:
 	virtual void scrollBarPositionChanged(int newValue);
 	void masterDead();
