@@ -42,10 +42,15 @@
 #include <qlabel.h>
 #include <qcheckbox.h>
 #include <qpushbutton.h>
-#include <qheader.h>
+#ifdef COMPILE_USE_QT4
+	#include <q3header.h>
+#else
+	#include <qheader.h>
+#endif
 #include <qlineedit.h>
 #include <qcursor.h>
-#include <qaccel.h>
+#include "kvi_accel.h"
+#include <qevent.h>
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
@@ -54,8 +59,8 @@
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
 
-KviIrcMessageCheckListItem::KviIrcMessageCheckListItem(QListView * par,KviIrcViewToolWidget * w,int id)
-: QCheckListItem(par,QString::null,QCheckListItem::CheckBox)
+KviIrcMessageCheckListItem::KviIrcMessageCheckListItem(KviTalListView * par,KviIrcViewToolWidget * w,int id)
+: KviTalCheckListItem(par,QString::null,KviTalCheckListItem::CheckBox)
 {
 	m_iId = id;
 	m_pToolWidget = 0;
@@ -70,7 +75,7 @@ KviIrcMessageCheckListItem::~KviIrcMessageCheckListItem()
 
 void KviIrcMessageCheckListItem::stateChange(bool bOn)
 {
-	QCheckListItem::stateChange(bOn);
+	KviTalCheckListItem::stateChange(bOn);
 	if(!m_pToolWidget)return;
 	m_pToolWidget->forceRepaint();
 }
@@ -90,7 +95,7 @@ KviIrcViewToolWidget::KviIrcViewToolWidget(KviIrcView * par)
 	l->setBackgroundColor(Qt::black);
 	gl->addWidget(l,0,0);
 
-	QToolButton *tb = new QToolButton(DownArrow,this);
+	QToolButton *tb = new QToolButton(Qt::DownArrow,this,"down_arrow");
 	tb->setFixedSize(14,14);
 	tb->setAutoRepeat(false);
 	connect(tb,SIGNAL(clicked()),m_pIrcView,SLOT(toggleToolWidget()));
@@ -143,7 +148,7 @@ KviIrcViewToolWidget::KviIrcViewToolWidget(KviIrcView * par)
 
 	g = new QGridLayout(w1,5,2,2,1);
 
-	m_pFilterView = new QListView(w1);
+	m_pFilterView = new KviTalListView(w1);
 	m_pFilterView->addColumn(__tr2qs("Type"));
 	m_pFilterView->header()->hide();
 	m_pFilterView->setMinimumSize(QSize(10,10));
@@ -181,8 +186,8 @@ KviIrcViewToolWidget::KviIrcViewToolWidget(KviIrcView * par)
 	gl->setResizeMode(QGridLayout::Fixed);
 	m_pStringToFind->setFocus();
 	tw->showPage(w);
-	QAccel *a = new QAccel( this );
-        a->connectItem( a->insertItem(Key_Escape), this,SLOT(close()) );
+	KviAccel *a = new KviAccel( this );
+        a->connectItem( a->insertItem(Qt::Key_Escape), this,SLOT(close()) );
 }
 
 KviIrcViewToolWidget::~KviIrcViewToolWidget()
@@ -212,6 +217,14 @@ void KviIrcViewToolWidget::filterEnableNone()
 	forceRepaint();
 }
 
+void KviIrcViewToolWidget::hideEvent ( QHideEvent * ){
+	m_pIrcView->toggleToolWidget();
+}
+
+void KviIrcViewToolWidget::closeEvent ( QCloseEvent * e ){
+	m_pIrcView->toggleToolWidget();
+}
+
 void KviIrcViewToolWidget::filterLoad()
 {
 	QString szFile;
@@ -242,12 +255,12 @@ void KviIrcViewToolWidget::filterLoad()
 
 void KviIrcViewToolWidget::filterSave()
 {
-	KviStr szFile;
-	KviStr szInit;
+	QString szFile;
+	QString szInit;
 	g_pApp->getLocalKvircDirectory(szInit,KviApp::Filters,"filter.kvf");
-	if(KviFileDialog::askForSaveFileName(szFile,__tr2qs("Select a Name for the Filter File"),szInit.ptr(),0,false,true))
+	if(KviFileDialog::askForSaveFileName(szFile,__tr2qs("Select a Name for the Filter File"),szInit,0,false,true))
 	{
-		QFile f(QString::fromUtf8(szFile.ptr()));
+		QFile f(szFile);
 		if(f.open(IO_WriteOnly))
 		{
 			char buffer[KVI_NUM_MSGTYPE_OPTIONS];
@@ -256,15 +269,20 @@ void KviIrcViewToolWidget::filterSave()
 				buffer[i] = messageEnabled(i) ? 1 : 0;
 			}
 			if(f.writeBlock(buffer,KVI_NUM_MSGTYPE_OPTIONS) < KVI_NUM_MSGTYPE_OPTIONS)
-				KviMessageBox::warning(__tr2qs("Failed to write the filter file %s (IO Error)"),szFile.ptr());
+				KviMessageBox::warning(__tr2qs("Failed to write the filter file %Q (IO Error)"),&szFile);
 			f.close();
-		} else KviMessageBox::warning(__tr2qs("Can't open the filter file %s for writing"),szFile.ptr());
+		} else KviMessageBox::warning(__tr2qs("Can't open the filter file %Q for writing"),&szFile);
 	}
 }
 
 void KviIrcViewToolWidget::forceRepaint()
 {
-	m_pIrcView->paintEvent(0);
+	#if defined(COMPILE_USE_QT4) && defined(COMPILE_ON_WINDOWS) 
+		m_pIrcView->repaint();
+	#else
+		m_pIrcView->paintEvent(0);
+	#endif
+
 }
 
 void KviIrcViewToolWidget::setFindResult(const QString & text)
@@ -314,7 +332,7 @@ void KviIrcViewToolWidget::mouseMoveEvent(QMouseEvent *)
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
 KviIrcViewToolTip::KviIrcViewToolTip(KviIrcView * pView)
-: QToolTip(pView,0)
+: KviTalToolTip(pView)
 {
 	m_pView = pView;
 }
