@@ -26,18 +26,19 @@
 
 #include "kvi_settings.h"
 
-#include <qtooltip.h>
+#include "kvi_tal_tooltip.h"
 #include <qframe.h>
-#include <qlistview.h>
+#include "kvi_tal_listview.h"
 #include <qstring.h>
 
 class QLabel;
-class KviStyledCheckBox;
+//class KviStyledCheckBox;
+#include "kvi_styled_controls.h"
 class QLineEdit;
 
 class KviIrcView;
 
-class KviIrcViewToolTip : public QToolTip
+class KviIrcViewToolTip : public KviTalToolTip
 {
 public:
 	KviIrcViewToolTip(KviIrcView * pView);
@@ -56,10 +57,10 @@ public:
 
 class KviIrcViewToolWidget;
 
-class KviIrcMessageCheckListItem : public QCheckListItem
+class KviIrcMessageCheckListItem : public KviTalCheckListItem
 {
 public:
-	KviIrcMessageCheckListItem(QListView * par,KviIrcViewToolWidget * w,int id);
+	KviIrcMessageCheckListItem(KviTalListView * par,KviIrcViewToolWidget * w,int id);
 	~KviIrcMessageCheckListItem();
 private:
 	int m_iId;
@@ -93,7 +94,7 @@ protected:
 
 	QLabel     * m_pFindResult;
 
-	QListView  * m_pFilterView;
+	KviTalListView  * m_pFilterView;
 
 	KviIrcMessageCheckListItem ** m_pFilterItems;
 
@@ -109,6 +110,8 @@ protected slots:
 	void filterSave();
 	void filterLoad();
 protected:
+	virtual void hideEvent( QHideEvent * );
+	virtual void closeEvent( QCloseEvent * e );
 	virtual void mouseMoveEvent(QMouseEvent *);
 	virtual void mousePressEvent(QMouseEvent *);
 };
