@@ -36,8 +36,8 @@
 #include <qlabel.h>
 #include <qvalidator.h> 
 
-KviMaskItem::KviMaskItem(QListView* parent,KviMaskEntry* entry)
-:QListViewItem(parent), m_Mask(*entry)
+KviMaskItem::KviMaskItem(KviTalListView* parent,KviMaskEntry* entry)
+:KviTalListViewItem(parent), m_Mask(*entry)
 {
 	QDateTime date;
 	date.setTime_t(mask()->uSetAt);
@@ -49,8 +49,11 @@ KviMaskItem::KviMaskItem(QListView* parent,KviMaskEntry* entry)
 KviMaskItem::~KviMaskItem()
 {
 }
-
+#ifdef COMPILE_USE_QT4
+int KviMaskItem::compare ( KviTalListViewItem * i, int col, bool ascending ) const
+#else
 int KviMaskItem::compare ( QListViewItem * i, int col, bool ascending ) const
+#endif
 {
 	if(col==2)
 	{
@@ -58,7 +61,7 @@ int KviMaskItem::compare ( QListViewItem * i, int col, bool ascending ) const
 		if( ((KviMaskItem*)i)->mask()->uSetAt == m_Mask.uSetAt ) return  0;
 		if( ((KviMaskItem*)i)->mask()->uSetAt < m_Mask.uSetAt )  return  1;
 	}
-	return QListViewItem::compare(i,col,ascending);
+	return KviTalListViewItem::compare(i,col,ascending);
 }
 
 KviMaskInputDialog::KviMaskInputDialog(const QString &szMask,KviMaskEditor* pEditor,KviChannel * pChannel)
@@ -120,8 +123,8 @@ void KviMaskInputDialog::accept()
 	QDialog::accept();
 }
 
-KviMaskEditor::KviMaskEditor(QWidget * par,KviWindowToolPageButton* button,KviPtrList<KviMaskEntry> * maskList,char flag,const char * nam)
-: KviWindowToolWidget(par,button,nam)
+KviMaskEditor::KviMaskEditor(QWidget * par,KviWindowToolPageButton* button,KviPointerList<KviMaskEntry> * maskList,char flag,const char * nam)
+: KviWindowToolWidget(par,button)
 {
 	bool isEnabled=1;
 	
@@ -136,10 +139,14 @@ KviMaskEditor::KviMaskEditor(QWidget * par,KviWindowToolPageButton* button,KviPt
 		}
 	w = w->parent();
 	}
-	
-	setFocusPolicy(QWidget::ClickFocus);
 
-	QGridLayout *g = new QGridLayout(this,3,3,2,2);
+#ifdef COMPILE_USE_QT4
+	setFocusPolicy(Qt::ClickFocus);
+#else
+	setFocusPolicy(QWidget::ClickFocus);
+#endif
+
+	QGridLayout *g = new QGridLayout(this,4,2,2,2);
 
 	m_cFlag = flag;
 
@@ -171,12 +178,23 @@ KviMaskEditor::KviMaskEditor(QWidget * par,KviWindowToolPageButton* button,KviPt
 	l = new QLabel(txt,this);
 	g->addWidget(l,0,1);
 
+	KviTalHBox * hb = new KviTalHBox(this);
+	g->addMultiCellWidget(hb,1,1,0,1);
+
+	new QLabel(__tr2qs("Filter:"),hb);
+	m_pSearch = new QLineEdit(hb);
+	connect(m_pSearch,SIGNAL(textChanged ( const QString & ) ),this,SLOT(searchTextChanged ( const QString & )));
+
 	l = new QLabel(__tr2qs("Use doubleclick to edit item"),this);
-	g->addWidget(l,0,1);
-	g->addMultiCellWidget(l,1,1,0,1);
+	g->addWidget(l,1,1);
+	g->addMultiCellWidget(l,2,2,0,1);
 	
-	m_pMaskBox = new QListView(this);
+	m_pMaskBox = new KviTalListView(this);
+#ifdef COMPILE_USE_QT4
+	m_pMaskBox->setFocusPolicy(Qt::ClickFocus);
+#else
 	m_pMaskBox->setFocusPolicy(QWidget::ClickFocus);
+#endif
 	m_pMaskBox->setFocusProxy(this);
 	m_pMaskBox->setFrameStyle(QFrame::StyledPanel|QFrame::Sunken);
 	m_pMaskBox->addColumn(__tr2qs("Mask"));
@@ -186,26 +204,34 @@ KviMaskEditor::KviMaskEditor(QWidget * par,KviWindowToolPageButton* button,KviPt
 	m_pMaskBox->setAllColumnsShowFocus(true);
 	m_pMaskBox->setShowSortIndicator(true);
 	m_pMaskBox->setSorting(2,false);
-	connect(m_pMaskBox,SIGNAL(doubleClicked ( QListViewItem * )),this,SLOT(listViewDoubleClicked( QListViewItem * )));
-	g->addMultiCellWidget(m_pMaskBox,2,2,0,1);
+	connect(m_pMaskBox,SIGNAL(doubleClicked ( KviTalListViewItem * )),this,SLOT(listViewDoubleClicked( KviTalListViewItem * )));
+	g->addMultiCellWidget(m_pMaskBox,3,3,0,1);
 
 	m_pRemoveMask  = new QPushButton(__tr2qs("Re&move"),this);
 	m_pRemoveMask->setEnabled(isEnabled);
+#ifdef COMPILE_USE_QT4
+	m_pRemoveMask->setFocusPolicy(Qt::ClickFocus);
+#else
 	m_pRemoveMask->setFocusPolicy(QWidget::ClickFocus);
+#endif
 	m_pRemoveMask->setFocusProxy(this);
-	g->addWidget(m_pRemoveMask,3,1);
+	g->addWidget(m_pRemoveMask,4,1);
 	connect(m_pRemoveMask,SIGNAL(clicked()),this,SLOT(removeClicked()));
 	m_pRemoveMask->setIconSet(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_DELETEITEM)));
 	
 	m_pAddButton = new QPushButton(__tr2qs("Add"),this);
 	m_pAddButton->setEnabled(isEnabled);
+#ifdef COMPILE_USE_QT4
+	m_pAddButton->setFocusPolicy(Qt::ClickFocus);
+#else
 	m_pAddButton->setFocusPolicy(QWidget::ClickFocus);
+#endif
 	m_pAddButton->setFocusProxy(this);
-	g->addWidget(m_pAddButton,3,0);
+	g->addWidget(m_pAddButton,4,0);
 	connect(m_pAddButton,SIGNAL(clicked()),this,SLOT(addClicked()));
 	m_pAddButton->setIconSet(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_NEWITEM)));
 	
-	g->setColStretch(1,1);
+	g->setColStretch(3,1);
 
 	for(KviMaskEntry * e = maskList->first();e;e = maskList->next()) addMask(e);
 	registerSelf();
@@ -216,9 +242,30 @@ KviMaskEditor::~KviMaskEditor()
 
 }
 
+void KviMaskEditor::searchTextChanged ( const QString & text)
+{
+	KviTalListViewItem *pItem=m_pMaskBox->firstChild();
+	KviMaskItem *pMaskItem;
+	bool bEmpty = text.isEmpty();
+	while(pItem)
+	{
+		pMaskItem = (KviMaskItem *)pItem;
+		if(bEmpty)
+		{
+			pMaskItem->setVisible(true);
+		} else {
+			if(pMaskItem->mask()->szMask.contains(text))
+				pMaskItem->setVisible(true);
+			else 
+				pMaskItem->setVisible(false);
+		}
+		pItem=pItem->nextSibling();
+	}
+}
+
 void KviMaskEditor::removeClicked()
 {
-	KviPtrList<KviMaskEntry>  * l = new KviPtrList<KviMaskEntry>;
+	KviPointerList<KviMaskEntry>  * l = new KviPointerList<KviMaskEntry>;
 	l->setAutoDelete(true);
 	KviMaskItem * it = (KviMaskItem *)(m_pMaskBox->firstChild());
 	while(it)
@@ -278,7 +325,7 @@ void KviMaskEditor::removeMask(KviMaskEntry *e)
 	}
 }
 
-void KviMaskEditor::listViewDoubleClicked( QListViewItem * pItem)
+void KviMaskEditor::listViewDoubleClicked( KviTalListViewItem * pItem)
 {
 	if(pItem)
 	{
