@@ -27,9 +27,9 @@
 #include <qdialog.h> 
 #include <qlineedit.h> 
 #include <qwidget.h>
-#include <qlistview.h>
+#include "kvi_tal_listview.h"
 #include <qpushbutton.h>
-#include "kvi_list.h"
+#include "kvi_pointerlist.h"
 
 #include "kvi_string.h"
 #include "kvi_toolwindows_container.h"
@@ -44,15 +44,18 @@ typedef struct _KviMaskEntry
 	unsigned int uSetAt;
 } KviMaskEntry;
 
-class KviMaskItem: public QListViewItem
+class KviMaskItem: public KviTalListViewItem
 {
 public:
-	KviMaskItem(QListView* parent,KviMaskEntry* entry);
+	KviMaskItem(KviTalListView* parent,KviMaskEntry* entry);
 	~KviMaskItem();
 	
 	KviMaskEntry* mask() { return &m_Mask; };
-	
+#ifdef COMPILE_USE_QT4
+	virtual int compare ( KviTalListViewItem * i, int col, bool ascending ) const;
+#else
 	virtual int compare ( QListViewItem * i, int col, bool ascending ) const;
+#endif
 protected:
 	KviMaskEntry m_Mask;
 	
@@ -79,15 +82,16 @@ class KVIRC_API KviMaskEditor : public KviWindowToolWidget
 {
 	Q_OBJECT
 public:
-	KviMaskEditor(QWidget * par,KviWindowToolPageButton* button,KviPtrList<KviMaskEntry> * maskList,
+	KviMaskEditor(QWidget * par,KviWindowToolPageButton* button,KviPointerList<KviMaskEntry> * maskList,
 		char flag,const char * nam);
 	~KviMaskEditor();
 protected:
-	QListView           * m_pMaskBox;
+	KviTalListView      * m_pMaskBox;
 	QPushButton         * m_pRemoveMask;
 	QPushButton   	    * m_pAddButton;
+	QLineEdit           * m_pSearch;
 	char                  m_cFlag;
-	int		      m_iIconId;
+	int		              m_iIconId;
 public:
 	char flag(){ return m_cFlag; };
 	void addMask(KviMaskEntry *e);
@@ -95,9 +99,10 @@ public:
 protected slots:
 	void removeClicked();
 	void addClicked();
-	void listViewDoubleClicked( QListViewItem * );
+	void listViewDoubleClicked( KviTalListViewItem * );
+	void searchTextChanged ( const QString & );
 signals:
-	void removeMasks(KviMaskEditor *,KviPtrList<KviMaskEntry> *);
+	void removeMasks(KviMaskEditor *,KviPointerList<KviMaskEntry> *);
 };
 
 #endif //_KVI_MASKEDITOR_H_
