@@ -40,13 +40,20 @@
 #include <qnamespace.h>
 #include <qapplication.h>
 #include <qfontmetrics.h>
-#include "kvi_list.h"
+#include "kvi_pointerlist.h"
 #include <qpixmap.h>
 #include <qstyle.h>
 #include <qpainter.h>
-#include <qpopupmenu.h>
-#include <qsimplerichtext.h>
+#include "kvi_tal_popupmenu.h"
+#ifdef COMPILE_USE_QT4
+	#include <q3simplerichtext.h>
+	#define QSimpleRichText Q3SimpleRichText
+	#include <qstyleoption.h>
+#else
+	#include <qsimplerichtext.h>
+#endif
 #include <qdrawutil.h>
+#include <qevent.h>
 
 KviMdiCaptionButton::KviMdiCaptionButton(const QPixmap &pix,QWidget * parent,const char * name)
 : QToolButton(parent,name)
@@ -61,16 +68,34 @@ KviMdiCaptionButton::~KviMdiCaptionButton()
 }
 
 
+#ifdef COMPILE_USE_QT4
+void KviMdiCaptionButton::paintEvent(QPaintEvent *e)
+{
+	QPainter painter(this);
+	drawButton(&painter);
+}
+#endif
+
 void KviMdiCaptionButton::drawButton(QPainter *p)
 {
+#ifdef COMPILE_USE_QT4
+	QBrush b(parentWidget()->palette().window());
+#else
 	QBrush b(parentWidget()->colorGroup().background());
+#endif
 	
 	if(isDown())
 		qDrawShadePanel(p,0,0,width(),height(),colorGroup(),true,1,&b);
 	else
 		p->fillRect(0,0,width(),height(),b);
-		
+
+#ifdef COMPILE_USE_QT4
+	int x = (width() - 16) / 2;
+	int y = (width() - 16) / 2;
+	p->drawPixmap(x,y,16,16,icon().pixmap(16,16),0,0,16,16);
+#else
 	drawButtonLabel(p);
+#endif
 }
 
 
@@ -95,6 +120,9 @@ KviMdiCaption::KviMdiCaption(KviMdiChild * parent,const char * name)
 	m_bMouseGrabbed = true;
 	m_bActive = false;
 	calcLineSpacing();
+#ifdef COMPILE_USE_QT4
+	setAutoFillBackground(false);
+#endif
 }
 
 KviMdiCaption::~KviMdiCaption()
@@ -140,11 +168,16 @@ void KviMdiCaption::fontChange(const QFont &old)
 	((KviMdiChild *)parent())->resizeEvent(0);
 }
 
-void KviMdiCaption::mousePressEvent(QMouseEvent *)
+void KviMdiCaption::mousePressEvent(QMouseEvent *e)
 {
 	m_bMouseGrabbed = true;
 	m_lastMousePos = QCursor::pos();
-	grabMouse(Qt::sizeAllCursor);
+#ifdef COMPILE_USE_QT4
+	setCursor(Qt::SizeAllCursor);
+#else
+	setCursor(QCursor::sizeAllCursor);
+#endif
+	((KviMdiChild *)parent())->activate(true);
 }
 
 void KviMdiCaption::mouseMoveEvent(QMouseEvent *)
@@ -202,7 +235,12 @@ void KviMdiCaption::paintEvent(QPaintEvent * e)
 void KviMdiCaption::mouseReleaseEvent(QMouseEvent *)
 {
 	m_bMouseGrabbed = false;
-	releaseMouse();
+#ifdef COMPILE_USE_QT4
+	setCursor(Qt::arrowCursor);
+#else
+	setCursor(QCursor::arrowCursor);
+#endif
+//	releaseMouse();
 }
 
 void KviMdiCaption::setFocusProxy(QWidget * w)
