@@ -1,9 +1,10 @@
+//=============================================================================
 //
 //   File : kvi_mdichild.cpp
 //   Creation date : Wed Jun 21 2000 17:35:45 by Szymon Stefanek
 //
 //   This file is part of the KVirc irc client distribution
-//   Copyright (C) 1999-2000 Szymon Stefanek (pragma at kvirc dot net)
+//   Copyright (C) 1999-2007 Szymon Stefanek (pragma at kvirc dot net)
 //
 //   This program is FREE software. You can redistribute it and/or
 //   modify it under the terms of the GNU General Public License
@@ -19,6 +20,7 @@
 //   along with this program. If not, write to the Free Software Foundation,
 //   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 //
+//=============================================================================
 #define __KVIRC__
 
 #define _KVI_DEBUG_CHECK_RANGE_
@@ -37,15 +39,21 @@
 #include <qnamespace.h>
 #include <qapplication.h>
 #include <qfontmetrics.h>
-#include "kvi_list.h"
+#include "kvi_pointerlist.h"
 #include <qpixmap.h>
 #include <qstyle.h>
 #include <qpainter.h>
-#include <qpopupmenu.h>
-#include <qobjectlist.h>
+#include "kvi_tal_popupmenu.h"
+#ifndef COMPILE_USE_QT4
+	#include <qobjectlist.h>
+#endif
+#include <qevent.h>
 
 #ifdef Q_OS_MACX
 #include "kvi_app.h"  //Needed for g_pApp
+#ifdef COMPILE_USE_QT4
+	#include <QDesktopWidget>
+#endif
 #endif
 
 #ifdef COMPILE_PSEUDO_TRANSPARENCY
@@ -83,6 +91,10 @@ KviMdiChild::KviMdiChild(KviMdiManager * par,const char * name)
 
 	setMouseTracking(true);
 	setMinimumSize(KVI_MDICHILD_MIN_WIDTH,KVI_MDICHILD_MIN_HEIGHT);
+
+#ifdef COMPILE_USE_QT4
+	setAutoFillBackground(true);
+#endif
 	
 }
 
@@ -104,11 +116,19 @@ QRect KviMdiChild::restoredGeometry()
 
 }
 
+#ifdef COMPILE_USE_QT4
+void KviMdiChild::setBackgroundRole(QPalette::ColorRole)
+{
+	// hack
+	QFrame::setBackgroundRole(QPalette::Window);
+}
+#else
 void KviMdiChild::setBackgroundMode(QWidget::BackgroundMode)
 {
 	// hack
 	QFrame::setBackgroundMode(QWidget::PaletteBackground);
 }
+#endif
 
 void KviMdiChild::setIcon(const QPixmap &pix)
 {
@@ -297,7 +317,7 @@ void KviMdiChild::mouseReleaseEvent(QMouseEvent *)
 		releaseMouse();
 	}
 
-	if(QApplication::overrideCursor())QApplication::restoreOverrideCursor();
+	//if(QApplication::overrideCursor())QApplication::restoreOverrideCursor();
 }
 
 QCursor KviMdiChild::getResizeCursor(int resizeCorner)
@@ -328,7 +348,7 @@ QCursor KviMdiChild::getResizeCursor(int resizeCorner)
 
 void KviMdiChild::mouseMoveEvent(QMouseEvent *e)
 {
-	if(e->state() & LeftButton)
+	if(e->state() & Qt::LeftButton)
 	{
 		if(m_iResizeCorner && (m_state != Maximized))resizeWindowOpaque(m_iResizeCorner);
 	} else {
@@ -338,14 +358,19 @@ void KviMdiChild::mouseMoveEvent(QMouseEvent *e)
 
 void KviMdiChild::setResizeCursor(int resizeCorner)
 {
-	if(resizeCorner == m_iLastCursorCorner)return; //Don't do it twice
+	if(resizeCorner == m_iLastCursorCorner)
+		return; //Don't do it twice
 	m_iLastCursorCorner = resizeCorner;
 	if(resizeCorner == KVI_MDI_NORESIZE)
 	{
-		if(QApplication::overrideCursor())QApplication::restoreOverrideCursor(); 
+		setCursor(getResizeCursor(resizeCorner));
+		//if(QApplication::overrideCursor())QApplication::restoreOverrideCursor(); 
 	} else {
 		if(m_state != Maximized)
-			QApplication::setOverrideCursor(getResizeCursor(resizeCorner),true);
+		{
+			setCursor(getResizeCursor(resizeCorner));
+			//QApplication::setOverrideCursor(getResizeCursor(resizeCorner),true);
+		}
 	}
 }
 
@@ -355,7 +380,7 @@ void KviMdiChild::leaveEvent(QEvent *)
 	{
 		m_iResizeCorner=KVI_MDI_NORESIZE;
 		m_iLastCursorCorner=KVI_MDI_NORESIZE;
-		if(QApplication::overrideCursor())QApplication::restoreOverrideCursor();
+		//if(QApplication::overrideCursor())QApplication::restoreOverrideCursor();
 	} else {
 		if(m_iResizeCorner != KVI_MDI_NORESIZE)resizeWindowOpaque(m_iResizeCorner);
 	}
@@ -504,7 +529,7 @@ void KviMdiChild::unsetClient()
 	//Kewl...the reparent function has a small prob now..
 	//the new toplelvel widgets gets not reenabled for dnd
 #ifndef Q_OS_MACX
-	m_pClient->reparent(0,QPoint(0,0),true);
+	m_pClient->reparent(0,m_pClient->mapToGlobal(QPoint(0,0)),true);
 #else
 	QRect r = g_pApp->desktop()->availableGeometry(m_pClient); 
 	r.moveBy(0, 22);
