@@ -36,14 +36,18 @@
 #include "kvi_mdicaption.h"
 #include "kvi_app.h"
 
-#include <qpopupmenu.h>
+#include "kvi_tal_popupmenu.h"
 #include <qmenubar.h>
 #include <qlayout.h>
 #include <qpainter.h>
 #include <math.h>
 #include <qcursor.h>
 #include <qdrawutil.h>
+#include <qevent.h>
 
+#ifdef COMPILE_USE_QT4
+	#include "kvi_tal_hbox.h"
+#endif
 
 #ifdef COMPILE_PSEUDO_TRANSPARENCY
 	#include <qpixmap.h>
@@ -54,10 +58,10 @@
 
 
 KviMdiManager::KviMdiManager(QWidget * parent,KviFrame * pFrm,const char * name)
-: QScrollView(parent,name)
+: KviTalScrollView(parent)
 {
 	setFrameShape(NoFrame);
-	m_pZ = new KviPtrList<KviMdiChild>;
+	m_pZ = new KviPointerList<KviMdiChild>;
 	m_pZ->setAutoDelete(true);
 
 	m_pFrm = pFrm;
@@ -70,19 +74,31 @@ KviMdiManager::KviMdiManager(QWidget * parent,KviFrame * pFrm,const char * name)
 	m_pSdiCloseButton = 0;
 	m_pSdiRestoreButton = 0;
 	m_pSdiMinimizeButton = 0;
+#ifdef COMPILE_USE_QT4
+	m_pSdiControls = 0;
+#endif
 
-	m_pWindowPopup = new QPopupMenu(this);
+	m_pWindowPopup = new KviTalPopupMenu(this);
 	connect(m_pWindowPopup,SIGNAL(activated(int)),this,SLOT(menuActivated(int)));
 	connect(m_pWindowPopup,SIGNAL(aboutToShow()),this,SLOT(fillWindowPopup()));
-	m_pTileMethodPopup = new QPopupMenu(this);
+	m_pTileMethodPopup = new KviTalPopupMenu(this);
 	connect(m_pTileMethodPopup,SIGNAL(activated(int)),this,SLOT(tileMethodMenuActivated(int)));
 
+#ifdef COMPILE_USE_QT4
+	viewport()->setAutoFillBackground(false);
+#else
 	viewport()->setBackgroundMode(QWidget::NoBackground);
+#endif
 	setStaticBackground(true);
 	resizeContents(width(),height());
 
+#ifdef COMPILE_USE_QT4
+	setFocusPolicy(Qt::NoFocus);
+	viewport()->setFocusPolicy(Qt::NoFocus);
+#else
 	setFocusPolicy(QWidget::NoFocus);
 	viewport()->setFocusPolicy(QWidget::NoFocus);
+#endif
 	
 	connect(g_pApp,SIGNAL(reloadImages()),this,SLOT(reloadImages()));
 }
@@ -110,6 +126,7 @@ bool KviMdiManager::focusNextPrevChild(bool bNext)
 
 void KviMdiManager::drawContents(QPainter *p,int x,int y,int w,int h)
 {
+	//debug("MY DRAW CONTENTS (%d,%d,%d,%d)",x,y,w,h);
 	QRect r(x,y,w,h);
 
 #ifdef COMPILE_PSEUDO_TRANSPARENCY
@@ -117,6 +134,7 @@ void KviMdiManager::drawContents(QPainter *p,int x,int y,int w,int h)
 	{
 		QPoint pnt = viewport()->mapToGlobal(contentsToViewport(r.topLeft()));
 		p->drawTiledPixmap(r,*(g_pShadedParentGlobalDesktopBackground),pnt);
+		return;
 	}
 #endif
 
@@ -175,7 +193,11 @@ void KviMdiManager::setTopChild(KviMdiChild *lpC,bool bSetFocus)
 	{
 		m_pZ->setAutoDelete(false);
 
-		if(!m_pZ->removeRef(lpC))return; // no such child ?
+		if(!m_pZ->removeRef(lpC))
+		{
+			m_pZ->setAutoDelete(true);
+			return; // no such child ?
+		}
 
 		// disable the labels of all the other children
 		//for(KviMdiChild *pC=m_pZ->first();pC;pC=m_pZ->next())
@@ -281,7 +303,7 @@ QPoint KviMdiManager::getCascadePoint(int indexOfWindow)
 void KviMdiManager::mousePressEvent(QMouseEvent *e)
 {
 	//Popup the window menu
-	if(e->button() & RightButton)m_pWindowPopup->popup(mapToGlobal(e->pos()));
+	if(e->button() & Qt::RightButton)m_pWindowPopup->popup(mapToGlobal(e->pos()));
 }
 
 void KviMdiManager::childMoved(KviMdiChild *)
@@ -324,7 +346,7 @@ void KviMdiManager::maximizeChild(KviMdiChild * lpC)
 void KviMdiManager::resizeEvent(QResizeEvent *e)
 {
 	//If we have a maximized children at the top , adjust its size
-	QScrollView::resizeEvent(e);
+	KviTalScrollView::resizeEvent(e);
 	KviMdiChild *lpC=m_pZ->last();
 	if(lpC)
 	{
@@ -410,8 +432,10 @@ void KviMdiManager::focusTopChild()
 	//	if(lpC->state()==KviMdiChild::Minimized)return;
 	//	debug("Focusing top child %s",lpC->name());
 	//disable the labels of all the other children
-	for(KviMdiChild *pC=m_pZ->first();pC;pC=m_pZ->next()){
-		if(pC != lpC)pC->captionLabel()->setActive(false);
+	for(KviMdiChild *pC=m_pZ->first();pC;pC=m_pZ->next())
+	{
+		if(pC != lpC)
+			pC->captionLabel()->setActive(false);
 	}
 	lpC->raise();
 	if(!lpC->hasFocus())lpC->setFocus();
@@ -470,14 +494,12 @@ void KviMdiManager::updateContentsSize()
 
 void KviMdiManager::updateSDIMode()
 {
-	__range_valid(m_pSdiCloseButton);
 
 	KviMdiChild * lpC = m_pZ->last();
 
-	m_pSdiCloseButton->setEnabled(lpC ? lpC->closeEnabled() : false);
+	if(m_pSdiCloseButton)
+		m_pSdiCloseButton->setEnabled(lpC ? lpC->closeEnabled() : false);
 
-
-	
 // This would result in an addictional main menu bar entry on MacOSX which would trigger a popup menu and not
 // a submenu. Due to the optical reasons it is removed here.
 // The same popup is triggered by right clicking on the window name in the channel window list.
@@ -492,7 +514,14 @@ void KviMdiManager::updateSDIMode()
 	{
 		m_pSdiIconButton = new KviMenuBarToolButton(b,*pix,"nonne");
 		connect(m_pSdiIconButton,SIGNAL(clicked()),this,SLOT(activeChildSystemPopup()));
+#ifdef COMPILE_USE_QT4
+		// This is an obscure, undocumented and internal function in QT4 QMenuBar
+		// I won't be surprised if this disappears....
+		b->setCornerWidget(m_pSdiIconButton,Qt::TopLeftCorner);
+		m_pSdiIconButton->show();
+#else
 		m_iSdiIconItemId = b->insertItem(m_pSdiIconButton,-1,0);
+#endif
 		connect(m_pSdiIconButton,SIGNAL(destroyed()),this,SLOT(sdiIconButtonDestroyed()));
 	} else {
 		m_pSdiIconButton->setPixmap(*pix);
@@ -522,37 +551,80 @@ bool KviMdiManager::isInSDIMode()
 
 void KviMdiManager::enterSDIMode(KviMdiChild *lpC)
 {
-	KviMenuBar * b = m_pFrm->mainMenuBar();
-
 	if(!m_pSdiCloseButton)
 	{
-		m_pSdiMinimizeButton = new KviMenuBarToolButton(b,*(g_pIconManager->getSmallIcon(KVI_SMALLICON_MINIMIZE)),"btnminimize");
+		KviMenuBar * b = m_pFrm->mainMenuBar();
+	
+		QWidget * pButtonParent;
+	
+#ifdef COMPILE_USE_QT4
+		m_pSdiControls = new KviTalHBox(b);
+		m_pSdiControls->setMargin(0);
+		m_pSdiControls->setSpacing(2);
+		m_pSdiControls->setAutoFillBackground(false);
+		pButtonParent = m_pSdiControls;
+#else
+		pButtonParent = b;
+#endif
+		m_pSdiMinimizeButton = new KviMenuBarToolButton(pButtonParent,*(g_pIconManager->getSmallIcon(KVI_SMALLICON_MINIMIZE)),"btnminimize");
 		connect(m_pSdiMinimizeButton,SIGNAL(clicked()),this,SLOT(minimizeActiveChild()));
+#ifndef COMPILE_USE_QT4
 		m_iSdiMinimizeItemId = b->insertItem(m_pSdiMinimizeButton,-1,b->count());
+#endif
 		connect(m_pSdiMinimizeButton,SIGNAL(destroyed()),this,SLOT(sdiMinimizeButtonDestroyed()));
 
-		m_pSdiRestoreButton = new KviMenuBarToolButton(b,*(g_pIconManager->getSmallIcon(KVI_SMALLICON_RESTORE)),"btnrestore");
+		m_pSdiRestoreButton = new KviMenuBarToolButton(pButtonParent,*(g_pIconManager->getSmallIcon(KVI_SMALLICON_RESTORE)),"btnrestore");
 		connect(m_pSdiRestoreButton,SIGNAL(clicked()),this,SLOT(restoreActiveChild()));
+#ifndef COMPILE_USE_QT4
 		m_iSdiRestoreItemId = b->insertItem(m_pSdiRestoreButton,-1,b->count());
+#endif
 		connect(m_pSdiRestoreButton,SIGNAL(destroyed()),this,SLOT(sdiRestoreButtonDestroyed()));
 
-		m_pSdiCloseButton = new KviMenuBarToolButton(b,*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CLOSE)),"btnclose");
+		m_pSdiCloseButton = new KviMenuBarToolButton(pButtonParent,*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CLOSE)),"btnclose");
 		connect(m_pSdiCloseButton,SIGNAL(clicked()),this,SLOT(closeActiveChild()));
+#ifndef COMPILE_USE_QT4
 		m_iSdiCloseItemId = b->insertItem(m_pSdiCloseButton,-1,b->count());
+#endif
 		connect(m_pSdiCloseButton,SIGNAL(destroyed()),this,SLOT(sdiCloseButtonDestroyed()));
 
+#ifdef COMPILE_USE_QT4
+		// This is an obscure, undocumented and internal function in QT4 QMenuBar
+		// I won't be surprised if this disappears....
+		b->setCornerWidget(m_pSdiControls,Qt::TopRightCorner);
+		// The show below SHOULD force a re-layout of the menubar..
+		// but it doesn't work when the KviFrame is still hidden (at startup)
+		// We handle this BUG in showEvent()
+		m_pSdiControls->show();
+#else
 		m_pSdiRestoreButton->show();
 		m_pSdiMinimizeButton->show();
 		m_pSdiCloseButton->show();
-
+#endif
 		emit enteredSdiMode();
 		
-		setVScrollBarMode(QScrollView::AlwaysOff);
-		setHScrollBarMode(QScrollView::AlwaysOff);
+		setVScrollBarMode(KviTalScrollView::AlwaysOff);
+		setHScrollBarMode(KviTalScrollView::AlwaysOff);
 	}
 
 	updateSDIMode();
 }
+void KviMdiManager::relayoutMenuButtons()
+{
+#ifdef COMPILE_USE_QT4
+	// force a re-layout of the menubar in Qt4 (see the note in enterSDIMode())
+	// by resetting the corner widget
+	if(m_pSdiControls)
+	{
+		m_pFrm->mainMenuBar()->setCornerWidget(0,Qt::TopRightCorner);
+		m_pFrm->mainMenuBar()->setCornerWidget(m_pSdiControls,Qt::TopRightCorner);
+	}
+	// also force an activation of the top MdiChild since it probably didn't get it yet
+	KviMdiChild * c = topChild();
+	if(c)
+		c->activate(false);
+#endif
+}
+
 
 void KviMdiManager::sdiIconButtonDestroyed()
 {
@@ -582,13 +654,27 @@ void KviMdiManager::leaveSDIMode()
 {
 	__range_valid(m_pSdiCloseButton);
 
+#ifdef COMPILE_USE_QT4
+	if(m_pSdiControls)
+	{
+		delete m_pSdiControls;
+		m_pSdiControls = 0;
+	}
+	if(m_pSdiIconButton)
+	{
+		m_pSdiIconButton->hide(); // this will force a QMenuBar relayout
+		delete m_pSdiIconButton;
+		m_pSdiIconButton = 0;
+	}
+#else
 	if(m_iSdiIconItemId != 0)m_pFrm->mainMenuBar()->removeItem(m_iSdiIconItemId);
 	if(m_iSdiCloseItemId != 0)m_pFrm->mainMenuBar()->removeItem(m_iSdiCloseItemId);
 	if(m_iSdiRestoreItemId != 0)m_pFrm->mainMenuBar()->removeItem(m_iSdiRestoreItemId);
 	if(m_iSdiMinimizeItemId != 0)m_pFrm->mainMenuBar()->removeItem(m_iSdiMinimizeItemId);
+#endif
 
-	setVScrollBarMode(QScrollView::Auto);
-	setHScrollBarMode(QScrollView::Auto);
+	setVScrollBarMode(KviTalScrollView::Auto);
+	setHScrollBarMode(KviTalScrollView::Auto);
 
 	emit leftSdiMode();
 }
@@ -719,7 +805,7 @@ void KviMdiManager::cascadeWindows()
 	if(g_pApp->closingDown())return;
 
 	int idx=0;
-	KviPtrList<KviMdiChild> list(*m_pZ);
+	KviPointerList<KviMdiChild> list(*m_pZ);
 	list.setAutoDelete(false);
 	while(!list.isEmpty())
 	{
@@ -747,7 +833,7 @@ void KviMdiManager::cascadeMaximized()
 	if(g_pApp->closingDown())return;
 	
 	int idx=0;
-	KviPtrList<KviMdiChild> list(*m_pZ);
+	KviPointerList<KviMdiChild> list(*m_pZ);
 
 	list.setAutoDelete(false);
 	while(!list.isEmpty())
@@ -778,7 +864,7 @@ void KviMdiManager::expandVertical()
 	g_pApp->sendPostedEvents();
 	if(g_pApp->closingDown())return;
 	
-	KviPtrList<KviMdiChild> list(*m_pZ);
+	KviPointerList<KviMdiChild> list(*m_pZ);
 	list.setAutoDelete(false);
 	while(!list.isEmpty())
 	{
@@ -804,7 +890,7 @@ void KviMdiManager::expandHorizontal()
 	g_pApp->sendPostedEvents();
 	if(g_pApp->closingDown())return;
 	
-	KviPtrList<KviMdiChild> list(*m_pZ);
+	KviPointerList<KviMdiChild> list(*m_pZ);
 	list.setAutoDelete(false);
 	while(!list.isEmpty())
 	{
@@ -822,7 +908,7 @@ void KviMdiManager::expandHorizontal()
 
 void KviMdiManager::minimizeAll()
 {
-	KviPtrList<KviMdiChild> list(*m_pZ);
+	KviPointerList<KviMdiChild> list(*m_pZ);
 	list.setAutoDelete(false);
     m_pFrm->setActiveWindow((KviWindow*)m_pFrm->firstConsole());
 	while(!list.isEmpty())
@@ -839,7 +925,7 @@ void KviMdiManager::minimizeAll()
 void KviMdiManager::restoreAll()
 {
 	int idx=0;
-	KviPtrList<KviMdiChild> list(*m_pZ);
+	KviPointerList<KviMdiChild> list(*m_pZ);
 	list.setAutoDelete(false);
 	while(!list.isEmpty())
 	{
