@@ -32,7 +32,6 @@
 #include "kvi_internalcmd.h"
 #include "kvi_settings.h"
 #include "kvi_ircurl.h"
-#include "kvi_uparser.h"
 #include "kvi_console.h"
 #include "kvi_kvs_popupmenu.h"
 #include "kvi_malloc.h"
@@ -41,7 +40,7 @@
 #include "kvi_coreactionnames.h"
 #include "kvi_kvs_script.h"
 
-#include <qpopupmenu.h>
+#include "kvi_tal_popupmenu.h"
 
 KviMenuBar::KviMenuBar(KviFrame * par,const char * name)
       : KviTalMenuBar(par,name)
@@ -51,7 +50,7 @@ KviMenuBar::KviMenuBar(KviFrame * par,const char * name)
 	m_iNumDefaultItems = 0;
 	m_pDefaultItemId = 0;
 	
-	QPopupMenu * pop = new QPopupMenu(this,"KVIrc");
+	KviTalPopupMenu * pop = new KviTalPopupMenu(this,"KVIrc");
 	connect(pop,SIGNAL(aboutToShow()),this,SLOT(setupMainPopup()));
 #ifndef Q_OS_MACX
 	addDefaultItem("&KVIrc",pop);
@@ -59,31 +58,31 @@ KviMenuBar::KviMenuBar(KviFrame * par,const char * name)
 	// Qt/Mac creates already a "KVirc" menu item on its own, and we don't like double entries ;-)
 	addDefaultItem("&IRC",pop);
 #endif //Q_OS_MACX
-	m_pRecentServersPopup = new QPopupMenu(this,"recentservers");
+	m_pRecentServersPopup = new KviTalPopupMenu(this,"recentservers");
 	connect(m_pRecentServersPopup,SIGNAL(aboutToShow()),this,SLOT(setupRecentServersPopup()));
 	connect(m_pRecentServersPopup,SIGNAL(activated(int)),this,SLOT(newConnectionToServer(int)));
 
 	m_pScriptItemList = 0;
 
-	pop = new QPopupMenu(this,"scripting");
+	pop = new KviTalPopupMenu(this,"scripting");
 	connect(pop,SIGNAL(aboutToShow()),this,SLOT(setupScriptingPopup()));
 	addDefaultItem(__tr2qs("Scri&pting"),pop);
 
-	pop = new QPopupMenu(this,"tools");
+	pop = new KviTalPopupMenu(this,"tools");
 	connect(pop,SIGNAL(aboutToShow()),this,SLOT(setupToolsPopup()));
 	connect(pop,SIGNAL(activated(int)),this,SLOT(toolsPopupSelected(int)));
 	addDefaultItem(__tr2qs("&Tools"),pop);
 
-	m_pToolbarsPopup = new QPopupMenu(this,"toolbars");
+	m_pToolbarsPopup = new KviTalPopupMenu(this,"toolbars");
 	connect(m_pToolbarsPopup,SIGNAL(aboutToShow()),this,SLOT(setupToolbarsPopup()));
 
-	pop = new QPopupMenu(this,"settings");
+	pop = new KviTalPopupMenu(this,"settings");
 	connect(pop,SIGNAL(aboutToShow()),this,SLOT(setupSettingsPopup()));
 	addDefaultItem(__tr2qs("&Settings"),pop);
 
 	addDefaultItem(__tr2qs("&Window"),par->mdiManager()->windowPopup());
 
-	pop = new QPopupMenu(this,"help");
+	pop = new KviTalPopupMenu(this,"help");
 	connect(pop,SIGNAL(aboutToShow()),this,SLOT(setupHelpPopup()));
 	addDefaultItem(__tr2qs("&Help"),pop);
 }
@@ -94,7 +93,17 @@ KviMenuBar::~KviMenuBar()
    if(m_pDefaultItemId)kvi_free(m_pDefaultItemId);
 }
 
-void KviMenuBar::addDefaultItem(const QString &text,QPopupMenu * pop)
+void KviMenuBar::showEvent(QShowEvent *e)
+{
+#ifdef COMPILE_USE_QT4
+	debug("menubar show");
+	// force a re-layout of the menubar in Qt4 (see the note in enterSDIMode())
+	// by resetting the corner widget
+	m_pFrm->mdiManager()->relayoutMenuButtons();
+#endif
+}
+
+void KviMenuBar::addDefaultItem(const QString &text,KviTalPopupMenu * pop)
 {
    m_iNumDefaultItems++;
    m_pDefaultItemId = (int *)kvi_realloc((void *)m_pDefaultItemId,sizeof(int) * m_iNumDefaultItems);
@@ -103,7 +112,7 @@ void KviMenuBar::addDefaultItem(const QString &text,QPopupMenu * pop)
 
 void KviMenuBar::setupHelpPopup()
 {
-	QPopupMenu * help = (QPopupMenu *)sender();
+	KviTalPopupMenu * help = (KviTalPopupMenu *)sender();
 	help->clear();
 
 	// FIXME: Convert these to actions!
@@ -120,19 +129,49 @@ void KviMenuBar::setupHelpPopup()
 	help->insertSeparator();
 	id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_HOMEPAGE)),__tr2qs("KVIrc Home&page"),m_pFrm,SLOT(executeInternalCommand(int)));
 	help->setItemParameter(id,KVI_INTERNALCOMMAND_KVIRC_HOMEPAGE);
-	id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_HOMEPAGE)),__tr2qs("KVIrc Russian Home&page"),m_pFrm,SLOT(executeInternalCommand(int)));
-	help->setItemParameter(id,KVI_INTERNALCOMMAND_KVIRC_HOMEPAGE_RU);
+	if(kvi_strEqualCIN(KviLocale::localeName(),"ru",2))
+	{
+		id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_HOMEPAGE)),__tr2qs("KVIrc Russian Home&page"),m_pFrm,SLOT(executeInternalCommand(int)));
+		help->setItemParameter(id,KVI_INTERNALCOMMAND_KVIRC_HOMEPAGE_RU);
+	}
+	if(kvi_strEqualCIN(KviLocale::localeName(),"fr",2))
+	{
+		id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_HOMEPAGE)),__tr2qs("KVIrc French Home&page"),m_pFrm,SLOT(executeInternalCommand(int)));
+		help->setItemParameter(id,KVI_INTERNALCOMMAND_KVIRC_HOMEPAGE_FR);
+	}
+	help->insertSeparator();
 	id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_MESSAGE)),__tr2qs("Subscribe to the Mailing List"),m_pFrm,SLOT(executeInternalCommand(int)));
 	help->setItemParameter(id,KVI_INTERNALCOMMAND_OPENURL_KVIRC_MAILINGLIST);
-	id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_BOMB)),__tr2qs("Report a Bug"),m_pFrm,SLOT(executeInternalCommand(int)));
+	id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_BOMB)),__tr2qs("Report a Bug / Propose Improvements"),m_pFrm,SLOT(executeInternalCommand(int)));
 	help->setItemParameter(id,KVI_INTERNALCOMMAND_OPENURL_KVIRC_BUGTRACK);
+	help->insertSeparator();
+	id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CHANNEL)),__tr2qs("Join KVIrc International Channel on Freenode"),m_pFrm,SLOT(executeInternalCommand(int)));
+	help->setItemParameter(id,KVI_INTERNALCOMMAND_OPENURL_KVIRC_ON_FREENODE);
+	id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CHANNEL)),__tr2qs("Join KVIrc International Channel on IRCNet"),m_pFrm,SLOT(executeInternalCommand(int)));
+	help->setItemParameter(id,KVI_INTERNALCOMMAND_OPENURL_KVIRC_ON_IRCNET);
+	if(kvi_strEqualCIN(KviLocale::localeName(),"it",2))
+	{
+		// join #kvirc.net on azzurra
+		id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CHANNEL)),__tr2qs("Join KVIrc Italian Channel on AzzurraNet"),m_pFrm,SLOT(executeInternalCommand(int)));
+		help->setItemParameter(id,KVI_INTERNALCOMMAND_OPENURL_KVIRC_IT_ON_AZZURRA);
+	}
+	if(kvi_strEqualCIN(KviLocale::localeName(),"fr",2))
+	{
+		// join #kvirc-fr on freenode
+		id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CHANNEL)),__tr2qs("Join KVIrc French Channel on Freenode"),m_pFrm,SLOT(executeInternalCommand(int)));
+		help->setItemParameter(id,KVI_INTERNALCOMMAND_OPENURL_KVIRC_FR_ON_FREENODE);
+		// join #kvirc on europnet
+		id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CHANNEL)),__tr2qs("Join KVIrc French Channel on EuropNet"),m_pFrm,SLOT(executeInternalCommand(int)));
+		help->setItemParameter(id,KVI_INTERNALCOMMAND_OPENURL_KVIRC_FR_ON_EUROPNET);
+	}
+	// add your localized #kvirc channels here...
 }
 
 void KviMenuBar::setupSettingsPopup()
 {
 	// FIXME: Move everything to actions!
 
-	QPopupMenu * opt = (QPopupMenu *)sender();
+	KviTalPopupMenu * opt = (KviTalPopupMenu *)sender();
 	opt->clear();
 	
 	opt->insertItem(__tr2qs("Toolbars"),m_pToolbarsPopup);
@@ -145,6 +184,7 @@ void KviMenuBar::setupSettingsPopup()
 	// FIXME: #warning "Toggle these items on the fly ?"
 	ACTION_POPUP_ITEM(KVI_COREACTION_GENERALOPTIONS,opt)
 	ACTION_POPUP_ITEM(KVI_COREACTION_THEMEOPTIONS,opt)
+	ACTION_POPUP_ITEM(KVI_COREACTION_MANAGETHEMES,opt)
 	ACTION_POPUP_ITEM(KVI_COREACTION_MANAGEADDONS,opt)
 	ACTION_POPUP_ITEM(KVI_COREACTION_SERVEROPTIONS,opt)
 	ACTION_POPUP_ITEM(KVI_COREACTION_TOOLBAREDITOR,opt)
@@ -156,7 +196,7 @@ void KviMenuBar::setupSettingsPopup()
 
 void KviMenuBar::setupScriptingPopup()
 {
-	QPopupMenu * script = (QPopupMenu *)sender();
+	KviTalPopupMenu * script = (KviTalPopupMenu *)sender();
 	script->clear();
 
 	ACTION_POPUP_ITEM(KVI_COREACTION_ACTIONEDITOR,script)
@@ -175,7 +215,7 @@ void KviMenuBar::setupScriptingPopup()
 
 void KviMenuBar::setupMainPopup()
 {
-	QPopupMenu * main = (QPopupMenu *)sender();
+	KviTalPopupMenu * main = (KviTalPopupMenu *)sender();
 	main->clear();
 
 	ACTION_POPUP_ITEM(KVI_COREACTION_NEWIRCCONTEXT,main)
@@ -209,7 +249,7 @@ void KviMenuBar::setupMainPopup()
 
 void KviMenuBar::setupRecentServersPopup()
 {
-	QPopupMenu * m = (QPopupMenu *)sender();
+	KviTalPopupMenu * m = (KviTalPopupMenu *)sender();
 	g_pApp->fillRecentServersPopup(m);
 	m->insertSeparator();
 	m->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_SERVER)),__tr2qs("&Other..."));
@@ -228,7 +268,7 @@ void KviMenuBar::newConnectionToServer(int id)
 		} else {
 			text.replace(QString("&"),QString(""));
 			KviStr szCommand;
-			if(parseIrcUrl(text.utf8().data(),szCommand,KVI_IRCURL_CONTEXT_NEW))
+			if(KviIrcUrl::parse(text.utf8().data(),szCommand,KVI_IRCURL_CONTEXT_NEW))
 				KviKvsScript::run(szCommand.ptr(),m_pFrm->firstConsole());
 		}
 	}
@@ -236,39 +276,41 @@ void KviMenuBar::newConnectionToServer(int id)
 
 void KviMenuBar::setupToolsPopup()
 {
-   QPopupMenu * m = (QPopupMenu *)sender();
-   if(!m)return;
+	KviTalPopupMenu * m = (KviTalPopupMenu *)sender();
+	if(!m)return;
 
-   m->clear();
+	m->clear();
 
-   KviModuleExtensionDescriptorList * l = g_pModuleExtensionManager->getExtensionList("tool");
-   if(l)
-   {
-      for(KviModuleExtensionDescriptor * d = l->first();d;d = l->next())
-      {
-         int id;
-         if(d->icon())id = m->insertItem(*(d->icon()),d->visibleName());
-         else id = m->insertItem(d->visibleName());
-         //m->setItemChecked(id,(m_pFrm->moduleExtensionToolBar(d->id())));
-         m->setItemParameter(id,d->id());
-      }
-   }
-   m->insertSeparator();
-   ACTION_POPUP_ITEM(KVI_COREACTION_SOCKETSPY,m)
-   ACTION_POPUP_ITEM(KVI_COREACTION_NETWORKLINKS,m)
-   ACTION_POPUP_ITEM(KVI_COREACTION_CHANNELLIST,m)
-   m->insertSeparator();
+	KviModuleExtensionDescriptorList * l = g_pModuleExtensionManager->getExtensionList("tool");
+	if(l)
+	{
+		for(KviModuleExtensionDescriptor * d = l->first();d;d = l->next())
+		{
+			int id;
+			if(d->icon())id = m->insertItem(*(d->icon()),d->visibleName());
+			else id = m->insertItem(d->visibleName());
+			//m->setItemChecked(id,(m_pFrm->moduleExtensionToolBar(d->id())));
+			m->setItemParameter(id,d->id());
+		}
+	}
+	m->insertSeparator();
+	ACTION_POPUP_ITEM(KVI_COREACTION_SOCKETSPY,m)
+	ACTION_POPUP_ITEM(KVI_COREACTION_NETWORKLINKS,m)
+	ACTION_POPUP_ITEM(KVI_COREACTION_CHANNELLIST,m)
+	m->insertSeparator();
 
-   // moved the old tools here
-   m->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_ICONMANAGER)),__tr2qs("Show &Icon Table"),g_pIconManager,SLOT(showIconWidget()));
+	ACTION_POPUP_ITEM(KVI_COREACTION_SCREENSHOT,m)
+
+	// moved the old tools here
+	m->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_ICONMANAGER)),__tr2qs("Show &Icon Table"),g_pIconManager,SLOT(showIconWidget()));
 #ifdef COMPILE_KDE_SUPPORT
-   int id;
-   id = m->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_TERMINAL)),__tr2qs("Open &Terminal"),m_pFrm,SLOT(executeInternalCommand(int)));
-   m->setItemParameter(id,KVI_INTERNALCOMMAND_TERM_OPEN);
+	int id;
+	id = m->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_TERMINAL)),__tr2qs("Open &Terminal"),m_pFrm,SLOT(executeInternalCommand(int)));
+	m->setItemParameter(id,KVI_INTERNALCOMMAND_TERM_OPEN);
 #endif
 
 	
-	KviPtrList<KviAction> list;
+	KviPointerList<KviAction> list;
 	KviActionManager::instance()->listActionsByCategory("tools",&list);
 	if(!list.isEmpty())
 	{
@@ -280,7 +322,7 @@ void KviMenuBar::setupToolsPopup()
 
 void KviMenuBar::toolsPopupSelected(int id)
 {
-   QPopupMenu * m = (QPopupMenu *)sender();
+   KviTalPopupMenu * m = (KviTalPopupMenu *)sender();
    if(!m)return;
    int idext = m->itemParameter(id);
    g_pModuleExtensionManager->allocateExtension("tool",idext,m_pFrm->firstConsole());
@@ -356,7 +398,7 @@ void KviMenuBar::addMenu(const QString &text,KviKvsPopupMenu * p,int index)
 {
 	if(!m_pScriptItemList)
 	{
-		m_pScriptItemList = new KviPtrList<KviScriptMenuBarItem>;
+		m_pScriptItemList = new KviPointerList<KviScriptMenuBarItem>;
 		m_pScriptItemList->setAutoDelete(true);
 	}/* else {
    		removeMenu(text);
