@@ -30,10 +30,10 @@
 #include "kvi_tal_menubar.h"
 #include "kvi_string.h"
 
-#include "kvi_list.h"
+#include "kvi_pointerlist.h"
 
 class KviFrame;
-class QPopupMenu;
+class KviTalPopupMenu;
 class KviKvsPopupMenu;
 
 typedef struct _KviScriptMenuBarItem
@@ -52,16 +52,17 @@ public:
 	KviMenuBar(KviFrame * par,const char * name);
 	~KviMenuBar();
 protected:
-	QPopupMenu                       * m_pToolbarsPopup;
-	QPopupMenu                       * m_pRecentServersPopup;
+	KviTalPopupMenu                       * m_pToolbarsPopup;
+	KviTalPopupMenu                       * m_pRecentServersPopup;
 	KviFrame                         * m_pFrm;
-	KviPtrList<KviScriptMenuBarItem> * m_pScriptItemList;
+	KviPointerList<KviScriptMenuBarItem> * m_pScriptItemList;
 	int                                m_iNumDefaultItems;
 	int                              * m_pDefaultItemId;
 protected:
 	KviScriptMenuBarItem * findMenu(const QString &text);
 	KviScriptMenuBarItem * findMenu(KviKvsPopupMenu * p);
-	void addDefaultItem(const QString &text,QPopupMenu * pop);
+	void addDefaultItem(const QString &text,KviTalPopupMenu * pop);
+	virtual void showEvent(QShowEvent *e);
 public:
 	int getDefaultItemRealIndex(int iDefaultIndex);
 	void addMenu(const QString &text,KviKvsPopupMenu * p,int index);
