@@ -31,15 +31,12 @@
 #include "kvi_ircconnectionuserinfo.h"
 #include "kvi_styled_controls.h"
 #include "kvi_toolwindows_container.h"
+#include "kvi_tal_scrollview.h"
 
 #include <qlayout.h>
 #include <qlabel.h>
-#include <qscrollview.h>
 
 
-// kvi_sp_numeric.cpp
-extern const QString & getChannelModeDescription(char c);
-
 //////////////////////////////////////////////////////////////////////
 // class KviModeEditor
 //
@@ -47,10 +44,10 @@ extern const QString & getChannelModeDescription(char c);
 
 //static char checkable_modes_table[KVI_NUM_CHECKABLE_MODES] = { 'p','s','t','n','m','i'};
 
-// FIXME: This widget should use a QScrollView!
+// FIXME: This widget should use a KviTalScrollView!
 
 KviModeEditor::KviModeEditor(QWidget * par,KviWindowToolPageButton* button,const char * nam,KviConsole * c,const char * mode,const char * key,const char * limit)
-: KviWindowToolWidget(par,button,nam)
+: KviWindowToolWidget(par,button)
 {
 	m_szMode = mode;
 	m_szKey = key;
@@ -71,10 +68,18 @@ KviModeEditor::KviModeEditor(QWidget * par,KviWindowToolPageButton* button,const
 	
 	QGridLayout *pMasterLayout = new QGridLayout(this,2,1,2,2);
 
+#ifdef COMPILE_USE_QT4
+	setFocusPolicy(Qt::ClickFocus);
+#else
 	setFocusPolicy(QWidget::ClickFocus);
+#endif
 	
-	QScrollView *pScrollView = new QScrollView(this);
+	KviTalScrollView *pScrollView = new KviTalScrollView(this);
+#ifdef COMPILE_USE_QT4
+	pScrollView->viewport()->setBackgroundRole(QPalette::Background);
+#else
 	pScrollView->viewport()->setBackgroundMode(QWidget::PaletteBackground);
+#endif
 	
 	pMasterLayout->addWidget(pScrollView,0,0);
 
@@ -104,7 +109,7 @@ KviModeEditor::KviModeEditor(QWidget * par,KviWindowToolPageButton* button,const
 	int i = 1;
 	QString tmp;
 
-	m_pCheckBoxes = new KviPtrList<KviStyledCheckBox>;
+	m_pCheckBoxes = new KviPointerList<KviStyledCheckBox>;
 	m_pCheckBoxes->setAutoDelete(false);
 
 	
@@ -116,16 +121,16 @@ KviModeEditor::KviModeEditor(QWidget * par,KviWindowToolPageButton* button,const
 		QChar ccc = szModes[0];
 		szModes.remove(0,1);
 
-		KviQString::sprintf(tmp,"%c: %Q",ccc.unicode(),&(getChannelModeDescription((char)ccc.unicode())));
+		KviQString::sprintf(tmp,"%c: %Q",ccc.unicode(),&(c->connection()->serverInfo()->getChannelModeDescription(ccc)));
 		KviStyledCheckBox * cb = new KviStyledCheckBox(tmp,pBackground);
 		cb->setEnabled(isEnabled);
 		m_pCheckBoxes->append(cb);
-		cb->setChecked(m_szMode.contains(ccc));
+		cb->setChecked(m_szMode.contains((char)ccc.unicode()));
 		i++;
 		g->addMultiCellWidget(cb,i,i,0,2);
 	}
 
-	KviQString::sprintf(tmp,"l: %Q",&(getChannelModeDescription('l')));
+	KviQString::sprintf(tmp,"l: %Q",&(c->connection()->serverInfo()->getChannelModeDescription('l')));
 	m_pLimitBox = new KviStyledCheckBox(tmp,pBackground);
 	m_pLimitBox->setEnabled(isEnabled);
 	i++;
@@ -144,7 +149,7 @@ KviModeEditor::KviModeEditor(QWidget * par,KviWindowToolPageButton* button,const
 		m_pLimitEdit->setEnabled(false);
 	}
 
-	KviQString::sprintf(tmp,"k: %Q",&(getChannelModeDescription('k')));
+	KviQString::sprintf(tmp,"k: %Q",&(c->connection()->serverInfo()->getChannelModeDescription('k')));
 	m_pKeyBox = new KviStyledCheckBox(tmp,pBackground);
 	m_pKeyBox->setEnabled(isEnabled);
 	i++;
@@ -188,7 +193,7 @@ KviModeEditor::KviModeEditor(QWidget * par,KviWindowToolPageButton* button,const
 		QChar ccc = szModes[0];
 		szModes.remove(0,1);
 
-		KviQString::sprintf(tmp,"%c: %Q",(char)ccc.unicode(),&(getChannelModeDescription((char)ccc.unicode())));
+		KviQString::sprintf(tmp,"%c: %Q",(char)ccc.unicode(),&(c->connection()->serverInfo()->getChannelModeDescription(ccc)));
 		KviStyledCheckBox * cb = new KviStyledCheckBox(tmp,pBackground);
 		cb->setEnabled(isEnabled);
 		m_pCheckBoxes->append(cb);
