@@ -1,9 +1,10 @@
+//=============================================================================
 //
 //   File : kvi_optionswidget.h
 //   Creation date : Mon Jun 10 2000 17:47:33 by Szymon Stefanek
 //
 //   This file is part of the KVirc irc client distribution
-//   Copyright (C) 2000 Szymon Stefanek (pragma at kvirc dot net)
+//   Copyright (C) 2000-2006 Szymon Stefanek (pragma at kvirc dot net)
 //
 //   This program is FREE software. You can redistribute it and/or
 //   modify it under the terms of the GNU General Public License
@@ -19,6 +20,8 @@
 //   along with this program. If not, write to the Free Software Foundation,
 //   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 //
+//=============================================================================
+
 #define __KVIRC__
 
 #include "kvi_optionswidget.h"
@@ -30,7 +33,7 @@
 
 #include "kvi_app.h"
 
-#include <qtooltip.h>
+#include "kvi_tal_tooltip.h"
 
 #define KVI_OPTIONSWIDGET_GRIDLAYOUT_BORDER 4
 #define KVI_OPTIONSWIDGET_GRIDLAYOUT_SPACE 6
@@ -56,7 +59,7 @@ KviOptionsWidget::KviOptionsWidget(QWidget * parent,const char * name,bool bSunk
 	m_pTabWidget = 0;
 	m_iResetFlags = 0;
 	m_iSelectors = 0;
-	m_pSelectorInterfaceList = new KviPtrList<KviSelectorInterface>;
+	m_pSelectorInterfaceList = new KviPointerList<KviSelectorInterface>;
 	m_pSelectorInterfaceList->setAutoDelete(false);
 }
 
@@ -70,15 +73,19 @@ void KviOptionsWidget::mergeTip(QWidget * w,const QString &tip)
 	static QString begin = "<table width=\"100%\" align=\"center\"><tr><td bgcolor=\"#fefef0\">";
 	static QString mid = "</td></tr><tr><td>";
 	static QString end = "</td></tr></table>";
-	QString s = QToolTip::textFor(w);
-	if(s.isEmpty())QToolTip::add(w,tip);
+#ifdef COMPILE_USE_QT4
+	QString s = w->toolTip();
+#else
+	QString s = KviTalToolTip::textFor(w);
+#endif
+	if(s.isEmpty())KviTalToolTip::add(w,tip);
 	else {
 		QString tmp = begin;
 		tmp += tip;
 		tmp += mid;
 		tmp += s;
 		tmp += end;
-		QToolTip::add(w,tmp);
+		KviTalToolTip::add(w,tmp);
 	}
 }
 
@@ -122,6 +129,14 @@ KviDirectorySelector * KviOptionsWidget::addDirectorySelector(int x1,int y1,int
 	return d;
 }
 
+KviDirectorySelector * KviOptionsWidget::addDirectorySelector(QWidget * pParent,const QString & txt,QString *pOption,bool bEnabled)
+{
+	KviDirectorySelector * d = new KviDirectorySelector(pParent,txt,pOption,bEnabled);
+	//addWidgetToLayout(d,x1,y1,x2,y2);
+	m_pSelectorInterfaceList->append(d);
+	return d;
+}
+
 KviDirectorySelector * KviOptionsWidget::addDirectorySelector(int x1,int y1,int x2,int y2,const QString & txt,int optId,bool bEnabled)
 {
 	m_iResetFlags |= (g_stringOptionsTable[optId].flags & KviOption_resetMask);
@@ -130,7 +145,20 @@ KviDirectorySelector * KviOptionsWidget::addDirectorySelector(int x1,int y1,int
 	QString tmp = m_szBasicTipStart;
 	tmp += g_stringOptionsTable[optId].name;
 	tmp += m_szBasicTipEnd;
-	QToolTip::add(d,tmp);
+	KviTalToolTip::add(d,tmp);
+
+	return d;
+}
+
+KviDirectorySelector * KviOptionsWidget::addDirectorySelector(QWidget * pParent,const QString & txt,int optId,bool bEnabled)
+{
+	m_iResetFlags |= (g_stringOptionsTable[optId].flags & KviOption_resetMask);
+	KviDirectorySelector * d = addDirectorySelector(pParent,txt,&(KVI_OPTION_STRING(optId)),bEnabled);
+
+	QString tmp = m_szBasicTipStart;
+	tmp += g_stringOptionsTable[optId].name;
+	tmp += m_szBasicTipEnd;
+	KviTalToolTip::add(d,tmp);
 
 	return d;
 }
@@ -162,7 +190,7 @@ KviFileSelector * KviOptionsWidget::addFileSelector(int x1,int y1,int x2,int y2,
 	QString tmp = m_szBasicTipStart;
 	tmp += g_stringOptionsTable[optId].name;
 	tmp += m_szBasicTipEnd;
-	QToolTip::add(d,tmp);
+	KviTalToolTip::add(d,tmp);
 
 	return d;
 }
@@ -175,7 +203,7 @@ KviFileSelector * KviOptionsWidget::addFileSelector(QWidget * pParent,const QStr
 	QString tmp = m_szBasicTipStart;
 	tmp += g_stringOptionsTable[optId].name;
 	tmp += m_szBasicTipEnd;
-	QToolTip::add(d,tmp);
+	KviTalToolTip::add(d,tmp);
 
 	return d;
 }
@@ -206,7 +234,7 @@ KviSoundSelector * KviOptionsWidget::addSoundSelector(int x1,int y1,int x2,int y
 	QString tmp = m_szBasicTipStart;
 	tmp += g_stringOptionsTable[optId].name;
 	tmp += m_szBasicTipEnd;
-	QToolTip::add(d,tmp);
+	KviTalToolTip::add(d,tmp);
 
 	return d;
 }
@@ -219,7 +247,7 @@ KviSoundSelector * KviOptionsWidget::addSoundSelector(QWidget * pParent,const QS
 	QString tmp = m_szBasicTipStart;
 	tmp += g_stringOptionsTable[optId].name;
 	tmp += m_szBasicTipEnd;
-	QToolTip::add(d,tmp);
+	KviTalToolTip::add(d,tmp);
 
 	return d;
 }
@@ -249,7 +277,7 @@ KviBoolSelector * KviOptionsWidget::addBoolSelector(int x1,int y1,int x2,int y2,
 	QString tmp = m_szBasicTipStart;
 	tmp += g_boolOptionsTable[optId].name;
 	tmp += m_szBasicTipEnd;
-	QToolTip::add(d,tmp);
+	KviTalToolTip::add(d,tmp);
 	return d;
 }
 
@@ -260,7 +288,7 @@ KviBoolSelector * KviOptionsWidget::addBoolSelector(QWidget * pParent,const QStr
 	QString tmp = m_szBasicTipStart;
 	tmp += g_boolOptionsTable[optId].name;
 	tmp += m_szBasicTipEnd;
-	QToolTip::add(d,tmp);
+	KviTalToolTip::add(d,tmp);
 	return d;
 }
 
@@ -282,7 +310,7 @@ KviPixmapSelector * KviOptionsWidget::addPixmapSelector(int x1,int y1,int x2,int
 	QString tmp = m_szBasicTipStart;
 	tmp += g_pixmapOptionsTable[optId].name;
 	tmp += m_szBasicTipEnd;
-	QToolTip::add(d,tmp);
+	KviTalToolTip::add(d,tmp);
 	return d;
 }
 
@@ -317,7 +345,7 @@ KviUIntSelector * KviOptionsWidget::addUIntSelector(int x1,int y1,int x2,int y2,
 	QString tmp = m_szBasicTipStart;
 	tmp += g_uintOptionsTable[optId].name;
 	tmp += m_szBasicTipEnd;
-	QToolTip::add(d,tmp);
+	KviTalToolTip::add(d,tmp);
 	return d;
 }
 
@@ -330,7 +358,7 @@ KviUIntSelector * KviOptionsWidget::addUIntSelector(QWidget * pParent,const QStr
 	QString tmp = m_szBasicTipStart;
 	tmp += g_uintOptionsTable[optId].name;
 	tmp += m_szBasicTipEnd;
-	QToolTip::add(d,tmp);
+	KviTalToolTip::add(d,tmp);
 	return d;
 }
 
@@ -371,7 +399,7 @@ KviStringSelector * KviOptionsWidget::addStringSelector(int x1,int y1,int x2,int
 	QString tmp = m_szBasicTipStart;
 	tmp += g_stringOptionsTable[optId].name;
 	tmp += m_szBasicTipEnd;
-	QToolTip::add(d,tmp);
+	KviTalToolTip::add(d,tmp);
 	return d;
 }
 
@@ -382,7 +410,7 @@ KviStringSelector * KviOptionsWidget::addStringSelector(QWidget * pParent,const
 	QString tmp = m_szBasicTipStart;
 	tmp += g_stringOptionsTable[optId].name;
 	tmp += m_szBasicTipEnd;
-	QToolTip::add(d,tmp);
+	KviTalToolTip::add(d,tmp);
 	return d;
 }
 
@@ -411,7 +439,7 @@ KviPasswordSelector * KviOptionsWidget::addPasswordSelector(int x1,int y1,int x2
 	QString tmp = m_szBasicTipStart;
 	tmp += g_stringOptionsTable[optId].name;
 	tmp += m_szBasicTipEnd;
-	QToolTip::add(d,tmp);
+	KviTalToolTip::add(d,tmp);
 	return d;
 }
 
@@ -422,7 +450,7 @@ KviPasswordSelector * KviOptionsWidget::addPasswordSelector(QWidget * pParent,co
 	QString tmp = m_szBasicTipStart;
 	tmp += g_stringOptionsTable[optId].name;
 	tmp += m_szBasicTipEnd;
-	QToolTip::add(d,tmp);
+	KviTalToolTip::add(d,tmp);
 	return d;
 }
 
@@ -444,7 +472,7 @@ KviStringListSelector * KviOptionsWidget::addStringListSelector(int x1,int y1,in
 	QString tmp = m_szBasicTipStart;
 	tmp += g_stringlistOptionsTable[optId].name;
 	tmp += m_szBasicTipEnd;
-	QToolTip::add(d,tmp);
+	KviTalToolTip::add(d,tmp);
 	return d;
 }
 
@@ -473,7 +501,7 @@ KviColorSelector * KviOptionsWidget::addColorSelector(int x1,int y1,int x2,int y
 	QString tmp = m_szBasicTipStart;
 	tmp += g_colorOptionsTable[optId].name;
 	tmp += m_szBasicTipEnd;
-	QToolTip::add(d,tmp);
+	KviTalToolTip::add(d,tmp);
 	return d;
 }
 
@@ -484,7 +512,7 @@ KviColorSelector * KviOptionsWidget::addColorSelector(QWidget * pParent,const QS
 	QString tmp = m_szBasicTipStart;
 	tmp += g_colorOptionsTable[optId].name;
 	tmp += m_szBasicTipEnd;
-	QToolTip::add(d,tmp);
+	KviTalToolTip::add(d,tmp);
 	return d;
 }
 
@@ -514,7 +542,7 @@ KviMircTextColorSelector * KviOptionsWidget::addMircTextColorSelector(int x1,int
 	QString tmp = m_szBasicTipStart;
 	tmp += g_uintOptionsTable[optForeId].name;
 	tmp += m_szBasicTipEnd;
-	QToolTip::add(d,tmp);
+	KviTalToolTip::add(d,tmp);
 	return d;
 }
 
@@ -526,7 +554,7 @@ KviMircTextColorSelector * KviOptionsWidget::addMircTextColorSelector(QWidget *
 	QString tmp = m_szBasicTipStart;
 	tmp += g_uintOptionsTable[optForeId].name;
 	tmp += m_szBasicTipEnd;
-	QToolTip::add(d,tmp);
+	KviTalToolTip::add(d,tmp);
 	return d;
 }
 
@@ -556,7 +584,7 @@ KviFontSelector * KviOptionsWidget::addFontSelector(int x1,int y1,int x2,int y2,
 	QString tmp = m_szBasicTipStart;
 	tmp += g_fontOptionsTable[optId].name;
 	tmp += m_szBasicTipEnd;
-	QToolTip::add(d,tmp);
+	KviTalToolTip::add(d,tmp);
 	return d;
 }
 
@@ -567,7 +595,7 @@ KviFontSelector * KviOptionsWidget::addFontSelector(QWidget * pParent,const QStr
 	QString tmp = m_szBasicTipStart;
 	tmp += g_fontOptionsTable[optId].name;
 	tmp += m_szBasicTipEnd;
-	QToolTip::add(d,tmp);
+	KviTalToolTip::add(d,tmp);
 	return d;
 }
 
@@ -600,11 +628,24 @@ void KviOptionsWidget::addRowSpacer(int x1,int y1,int x2,int y2)
 QLabel * KviOptionsWidget::addLabel(int x1,int y1,int x2,int y2,const QString & text,bool bEnabled)
 {
 	QLabel * l = new QLabel(text,this);
+#ifdef COMPILE_USE_QT4
+	l->setWordWrap(true);
+#endif
 	l->setEnabled(bEnabled);
 	addWidgetToLayout(l,x1,y1,x2,y2);
 	return l;
 }
 
+QLabel * KviOptionsWidget::addLabel(QWidget * pParent,const QString & text,bool bEnabled)
+{
+	QLabel * l = new QLabel(text,pParent);
+#ifdef COMPILE_USE_QT4
+	l->setWordWrap(true);
+#endif
+	l->setEnabled(bEnabled);
+	return l;
+}
+
 QLineEdit * KviOptionsWidget::addLineEdit(int x1,int y1,int x2,int y2,bool bEnabled)
 {
 	QLineEdit * l = new QLineEdit(this);
@@ -621,9 +662,13 @@ QFrame * KviOptionsWidget::addSeparator(int x1,int y1,int x2,int y2)
 	return f;
 }
 
-QGroupBox * KviOptionsWidget::addGroupBox(int x1,int y1,int x2,int y2,int nStrips,QGroupBox::Orientation o,const QString &txt,bool bEnabled)
+#ifdef COMPILE_USE_QT4
+KviTalGroupBox * KviOptionsWidget::addGroupBox(int x1,int y1,int x2,int y2,int nStrips,Qt::Orientation o,const QString &txt,bool bEnabled)
+#else
+KviTalGroupBox * KviOptionsWidget::addGroupBox(int x1,int y1,int x2,int y2,int nStrips,KviTalGroupBox::Orientation o,const QString &txt,bool bEnabled)
+#endif
 {
-	QGroupBox * g = new QGroupBox(nStrips,o,txt,this);
+	KviTalGroupBox * g = new KviTalGroupBox(nStrips,o,txt,this);
 	g->setEnabled(bEnabled);
 	addWidgetToLayout(g,x1,y1,x2,y2);
 	return g;
