@@ -29,11 +29,11 @@
 
 #include <qframe.h>
 #include <qlayout.h>
-#include "kvi_list.h"
+#include "kvi_pointerlist.h"
 #include <qlineedit.h>
-#include <qgroupbox.h>
+#include <kvi_tal_groupbox.h>
 #include <qtabwidget.h>
-
+#include "kvi_tal_groupbox.h"
 #include "kvi_selectors.h"
 
 class KVIRC_API KviOptionsWidget : public QFrame, public KviSelectorInterface
@@ -47,7 +47,7 @@ private:
 	QTabWidget                       * m_pTabWidget;
 	int                                m_iResetFlags;
 	int                                m_iSelectors;
-	KviPtrList<KviSelectorInterface> * m_pSelectorInterfaceList;
+	KviPointerList<KviSelectorInterface> * m_pSelectorInterfaceList;
 	static QString                     m_szBasicTipStart;
 	static QString                     m_szBasicTipEnd;
 public:
@@ -82,7 +82,9 @@ public:
 	KviMircTextColorSelector * addMircTextColorSelector(QWidget * pParent,const QString & txt,int optForeId,int optBackId,bool bEnabled = true);
 
 	KviDirectorySelector  * addDirectorySelector(int x1,int y1,int x2,int y2,const QString & txt,QString * pOption,bool bEnabled = true);
+	KviDirectorySelector  * addDirectorySelector(QWidget * pParent,const QString & txt,QString * pOption,bool bEnabled = true);
 	KviDirectorySelector  * addDirectorySelector(int x1,int y1,int x2,int y2,const QString & txt,int optId,bool bEnabled = true);
+	KviDirectorySelector  * addDirectorySelector(QWidget * pParent,const QString & txt,int optId,bool bEnabled = true);
 
 	KviFileSelector       * addFileSelector(int x1,int y1,int x2,int y2,const QString & txt,QString * pOption,bool bEnabled = true);
 	KviFileSelector       * addFileSelector(QWidget * pParent,const QString & txt,QString * pOption,bool bEnabled = true);
@@ -130,8 +132,13 @@ public:
 							unsigned int uLowBound,unsigned int uHighBound,unsigned int uDefault,bool bEnabled = true);
 
 	QLabel * addLabel(int x1,int y1,int x2,int y2,const QString & text,bool bEnabled = true);
+	QLabel * addLabel(QWidget * pParent,const QString & text,bool bEnabled = true);
 	QLineEdit * addLineEdit(int x1,int y1,int x2,int y2,bool bEnabled = true);
-	QGroupBox * addGroupBox(int x1,int y1,int x2,int y2,int nStrips,QGroupBox::Orientation o,const QString &txt,bool bEnabled = true);
+#ifdef COMPILE_USE_QT4
+	KviTalGroupBox * addGroupBox(int x1,int y1,int x2,int y2,int nStrips,Qt::Orientation o,const QString &txt,bool bEnabled = true);
+#else
+	KviTalGroupBox * addGroupBox(int x1,int y1,int x2,int y2,int nStrips,KviTalGroupBox::Orientation o,const QString &txt,bool bEnabled = true);
+#endif
 	QFrame * addSeparator(int x1,int y1,int x2,int y2);
 	void addRowSpacer(int x1,int y1,int x2,int y2);
 
