@@ -46,6 +46,7 @@
 #include "kvi_ircuserdb.h"
 #include "kvi_mirccntrl.h"
 #include "kvi_toolwindows_container.h"
+#include "kvi_qcstring.h"
 
 #ifdef COMPILE_CRYPT_SUPPORT
 	#include "kvi_crypt.h"
@@ -56,10 +57,10 @@
 
 #include <qpixmap.h>
 #include <qsplitter.h>
-#include <qhbox.h>
+#include "kvi_tal_hbox.h"
 #include <qtoolbutton.h>
-#include <qdragobject.h>
-#include <qgrid.h> 
+#include "kvi_draganddrop.h"
+#include "kvi_valuelist.h"
 
 KviQuery::KviQuery(KviFrame * lpFrm,KviConsole * lpConsole,const QString &nick)
 : KviWindow(KVI_WINDOW_TYPE_QUERY,lpFrm,nick,lpConsole)
@@ -69,23 +70,26 @@ KviQuery::KviQuery(KviFrame * lpFrm,KviConsole * lpConsole,const QString &nick)
 	connection()->registerQuery(this);
 
 	//m_pTopSplitter = new QSplitter(QSplitter::Horizontal,this,"top_splitter");
-	m_pButtonBox = new QHBox(this,"button_box");
+	m_pButtonBox = new KviTalHBox(this);
 	m_pLabel = new KviThemedLabel(m_pButtonBox,"query_label");
 	m_pLabel->setAutoHeight(1);
 	updateLabelText();
 	m_pButtonBox->setStretchFactor(m_pLabel,1);
 
 	// The button box on the right
-	//QHBox * box = new QHBox(m_pTopSplitter,"button_box");
+	//KviTalHBox * box = new KviTalHBox(m_pTopSplitter,"button_box");
 	if(KVI_OPTION_BOOL(KviOption_boolShowExtendedInfoInQueryLabel))
-		m_pButtonGrid= new QGrid(2,Qt::Vertical,m_pButtonBox);
+		m_pButtonGrid= (QFrame*) new KviTalGrid(2,Qt::Horizontal,m_pButtonBox);
 	else
-		m_pButtonGrid= new QGrid(1,Qt::Vertical,m_pButtonBox);
-
+		m_pButtonGrid= (QFrame*) new KviTalGrid(4,Qt::Horizontal,m_pButtonBox);
 
 	createTextEncodingButton(m_pButtonGrid);
 
+#ifdef COMPILE_USE_QT4
+	m_pSplitter = new QSplitter(Qt::Horizontal,this,"main_splitter");
+#else
 	m_pSplitter = new QSplitter(QSplitter::Horizontal,this,"main_splitter");
+#endif
 	m_pIrcView = new KviIrcView(m_pSplitter,lpFrm,this);
 	connect(m_pIrcView,SIGNAL(rightClicked()),this,SLOT(textViewRightClicked()));
 	//m_pEditorsContainer= new KviToolWindowsContainer(m_pSplitter);
@@ -102,7 +106,7 @@ KviQuery::KviQuery(KviFrame * lpFrm,KviConsole * lpConsole,const QString &nick)
 
 	m_pInput   = new KviInput(this,m_pUserListView);
 
-	if(KVI_OPTION_BOOL(KviOption_boolAutoLogQueries)) m_pIrcView->startLogging(0);
+	if(KVI_OPTION_BOOL(KviOption_boolAutoLogQueries)) m_pIrcView->startLogging();
 	// FIXME: #warning "Maybe tell the user all that we know about the remote end(s)....channels..."
 
 	m_pIrcView->enableDnd(TRUE);
@@ -126,7 +130,7 @@ void KviQuery::updateLabelText()
 	if(szText!=m_pLabel->text())
 	{
 		m_pLabel->setText(szText);
-		QToolTip::add(m_pLabel,getInfoLabelTipText());
+		KviTalToolTip::add(m_pLabel,getInfoLabelTipText());
 	}
 }
 
@@ -157,11 +161,9 @@ QString KviQuery::getInfoLabelTipText()
 					"<body>" \
 						"<table width=\"100%\">";
 		
-			txt +=          "<tr><td bgcolor=\"#303030\">" \
-								"<font color=\"#FFFFFF\"><b>";
+			txt +=          START_TABLE_BOLD_ROW;
 			txt += __tr2qs("Query target:");
-			txt +=              "</b></font>" \
-							"</td></tr>";
+			txt +=              END_TABLE_BOLD_ROW;
 			txt +=          "<tr><td>";
 		
 			if(e->hasRealName())
@@ -266,14 +268,6 @@ void KviQuery::triggerCreationEvents()
 	KVS_TRIGGER_EVENT_0(KviEvent_OnQueryWindowCreated,this);
 }
 
-void KviQuery::getBaseLogFileName(KviStr &buffer)
-{
-	if(console()->connection())
-		buffer.sprintf("%s.%s",windowName().utf8().data(),console()->currentNetworkName().utf8().data());
-	else
-		buffer.sprintf("%s.%u",windowName().utf8().data(),console()->ircContextId());
-}
-
 void KviQuery::getBaseLogFileName(QString &buffer)
 {
 	if(console()->connection())
@@ -310,7 +304,7 @@ void KviQuery::loadProperties(KviConfig *cfg)
 {
 	int w = width();
 	KviWindow::loadProperties(cfg);
-	QValueList<int> def;
+	KviValueList<int> def;
 	def.append((w * 80) / 100);
 	def.append((w * 20) / 100);
 	m_pSplitter->setSizes(cfg->readIntListEntry("Splitter",def));
@@ -410,7 +404,7 @@ void KviQuery::notifyCommonChannels(const QString &nick,const QString &user,cons
 
 	if(targetCount() > 0)
 	{
-		QDictIterator<KviUserListEntry> it(*(m_pUserListView->entryDict()));
+		KviPointerHashTableIterator<QString,KviUserListEntry> it(*(m_pUserListView->entryDict()));
 		if(it.current())szName = it.currentKey();
 	}
 
@@ -543,7 +537,7 @@ void KviQuery::setAliveQuery()
 	context()->unregisterDeadQuery(this);
 	connection()->registerQuery(this);
 	// Update log file name
-	if(m_pIrcView->isLogging()) m_pIrcView->startLogging(0);
+	if(m_pIrcView->isLogging()) m_pIrcView->startLogging();
 	updateIcon();
 	updateCaption();
 	updateLabelText();
@@ -585,8 +579,8 @@ void KviQuery::ownMessage(const QString &buffer)
 		return;
 	}
 	
-	QCString szName = connection()->encodeText(windowName());
-	QCString szData = encodeText(buffer);
+	KviQCString szName = connection()->encodeText(windowName());
+	KviQCString szData = encodeText(buffer);
 
 	const char * d = szData.data();
 	if(!d)return;
@@ -617,9 +611,12 @@ void KviQuery::ownMessage(const QString &buffer)
 					}
 					break;
 					default: // also case KviCryptEngine::EncryptError
+					{
+						QString szEngineError = cryptSessionInfo()->pEngine->lastError();
 						output(KVI_OUT_SYSTEMERROR,
 							__tr2qs("The crypto engine was unable to encrypt the current message (%Q): %s, no data sent to the server"),
-							&buffer,cryptSessionInfo()->pEngine->lastError());
+							&buffer,&szEngineError);
+					}
 					break;
 				}
 				userAction(connection()->currentNickName(),KVI_USERACTION_PRIVMSG);
@@ -647,12 +644,13 @@ void KviQuery::ownAction(const QString &buffer)
 	{
 		outputNoFmt(KVI_OUT_SYSTEMWARNING,__tr2qs("This query has no active targets, no message sent"));
 	} else {
-		QCString szBuffer = encodeText(buffer);
+		KviQCString szBuffer = encodeText(buffer);
 		if(!szBuffer.data())return;
-		QCString sz = connection()->encodeText(windowName());
+		KviQCString sz = connection()->encodeText(windowName());
 		if(sz.isEmpty())return;
 		if(!connection()->sendFmtData("PRIVMSG %s :%cACTION %s%c",
 			sz.data(),0x01,szBuffer.data(),0x01))return;
+		if(KVS_TRIGGER_EVENT_1_HALTED(KviEvent_OnMeAction,this,QString(szBuffer.data())))return;
 		output(KVI_OUT_ACTION,"\r!nc\r%Q\r %Q",&(connection()->currentNickName()),&buffer);
 		m_pUserListView->userAction(connection()->currentNickName(),KVI_USERACTION_ACTION);
 	}
