@@ -31,8 +31,8 @@
 #include "kvi_userlistview.h"
 #include "kvi_themedlabel.h"
 
-#include <qasciidict.h>
-#include <qgrid.h> 
+#include "kvi_pointerhashtable.h"
+#include "kvi_tal_grid.h"
 
 class KviConsole;
 class KviConfig;
@@ -51,15 +51,14 @@ protected:
 	KviUserListView                     * m_pUserListView;
 	KviWindowToolPageButton             * m_pListViewButton;
 	int                                   m_iFlags;
-	KviThemedLabel 			    * m_pLabel;
-	QGrid			 	    * m_pButtonGrid;
+	KviThemedLabel                      * m_pLabel;
+	QFrame                              * m_pButtonGrid;
 protected:
 	virtual QPixmap * myIconPtr();
 	virtual void fillCaptionBuffers();
 	virtual void resizeEvent(QResizeEvent *e);
 	virtual void loadProperties(KviConfig * cfg);
 	virtual void saveProperties(KviConfig * cfg);
-	virtual void getBaseLogFileName(KviStr &buffer);
 	virtual void getBaseLogFileName(QString &buffer);
 	virtual void triggerCreationEvents();
 public:
