@@ -39,7 +39,7 @@
 #include <qcolordialog.h>
 #include <qpalette.h>
 #include <qfontdialog.h>
-#include <qpopupmenu.h>
+#include "kvi_tal_popupmenu.h"
 
 KviBoolSelector::KviBoolSelector(QWidget * par,const QString & txt,bool *pOption,bool bEnabled)
 : KviStyledCheckBox(txt,par), KviSelectorInterface()
@@ -61,7 +61,7 @@ void KviBoolSelector::commit()
 
 KviUIntSelector::KviUIntSelector(QWidget * par,const QString & txt,unsigned int *pOption,
 	unsigned int uLowBound,unsigned int uHighBound,unsigned int uDefault,bool bEnabled,bool bShortInt)
-: QHBox(par) , KviSelectorInterface()
+: KviTalHBox(par) , KviSelectorInterface()
 {
 	m_pLabel = new QLabel(txt,this);
 	//m_pLineEdit = new QLineEdit(this);
@@ -118,7 +118,7 @@ void KviUIntSelector::commit()
 
 void KviUIntSelector::setEnabled(bool bEnabled)
 {
-	QHBox::setEnabled(bEnabled);
+	KviTalHBox::setEnabled(bEnabled);
 	m_pLabel->setEnabled(bEnabled);
 	m_pSpinBox->setEnabled(bEnabled);
 }
@@ -126,7 +126,7 @@ void KviUIntSelector::setEnabled(bool bEnabled)
 
 
 KviStringSelector::KviStringSelector(QWidget * par,const QString & txt,QString * pOption,bool bEnabled)
-: QHBox(par) , KviSelectorInterface()
+: KviTalHBox(par) , KviSelectorInterface()
 {
 	m_pLabel = new QLabel(txt,this);
 	m_pLineEdit = new QLineEdit(this);
@@ -154,11 +154,15 @@ void KviStringSelector::commit()
 
 void KviStringSelector::setEnabled(bool bEnabled)
 {
-	QHBox::setEnabled(bEnabled);
+	KviTalHBox::setEnabled(bEnabled);
 	m_pLineEdit->setEnabled(bEnabled);
 	m_pLabel->setEnabled(bEnabled);
 }
 
+void KviStringSelector::setText(const QString& text){
+	m_pLineEdit->setText(text);
+}
+
 KviPasswordSelector::KviPasswordSelector(QWidget * par,const QString & txt,QString *pOption,bool bEnabled)
 : KviStringSelector(par,txt,pOption,bEnabled)
 {
@@ -169,7 +173,7 @@ KviPasswordSelector::KviPasswordSelector(QWidget * par,const QString & txt,QStri
 
 
 KviPixmapPreview::KviPixmapPreview(QWidget * par)
-: QScrollView(par)
+: KviTalScrollView(par)
 {
 	m_pPixmap = 0;
 	resizeContents(0,0);
@@ -300,9 +304,11 @@ void KviPixmapSelector::setEnabled(bool bEnabled)
 
 
 // FIXME: #warning "Option for DIR_MUST_EXISTS...(this widget could be turned into a file selector too)"
-KviFileSelector::KviFileSelector(QWidget * par,const QString & txt,QString * pOption,bool bEnabled)
-: QHBox(par), KviSelectorInterface()
+KviFileSelector::KviFileSelector(QWidget * par,const QString & txt,QString * pOption,bool bEnabled,unsigned int uFlags,const QString &szFilter)
+: KviTalHBox(par), KviSelectorInterface()
 {
+	m_uFlags = uFlags;
+	m_szFilter = szFilter;
 	m_pLabel = new QLabel(txt,this);
 	m_pLineEdit = new QLineEdit(this);
 	//m_pLineEdit->setMinimumWidth(200);
@@ -326,7 +332,7 @@ void KviFileSelector::commit()
 
 void KviFileSelector::setEnabled(bool bEnabled)
 {
-	QHBox::setEnabled(bEnabled);
+	KviTalHBox::setEnabled(bEnabled);
 	m_pLineEdit->setEnabled(bEnabled);
 	m_pLabel->setEnabled(bEnabled);
 	m_pButton->setEnabled(bEnabled);
@@ -337,13 +343,29 @@ void KviFileSelector::browseClicked()
 	select();
 }
 
+void KviFileSelector::setSelection(const QString &szSelection)
+{
+	m_pLineEdit->setText(szSelection);
+}
+
+
 void KviFileSelector::select()
 {
 	//KviStr tmp;
-	QString tmp;
- 	if(KviFileDialog::askForOpenFileName(tmp,__tr2qs("Choose a File - KVIrc")))
+	QString tmp = *m_pOption;
+	if(m_uFlags & ChooseSaveFileName)
 	{
-		m_pLineEdit->setText(tmp);
+ 		if(KviFileDialog::askForSaveFileName(tmp,__tr2qs("Choose a File - KVIrc"),tmp,m_szFilter,true,!(m_uFlags & DontConfirmOverwrite)))
+		{
+			m_pLineEdit->setText(tmp);
+			emit selectionChanged(tmp);
+		}
+	} else {
+ 		if(KviFileDialog::askForOpenFileName(tmp,__tr2qs("Choose a File - KVIrc"),tmp,m_szFilter,true))
+		{
+			m_pLineEdit->setText(tmp);
+			emit selectionChanged(tmp);
+		}
 	}
 
 }
@@ -356,10 +378,10 @@ KviDirectorySelector::KviDirectorySelector(QWidget * par,const QString & txt,QSt
 
 void KviDirectorySelector::select()
 {
-	KviStr tmp;
- 	if(KviFileDialog::askForDirectoryName(tmp,__tr2qs("Choose a Directory - KVIrc")))
+	QString tmp;
+	if(KviFileDialog::askForDirectoryName(tmp,__tr2qs("Choose a Directory - KVIrc"),""))
 	{
-		m_pLineEdit->setText(tmp.ptr());
+		m_pLineEdit->setText(tmp);
 	}
 
 }
@@ -372,21 +394,21 @@ void KviDirectorySelector::select()
 
 
 KviStringListSelector::KviStringListSelector(QWidget * par,const QString & txt,QStringList * pOption,bool bEnabled)
-: QVBox(par), KviSelectorInterface()
+: KviTalVBox(par), KviSelectorInterface()
 {
 	m_pLabel = new QLabel(txt,this);
-	m_pListBox = new QListBox(this);
+	m_pListBox = new KviTalListBox(this);
 	m_pLineEdit = new QLineEdit(this);
 	connect(m_pLineEdit,SIGNAL(textChanged(const QString &)),this,SLOT(textChanged(const QString &)));
 	connect(m_pLineEdit,SIGNAL(returnPressed()),this,SLOT(addClicked()));
-	QHBox * hBox = new QHBox(this);
+	KviTalHBox * hBox = new KviTalHBox(this);
 	m_pAddButton = new QPushButton(__tr2qs("A&dd"),hBox);
 	connect(m_pAddButton,SIGNAL(clicked()),this,SLOT(addClicked()));
 	m_pRemoveButton = new QPushButton(__tr2qs("Re&move"),hBox);
 	connect(m_pRemoveButton,SIGNAL(clicked()),this,SLOT(removeClicked()));
 	m_pOption = pOption;
 	m_pListBox->insertStringList(*pOption);
-	m_pListBox->setSelectionMode(QListBox::Extended);
+	m_pListBox->setSelectionMode(KviTalListBox::Extended);
 	connect(m_pListBox,SIGNAL(selectionChanged()),this,SLOT(selectionChanged()));
 	setSpacing(4);
 	setStretchFactor(m_pListBox,1);
@@ -420,7 +442,7 @@ void KviStringListSelector::textChanged(const QString &str)
 
 void KviStringListSelector::setEnabled(bool bEnabled)
 {
-	QVBox::setEnabled(bEnabled);
+	KviTalVBox::setEnabled(bEnabled);
 	m_pLineEdit->setEnabled(bEnabled);
 	m_pLabel->setEnabled(bEnabled);
 	QString txt = m_pLineEdit->text();
@@ -471,7 +493,7 @@ void KviStringListSelector::removeClicked()
 
 
 KviColorSelector::KviColorSelector(QWidget * par,const QString & txt,QColor * pOption,bool bEnabled)
-: QHBox(par), KviSelectorInterface()
+: KviTalHBox(par), KviSelectorInterface()
 {
 	m_pLabel = new QLabel(txt,this);
 
@@ -518,14 +540,14 @@ void KviColorSelector::commit()
 
 void KviColorSelector::setEnabled(bool bEnabled)
 {
-	QHBox::setEnabled(bEnabled);
+	KviTalHBox::setEnabled(bEnabled);
 	m_pLabel->setEnabled(bEnabled);
 	m_pButton->setEnabled(bEnabled);
 }
 
 
 KviFontSelector::KviFontSelector(QWidget * par,const QString & txt,QFont * pOption,bool bEnabled)
-: QHBox(par), KviSelectorInterface()
+: KviTalHBox(par), KviSelectorInterface()
 {
 	m_pLabel = new QLabel(txt,this);
 
@@ -563,7 +585,7 @@ void KviFontSelector::commit()
 
 void KviFontSelector::setEnabled(bool bEnabled)
 {
-	QHBox::setEnabled(bEnabled);
+	KviTalHBox::setEnabled(bEnabled);
 	m_pLabel->setEnabled(bEnabled);
 	m_pButton->setEnabled(bEnabled);
 }
@@ -573,7 +595,7 @@ void KviFontSelector::setEnabled(bool bEnabled)
 
 
 KviMircTextColorSelector::KviMircTextColorSelector(QWidget * par,const QString &txt,unsigned int * uFore,unsigned int * uBack,bool bEnabled)
-: QHBox(par), KviSelectorInterface()
+: KviTalHBox(par), KviSelectorInterface()
 {
 	m_pLabel = new QLabel(txt,this);
 
@@ -594,21 +616,25 @@ KviMircTextColorSelector::KviMircTextColorSelector(QWidget * par,const QString &
 
 	setEnabled(bEnabled);
 	
-	m_pContextPopup = new QPopupMenu(this);
+	m_pContextPopup = new KviTalPopupMenu(this);
 	
-	m_pForePopup = new QPopupMenu(this);
+	m_pForePopup = new KviTalPopupMenu(this);
 	connect(m_pForePopup,SIGNAL(activated(int)),this,SLOT(foreSelected(int)));
 	int i;
 	for(i=0;i<KVI_MIRCCOLOR_MAX_FOREGROUND;i++)
 	{
 		QPixmap tmp(120,16);
 		tmp.fill(KVI_OPTION_MIRCCOLOR(i));
+#ifdef COMPILE_USE_QT4
+		int id = m_pForePopup->insertItem(tmp,QString("x"));
+#else
 		int id = m_pForePopup->insertItem(tmp);
+#endif
 		m_pForePopup->setItemParameter(id,i);
 	}
 	m_pContextPopup->insertItem(__tr2qs("Foreground"),m_pForePopup);
 
-	m_pBackPopup = new QPopupMenu(this);
+	m_pBackPopup = new KviTalPopupMenu(this);
 	connect(m_pBackPopup,SIGNAL(activated(int)),this,SLOT(backSelected(int)));
 	i = m_pBackPopup->insertItem(__tr2qs("Transparent"));
 	m_pBackPopup->setItemParameter(i,KVI_TRANSPARENT);
@@ -616,7 +642,11 @@ KviMircTextColorSelector::KviMircTextColorSelector(QWidget * par,const QString &
 	{
 		QPixmap tmp(120,16);
 		tmp.fill(KVI_OPTION_MIRCCOLOR(i));
+#ifdef COMPILE_USE_QT4
+		int id = m_pForePopup->insertItem(tmp,QString("x"));
+#else
 		int id = m_pBackPopup->insertItem(tmp);
+#endif
 		m_pBackPopup->setItemParameter(id,i);
 	}
 	m_pContextPopup->insertItem(__tr2qs("Background"),m_pBackPopup);
@@ -634,7 +664,7 @@ void KviMircTextColorSelector::commit()
 
 void KviMircTextColorSelector::setEnabled(bool bEnabled)
 {
-	QHBox::setEnabled(bEnabled);
+	KviTalHBox::setEnabled(bEnabled);
 	m_pLabel->setEnabled(bEnabled);
 	m_pButton->setEnabled(bEnabled);
 }
@@ -701,8 +731,8 @@ void KviSoundSelector::setEnabled(bool bEnabled)
 	m_pPlayButton->setEnabled(bEnabled);
 }
 
-KviChanListViewItem::KviChanListViewItem(QListView* pList,QString szChan,QString szPass)
-:QListViewItem(pList,szChan)
+KviChanListViewItem::KviChanListViewItem(KviTalListView* pList,QString szChan,QString szPass)
+:KviTalListViewItem(pList,szChan)
 {
 	m_szPass=szPass;
 	QString mask;
@@ -711,14 +741,14 @@ KviChanListViewItem::KviChanListViewItem(QListView* pList,QString szChan,QString
 }
 
 KviCahnnelListSelector::KviCahnnelListSelector(QWidget * par,const QString & txt,QStringList * pOption,bool bEnabled)
-: QVBox(par), KviSelectorInterface()
+: KviTalVBox(par), KviSelectorInterface()
 {
 	m_pLabel = new QLabel(txt,this);
-	m_pListView = new QListView(this);
+	m_pListView = new KviTalListView(this);
 	m_pListView->addColumn(__tr2qs("Channel name"));
 	m_pListView->addColumn(__tr2qs("Channel password"));
 	
-	QHBox* pEditsHBox = new QHBox(this);
+	KviTalHBox* pEditsHBox = new KviTalHBox(this);
 	
 	m_pChanLineEdit = new QLineEdit(pEditsHBox);
 	connect(m_pChanLineEdit,SIGNAL(textChanged(const QString &)),this,SLOT(textChanged(const QString &)));
@@ -730,7 +760,7 @@ KviCahnnelListSelector::KviCahnnelListSelector(QWidget * par,const QString & txt
 	connect(m_pPassLineEdit,SIGNAL(returnPressed()),this,SLOT(addClicked()));
 	
 	
-	QHBox * hBox = new QHBox(this);
+	KviTalHBox * hBox = new KviTalHBox(this);
 	m_pAddButton = new QPushButton(__tr2qs("A&dd"),hBox);
 	connect(m_pAddButton,SIGNAL(clicked()),this,SLOT(addClicked()));
 	m_pRemoveButton = new QPushButton(__tr2qs("Re&move"),hBox);
@@ -741,7 +771,7 @@ KviCahnnelListSelector::KviCahnnelListSelector(QWidget * par,const QString & txt
 		new KviChanListViewItem(m_pListView,(*it).section(':',0,0),(*it).section(':',1));
 	}
 
-	m_pListView->setSelectionMode(QListView::Extended);
+	m_pListView->setSelectionMode(KviTalListView::Extended);
 	m_pListView->setAllColumnsShowFocus(TRUE);
 	connect(m_pListView,SIGNAL(selectionChanged()),this,SLOT(selectionChanged()));
 	setSpacing(4);
@@ -757,7 +787,7 @@ void KviCahnnelListSelector::commit()
 {
 	m_pOption->clear();
 	register KviChanListViewItem* pItem;
-	QListViewItemIterator it( m_pListView);
+	KviTalListViewItemIterator it( m_pListView);
 	while ( it.current() ) {
 		pItem = (KviChanListViewItem*)( it.current() );
 		m_pOption->append(pItem->text(0)+":"+pItem->pass());
@@ -796,10 +826,10 @@ void KviCahnnelListSelector::addClicked()
 
 void KviCahnnelListSelector::removeClicked()
 {
-	QPtrList<QListViewItem> lst;
-	QListViewItemIterator it( m_pListView, QListViewItemIterator::Selected );
+	KviPointerList<KviTalListViewItem> lst;
+	KviTalListViewItemIterator it( m_pListView, KviTalListViewItemIterator::Selected );
 	while ( it.current() ) {
-		lst.append( it.current() );
+		lst.append((KviTalListViewItem *)it.current() );
 		++it;
 	}
 	lst.setAutoDelete(TRUE);
