@@ -31,6 +31,10 @@
 #include "kvi_fileutils.h"
 #include <qsplashscreen.h> 
 
+#ifdef COMPILE_USE_QT4
+	#include <qdesktopwidget.h>
+#endif
+
 #include <qpixmap.h>
 #include <qpainter.h>
 #include <qlayout.h>
@@ -102,6 +106,15 @@ KviSplashScreen::KviSplashScreen()
 	m_pTimer = new QTimer(this);
 	connect(m_pTimer,SIGNAL(timeout()),this,SLOT(suicide()));
 	delete pix;
+
+#ifdef COMPILE_USE_QT4
+	setWindowOpacity(0);
+	m_bIncreasing=true;
+	m_rTransparency=0;
+	m_pFadeTimer= new QTimer(this);
+	connect(m_pFadeTimer,SIGNAL(timeout()),this,SLOT(fadeTimerShot()));
+	m_pFadeTimer->start(6);
+#endif
 }
 
 // We don't need messages on the splash: they just add work to the translators and nobody can read them anyway :D
@@ -132,24 +145,39 @@ void KviSplashScreen::hideEvent(QHideEvent *e)
 
 void KviSplashScreen::setProgress(int progress)
 {
+#ifdef COMPILE_USE_QT4
+	QPixmap slowQt4Copy = pixmap();
+	QPainter painter(&slowQt4Copy);
+	QSize size = slowQt4Copy.size();
+	int w = (m_pOverlay->width() * progress) / 100;
+	painter.drawPixmap(0,size.height() - m_pOverlay->height(),w,m_pOverlay->height(),*m_pOverlay,0,0,w,m_pOverlay->height());
+	painter.end();
+	setPixmap(slowQt4Copy);
+#else
 	QPainter painter(pixmap());
 	QSize size = pixmap()->size();
 	painter.drawPixmap(0,size.height() - m_pOverlay->height(),*m_pOverlay,0,0,(m_pOverlay->width() * progress) / 100,m_pOverlay->height());
 	painter.end();
+#endif
 	//raise();
 	repaint();
 	g_pApp->processEvents(); //damn...
 }
 
-#define KVI_SPLASH_SCREEN_MINIMUM_TIMEOUT_IN_MSECS 4000
+#define KVI_SPLASH_SCREEN_MINIMUM_TIMEOUT_IN_MSECS 2000
 
 void KviSplashScreen::die()
 {
+#ifdef COMPILE_USE_QT4
+	m_bIncreasing = false;
+	m_pFadeTimer->start(6);
+#else
 	QTime now = QTime::currentTime();
 	int mSecs = m_creationTime.msecsTo(now);
 	int mRemaining = KVI_SPLASH_SCREEN_MINIMUM_TIMEOUT_IN_MSECS - mSecs;
 	if(mRemaining < 0)mRemaining = 0;
 	m_pTimer->start(mRemaining,true);
+#endif
 }
 
 
@@ -163,4 +191,32 @@ void KviSplashScreen::suicide()
 }
 
 
+void KviSplashScreen::fadeTimerShot()
+{
+#ifdef COMPILE_USE_QT4
+	if(m_bIncreasing)
+	{
+		m_rTransparency+=0.05;
+		setWindowOpacity(m_rTransparency);
+		if(m_rTransparency>=1)
+		{
+			m_pFadeTimer->stop();
+			m_bIncreasing=false;
+		}
+
+
+	} else {
+		m_rTransparency-=0.02;
+		setWindowOpacity(m_rTransparency);
+		if(m_rTransparency<=0)
+		{
+			m_pFadeTimer->stop();
+			m_bIncreasing=true;
+			suicide();
+		}
+	}
+#endif
+}
+
+
 #include "kvi_splash.moc"
