@@ -46,9 +46,13 @@
 #include <qlayout.h>
 #include <qtimer.h>
 #include <qcursor.h>
-#include <qpopupmenu.h>
+#include "kvi_tal_popupmenu.h"
 #include <qpixmap.h>
 
+#ifdef COMPILE_USE_QT4
+	#include <qevent.h>
+#endif
+
 // This class COULD be derived also from KStatusBar but in fact
 // it adds no graphic functionality and it has only useless methods for us.
 // ... for now let's keep it simple :)
@@ -82,7 +86,7 @@ KviStatusBar::KviStatusBar(KviFrame * pFrame)
 	
 	m_pClickedApplet = 0;
 
-	m_pAppletDescriptors = new QDict<KviStatusBarAppletDescriptor>;
+	m_pAppletDescriptors = new KviPointerHashTable<QString,KviStatusBarAppletDescriptor>;
 	m_pAppletDescriptors->setAutoDelete(true);
 
 	KviStatusBarClock::selfRegister(this);
@@ -91,24 +95,26 @@ KviStatusBar::KviStatusBar(KviFrame * pFrame)
 	KviStatusBarConnectionTimer::selfRegister(this);
 	KviStatusBarSeparator::selfRegister(this);
 
-	m_pAppletList = new KviPtrList<KviStatusBarApplet>;
+	m_pAppletList = new KviPointerList<KviStatusBarApplet>;
 	m_pAppletList->setAutoDelete(false);
 
-	m_pMessageQueue = new KviPtrList<KviStatusBarMessage>;
+	m_pMessageQueue = new KviPointerList<KviStatusBarMessage>;
 	m_pMessageQueue->setAutoDelete(true);
 
 	m_pMessageTimer = 0;
 
 	m_pMessageLabel = new QLabel("<b>[x]</b> x",this,"msgstatuslabel");
 	m_pMessageLabel->setMargin(1);
-	m_pMessageLabel->setAlignment(SingleLine | AlignVCenter | AlignLeft);
+#ifdef COMPILE_USE_QT4
+	m_pMessageLabel->setAlignment(Qt::AlignVCenter | Qt::AlignLeft);
+#else
+	m_pMessageLabel->setAlignment(SingleLine | Qt::AlignVCenter | Qt::AlignLeft);
+#endif
 	m_pMessageLabel->setMinimumWidth(350);
 	
 	m_iLastMinimumHeight = 0;
 	m_bStopLayoutOnAddRemove = true;
 
-	load();
-
 	connect(m_pFrame,SIGNAL(activeContextChanged()),this,SLOT(setPermanentMessage()));
 	connect(m_pFrame,SIGNAL(activeContextStateChanged()),this,SLOT(setPermanentMessage()));
 	connect(m_pFrame,SIGNAL(activeConnectionUserModeChanged()),this,SLOT(setPermanentMessage()));
@@ -155,8 +161,13 @@ void KviStatusBar::load()
 			QString szPreloadModule = cfg.readEntry(tmp.ptr(),"");
 			if(!szPreloadModule.isEmpty())
 				g_pModuleManager->getModule(szPreloadModule.utf8().data());
+
 			KviStatusBarApplet * a = createApplet(szInternalName);
-			a->loadState(prefix.ptr(),&cfg);
+			if (a)
+				a->loadState(prefix.ptr(),&cfg);
+			else
+				debug("warning: failed to create applet %s (preload: %s)!",
+					szInternalName.utf8().data(), szPreloadModule.utf8().data());
 		}
 	}
 }
@@ -306,11 +317,11 @@ void KviStatusBar::tipRequest(KviDynamicToolTip *pTip,const QPoint &pnt)
 	pTip->tip(r,szTip);
 }
 
-QPopupMenu * KviStatusBar::contextPopup()
+KviTalPopupMenu * KviStatusBar::contextPopup()
 {
 	if(!m_pContextPopup)
 	{
-		m_pContextPopup = new QPopupMenu(this);
+		m_pContextPopup = new KviTalPopupMenu(this);
 		connect(m_pContextPopup,SIGNAL(aboutToShow()),this,SLOT(contextPopupAboutToShow()));
 	}
 	m_pClickedApplet = appletAt(QCursor::pos());
@@ -330,10 +341,13 @@ void KviStatusBar::contextPopupAboutToShow()
 		QString tmp;
 		KviQString::sprintf(tmp,"<center><b>%Q</b></center>",&app);
 
+#ifndef COMPILE_USE_QT4
+		// FIXME: This is not supported under Qt4.. :(
 		QLabel * l = new QLabel(tmp,m_pContextPopup);
 		l->setFrameStyle(QFrame::Raised | QFrame::StyledPanel);
 		m_pContextPopup->insertItem(l);
-		
+#endif
+
 		m_pClickedApplet->fillContextPopup(m_pContextPopup);
 		
 		KviQString::sprintf(tmp,__tr2qs("Remove %Q"),&app);
@@ -343,7 +357,7 @@ void KviStatusBar::contextPopupAboutToShow()
 
 	if(!m_pAppletsPopup)
 	{
-		m_pAppletsPopup = new QPopupMenu(this);
+		m_pAppletsPopup = new KviTalPopupMenu(this);
 		connect(m_pAppletsPopup,SIGNAL(aboutToShow()),this,SLOT(appletsPopupAboutToShow()));
 		connect(m_pAppletsPopup,SIGNAL(activated(int)),this,SLOT(appletsPopupActivated(int)));
 	}
@@ -366,7 +380,7 @@ void KviStatusBar::appletsPopupAboutToShow()
 	// FIXME: could we cache the module results in some way ?
 	g_pModuleManager->loadModulesByCaps("statusbarapplet");
 	
-	QDictIterator<KviStatusBarAppletDescriptor> it(*m_pAppletDescriptors);
+	KviPointerHashTableIterator<QString,KviStatusBarAppletDescriptor> it(*m_pAppletDescriptors);
 	while(KviStatusBarAppletDescriptor * d = it.current())
 	{
 		int id;
@@ -398,7 +412,7 @@ void KviStatusBar::appletsPopupActivated(int id)
 
 	if(!m_pAppletsPopup)return;
 	int par = m_pAppletsPopup->itemParameter(id);
-	QDictIterator<KviStatusBarAppletDescriptor> it(*m_pAppletDescriptors);
+	KviPointerHashTableIterator<QString,KviStatusBarAppletDescriptor> it(*m_pAppletDescriptors);
 	while(KviStatusBarAppletDescriptor * d = it.current())
 	{
 		if(par == d->id())
@@ -461,18 +475,22 @@ void KviStatusBar::paintEvent(QPaintEvent * e)
 void KviStatusBar::mousePressEvent(QMouseEvent * e)
 {
 	m_pClickedApplet = 0;
-	if(e->button() & RightButton)
+	if(e->button() & Qt::RightButton)
 	{
 		contextPopup()->popup(QCursor::pos());
 		return;
 	}
-	if((e->button() & LeftButton) && (e->state() & (ShiftButton | ControlButton)))
+	if((e->button() & Qt::LeftButton) && (e->state() & (Qt::ShiftButton | Qt::ControlButton)))
 	{
 		// move!
 		m_pClickedApplet = appletAt(mapToGlobal(e->pos()));
 		if(!m_pClickedApplet)return;
 		m_pClickedApplet->select();
+#ifdef COMPILE_USE_QT4
+		g_pApp->setOverrideCursor(Qt::SizeAllCursor);
+#else
 		g_pApp->setOverrideCursor(sizeAllCursor);
+#endif
 	}
 }
 
@@ -512,7 +530,7 @@ void KviStatusBar::mouseMoveEvent(QMouseEvent * e)
 
 void KviStatusBar::mouseReleaseEvent(QMouseEvent * e)
 {
-	if(e->button() & LeftButton)
+	if(e->button() & Qt::LeftButton)
 	{
 		if(m_pClickedApplet && appletExists(m_pClickedApplet))
 		{
