@@ -35,7 +35,6 @@
 #include "kvi_app.h"
 #include "kvi_config.h"
 #include "kvi_modulemanager.h"
-//#include "kvi_uparser.h"
 #include "kvi_console.h"
 #include "kvi_lagmeter.h"
 #include "kvi_options.h"
@@ -46,8 +45,11 @@
 #include <qlayout.h>
 #include <qtimer.h>
 #include <qcursor.h>
-#include <qpopupmenu.h>
+#include "kvi_tal_popupmenu.h"
 #include <qpixmap.h>
+#ifdef COMPILE_USE_QT4
+	#include <qevent.h>
+#endif
 
 // This class COULD be derived also from KStatusBar but in fact
 // it adds no graphic functionality and it has only useless methods for us.
@@ -77,7 +79,7 @@ KviStatusBarAppletDescriptor::KviStatusBarAppletDescriptor(const QString &szVisi
 	m_szInternalName = szInternalName;
 	m_szPreloadModule = szPreloadModule;
 	m_pProc = pProc;
-	m_pAppletList = new KviPtrList<KviStatusBarApplet>;
+	m_pAppletList = new KviPointerList<KviStatusBarApplet>;
 	m_pAppletList->setAutoDelete(false);
 	if(!pixIcon.isNull())m_pIcon = new QPixmap(pixIcon);
 	else m_pIcon = 0;
@@ -136,9 +138,15 @@ void KviStatusBarApplet::paintEvent(QPaintEvent * e)
 	if(m_bSelected)
 	{
 		QPainter p(this);
+#ifdef COMPILE_USE_QT4
+		p.setCompositionMode(QPainter::CompositionMode_SourceOut);
+		p.fillRect(rect(),Qt::black);
+		p.setCompositionMode(QPainter::CompositionMode_SourceOver);
+#else
 		p.setRasterOp(Qt::NotROP);
 		p.fillRect(rect(),Qt::black);
 		p.setRasterOp(Qt::CopyROP);
+#endif
 	}
 }
 
@@ -155,6 +163,7 @@ void KviStatusBarApplet::select(bool bSelect)
 KviStatusBarAwayIndicator::KviStatusBarAwayIndicator(KviStatusBar * pParent,KviStatusBarAppletDescriptor *pDescriptor)
 : KviStatusBarApplet(pParent,pDescriptor)
 {
+	m_bAwayOnAllContexts = false;
 	connect(pParent->frame(),SIGNAL(activeContextChanged()),this,SLOT(updateDisplay()));
 	connect(pParent->frame(),SIGNAL(activeContextStateChanged()),this,SLOT(updateDisplay()));
 	connect(pParent->frame(),SIGNAL(activeConnectionAwayStateChanged()),this,SLOT(updateDisplay()));
@@ -184,6 +193,29 @@ void KviStatusBarAwayIndicator::updateDisplay()
 	}
 }
 
+void KviStatusBarAwayIndicator::toggleContext()
+{
+	m_bAwayOnAllContexts = !m_bAwayOnAllContexts;
+}
+
+void KviStatusBarAwayIndicator::fillContextPopup(KviTalPopupMenu *p)
+{
+	int id = p->insertItem(__tr2qs("Apply to all IRC Contexts"),this,SLOT(toggleContext()));
+	p->setItemChecked(id,m_bAwayOnAllContexts);	
+}
+
+void KviStatusBarAwayIndicator::loadState(const char * prefix,KviConfig *cfg)
+{
+	KviStr tmp(KviStr::Format,"%s_AwayOnAllContexts",prefix);
+	m_bAwayOnAllContexts = cfg->readBoolEntry(tmp.ptr(),false);
+}
+
+void KviStatusBarAwayIndicator::saveState(const char * prefix,KviConfig *cfg)
+{
+	KviStr tmp(KviStr::Format,"%s_AwayOnAllContexts",prefix);
+	cfg->writeEntry(tmp.ptr(),m_bAwayOnAllContexts);
+}
+
 KviStatusBarApplet * CreateStatusBarAwayIndicator(KviStatusBar * pBar,KviStatusBarAppletDescriptor *pDescriptor)
 {
 	return new KviStatusBarAwayIndicator(pBar,pDescriptor);
@@ -196,13 +228,18 @@ void KviStatusBarAwayIndicator::selfRegister(KviStatusBar * pBar)
 	pBar->registerAppletDescriptor(d);
 }
 
+// FIXME: Away on all context should know where user is not away/back before toggling status
 void KviStatusBarAwayIndicator::mouseDoubleClickEvent(QMouseEvent * e)
 {
-	if(!(e->button() & LeftButton))return;
+	if(!(e->button() & Qt::LeftButton))return;
 	KviIrcConnection * c = statusBar()->frame()->activeConnection();
 	if(!c)return;
 	if(c->state() != KviIrcConnection::Connected)return;
-	QString command = "if($away)back; else away";
+	QString command;
+	if(m_bAwayOnAllContexts)
+		command = "if($away)back -a; else away -a";
+	else
+		command = "if($away)back; else away";
 	KviKvsScript::run(command,c->console());
 }
 
@@ -258,7 +295,7 @@ KviStatusBarLagIndicator::~KviStatusBarLagIndicator()
 
 void KviStatusBarLagIndicator::mouseDoubleClickEvent(QMouseEvent *e)
 {
-	if(!(e->button() & LeftButton))return;
+	if(!(e->button() & Qt::LeftButton))return;
 
 	KviIrcConnection * c = statusBar()->frame()->activeConnection();
 	if(!c)return;
@@ -389,7 +426,7 @@ void KviStatusBarClock::timerEvent(QTimerEvent *)
 	setText(tmp);
 }
 
-void KviStatusBarClock::fillContextPopup(QPopupMenu * p)
+void KviStatusBarClock::fillContextPopup(KviTalPopupMenu * p)
 {
 	int id = p->insertItem("UTC",this,SLOT(toggleUtc()));
 	p->setItemChecked(id,m_bUtc);
@@ -470,7 +507,7 @@ void KviStatusBarConnectionTimer::toggleTotal()
 	m_bTotal = !m_bTotal;
 }
 
-void KviStatusBarConnectionTimer::fillContextPopup(QPopupMenu *p)
+void KviStatusBarConnectionTimer::fillContextPopup(KviTalPopupMenu *p)
 {
 	int id = p->insertItem(__tr2qs("Show total connection time"),this,SLOT(toggleTotal()));
 	p->setItemChecked(id,m_bTotal);	
