@@ -25,19 +25,19 @@
 //=============================================================================
 
 #include "kvi_settings.h"
-#include "kvi_list.h"
+#include "kvi_pointerlist.h"
 #include "kvi_heapobject.h"
 #include "kvi_statusbar.h"
 
 #include <qstring.h>
-#include <qdict.h>
+#include "kvi_pointerhashtable.h"
 #include <qstatusbar.h>
 #include <qlabel.h>
 #include <qpixmap.h>
 
 class QTimer;
 class QLabel;
-class QPopupMenu;
+class KviTalPopupMenu;
 
 class KviConfig;
 class KviFrame;
@@ -59,7 +59,7 @@ protected:
 	CreateAppletCallback             m_pProc;               // creation callback
 	QPixmap                        * m_pIcon;
 	int                              m_iId;
-	KviPtrList<KviStatusBarApplet> * m_pAppletList;
+	KviPointerList<KviStatusBarApplet> * m_pAppletList;
 public:
 	KviStatusBarAppletDescriptor(const QString &szVisibleName,
 					const QString &szInternalName,
@@ -99,7 +99,7 @@ public:
 	bool isSelected(){ return m_bSelected; };
 protected:
 	virtual void paintEvent(QPaintEvent *e);
-	virtual void fillContextPopup(QPopupMenu *p){};
+	virtual void fillContextPopup(KviTalPopupMenu *p){};
 	virtual void loadState(const char * prefix,KviConfig *cfg){};
 	virtual void saveState(const char * prefix,KviConfig *cfg){};
 	virtual QString tipText(const QPoint &);
@@ -118,7 +118,7 @@ protected:
 public:
 	static void selfRegister(KviStatusBar * pBar);
 protected:
-	virtual void fillContextPopup(QPopupMenu * p);
+	virtual void fillContextPopup(KviTalPopupMenu * p);
 	virtual void timerEvent(QTimerEvent * e);
 	virtual void loadState(const char * prefix,KviConfig *cfg);
 	virtual void saveState(const char * prefix,KviConfig *cfg);
@@ -136,7 +136,7 @@ protected:
 	bool m_bTotal;
 protected:
 	virtual void timerEvent(QTimerEvent * e);
-	virtual void fillContextPopup(QPopupMenu *p);
+	virtual void fillContextPopup(KviTalPopupMenu *p);
 	virtual void loadState(const char * prefix,KviConfig *cfg);
 	virtual void saveState(const char * prefix,KviConfig *cfg);
 public:
@@ -163,11 +163,17 @@ public:
 	virtual ~KviStatusBarAwayIndicator();
 public:
 	static void selfRegister(KviStatusBar * pBar);
+protected:
+	bool m_bAwayOnAllContexts;
 protected:
 	virtual void mouseDoubleClickEvent(QMouseEvent *e);
 	virtual QString tipText(const QPoint &);
+	virtual void fillContextPopup(KviTalPopupMenu *p);
+	virtual void loadState(const char * prefix,KviConfig *cfg);
+	virtual void saveState(const char * prefix,KviConfig *cfg);
 protected slots:
 	void updateDisplay();
+	void toggleContext();
 };
 
 class KviStatusBarLagIndicator : public KviStatusBarApplet
