@@ -51,8 +51,21 @@
 #include <qfontmetrics.h>
 #include <qpainter.h>
 #include <qpixmap.h>
-#include <qheader.h>
 #include <qimage.h>
+#include "kvi_tal_popupmenu.h"
+#include <qcursor.h>
+
+#ifdef COMPILE_USE_QT4
+	#include <q3header.h>
+#else
+	#include <qheader.h>
+#endif
+#include <qevent.h>
+
+#ifdef COMPILE_USE_QT4
+	#include <QPaintEvent>
+#endif
+
 
 #ifdef COMPILE_PSEUDO_TRANSPARENCY
 	extern QPixmap * g_pShadedChildGlobalDesktopBackground;
@@ -60,15 +73,24 @@
 
 extern QPixmap * g_pActivityMeterPixmap;
 
+// FIXME: This should be renamed to "Window List"
 
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 // KviTaskBarBase
 //
 
 KviTaskBarBase::KviTaskBarBase()
+#ifdef COMPILE_USE_QT4
+: QDockWidget(__tr2qs("Taskbar"),g_pFrame)
+#else
 : KviToolBar(__tr2qs("Taskbar"),QT_DOCK_BOTTOM,false,"taskbar")
+#endif
 {
 	// FIXME: this timer should be started only if KVI_OPTION_BOOL(KviOption_boolUseTaskBarActivityMeter)
+#ifdef COMPILE_USE_QT4
+	setObjectName(__tr2qs("taskbar"));
+	setFeatures(QDockWidget::DockWidgetMovable);
+#endif //COMPILE_USE_QT4
 	m_pActivityMeterTimer = new QTimer();
 	connect(m_pActivityMeterTimer,SIGNAL(timeout()),this,SLOT(updateActivityMeter()));
 	m_pActivityMeterTimer->start(5000);
@@ -83,6 +105,27 @@ void KviTaskBarBase::updateActivityMeter()
 {
 }
 
+void KviTaskBarBase::getTextForConsole(QString &szText,KviConsole * pConsole)
+{
+	if(pConsole->isConnected())
+	{
+		if(KVI_OPTION_BOOL(KviOption_boolShowNetworkNameForConsoleTaskBarEntry))
+		{
+			// FIXME: Should never show "Standalone Servers" or "orphan_servers".
+			//        It would also be nice to have a number appended to
+			//        multiple entries with the same server name...but this costs too much.
+			szText = pConsole->connection()->networkName();
+			if(szText.isEmpty())
+				szText = pConsole->connection()->currentServerName();
+		} else {
+			szText = pConsole->connection()->currentServerName();
+		}
+	} else {
+		szText = pConsole->statusString();
+	}
+}
+
+
 KviTaskBarItem *  KviTaskBarBase::item(int number)
 {
 	KviTaskBarItem * it = firstItem();
@@ -114,13 +157,13 @@ void KviTaskBarBase::switchWindow(bool bNext,bool bInContextOnly)
 		{
 			if(bInContextOnly)
 			{
-				if(it->window()->console() == cons)
+				if(it->kviWindow()->console() == cons)
 				{
-					g_pFrame->setActiveWindow(it->window());
+					g_pFrame->setActiveWindow(it->kviWindow());
 					return;
 				}
 			} else {
-				g_pFrame->setActiveWindow(it->window());
+				g_pFrame->setActiveWindow(it->kviWindow());
 				return;
 			}
 		}
@@ -152,12 +195,14 @@ KviTaskBarItem::~KviTaskBarItem()
 
 
 KviTaskBarButton::KviTaskBarButton(QWidget * par,KviWindow * wnd,const char * name)
-: QWidget(par,name) , KviTaskBarItem(wnd)
+: QPushButton(par,name) , KviTaskBarItem(wnd)
 {
 	m_bActive         = false;
 	m_pTip            = new KviDynamicToolTip(this);
 	connect(m_pTip,SIGNAL(tipRequest(KviDynamicToolTip *,const QPoint &)),this,SLOT(tipRequest(KviDynamicToolTip *,const QPoint &)));
-	setBackgroundMode(QWidget::NoBackground);
+//	setBackgroundMode(QWidget::NoBackground);
+	setToggleButton (true);
+	setFlat ( KVI_OPTION_BOOL(KviOption_boolUseFlatClassicTaskbarButtons) );
 }
 
 KviTaskBarButton::~KviTaskBarButton()
@@ -177,9 +222,9 @@ void KviTaskBarButton::tipRequest(KviDynamicToolTip *,const QPoint &pnt)
 
 void KviTaskBarButton::mousePressEvent(QMouseEvent *e)
 {
-	if(e->button() & LeftButton)
+	if(e->button() & Qt::LeftButton)
 	{
-		if(e->state() & ShiftButton)
+		if(e->state() & Qt::ShiftButton)
 		{
 			m_pWindow->delayedClose();
 		} else {
@@ -211,79 +256,59 @@ void KviTaskBarButton::setActive(bool bActive)
 		}
 		m_bActive      = false;
 	}
+	setOn(bActive);
 	update();
 }
 
-static void draw_frame_helper(QPainter * p,int x1,int y1,int x2,int y2,QColor light,QColor dark)
-{
-	p->setPen(light);
-	p->drawLine(x1,y1,x2,y1);
-	p->drawLine(x1,y1,x1,y2);
-
-	p->setPen(dark);
-	p->drawLine(x1,y2,x2,y2);
-	p->drawLine(x2,y1,x2,y2);
-}
-
-//   ##################  #####################
-//   #@@@@@@@@@@@@@@@@@  #@@@@@@@@@@@@@@@@@@@@
-//   #@                  #@
-//   #@ ***********      #@ ************* <-|
-//   #@ ***********      #@ *************   |
-//   #@ ***********      #@ *************    16
-//   #@ ***********      #@ *************   |
-//   #@ ***********      #@ *************   |
-//   #@ ***********      #@ ************* <-|
-//   #@                  #@
-//   #@@@@@@@@@@@@@@@@@  #@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
-//   ##################  #++++++++++++++++++++   <-|
-//                       #+                        KVI_TASKBARBUTTON_CONTEXTINDICATORHEIGHT
-//                       #++++++++++++++++++++   <-|
-//                       ####################################
-//
-//
-//
-
-void KviTaskBarButton::paintEvent(QPaintEvent *e)
+#ifdef COMPILE_USE_QT4
+void KviTaskBarButton::paintEvent(QPaintEvent * e)
 {
 	QPainter p(this);
+	QStyleOption opt;
+	opt.initFrom(this);
+	if(isOn())
+		opt.state = QStyle::State_On | QStyle::State_Active;
+	style()->drawPrimitive(QStyle::PE_PanelButtonTool,&opt,&p,this);
+	drawButtonLabel(&p);
+}
+#endif
 
-	draw_frame_helper(&p,0,0,width() - 1,height() - 1,
-		m_pWindow->mdiParent() ? (m_bActive ? colorGroup().shadow() : colorGroup().midlight()) : colorGroup().background(),
-		m_pWindow->mdiParent() ? (m_bActive ? colorGroup().midlight() : colorGroup().shadow()) : colorGroup().background());
-
-	int h = height();
+void KviTaskBarButton::drawButtonLabel(QPainter * painter)
+{
+	QRect distRect = painter->window();
+	int iHeight = distRect.height();
+	int iWidth = distRect.width();
 
+	QPainter * pPainter;
+#ifdef COMPILE_USE_QT4
+	pPainter = painter;
+#else //!COMPILE_USE_QT4
+	KviDoubleBuffer db(iWidth,iHeight);
+	QPixmap * pMemBuffer = db.pixmap();
+	QPainter p(pMemBuffer);
+	bitBlt(pMemBuffer,0,0,painter->device(),distRect.x(),distRect.y(),iWidth,iHeight);
+	pPainter = &p;
+#endif //!COMPILE_USE_QT4
 	if(KVI_OPTION_BOOL(KviOption_boolUseTaskBarIrcContextIndicator))
 	{
-		h -= KVI_TASKBARBUTTON_CONTEXTINDICATORHEIGHT;
+		iHeight -= KVI_TASKBARBUTTON_CONTEXTINDICATORHEIGHT;
 		QColor base = colorGroup().background();
 		if(m_pWindow->console())
 		{
 			QColor cntx = KVI_OPTION_ICCOLOR(m_pWindow->console()->ircContextId() % KVI_NUM_ICCOLOR_OPTIONS);
 			base.setRgb((base.red() + cntx.red()) >> 1,(base.green() + cntx.green()) >> 1,
 				(base.blue() + cntx.blue()) >> 1);
-			p.fillRect(2,h,width() - 4,KVI_TASKBARBUTTON_CONTEXTINDICATORHEIGHT - 2,base);
+			pPainter->fillRect(2,iHeight,iWidth - 4,KVI_TASKBARBUTTON_CONTEXTINDICATORHEIGHT - 2,base);
 		} else {
-			p.fillRect(2,h,width() - 4,KVI_TASKBARBUTTON_CONTEXTINDICATORHEIGHT - 2,colorGroup().brush(QColorGroup::Background));
+			pPainter->fillRect(2,iHeight,iWidth - 4,KVI_TASKBARBUTTON_CONTEXTINDICATORHEIGHT - 2,colorGroup().brush(QColorGroup::Background));
 		}
-
-		draw_frame_helper(&p,1,h - 1,width() - 2,height() - 2,
-			m_bActive ? base.dark() : base.light(180),
-			m_bActive ? base.light(180) : base.dark());
 	}
 
-	draw_frame_helper(&p,1,1,width() - 2,h - 2,
-		m_bActive ? colorGroup().dark() : colorGroup().light(),
-		m_bActive ? colorGroup().light() : colorGroup().dark());
-
-	p.fillRect(2,2,width() - 4,h - 4,colorGroup().brush(QColorGroup::Background));
-
 	int daX = 3;
 
 	if(KVI_OPTION_BOOL(KviOption_boolUseTaskBarIcons))
 	{
-		p.drawPixmap(3,3,*(m_pWindow->myIconPtr()));
+		pPainter->drawPixmap(3,3,*(m_pWindow->myIconPtr()));
 		daX = 20;
 	}
 
@@ -293,20 +318,20 @@ void KviTaskBarButton::paintEvent(QPaintEvent *e)
 		unsigned int uActivityTemperature;
 		if(m_pWindow->activityMeter(&uActivityValue,&uActivityTemperature))
 		{
-			p.drawPixmap(daX,3,*g_pActivityMeterPixmap,uActivityValue * 5,uActivityTemperature * 16,5,16);
+			pPainter->drawPixmap(daX,3,*g_pActivityMeterPixmap,uActivityValue * 5,uActivityTemperature * 16,5,16);
 			daX = 27;
 		}
 	}
 
-	QRect cRect(daX,3,width() - (20 + daX),h - 6);
+	QRect cRect(daX,3,iWidth - (20 + daX),iHeight - 6);
 
 	if(m_iProgress >= 0)
 	{
 		// paint the progress bar
 		int wdth = (m_iProgress * cRect.width()) / 100;
-		p.setPen(KVI_OPTION_COLOR(KviOption_colorTaskBarProgressBar));
-		p.drawRect(cRect);
-		p.fillRect(daX,3,wdth,cRect.height(),KVI_OPTION_COLOR(KviOption_colorTaskBarProgressBar));
+		pPainter->setPen(KVI_OPTION_COLOR(KviOption_colorTaskBarProgressBar));
+		pPainter->drawRect(cRect);
+		pPainter->fillRect(daX,3,wdth,cRect.height(),KVI_OPTION_COLOR(KviOption_colorTaskBarProgressBar));
 	}
 
 	QRect bRect;
@@ -316,7 +341,7 @@ void KviTaskBarButton::paintEvent(QPaintEvent *e)
 
 	if(m_bActive)
 	{
-		p.setPen(KVI_OPTION_COLOR(KviOption_colorTaskBarNormalText));
+		pPainter->setPen(KVI_OPTION_COLOR(KviOption_colorTaskBarNormalText));
 	} else {
 		int iLevel;
 	
@@ -329,10 +354,10 @@ void KviTaskBarButton::paintEvent(QPaintEvent *e)
 			case 4: iLevel = KviOption_colorTaskBarHighlight4Text; break;
 			default: iLevel = KviOption_colorTaskBarHighlight5Text; break;
 		}
-		p.setPen(KVI_OPTION_COLOR(iLevel));
+		pPainter->setPen(KVI_OPTION_COLOR(iLevel));
 	}
 
-	p.setFont(KVI_OPTION_FONT(KviOption_fontTaskbar));
+	pPainter->setFont(KVI_OPTION_FONT(KviOption_fontTaskbar));
 
 	switch(m_pWindow->type())
 	{
@@ -340,10 +365,8 @@ void KviTaskBarButton::paintEvent(QPaintEvent *e)
 		{
 			QFont f = QFont(KVI_OPTION_FONT(KviOption_fontTaskbar));
 			f.setBold(true);
-			p.setFont(f);
-			if (((KviConsole *)m_pWindow)->isConnected())
-				szText = ((KviConsole *)m_pWindow)->connection()->currentServerName();
-			else szText = ((KviConsole *)m_pWindow)->statusString();
+			pPainter->setFont(f);
+			KviTaskBarBase::getTextForConsole(szText,(KviConsole *)m_pWindow);
 		}
 		break;
 		case KVI_WINDOW_TYPE_CHANNEL:
@@ -364,26 +387,30 @@ void KviTaskBarButton::paintEvent(QPaintEvent *e)
 		QString tmp = QChar('(');
 		tmp += szText;
 		tmp += QChar(')');
-		p.drawText(cRect,AlignLeft | AlignVCenter,tmp,-1,&bRect);
+		pPainter->drawText(cRect,Qt::AlignLeft | Qt::AlignTop,tmp,-1,&bRect);
 	} else {
-		p.drawText(cRect,AlignLeft | AlignVCenter,szText,-1,&bRect);
+		pPainter->drawText(cRect,Qt::AlignLeft | Qt::AlignTop,szText,-1,&bRect);
 	}
 
 	if(bRect.width() > cRect.width())
 	{
-		p.setClipRect(cRect.right(),cRect.y(),10,cRect.height());
-		QColor base = p.pen().color();
+		pPainter->setClipRect(cRect.right(),cRect.y(),10,cRect.height());
+		QColor base = pPainter->pen().color();
 		QColor bg   = colorGroup().color(QColorGroup::Background);
 		base.setRgb((base.red() + bg.red()) / 2,(base.green() + bg.green()) / 2,(base.blue() + bg.blue()) / 2);
-		p.setPen(base);
+		pPainter->setPen(base);
 		cRect.setWidth(cRect.width() + 10);
-		p.drawText(cRect,AlignLeft | AlignVCenter,szText,-1);
-		p.setClipRect(cRect.right(),cRect.y(),5,cRect.height());
+		pPainter->drawText(cRect,Qt::AlignLeft | Qt::AlignTop,szText,-1);
+		pPainter->setClipRect(cRect.right(),cRect.y(),5,cRect.height());
 		base.setRgb((base.red() + bg.red()) / 2,(base.green() + bg.green()) / 2,(base.blue() + bg.blue()) / 2);
-		p.setPen(base);
+		pPainter->setPen(base);
 		cRect.setWidth(cRect.width() + 10);
-		p.drawText(cRect,AlignLeft | AlignVCenter,szText,-1);
+		pPainter->drawText(cRect,Qt::AlignLeft | Qt::AlignTop,szText,-1);
 	}
+#ifndef COMPILE_USE_QT4
+	pPainter->setClipping(FALSE);
+	painter->drawPixmap(0,0,*pMemBuffer,distRect.x(),distRect.y(),iWidth,iHeight);
+#endif
 }
 
 
@@ -424,7 +451,7 @@ void KviTaskBarButton::highlight(int iLevel)
 //
 /*
 KviTaskBarToolTip::KviTaskBarToolTip(KviTaskBarButton * b)
-: QToolTip(b,0)
+: KviTalToolTip(b,0)
 {
 	m_pTaskBarButton = b;
 }
@@ -447,23 +474,34 @@ void KviTaskBarToolTip::maybeTip(const QPoint &pnt)
 KviClassicTaskBar::KviClassicTaskBar()
 : KviTaskBarBase()
 {
-	m_pButtonList = new KviPtrList<KviTaskBarButton>;
+	m_pButtonList = new KviPointerList<KviTaskBarButton>;
 	m_pButtonList->setAutoDelete(true);
 
 	calcButtonHeight();
 
 	m_pBase = new QWidget(this);
 //	m_pBase->setBackgroundMode(NoBackground);
+#ifdef COMPILE_USE_QT4
+	setWidget(m_pBase);
 
+	m_pBase->setMinimumWidth(KVI_TASKBAR_MIN_WIDTH);
+	setMinimumWidth(KVI_TASKBAR_MIN_WIDTH);
+#else //!COMPILE_USE_QT4
 	setStretchableWidget(m_pBase);
 
 	setVerticalStretchable(true);
 	setHorizontalStretchable(true);
+#endif //!COMPILE_USE_QT4
+	//m_pBase->setMinimumWidth(KVI_TASKBAR_MIN_WIDTH);
+	//setMinimumWidth(KVI_TASKBAR_MIN_WIDTH);
 
-	m_pBase->setMinimumWidth(KVI_TASKBAR_MIN_WIDTH);
-	setMinimumWidth(KVI_TASKBAR_MIN_WIDTH);
+	m_pBase->setMinimumHeight(m_iButtonHeight+5);
+	setMinimumHeight(m_iButtonHeight+5);
 	
+#ifndef COMPILE_USE_QT4
+	setResizeEnabled( true );
 	connect(this,SIGNAL(orientationChanged(Orientation)),this,SLOT(orientationChangedSlot(Orientation)));
+#endif
 }
 
 KviClassicTaskBar::~KviClassicTaskBar()
@@ -472,8 +510,11 @@ KviClassicTaskBar::~KviClassicTaskBar()
 	m_pButtonList = 0;
 }
 
-void KviClassicTaskBar::orientationChangedSlot(Orientation o)
+void KviClassicTaskBar::orientationChangedSlot(Qt::Orientation o)
 {
+#ifndef COMPILE_USE_QT4
+	if (orientation() == Qt::Horizontal) m_pBase->setMinimumHeight(m_iButtonHeight);
+#endif
 	doLayout();
 }
 
@@ -512,23 +553,23 @@ void KviClassicTaskBar::insertButton(KviTaskBarButton * b)
 		// first sort by irc context
 		for(KviTaskBarButton * btn = m_pButtonList->first();btn;btn = m_pButtonList->next())
 		{
-			if(btn->window()->console() == b->window()->console())
+			if(btn->kviWindow()->console() == b->kviWindow()->console())
 			{
 				// same irc context (or none)
 				// sort by type now
 				for(;btn;btn = m_pButtonList->next())
 				{
-					if((btn->window()->type() > b->window()->type()) ||
-						(btn->window()->console() != b->window()->console()))
+					if((btn->kviWindow()->type() > b->kviWindow()->type()) ||
+						(btn->kviWindow()->console() != b->kviWindow()->console()))
 					{
 						// greater type or another irc context
 						m_pButtonList->insert(idx,b);
 						return;
-					} else if(btn->window()->type() == b->window()->type())
+					} else if(btn->kviWindow()->type() == b->kviWindow()->type())
 					{
 						// same type!
 						// sort by name
-						if(!KVI_OPTION_BOOL(KviOption_boolSortTaskBarItemsByName) || (KviQString::cmpCI(btn->window()->windowName(),b->window()->windowName()) > 0))
+						if(!KVI_OPTION_BOOL(KviOption_boolSortTaskBarItemsByName) || (KviQString::cmpCI(btn->kviWindow()->windowName(),b->kviWindow()->windowName()) > 0))
 						{
 							// got a "higher one"
 							m_pButtonList->insert(idx,b);
@@ -541,10 +582,10 @@ void KviClassicTaskBar::insertButton(KviTaskBarButton * b)
 				m_pButtonList->append(b);
 				return;
 			} else {
-				if(!(btn->window()->console()) && b->window()->console())
+				if(!(btn->kviWindow()->console()) && b->kviWindow()->console())
 				{
 					// this must be a new console...insert before the contextless windows
-					__range_valid(b->window()->console() == b->window());
+					__range_valid(b->kviWindow()->console() == b->kviWindow());
 					m_pButtonList->insert(idx,b);
 					return;
 				} else idx++; // wrong irc contet...go on searching
@@ -563,25 +604,32 @@ KviTaskBarItem * KviClassicTaskBar::addItem(KviWindow * wnd)
 	b->show();
 	doLayout();
 	if(g_pFrame->dockExtension())g_pFrame->dockExtension()->refresh();
+/*	if(b->width() < m_pBase->width()) m_pBase->setMinimumWidth(b->width());
+	if(b->height() < m_pBase->height()) m_pBase->setMinimumWidth(b->height());*/
 	return b;
 }
 
 bool KviClassicTaskBar::removeItem(KviTaskBarItem * it)
 {
-	m_pButtonList->removeRef((KviTaskBarButton *)it);
-	doLayout();
-	if(g_pFrame->dockExtension())g_pFrame->dockExtension()->refresh();
+	if(it)
+	{
+		m_pButtonList->removeRef((KviTaskBarButton *)it);
+		doLayout();
+		if(g_pFrame->dockExtension())g_pFrame->dockExtension()->refresh();
+	}
 	return true;
 }
 
 void KviClassicTaskBar::setActiveItem(KviTaskBarItem * it)
 {
-	for(KviTaskBarButton * b = m_pButtonList->first();b;b = m_pButtonList->next())
+	if(it)
 	{
-		b->setActive(((KviTaskBarButton *)it) == b);
+		for(KviTaskBarButton * b = m_pButtonList->first();b;b = m_pButtonList->next())
+		{
+			b->setActive(((KviTaskBarButton *)it) == b);
+		}
+		if(g_pFrame->dockExtension())g_pFrame->dockExtension()->refresh();
 	}
-	if(g_pFrame->dockExtension())g_pFrame->dockExtension()->refresh();
-
 }
 
 
@@ -609,17 +657,40 @@ void KviClassicTaskBar::doLayout()
 		totCount -= btnsInRow;
 	}
 
-	if ((orientation() == Horizontal) &&
-		(((unsigned int)rows) > KVI_OPTION_UINT(KviOption_uintTaskBarMaximumRows)))
+#ifdef COMPILE_USE_QT4
+	if(isFloating() || ((g_pFrame->dockWidgetArea(this) != Qt::BottomDockWidgetArea) && (g_pFrame->dockWidgetArea(this) != Qt::TopDockWidgetArea)))
 	{
-		rows = KVI_OPTION_UINT(KviOption_uintTaskBarMaximumRows);
+		QDockWidget::DockWidgetFeatures f = features();
+		if(f & QDockWidget::DockWidgetVerticalTitleBar)
+		{
+			f &= ~QDockWidget::DockWidgetVerticalTitleBar;
+			setFeatures(f);
+		}
+	} else {
+		QDockWidget::DockWidgetFeatures f = features();
+		if(!(f & QDockWidget::DockWidgetVerticalTitleBar))
+		{
+			f |= QDockWidget::DockWidgetVerticalTitleBar;
+			setFeatures(f);
+		}
 	}
+#endif
 
+#ifdef COMPILE_USE_QT4
+	if ((width() > height()) && 
+#else
+	if ((orientation() == Qt::Horizontal) &&
+#endif
+		(((unsigned int)rows) > m_pBase->height() / m_iButtonHeight ))
+	{
+		rows = m_pBase->height() / m_iButtonHeight;
+	}
+	if(rows==0) rows=1;
 	totCount = m_pButtonList->count();
 	btnsInRow = totCount / rows;
 	if(totCount % rows)btnsInRow++;
 
-	m_pBase->setMinimumHeight(rows * m_iButtonHeight);
+	//m_pBase->setMinimumHeight(rows * m_iButtonHeight);
 
 	int theWidth      = 0;
 	int theX          = 0;
@@ -632,14 +703,21 @@ void KviClassicTaskBar::doLayout()
 		{
 			int inRow = ((totCount < btnsInRow ) ? totCount : btnsInRow);
 			theWidth = baseWidth / (inRow ? inRow : 1);
-			if( KVI_OPTION_BOOL(KviOption_boolClassicTaskBarSetMaximumButtonWidth) && (theWidth > KVI_OPTION_UINT(KviOption_uintClassicTaskBarMaximumButtonWidth)) && (orientation() == Horizontal))
-				theWidth = KVI_OPTION_UINT(KviOption_uintClassicTaskBarMaximumButtonWidth);
 			theX     = 0;
 			theY    += m_iButtonHeight;
 			btnInRow = 1;
 		} else {
 			if((btnInRow == btnsInRow) || (totCount == 1))theWidth = baseWidth - theX;
 		}
+		
+		if( KVI_OPTION_BOOL(KviOption_boolClassicTaskBarSetMaximumButtonWidth) && (theWidth > KVI_OPTION_UINT(KviOption_uintClassicTaskBarMaximumButtonWidth)) &&
+#ifdef COMPILE_USE_QT4
+				(width() > height())
+#else
+				(orientation() == Qt::Horizontal)
+#endif
+			)
+				theWidth = KVI_OPTION_UINT(KviOption_uintClassicTaskBarMaximumButtonWidth);
 
 		b->setGeometry(theX,theY,theWidth,m_iButtonHeight);
 
@@ -655,12 +733,27 @@ void KviClassicTaskBar::doLayout()
 
 void KviClassicTaskBar::applyOptions()
 {
+	for(KviTaskBarButton * b = m_pButtonList->first();b;b = m_pButtonList->next())
+	{
+		b->setFlat(KVI_OPTION_BOOL(KviOption_boolUseFlatClassicTaskbarButtons));
+	}
 	doLayout();
 }
 
 void KviClassicTaskBar::resizeEvent(QResizeEvent *e)
 {
-	QToolBar::resizeEvent(e);
+/*
+#ifdef COMPILE_USE_QT4
+	if(orientation() == Qt::Horizontal)
+	{
+		int iRows = height()/m_iButtonHeight;
+		if(!iRows) iRows=1;
+		debug("%i %i",height(),iRows);
+		resize(width(),iRows*m_iButtonHeight);
+	}
+#endif
+*/
+	KviTaskBarBase::resizeEvent(e);
 	doLayout();
 }
 
@@ -695,8 +788,8 @@ inline bool KviClassicTaskBar::setIterationPointer(KviTaskBarItem * it)
 //
 
 
-KviTreeTaskBarItem::KviTreeTaskBarItem(QListView * par,KviWindow * wnd)
-: QListViewItem(par) , KviTaskBarItem(wnd)
+KviTreeTaskBarItem::KviTreeTaskBarItem(KviTalListView * par,KviWindow * wnd)
+: KviTalListViewItem(par) , KviTaskBarItem(wnd)
 {
 	m_iStepNumber=0;
 	m_bIncreasing=0;
@@ -707,7 +800,7 @@ KviTreeTaskBarItem::KviTreeTaskBarItem(QListView * par,KviWindow * wnd)
 }
 
 KviTreeTaskBarItem::KviTreeTaskBarItem(KviTreeTaskBarItem * par,KviWindow * wnd)
-: QListViewItem(par) , KviTaskBarItem(wnd)
+: KviTalListViewItem(par) , KviTaskBarItem(wnd)
 {
 	m_iStepNumber=0;
 	m_bIncreasing=0;
@@ -725,7 +818,7 @@ int KviTreeTaskBarItem::calculateColor(int col1,int col2)
 
 KviTreeTaskBarItem::~KviTreeTaskBarItem()
 {
-	QListView* pView=listView();
+	KviTalListView* pView=(KviTalListView *)listView();
 	if(pView)
 		if(((KviTreeTaskBarListView*)(pView))->m_pPrevItem==this) ((KviTreeTaskBarListView*)(listView()))->m_pPrevItem=0;
 	delete m_pAnimTimer;
@@ -790,8 +883,13 @@ void KviTreeTaskBarItem::setActive(bool bActive)
 	}
 }
 
+#ifdef COMPILE_USE_QT4
+void KviTreeTaskBarItem::paintBranches(QPainter *p,const QColorGroup &,int w,int y,int h)
+#else
 void KviTreeTaskBarItem::paintBranches(QPainter *p,const QColorGroup &,int w,int y,int h,GUIStyle s)
+#endif
 {
+	SET_ANTI_ALIASING(*p);
 	((KviTreeTaskBarListView *)listView())->paintEmptyArea(p,QRect(0,y,w,totalHeight() - height()));
 }
 
@@ -800,6 +898,7 @@ void KviTreeTaskBarItem::paintCell(QPainter *painter,const QColorGroup &cg,int c
 	KviDoubleBuffer db(width,height());
 	QPixmap * pMemBuffer = db.pixmap();
 	QPainter p(pMemBuffer);
+	SET_ANTI_ALIASING(p);
 	
 	if(isSelected())
 	{
@@ -823,9 +922,9 @@ void KviTreeTaskBarItem::paintCell(QPainter *painter,const QColorGroup &cg,int c
 			{
 				QPoint pnt = listView()->viewportToContents(QPoint(int(painter->worldMatrix().dx()),int(painter->worldMatrix().dy())));
 				//p.drawTiledPixmap(0,0,width,height(),*pix,pnt.x(),pnt.y());
-				debug("%i %i",pnt.x(),pnt.y());
+//				debug("%i %i",pnt.x(),pnt.y());
 				p.translate(-pnt.x(),-pnt.y());
-				KviPixmapUtils::drawPixmapWithPainter(&p,pix,(Qt::AlignmentFlags)(KVI_OPTION_UINT(KviOption_uintTreeTaskBarPixmapAlign)),QRect(pnt.x(),pnt.y(),width,height()),listView()->width(),listView()->height());
+				KviPixmapUtils::drawPixmapWithPainter(&p,pix,KVI_OPTION_UINT(KviOption_uintTreeTaskBarPixmapAlign),QRect(pnt.x(),pnt.y(),width,height()),listView()->width(),listView()->height());
 				p.translate(pnt.x(),pnt.y());
 			}
 		} else {
@@ -858,7 +957,7 @@ void KviTreeTaskBarItem::paintCell(QPainter *painter,const QColorGroup &cg,int c
 				base.setRgb((base.red() + cntx.red()) >> 1,(base.green() + cntx.green()) >> 1,
 					(base.blue() + cntx.blue()) >> 1);
 				p.fillRect(im + 2,yPixmap + 1,14,15,base);
-				draw_frame_helper(&p,im + 1,yPixmap,im + 15,yPixmap + 15,base.light(180),base.dark());
+				//draw_frame_helper(&p,im + 1,yPixmap,im + 15,yPixmap + 15,base.light(180),base.dark());
 				if(KVI_OPTION_BOOL(KviOption_boolUseTaskBarIcons))
 				{
 					p.drawPixmap(im + 20,yPixmap,*(m_pWindow->myIconPtr()));
@@ -876,9 +975,7 @@ void KviTreeTaskBarItem::paintCell(QPainter *painter,const QColorGroup &cg,int c
 			QFont f = QFont();
 			f.setBold(true);
 			p.setFont(f);
-			if (((KviConsole *)m_pWindow)->isConnected())
-				   szText = ((KviConsole *)m_pWindow)->connection()->currentServerName();
-			else szText = ((KviConsole *)m_pWindow)->statusString();
+			KviTaskBarBase::getTextForConsole(szText,(KviConsole *)m_pWindow);
 		}
 		break;
 		case KVI_WINDOW_TYPE_CHANNEL:
@@ -955,9 +1052,9 @@ void KviTreeTaskBarItem::paintCell(QPainter *painter,const QColorGroup &cg,int c
 		QString tmp = QChar('(');
 		tmp += szText;
 		tmp += QChar(')');
-		p.drawText(cRect,AlignLeft | AlignVCenter,tmp,-1,0);
+		p.drawText(cRect,Qt::AlignLeft | Qt::AlignVCenter,tmp,-1,0);
 	} else {
-		p.drawText(cRect,AlignLeft | AlignVCenter,szText,-1,0);
+		p.drawText(cRect,Qt::AlignLeft | Qt::AlignVCenter,szText,-1,0);
 	}
 	
 	painter->drawPixmap(0,0,*pMemBuffer,0,0,width,height());
@@ -995,7 +1092,7 @@ void KviTreeTaskBarItem::mouseEnter()
 	{
 		m_bIncreasing=true;
 		if(!m_pAnimTimer->isActive()) m_pAnimTimer->start(KVI_TIMER_DELAY);
-	}
+ 	}
 }
 
 void KviTreeTaskBarItem::mouseLeave()
@@ -1014,7 +1111,7 @@ void KviTreeTaskBarItem::mouseLeave()
 
 
 KviTreeTaskBarListView::KviTreeTaskBarListView(QWidget * par)
-: QListView(par,"ttblistview")
+: KviTalListView(par)
 {
 	//setSorting(0);
 	setShowSortIndicator(true);
@@ -1022,7 +1119,7 @@ KviTreeTaskBarListView::KviTreeTaskBarListView(QWidget * par)
 	setFrameShape(NoFrame);
 	viewport()->setMouseTracking(TRUE);
 	m_pPrevItem=0;
-	setHScrollBarMode(QScrollView::AlwaysOff);
+	setHScrollBarMode(KviTalListView::AlwaysOff);
 }
 
 KviTreeTaskBarListView::~KviTreeTaskBarListView()
@@ -1035,31 +1132,53 @@ void KviTreeTaskBarListView::contentsMouseMoveEvent ( QMouseEvent * e )
 	KviTreeTaskBarItem* pCur=(KviTreeTaskBarItem*)(itemAt(contentsToViewport(e->pos())));
 	if(pCur!=m_pPrevItem)
 	{
-		if(m_pPrevItem) m_pPrevItem->mouseLeave();
+		if(m_pPrevItem)m_pPrevItem->mouseLeave();
 		if(pCur) pCur->mouseEnter();
+		setCursor(Qt::PointingHandCursor);
 		m_pPrevItem=pCur;
+	} else if(!pCur) {
+		setCursor(Qt::ArrowCursor);
 	}
 }
 void KviTreeTaskBarListView::leaveEvent(QEvent *)
 {
 	if(m_pPrevItem) m_pPrevItem->mouseLeave();
 	m_pPrevItem=0;
+	setCursor(Qt::ArrowCursor);
 }
 
 
 void KviTreeTaskBarListView::contentsMousePressEvent(QMouseEvent *e)
 {
-	QListViewItem * it = itemAt(contentsToViewport(e->pos()));
+	KviTalListViewItem * it = (KviTalListViewItem *)itemAt(contentsToViewport(e->pos()));
 	if(it)
 	{
-		if(e->button() & LeftButton)emit leftMousePress(it);
-		else if(e->button() & RightButton)emit rightMousePress(it);
+		if(e->button() & Qt::LeftButton)emit leftMousePress(it);
+		else if(e->button() & Qt::RightButton)emit rightMousePress(it);
+	} else {
+		if(e->button() & Qt::RightButton)
+		{
+			KviTalPopupMenu* pPopup=new KviTalPopupMenu();
+			pPopup->insertItem(__tr2qs("Sort"),this,SLOT(sort()));
+			pPopup->insertItem(__tr2qs("Reverse Sort"),this,SLOT(reverseSort()));
+			pPopup->popup(QCursor::pos());
+		}
 	}
 }
 
+void KviTreeTaskBarListView::sort()
+{
+	setSorting(0,TRUE);
+}
+
+void KviTreeTaskBarListView::reverseSort()
+{
+	setSorting(0,FALSE);
+}
+
 void KviTreeTaskBarListView::resizeEvent(QResizeEvent *e)
 {
-	QListView::resizeEvent(e);
+	KviTalListView::resizeEvent(e);
 	setColumnWidth(0,viewport()->width());
 	resizeContents(viewport()->width(),contentsHeight());
 }
@@ -1071,6 +1190,7 @@ void KviTreeTaskBarListView::resizeEvent(QResizeEvent *e)
 
 void KviTreeTaskBarListView::paintEmptyArea(QPainter * p,const QRect &rct)
 {
+	SET_ANTI_ALIASING(*p);
 #ifdef COMPILE_PSEUDO_TRANSPARENCY
 	if(g_pShadedChildGlobalDesktopBackground)
 	{
@@ -1088,7 +1208,7 @@ void KviTreeTaskBarListView::paintEmptyArea(QPainter * p,const QRect &rct)
 	{
 		QPoint pnt = viewportToContents(QPoint(rct.x() + int(p->worldMatrix().dx()),rct.y() + int(p->worldMatrix().dy())));
 		//p->drawTiledPixmap(rct.x(),rct.y(),rct.width(),rct.height(),*pix,pnt.x(),pnt.y());
-		KviPixmapUtils::drawPixmapWithPainter(p,pix,(Qt::AlignmentFlags)(KVI_OPTION_UINT(KviOption_uintTreeTaskBarPixmapAlign)),rct,viewport()->width(),viewport()->height(),pnt.x(),pnt.y());
+		KviPixmapUtils::drawPixmapWithPainter(p,pix,KVI_OPTION_UINT(KviOption_uintTreeTaskBarPixmapAlign),rct,viewport()->width(),viewport()->height(),pnt.x(),pnt.y());
 	}
 }
 
@@ -1103,10 +1223,16 @@ KviTreeTaskBar::KviTreeTaskBar()
 	m_pListView->addColumn(__tr2qs("Window List"),135);
 	m_pListView->setAllColumnsShowFocus(true);
 	m_pListView->setMultiSelection(false);
+
+#ifdef COMPILE_USE_QT4
+	setWidget(m_pListView);
+#else //!COMPILE_USE_QT4
 	setStretchableWidget(m_pListView);
 
 	setVerticalStretchable(true);
 	setHorizontalStretchable(true);
+#endif //!COMPILE_USE_QT4
+
 
 	// FIXME: this code is useless ?
 	if(KVI_OPTION_UINT(KviOption_uintTreeTaskBarMinimumWidth) < 48)
@@ -1122,17 +1248,34 @@ KviTreeTaskBar::KviTreeTaskBar()
 	//setMaximumWidth(KVI_OPTION_UINT(KviOption_uintTreeTaskBarMaximumWidth));
 	//m_pListView->setMinimumWidth(KVI_OPTION_UINT(KviOption_uintTreeTaskBarMinimumWidth));
     //m_pListView->setMaximumWidth(KVI_OPTION_UINT(KviOption_uintTreeTaskBarMaximumWidth));
+#ifdef COMPILE_USE_QT4
+	m_pListView->setFocusPolicy(Qt::NoFocus);
+#else
 	m_pListView->setFocusPolicy(QWidget::NoFocus);
+#endif
 	m_pListView->setStaticBackground(true);
+#ifdef COMPILE_USE_QT4
+	m_pListView->viewport()->setAutoFillBackground(false);
+#else
 	m_pListView->viewport()->setBackgroundMode(QWidget::NoBackground);
-	m_pListView->header()->setResizeEnabled(true); 
+#endif
+	if(!KVI_OPTION_BOOL(KviOption_boolShowTreeTaskbarHeader))
+	{
+		m_pListView->header()->hide();
+	} 
+	
+	m_pListView->header()->setResizeEnabled(true);
 
-	//setMaximumWidth(600);
+#ifdef COMPILE_USE_QT4
+	setMaximumWidth(600);
+#endif
 
 	m_pListView->viewport()->installEventFilter(this);
 
 #if QT_VERSION >= 300
+#ifndef COMPILE_USE_QT4
     setResizeEnabled(true);
+#endif
 #endif
 
 	m_pToolTip = new KviDynamicToolTip(m_pListView->viewport(),"tree_taskbar_tooltip");
@@ -1161,7 +1304,7 @@ void KviTreeTaskBar::tipRequest(KviDynamicToolTip *,const QPoint &pnt)
 {
 	if(KVI_OPTION_BOOL(KviOption_boolShowTaskBarToolTips))
 	{
-		QListViewItem * it = m_pListView->itemAt(pnt);
+		KviTalListViewItem * it = (KviTalListViewItem *)m_pListView->itemAt(pnt);
 		if(it)
 		{
 			QString szText;
@@ -1180,19 +1323,21 @@ bool KviTreeTaskBar::eventFilter(QObject * o,QEvent *e)
 			QMouseEvent * ev = (QMouseEvent *)e;
 			KviTreeTaskBarItem * it = (KviTreeTaskBarItem *)m_pListView->itemAt(ev->pos());
 			if(!it)return false;
-			KviWindow * wnd = it->window();
-			if(!wnd)return true;
-			if(ev->button() & LeftButton)
+			KviWindow * wnd = it->kviWindow();
+			if(wnd)
 			{
-				if(ev->state() & ShiftButton)
+				if(ev->button() & Qt::LeftButton)
 				{
-					wnd->delayedClose();
+					if(ev->state() & Qt::ShiftButton)
+					{
+						wnd->delayedClose();
+					} else {
+						if((g_pActiveWindow != wnd) || (wnd->isMinimized()))g_pFrame->setActiveWindow(wnd);
+						else wnd->minimize();
+					}
 				} else {
-					if((g_pActiveWindow != wnd) || (wnd->isMinimized()))g_pFrame->setActiveWindow(wnd);
-					else wnd->minimize();
+					wnd->contextPopup();
 				}
-			} else {
-				wnd->contextPopup();
 			}
 			return true;
 		}
@@ -1200,6 +1345,7 @@ bool KviTreeTaskBar::eventFilter(QObject * o,QEvent *e)
 	return false;
 }
 
+
 KviTaskBarItem * KviTreeTaskBar::addItem(KviWindow * wnd)
 {
 	// complex insertion task
@@ -1224,18 +1370,21 @@ bool KviTreeTaskBar::removeItem(KviTaskBarItem * it)
 
 void KviTreeTaskBar::setActiveItem(KviTaskBarItem * it)
 {
-	KviTreeTaskBarItem * cur = (KviTreeTaskBarItem *)m_pListView->currentItem();
-	if(cur && (cur != (KviTreeTaskBarItem *)it))
+	if(it)
 	{
-		cur->setActive(false);
+		KviTreeTaskBarItem * cur = (KviTreeTaskBarItem *)m_pListView->currentItem();
+		if(cur && (cur != (KviTreeTaskBarItem *)it))
+		{
+			cur->setActive(false);
+		}
+		if(((KviTreeTaskBarItem *)it)->parent())
+		{
+			if(!((KviTreeTaskBarItem *)it)->parent()->isOpen())((KviTreeTaskBarItem *)it)->parent()->setOpen(true);
+		}
+		((KviTreeTaskBarItem *)it)->setActive(true);
+		m_pListView->setSelected(((KviTreeTaskBarItem *)it),true); // this MUST go after it->setActive()
+		if(g_pFrame->dockExtension())g_pFrame->dockExtension()->refresh();
 	}
-	if(((KviTreeTaskBarItem *)it)->parent())
-	{
-		if(!((KviTreeTaskBarItem *)it)->parent()->isOpen())((KviTreeTaskBarItem *)it)->parent()->setOpen(true);
-	}
-	((KviTreeTaskBarItem *)it)->setActive(true);
-	m_pListView->setSelected(((KviTreeTaskBarItem *)it),true); // this MUST go after it->setActive()
-	if(g_pFrame->dockExtension())g_pFrame->dockExtension()->refresh();
 }
 
 void KviTreeTaskBar::updateActivityMeter()
@@ -1341,7 +1490,7 @@ bool KviTreeTaskBar::setIterationPointer(KviTaskBarItem * it)
 {
 	m_pCurrentItem = (KviTreeTaskBarItem *)it;
 	if(!it)return true;
-	if(((QListView *)m_pListView) == ((KviTreeTaskBarItem *)it)->listView())return true;
+	if(((KviTalListView *)m_pListView) == ((KviTreeTaskBarItem *)it)->listView())return true;
 	m_pCurrentItem = 0;
 	return false;
 }
@@ -1349,6 +1498,12 @@ bool KviTreeTaskBar::setIterationPointer(KviTaskBarItem * it)
 void KviTreeTaskBar::applyOptions()
 {
 	m_pListView->update();
+	if(!KVI_OPTION_BOOL(KviOption_boolShowTreeTaskbarHeader))
+	{
+		m_pListView->header()->hide();
+	} else {
+		m_pListView->header()->show();
+	}
 }
 
 #include "kvi_taskbar.moc"
