@@ -26,12 +26,11 @@
 
 #include "kvi_settings.h"
 
-#include "kvi_toolbar.h"
-
-#include "kvi_list.h"
+#include "kvi_pointerlist.h"
 #include <qframe.h>
-#include <qtooltip.h>
-#include <qlistview.h>
+#include "kvi_tal_tooltip.h"
+#include "kvi_tal_listview.h"
+#include <qpushbutton.h>
 
 
 
@@ -39,6 +38,7 @@ class KviWindow;
 class KviFrame;
 class QPixmap;
 class KviDynamicToolTip;
+class KviConsole;
 
 //
 // KviTaskBarItem
@@ -57,7 +57,7 @@ protected:
 	int         m_iHighlightLevel;
 	int         m_iProgress;
 public:
-	KviWindow * window(){ return m_pWindow; };
+	KviWindow * kviWindow(){ return m_pWindow; };
 	virtual void captionChanged(){};
 	virtual void highlight(int iLevel = 1){};
 	virtual void setProgress(int progress){};
@@ -74,9 +74,38 @@ public:
 // This is the basic interface that all the external classes should see
 //
 
+// Please note that Qt3 moc skips the  *_SKIP_BEGIN -> *_SKIP_END blocks
+// while the Qt4 moc skips the Q_MOC_RUN ifdef block.. so...
+
+// Qt4 version
+
+// If you get failures (undefined references) in some non-autotools based
+// build system that uses Qt4 then you must add the -DCOMPILE_USE_QT4
+// commandline parameter to moc (at leat) when parsing this file.
+
+// MOC_SKIP_BEGIN
+#ifdef COMPILE_USE_QT4
+
+#include <QDockWidget>
+
+class KVIRC_API KviTaskBarBase : public QDockWidget
+{
+	Q_OBJECT
+#endif //COMPILE_USE_QT4
+// MOC_SKIP_END
+
+// Qt3 version
+#ifndef Q_MOC_RUN
+#ifndef COMPILE_USE_QT4
+
+#include "kvi_toolbar.h"
+
 class KVIRC_API KviTaskBarBase : public KviToolBar
 {
 	Q_OBJECT
+#endif
+#endif
+
 public:
 	KviTaskBarBase();
 	virtual ~KviTaskBarBase();
@@ -96,6 +125,7 @@ public:
 	virtual void switchWindow(bool bNext,bool bInContextOnly);
 	virtual void updatePseudoTransparency(){};
 	virtual void applyOptions(){};
+	static void getTextForConsole(QString &szText,KviConsole * pConsole);
 protected slots:
 	virtual void updateActivityMeter();
 };
@@ -108,7 +138,7 @@ protected slots:
 
 class KviClassicTaskBar;
 
-class KVIRC_API KviTaskBarButton : public QWidget , KviTaskBarItem
+class KVIRC_API KviTaskBarButton : public QPushButton , KviTaskBarItem
 {
 	friend class KviClassicTaskBar;
 	Q_OBJECT
@@ -123,7 +153,10 @@ protected:
 #if QT_VERSION >= 300
 	virtual void contextMenuEvent(QContextMenuEvent *e);
 #endif
-	virtual void paintEvent(QPaintEvent *e);
+	virtual void drawButtonLabel(QPainter *p);
+#ifdef COMPILE_USE_QT4
+	virtual void paintEvent(QPaintEvent * e);
+#endif
 public:
 	virtual bool active(){ return m_bActive; };
 	virtual void highlight(int iLevel = 1);
@@ -144,7 +177,7 @@ public:
 	KviClassicTaskBar();
 	~KviClassicTaskBar();
 protected:
-	KviPtrList<KviTaskBarButton> * m_pButtonList;
+	KviPointerList<KviTaskBarButton> * m_pButtonList;
 	int                       m_iButtonHeight;
 	QWidget                 * m_pBase;
 protected:
@@ -166,19 +199,19 @@ public:
 	virtual void updateActivityMeter();
 	virtual void applyOptions();
 protected slots:
-	void orientationChangedSlot(Orientation o);
+	void orientationChangedSlot(Qt::Orientation o);
 };
 
 class KviTreeTaskBar;
 class KviTreeTaskBarItemInternal;
 
-class KVIRC_API KviTreeTaskBarItem : public QListViewItem , public KviTaskBarItem
+class KVIRC_API KviTreeTaskBarItem : public KviTalListViewItem , public KviTaskBarItem
 {
 	friend class KviTreeTaskBar;
 	friend class KviTreeTaskBarListView;
 	friend class KviTreeTaskBarItemInternal;
 public:
-	KviTreeTaskBarItem(QListView * par,KviWindow * wnd);
+	KviTreeTaskBarItem(KviTalListView * par,KviWindow * wnd);
 	KviTreeTaskBarItem(KviTreeTaskBarItem * par,KviWindow * wnd);
 	~KviTreeTaskBarItem();
 protected:
@@ -192,7 +225,11 @@ protected:
 public:
 	virtual QString key(int column,bool) const;
 	virtual void paintCell(QPainter *p,const QColorGroup &cg,int column,int width,int alignment);
+#ifdef COMPILE_USE_QT4
+	virtual void paintBranches(QPainter *p,const QColorGroup &cg,int w,int y,int h);
+#else
 	virtual void paintBranches(QPainter *p,const QColorGroup &cg,int w,int y,int h,GUIStyle s);
+#endif
 	virtual void captionChanged();
 	virtual void highlight(int iLevel = 1);
 	virtual void unhighlight();
@@ -219,7 +256,7 @@ public slots:
 	void timerShot() { m_pItem->timerShot();};	
 };
 
-class KVIRC_API KviTreeTaskBarListView : public QListView
+class KVIRC_API KviTreeTaskBarListView : public KviTalListView
 {
 	friend class KviTreeTaskBarItem;
 	Q_OBJECT
@@ -234,8 +271,11 @@ protected:
 	virtual void contentsMouseMoveEvent ( QMouseEvent * e );
 	virtual void leaveEvent(QEvent *);
 signals:
-	void leftMousePress(QListViewItem * it);
-	void rightMousePress(QListViewItem * it);
+	void leftMousePress(KviTalListViewItem * it);
+	void rightMousePress(KviTalListViewItem * it);
+public slots:
+	void sort();
+	void reverseSort();
 };
 
 
