@@ -27,13 +27,13 @@
 #include "kvi_settings.h"
 #include "kvi_string.h"
 
-#include <qiconview.h>
+#include "kvi_tal_iconview.h"
 
 
 #define KVI_TEXTICON_WIN_WIDTH 230
 #define KVI_TEXTICON_WIN_HEIGHT 200
 
-class KVIRC_API KviTextIconWindow : public QIconView
+class KVIRC_API KviTextIconWindow : public KviTalIconView
 {
 	Q_OBJECT
 public:
@@ -45,6 +45,7 @@ private:
 	QString         m_szCurFullSeq;
 	bool            m_bAltMode; // in alt mode the itemSelected() string contains
 	                            // also the CTRL+I escape code
+	int             m_iTimerId;
 public:
 	void popup(QWidget *owner,bool bAltMode = false);
 private:
@@ -57,7 +58,7 @@ private:
 public slots:
 	void fill();
 	void ownerDead();
-	void itemSelected(QIconViewItem * item);
+	void itemSelected(KviTalIconViewItem * item);
 };
 
 #endif //_KVI_TEXTICONWIN_H_
