@@ -40,7 +40,11 @@ private:
 	QString m_szText;
 	bool    m_bAutoHeight;
 protected:
+#ifdef COMPILE_USE_QT4
+	virtual void paintEvent ( QPaintEvent * event );
+#else
 	virtual void drawContents(QPainter *p);
+#endif
 	virtual void mouseDoubleClickEvent(QMouseEvent *e);
 public:
 	int dummyRead() const { return 0; };
