@@ -48,12 +48,13 @@ static int g_iInputFontCharWidth[256];
 
 #include <qpainter.h>
 #include <qfontmetrics.h>
-#include <qtooltip.h>
+#include "kvi_tal_tooltip.h"
 #include <qlineedit.h>
-#include <qlistbox.h>
+#include "kvi_tal_listbox.h"
 #include <qregexp.h>
 #include <qclipboard.h>
-#include <qpopupmenu.h>
+#include "kvi_tal_popupmenu.h"
+#include <qevent.h>
 
 // FIXME: #warning "The combo should disappear when it looses focus!...(how to do it ?)"
 
@@ -65,7 +66,7 @@ static int g_iInputFontCharWidth[256];
 
 extern QStringList  * g_pRecentTopicList;
 
-int KviListBoxTopicItem::width ( const QListBox * lb )
+int KviListBoxTopicItem::width ( const KviTalListBox * lb ) const
 {
 	QFontMetrics fm(lb->font());
 	return fm.width(KviMircCntrl::stripControlBytes(text()));
@@ -88,13 +89,21 @@ KviTopicWidget::KviTopicWidget(QWidget * par,const char * name)
 	m_pContextPopup = 0;
 	m_iCursorPosition = 0;
 	m_pInput = 0;
+#ifdef COMPILE_USE_QT4
+	setAutoFillBackground(false);
+#else
 	setBackgroundMode(QWidget::NoBackground);
+#endif
 	reset();
-	m_pCompletionBox=new QListBox(this,"m_pCompletionBox",Qt::WType_Popup);
+#ifdef COMPILE_USE_QT4
+	m_pCompletionBox=new KviTalListBox(this,Qt::Popup);
+#else
+	m_pCompletionBox=new KviTalListBox(this,Qt::WType_Popup);
+#endif
 	m_pCompletionBox->setFont( font() );
 	m_pCompletionBox->setPalette( palette() );
-//	m_pCompletionBox->setVScrollBarMode( QListBox::AlwaysOff );
-//	m_pCompletionBox->setHScrollBarMode( QListBox::AlwaysOff );
+//	m_pCompletionBox->setVScrollBarMode( KviTalListBox::AlwaysOff );
+//	m_pCompletionBox->setHScrollBarMode( KviTalListBox::AlwaysOff );
 	m_pCompletionBox->setFrameStyle( QFrame::Box | QFrame::Plain );
 	m_pCompletionBox->setLineWidth( 1 );
 	connect(m_pCompletionBox,SIGNAL(selected(int)),this,SLOT(complete(int)));
@@ -114,9 +123,9 @@ void KviTopicWidget::popDownListBox()
 
 void KviTopicWidget::reset()
 {
-	QToolTip::remove(this);
+	KviTalToolTip::remove(this);
 	m_szTopic = __tr2qs("Unknown");
-	QToolTip::add(this,__tr2qs("No topic message has been received from the server yet"));
+	KviTalToolTip::add(this,__tr2qs("No topic message has been received from the server yet"));
 	m_szSetAt = "";
 	m_szSetBy = "";
 	update();
@@ -132,6 +141,137 @@ void KviTopicWidget::applyOptions()
 #define KVI_LABEL_DEF_BACK 100
 #define KVI_LABEL_DEF_FORE 101
 
+QString convertToHtml(const QString &text)
+{
+	QString result;
+	bool curBold      = false;
+	bool curUnderline = false;
+	unsigned char curFore      = KVI_LABEL_DEF_FORE; //default fore
+	unsigned char curBack      = KVI_LABEL_DEF_BACK; //default back
+
+	unsigned int idx = 0;
+
+	while(idx < text.length())
+	{
+		unsigned short c = text[(int)idx].unicode();
+
+		unsigned int start = idx;
+
+		while(
+				(c != KVI_TEXT_COLOR) &&
+				(c != KVI_TEXT_BOLD) &&
+				(c != KVI_TEXT_UNDERLINE) &&
+				(c != KVI_TEXT_REVERSE) &&
+				(c != KVI_TEXT_RESET) &&
+				(c != KVI_TEXT_ICON)
+			)
+		{
+			idx++;
+			if(idx >= text.length())break;
+			else c = text[(int)idx].unicode();
+		}
+		
+		int len = idx - start;
+
+		if(len > 0)
+		{
+			bool bOpened = FALSE;
+			QString szText = text.mid(start,len);
+			
+			if(curBold) result.append("<b>");
+			if(curUnderline) result.append("<u>");
+			
+			if(curFore != KVI_LABEL_DEF_FORE)
+			{
+				result.append("<font color=\"");
+				result.append(KVI_OPTION_MIRCCOLOR(curFore).name());
+				result.append('"');
+				bOpened = TRUE;
+			}
+		
+/*			if(curBack != KVI_LABEL_DEF_BACK)
+			{
+				if(!bOpened) 
+					result.append("<font bgcolor=");
+				else
+					result.append(" bgcolor=");
+				result.append(KVI_OPTION_MIRCCOLOR(curBack).name());
+			}*/
+
+			if(bOpened) result.append(">");
+
+			result.append(text.mid(start,len));
+
+			if( (curFore != KVI_LABEL_DEF_FORE) /*|| (curBack != KVI_LABEL_DEF_BACK)*/ )
+				result.append("</font>");
+
+			if(curUnderline) result.append("</u>");
+			if(curBold) result.append("</b>");
+
+		}
+
+		switch(c)
+		{
+			case KVI_TEXT_BOLD: curBold = !curBold; ++idx; break;
+			case KVI_TEXT_UNDERLINE: curUnderline = !curUnderline; ++idx; break;
+			case KVI_TEXT_REVERSE:
+				{
+					char auxBack = curBack;
+					curBack = curFore;
+					curFore = auxBack;
+				}
+				++idx;
+			break;
+			case KVI_TEXT_RESET:
+				curFore = KVI_LABEL_DEF_FORE;
+				curBack = KVI_LABEL_DEF_BACK;
+				curBold = false;
+				curUnderline = false;
+				++idx;
+			break;
+			case KVI_TEXT_COLOR:
+			{
+				++idx;
+				unsigned char fore;
+				unsigned char back;
+				idx = getUnicodeColorBytes(text,idx,&fore,&back);
+				if(fore != KVI_NOCHANGE)
+				{
+					curFore = fore;
+					if(back != KVI_NOCHANGE)curBack = back;
+				} else {
+					// only a CTRL+K
+					curBack = KVI_LABEL_DEF_BACK;
+					curFore = KVI_LABEL_DEF_FORE;
+				}
+			}
+			break;
+			case KVI_TEXT_ICON:
+			{
+				++idx;
+
+				unsigned int icoStart = idx;
+				while((idx < text.length()) && (text[(int)idx].unicode() > 32))idx++;
+
+				KviStr lookupString = text.mid(icoStart,idx - icoStart);
+
+				KviTextIcon * icon = g_pTextIconManager->lookupTextIcon(lookupString.ptr());
+				if(icon)
+				{
+					//TODO: icons
+/*					QPixmap * pigzmap = icon->pixmap();
+					p->drawPixmap(curX,(baseline + 2) - pigzmap->height(),*(pigzmap));
+					curX += pigzmap->width();*/
+				} else {
+					idx = icoStart;
+				}
+			}
+			break;
+		}
+	}
+	return result;
+}
+
 void KviTopicWidget::paintColoredText(QPainter *p, QString text,const QColorGroup& cg,int height, int width)
 {
 	QFontMetrics fm(p->font());
@@ -271,6 +411,15 @@ void KviTopicWidget::paintColoredText(QPainter *p, QString text,const QColorGrou
 	}
 }
 
+#ifdef COMPILE_USE_QT4
+void KviTopicWidget::paintEvent(QPaintEvent * e)
+{
+	QPainter pa(this);
+	drawFrame(&pa);
+	drawContents(&pa);
+}
+#endif
+
 void KviTopicWidget::drawContents(QPainter *p)
 {
 #ifdef COMPILE_PSEUDO_TRANSPARENCY
@@ -334,7 +483,7 @@ void KviTopicWidget::setTopicSetAt(const QString & setAt)
 
 void KviTopicWidget::updateToolTip()
 {
-	QToolTip::remove(this);
+	KviTalToolTip::remove(this);
 
 	QString txt = "<html>" \
 			"<body>" \
@@ -342,21 +491,21 @@ void KviTopicWidget::updateToolTip()
 
 	if(!m_szTopic.isEmpty())
 	{
-		txt +=          "<tr><td bgcolor=\"#303030\">" \
-							"<font color=\"#FFFFFF\"><b>";
+		txt +=          START_TABLE_BOLD_ROW;
 		txt += __tr2qs("Channel topic:");
-		txt +=              "</b></font>" \
-						"</td></tr>";
+		txt +=              END_TABLE_BOLD_ROW;
 
-		txt +=          "<tr><td><center><br>";
+		txt +=          "<tr><td><center>";
 
-		QString tmp = KviMircCntrl::stripControlBytes(m_szTopic);
+		QString tmp = m_szTopic;
+		
 		tmp.replace('&',"&amp;");
 		tmp.replace('<',"&lt;");
 		tmp.replace('>',"&gt;");
+		tmp = convertToHtml(tmp);
 		
 		txt += tmp;
-		txt +=          "</center><br><br></td></tr>";
+		txt +=          "</center></td></tr>";
 		
 		if(!m_szSetBy.isEmpty())
 		{
@@ -389,7 +538,7 @@ void KviTopicWidget::updateToolTip()
 		"</body>" \
 	"<html>";
 
-	QToolTip::add(this,txt);
+	KviTalToolTip::add(this,txt);
 }
 
 QSize KviTopicWidget::sizeHint() const
@@ -435,7 +584,7 @@ void KviTopicWidget::mouseDoubleClickEvent(QMouseEvent *)
 		m_pHistory = new QPushButton(this);
 		m_pHistory->setPixmap(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_TIME)));
 		m_pHistory->setGeometry(width() - (height() << 2)+height(),0,height(),height());
-		QToolTip::add(m_pHistory,__tr2qs("History"));
+		KviTalToolTip::add(m_pHistory,__tr2qs("History"));
 		m_pHistory->show();
 		connect(m_pHistory,SIGNAL(clicked()),this,SLOT(historyClicked()));
 		
@@ -444,13 +593,13 @@ void KviTopicWidget::mouseDoubleClickEvent(QMouseEvent *)
 		m_pAccept->setGeometry(width() - (height() << 1),0,height(),height());
 		m_pAccept->setEnabled(bCanEdit);
 		m_pAccept->show();
-		QToolTip::add(m_pAccept,__tr2qs("Commit Changes"));
+		KviTalToolTip::add(m_pAccept,__tr2qs("Commit Changes"));
 		connect(m_pAccept,SIGNAL(clicked()),this,SLOT(acceptClicked()));
 		
 		m_pDiscard = new QPushButton(this);
 		m_pDiscard->setPixmap(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_DISCARD)));
 		m_pDiscard->setGeometry(width() - height(),0,height(),height());
-		QToolTip::add(m_pDiscard,__tr2qs("Discard Changes"));
+		KviTalToolTip::add(m_pDiscard,__tr2qs("Discard Changes"));
 		m_pDiscard->show();
 		connect(m_pDiscard,SIGNAL(clicked()),this,SLOT(discardClicked()));
 		
@@ -462,10 +611,10 @@ void KviTopicWidget::mouseDoubleClickEvent(QMouseEvent *)
 void KviTopicWidget::mousePressEvent(QMouseEvent * e)
 {
 
-	if(!(e->button() & RightButton))return;
+	if(!(e->button() & Qt::RightButton))return;
 	if(!m_pContextPopup)
 	{
-		m_pContextPopup = new QPopupMenu(this);
+		m_pContextPopup = new KviTalPopupMenu(this);
 		connect(m_pContextPopup,SIGNAL(aboutToShow()),this,SLOT(contextPopupAboutToShow()));
 	}
 	m_pContextPopup->popup(mapToGlobal(e->pos()));
@@ -513,12 +662,12 @@ bool KviTopicWidget::eventFilter(QObject *object,QEvent *e)
 			break;
 		case QEvent::KeyPress:
 			switch( ((QKeyEvent *)e)->key() ) {
-			case Key_Up:
-			case Key_Down:
-				if ( !(((QKeyEvent *)e)->state() & AltButton) )
+			case Qt::Key_Up:
+			case Qt::Key_Down:
+				if ( !(((QKeyEvent *)e)->state() & Qt::AltButton) )
 				break;
-			case Key_F4:
-			case Key_Escape:
+			case Qt::Key_F4:
+			case Qt::Key_Escape:
 				if ( m_pCompletionBox->isVisible() ) {
 				popDownListBox();
 				return TRUE;
