@@ -29,7 +29,7 @@
 
 #include <qframe.h>
 #include <qpushbutton.h>
-#include <qlistbox.h> 
+#include "kvi_tal_listbox.h" 
 
 #include "kvi_string.h"
 #include "kvi_app.h"
@@ -37,15 +37,15 @@
 
 class QComboBox;
 class KviChannel;
-class QPopupMenu;
+class KviTalPopupMenu;
 class KviIrcConnection;
-class QListBox;
+class KviTalListBox;
 
-class KVIRC_API KviListBoxTopicItem : public QListBoxText
+class KVIRC_API KviListBoxTopicItem : public KviTalListBoxText
 {
 public:
-	KviListBoxTopicItem( QListBox * listbox = 0 , const QString & text = QString::null):QListBoxText(listbox,text) { ; };
-	virtual int width ( const QListBox * lb );
+	KviListBoxTopicItem( KviTalListBox * listbox = 0 , const QString & text = QString::null):KviTalListBoxText(listbox,text) { ; };
+	virtual int width ( const KviTalListBox * lb ) const;
 protected:
 	virtual void paint ( QPainter * p );
 
@@ -68,11 +68,11 @@ private:
 	QPushButton * m_pAccept;
 	QPushButton * m_pDiscard;
 	QPushButton * m_pHistory;
-	QPopupMenu  * m_pContextPopup;
+	KviTalPopupMenu  * m_pContextPopup;
 	QChar getSubstituteChar(unsigned short control_code);
 	int xCursorPostionCalculation(int xInd);
 	KviInputEditor* m_pInput;
-	QListBox* 	m_pCompletionBox;
+	KviTalListBox* 	m_pCompletionBox;
 protected:
 	int  m_iCursorPosition;
 	virtual void drawContents(QPainter *p);
@@ -80,6 +80,9 @@ protected:
 	virtual void mousePressEvent(QMouseEvent *e);
 	virtual void keyPressEvent(QKeyEvent *e);
 	virtual void resizeEvent(QResizeEvent *e);
+#ifdef COMPILE_USE_QT4
+	virtual void paintEvent(QPaintEvent * e);
+#endif
 	void updateToolTip();
 	void deactivate();
 	void iconButtonClicked();
