@@ -46,6 +46,7 @@
 #include "kvi_doublebuffer.h"
 #include "kvi_stringconversion.h"
 #include "kvi_ircconnection.h"
+#include "kvi_ircconnectionserverinfo.h"
 
 #include <qlabel.h>
 #include <qscrollbar.h>
@@ -54,13 +55,13 @@
 #include <qfontmetrics.h>
 #include <qdatetime.h>
 #include <qmime.h>
+#include "kvi_styled_controls.h"
+#include <qevent.h>
 
 #ifdef COMPILE_PSEUDO_TRANSPARENCY
 	extern QPixmap * g_pShadedChildGlobalDesktopBackground;
 #endif
 
-// kvi_app.cpp
-extern KviRegisteredUserDataBase * g_pRegisteredUserDataBase;
 
 // kvi_app.cpp (loaded and destroyed by KviIconManager)
 extern QPixmap * g_pUserChanStatePixmap;
@@ -73,7 +74,7 @@ extern QPixmap * g_pUserChanStatePixmap;
 // FIXME: #warning "We want to be able to navigate the list with the keyboard!"
 
 KviUserListToolTip::KviUserListToolTip(KviUserListView * v,KviUserListViewArea * a)
-: QToolTip(a,0)
+: KviTalToolTip(a)
 {
 	m_pListView = v;
 }
@@ -115,13 +116,12 @@ bool KviUserListEntry::color(QColor& color)
 	//
 	// FIXME: Unused ?
 	//
-	KviRegisteredUser* pRegisteredUser=g_pRegisteredUserDataBase->findMatchingUser(m_szNick,m_pGlobalData->user(),m_pGlobalData->host());
+	KviRegisteredUser* pRegisteredUser=m_pListView->m_pKviWindow->connection()->userDataBase()->registeredUser(m_szNick);
 	if(pRegisteredUser)
 	{
-		if(pRegisteredUser->getBoolProperty("useCustomColor"))
+		if(m_pListView->m_pKviWindow->connection()->userDataBase()->haveCustomColor(m_szNick))
 		{
-			QString szTmp=pRegisteredUser->getProperty("customColor");
-			KviStringConversion::fromString(szTmp,color);
+			color=*(m_pListView->m_pKviWindow->connection()->userDataBase()->customColor(m_szNick));
 			return true;
 		}
 	}
@@ -153,7 +153,7 @@ void KviUserListEntry::recalcSize()
 {
 	KviAvatar * av = m_pGlobalData->avatar();
 	m_iHeight = m_pListView->m_iFontHeight;
-	if(KVI_OPTION_BOOL(KviOption_boolShowUserChannelIcons) && (m_iHeight < 22))m_iHeight = 22;
+	if(KVI_OPTION_BOOL(KviOption_boolShowUserChannelIcons) && (m_iHeight < 20))m_iHeight = 20;
 	
 	if(!KVI_OPTION_BOOL(KviOption_boolDisableAvatars))//G&N  2005
 	{
@@ -185,15 +185,15 @@ void KviUserListEntry::recalcSize()
 
 
 KviUserListView::KviUserListView(QWidget * parent,KviWindowToolPageButton* button,KviIrcUserDataBase * db,KviWindow * pWnd,int dictSize,const QString & label_text,const char * name)
-: KviWindowToolWidget(parent,button,name)
+: KviWindowToolWidget(parent,button)
 {
 	setAutoDelete(0);
 	m_pKviWindow  = pWnd;
-	m_pEntryDict  = new QDict<KviUserListEntry>(dictSize,false);
+	m_pEntryDict  = new KviPointerHashTable<QString,KviUserListEntry>(dictSize,false);
 	m_pEntryDict->setAutoDelete(true);
 
 	m_pUsersLabel = new QLabel(this,"userslabel");
-	QToolTip::add(m_pUsersLabel,label_text);
+	KviTalToolTip::add(m_pUsersLabel,label_text);
 
 	m_pViewArea   = new KviUserListViewArea(this);
 	m_pToolTip    = new KviUserListToolTip(this,m_pViewArea);
@@ -307,6 +307,13 @@ void KviUserListView::applyOptions()
 	resizeEvent(0); // this will call update() too
 	repaint();
 }
+void KviUserListView::updateArea()
+{
+	bool bEnable = m_pViewArea->isUpdatesEnabled();
+	if(!bEnable) m_pViewArea->setUpdatesEnabled(true);
+	triggerUpdate();
+	if(!bEnable) m_pViewArea->setUpdatesEnabled(false);
+}
 
 void KviUserListView::enableUpdates(bool bEnable)
 {
@@ -331,7 +338,7 @@ void KviUserListView::setMaskEntries(char type, int num)
 	updateUsersLabel();
 }
 
-void KviUserListView::completeNickBashLike(const QString &begin,KviPtrList<QString> *l,bool bAppendMask)
+void KviUserListView::completeNickBashLike(const QString &begin,KviPointerList<QString> *l,bool bAppendMask)
 {
 	KviUserListEntry * entry = m_pHeadItem;
 
@@ -607,23 +614,11 @@ KviUserListEntry * KviUserListView::join(const QString &nick,const QString &user
 		it = new KviUserListEntry(this,nick,pGlobalData,iFlags,(user == QString::null));
 		insertUserEntry(nick,it);
 	} else {
-		if(host != QString::null)
-		{
-			// Bad luck...we must be out of sync , or the server got drunk
-// FIXME: #warning "DO SOMETHING REASONABLE HERE!"
-		} else {
+//		if(!host.isEmpty()) - it can be UHNAMES with host or NAMEX(X) w/o it
+//		{
 			// Ok...the user was already on...
-			// Probably this is a NAMES reply , and the user IS_ME
+			// Probably this is a NAMES(X) reply , and the user IS_ME
 			// (already joined after the JOIN message)
-//			if((bOp && (!(it->m_iFlags & KVI_USERFLAG_OP))) || ((!bOp) && (it->m_iFlags & KVI_USERFLAG_OP)) )
-//			{
-//				// WE WANT A LOGICAL XOR! :))))
-//				op(nick,bOp);
-//			}
-//			if((bVoice && (!(it->m_iFlags & KVI_USERFLAG_VOICE))) || ((!bVoice) && (it->m_iFlags & KVI_USERFLAG_VOICE)) )
-//			{
-//				voice(nick,bVoice);
-//			}
 			if(iFlags != it->m_iFlags)
 			{
 //// FIXME: #warning "Maybe say to the channel that we're oped : and the op is guessed from the names reply"
@@ -634,7 +629,7 @@ KviUserListEntry * KviUserListView::join(const QString &nick,const QString &user
 				if((iFlags & KVI_USERFLAG_VOICE) != (it->m_iFlags & KVI_USERFLAG_VOICE))voice(nick,iFlags & KVI_USERFLAG_VOICE);
 				if((iFlags & KVI_USERFLAG_USEROP) != (it->m_iFlags & KVI_USERFLAG_USEROP))userop(nick,iFlags & KVI_USERFLAG_USEROP);
 			}
-		}
+//		}
 	}
 	return it;
 }
@@ -843,16 +838,7 @@ int KviUserListView::getUserModeLevel(const QString &szNick)
 char KviUserListView::getUserFlag(KviUserListEntry * e)
 {
 	if(!e)return 0;
-	if(e->m_iFlags & KVI_USERFLAG_MODEMASK)
-	{
-		if(e->m_iFlags & KVI_USERFLAG_CHANOWNER)return '~';
-		if(e->m_iFlags & KVI_USERFLAG_CHANADMIN)return '!';
-		if(e->m_iFlags & KVI_USERFLAG_OP)return '@';
-		if(e->m_iFlags & KVI_USERFLAG_HALFOP)return '%';
-		if(e->m_iFlags & KVI_USERFLAG_VOICE)return '+';
-		if(e->m_iFlags & KVI_USERFLAG_USEROP)return '-';
-	}
-	return 0;
+	return (char)m_pKviWindow->connection()->serverInfo()->modePrefixChar(e->m_iFlags).unicode();
 }
 
 void KviUserListView::prependUserFlag(const QString &nick,QString &buffer)
@@ -956,6 +942,26 @@ void KviUserListView::appendSelectedNicknames(QString &buffer)
 	}
 }
 
+void KviUserListView::select(const QString& nick){
+	KviPointerHashTableIterator<QString,KviUserListEntry> it(*m_pEntryDict);
+	while(it.current())
+	{
+		((KviUserListEntry *)it.current())->m_bSelected = false;
+		++it;
+	}
+
+	KviUserListEntry * entry = m_pEntryDict->find(nick);
+	if(entry)
+	{
+		entry->m_bSelected = true;
+		m_iSelectedCount = 1;
+	} else {
+		m_iSelectedCount = 0;
+	}
+	g_pFrame->childWindowSelectionStateChange(m_pKviWindow,true);
+	m_pViewArea->update();
+}
+
 bool KviUserListView::partInternal(const QString &nick,bool bRemove)
 {
 	KviUserListEntry * it = m_pEntryDict->find(nick);
@@ -1033,9 +1039,13 @@ bool KviUserListView::nickChange(const QString &oldNick,const QString &newNick)
 		kvi_time_t joint  = it->m_joinTime;
 		bool bSelect      = it->m_bSelected;
 		KviAvatar * av    = it->m_pGlobalData->forgetAvatar();
+		KviIrcUserEntry::Gender gender = it->m_pGlobalData->gender();
+		bool bBot = it->m_pGlobalData->isBot();
 		part(oldNick);
 		__range_invalid(m_pEntryDict->find(oldNick));
 		it = join(newNick,user,host,iFlags);
+		it->m_pGlobalData->setGender(gender);
+		it->m_pGlobalData->setBot(bBot);
 		it->m_joinTime = joint;
 		it->m_lastActionTime = kvi_unixTime();
 		it->m_bSelected = bSelect;
@@ -1075,7 +1085,7 @@ void KviUserListView::updateUsersLabel()
 void KviUserListView::partAllButOne(const QString &whoNot)
 {
 	QStringList ll;
-	QDictIterator<KviUserListEntry> it(*m_pEntryDict);
+	KviPointerHashTableIterator<QString,KviUserListEntry> it(*m_pEntryDict);
 	while(it.current())
 	{
 		if(!KviQString::equalCI(whoNot,it.currentKey()))
@@ -1090,7 +1100,7 @@ void KviUserListView::partAllButOne(const QString &whoNot)
 
 void KviUserListView::removeAllEntries()
 {
-	QDictIterator<KviUserListEntry> it(*m_pEntryDict);
+	KviPointerHashTableIterator<QString,KviUserListEntry> it(*m_pEntryDict);
 	while(it.current())
 	{
 		m_pIrcUserDataBase->removeUser(it.currentKey(),
@@ -1299,8 +1309,16 @@ KviUserListViewArea::KviUserListViewArea(KviUserListView * par)
 : QWidget(par)
 {
 	m_pListView = par;
+#ifdef COMPILE_USE_QT4
+	setAutoFillBackground(false);
+#else
 	setBackgroundMode(QWidget::NoBackground);
+#endif
+#ifdef COMPILE_USE_QT4
+	m_pScrollBar = new QScrollBar(Qt::Vertical,this,"scrollbar");
+#else
 	m_pScrollBar = new QScrollBar(QScrollBar::Vertical,this,"scrollbar");
+#endif
 	m_pScrollBar->setRange(0,0);
 	m_pScrollBar->setValue(0);
 	connect(m_pScrollBar,SIGNAL(valueChanged(int)),this,SLOT(scrollBarMoved(int)));
@@ -1400,8 +1418,13 @@ void KviUserListViewArea::paintEvent(QPaintEvent *ev)
 	QPixmap * pMemBuffer = db.pixmap();
 
 	QPainter p(pMemBuffer);
+	SET_ANTI_ALIASING(p);
 	p.setFont(KVI_OPTION_FONT(KviOption_fontUserListView));
 
+#ifdef COMPILE_USE_QT4
+	QFontMetrics fm(p.fontMetrics());
+#endif
+
 #ifdef COMPILE_PSEUDO_TRANSPARENCY
 	if(g_pShadedChildGlobalDesktopBackground)
 	{
@@ -1409,17 +1432,14 @@ void KviUserListViewArea::paintEvent(QPaintEvent *ev)
 		p.drawTiledPixmap(r.left(),r.top(),r.width(),r.height(),*g_pShadedChildGlobalDesktopBackground,pnt.x(),pnt.y());
 	} else {
 #endif
+		QPixmap *pix = KVI_OPTION_PIXMAP(KviOption_pixmapUserListViewBackground).pixmap();
 		p.fillRect(r.left(),r.top(),r.width(),r.height(),KVI_OPTION_COLOR(KviOption_colorUserListViewBackground));
+		if(pix)
+			KviPixmapUtils::drawPixmapWithPainter(&p,pix,KVI_OPTION_UINT(KviOption_uintUserListPixmapAlign),r,width(),height());
 #ifdef COMPILE_PSEUDO_TRANSPARENCY
 	}
 #endif
 
-	QPixmap *pix=KVI_OPTION_PIXMAP(KviOption_pixmapUserListViewBackground).pixmap();
-	if(pix)
-	{
-		KviPixmapUtils::drawPixmapWithPainter(&p,pix,(Qt::AlignmentFlags)(KVI_OPTION_UINT(KviOption_uintUserListPixmapAlign)),r,width(),height());
-	}
-
 	KviUserListEntry * e = m_pListView->m_pTopItem;
 
 	int theY = KVI_USERLIST_BORDER_WIDTH - m_iTopItemOffset;
@@ -1428,6 +1448,7 @@ void KviUserListViewArea::paintEvent(QPaintEvent *ev)
 
 	bool bShowIcons = KVI_OPTION_BOOL(KviOption_boolShowUserChannelIcons);
 	bool bShowState = KVI_OPTION_BOOL(KviOption_boolShowUserChannelState);
+	bool bShowGender = KVI_OPTION_BOOL(KviOption_boolDrawGenderIcons);
 	
 	while(e && theY <= r.bottom())
 	{
@@ -1459,16 +1480,9 @@ void KviUserListViewArea::paintEvent(QPaintEvent *ev)
 				// if we REALLY need to use custom colors for regged users then
 				// they should be updated ONCE and stored (cached) in the KviUserListEntry structure
 				//
-				KviRegisteredUser* pRegisteredUser=g_pRegisteredUserDataBase->findMatchingUser(e->m_szNick,e->m_pGlobalData->user(),e->m_pGlobalData->host());
-				if(pRegisteredUser)
+				if(m_pListView->m_pKviWindow->connection()->userDataBase()->haveCustomColor(e->m_szNick))
 				{
-					if(pRegisteredUser->getBoolProperty("useCustomColor"))
-					{
-						pClrFore = new QColor();
-						QString szTmp=pRegisteredUser->getProperty("customColor");
-						KviStringConversion::fromString(szTmp,(*pClrFore));
-						bColorAllocated=1; // bool is true or false
-					}
+					pClrFore = m_pListView->m_pKviWindow->connection()->userDataBase()->customColor(e->m_szNick);
 				}
 				if(!pClrFore)
 				{
@@ -1490,8 +1504,9 @@ void KviUserListViewArea::paintEvent(QPaintEvent *ev)
 	
 			int iAvatarAndTextX = theX;
 	
-			if(bShowState)iAvatarAndTextX += 11;
+			if(bShowGender)iAvatarAndTextX += 11;
 			if(bShowIcons)iAvatarAndTextX += 18;
+			if(bShowState)iAvatarAndTextX += 11;
 
 			if(KVI_OPTION_BOOL(KviOption_boolUserListViewDrawGrid))
 			{
@@ -1501,7 +1516,11 @@ void KviUserListViewArea::paintEvent(QPaintEvent *ev)
 					case KVI_USERLISTVIEW_GRIDTYPE_PLAINGRID:
 					case KVI_USERLISTVIEW_GRIDTYPE_DOTGRID:
 						p.setPen(QPen(KVI_OPTION_COLOR(KviOption_colorUserListViewGrid),0,
+#ifdef COMPILE_USE_QT4
+							(KVI_OPTION_UINT(KviOption_uintUserListViewGridType) == KVI_USERLISTVIEW_GRIDTYPE_DOTGRID) ? Qt::DotLine : Qt::SolidLine));
+#else
 							(KVI_OPTION_UINT(KviOption_uintUserListViewGridType) == KVI_USERLISTVIEW_GRIDTYPE_DOTGRID) ? QPen::DotLine : QPen::SolidLine));
+#endif
 						p.drawLine(0,bottom - 1,wdth,bottom - 1);
 						if(bShowState || bShowIcons)
 							p.drawLine(iAvatarAndTextX,bottom - 1,iAvatarAndTextX,theY);
@@ -1554,8 +1573,24 @@ void KviUserListViewArea::paintEvent(QPaintEvent *ev)
 						pix=av->pixmap();
 					p.drawPixmap(iAvatarAndTextX,theY,*pix);
 					theY += pix->height() + 1;
+				}
 			}
+
+			if(bShowGender)
+			{
+				if(e->globalData()->gender()!=KviIrcUserEntry::Unknown)
+				{
+					QPixmap * ico = g_pIconManager->getBigIcon((e->globalData()->gender()==KviIrcUserEntry::Male) ? "kvi_icon_male.png" : "kvi_icon_female.png");
+					p.drawPixmap(theX,theY+(m_pListView->m_iFontHeight-11)/2,*ico);
+				}
+				if(e->globalData()->isBot())
+				{
+					QPixmap * ico = g_pIconManager->getBigIcon("kvi_icon_bot.png");
+					p.drawPixmap(theX,theY+(m_pListView->m_iFontHeight-11)/2,*ico);
+				}
+				theX +=11;
 			}
+
 			if(bShowState)
 			{
 				if(e->m_lastActionTime)
@@ -1622,7 +1657,7 @@ void KviUserListViewArea::paintEvent(QPaintEvent *ev)
 				}
 				theX += 11;
 			}
-	
+			
 			if(bShowIcons)
 			{
 				//p.drawRect(theX,theY + 2,18,e->m_iHeight - 4);
@@ -1648,18 +1683,36 @@ void KviUserListViewArea::paintEvent(QPaintEvent *ev)
 													KVI_SMALLICON_VOICE : KVI_SMALLICON_USEROP)))) \
 												) \
 										);
-					p.drawPixmap(theX,theY,*ico);
+#ifdef COMPILE_USE_QT4
+					p.drawPixmap(theX,theY+(fm.lineSpacing()-16/*size of small icon*/)/2,*ico);
+#else
+					p.drawPixmap(theX,theY+(m_pListView->m_iFontHeight-16/*size of small icon*/)/2,*ico);
+#endif
 				}
-				p.drawText(iAvatarAndTextX,theY,wdth - theX,m_pListView->m_iFontHeight,AlignLeft|AlignVCenter,e->m_szNick);
+				theX +=18;
+#ifdef COMPILE_USE_QT4
+				p.drawText(iAvatarAndTextX,theY,wdth - theX,fm.lineSpacing(),Qt::AlignLeft|Qt::AlignVCenter,e->m_szNick);
+#else
+				p.drawText(iAvatarAndTextX,theY,wdth - theX,m_pListView->m_iFontHeight,Qt::AlignLeft|Qt::AlignVCenter,e->m_szNick);
+#endif
 			} else {
+
 				char flag = m_pListView->getUserFlag(e);
 				if(flag)
 				{
 					QString ttt = QChar(flag);
 					ttt += e->m_szNick;
-					p.drawText(iAvatarAndTextX,theY,wdth - theX,m_pListView->m_iFontHeight,AlignLeft|AlignVCenter,ttt);
+#ifdef COMPILE_USE_QT4
+					p.drawText(iAvatarAndTextX,theY,wdth - theX,fm.lineSpacing(),Qt::AlignLeft|Qt::AlignVCenter,ttt);
+#else
+					p.drawText(iAvatarAndTextX,theY,wdth - theX,m_pListView->m_iFontHeight,Qt::AlignLeft|Qt::AlignVCenter,ttt);
+#endif
 				} else {
-					p.drawText(iAvatarAndTextX,theY,wdth - theX,m_pListView->m_iFontHeight,AlignLeft|AlignVCenter,e->m_szNick);
+#ifdef COMPILE_USE_QT4
+					p.drawText(iAvatarAndTextX,theY,wdth - theX,fm.lineSpacing(),Qt::AlignLeft|Qt::AlignVCenter,e->m_szNick);
+#else
+					p.drawText(iAvatarAndTextX,theY,wdth - theX,m_pListView->m_iFontHeight,Qt::AlignLeft|Qt::AlignVCenter,e->m_szNick);
+#endif
 				}
 			}
 			if(bColorAllocated) delete pClrFore;
@@ -1669,14 +1722,22 @@ void KviUserListViewArea::paintEvent(QPaintEvent *ev)
 		e = e->m_pNext;
 	}
 
-	p.setPen(colorGroup().dark());
-	p.drawLine(0,0,wdth,0);
-	p.drawLine(0,0,0,height());
-	p.setPen(colorGroup().light());
-	p.drawLine(1,height()-1,wdth,height()-1);
-	p.drawLine(wdth - 1,1,wdth - 1,height());
+	//we really do not need any self-draw borders. 
+	//if we will need it, we will draw a better one with system style
 
+	//p.setPen(colorGroup().dark());
+	//p.drawLine(0,0,wdth,0);
+	//p.drawLine(0,0,0,height());
+	//p.setPen(colorGroup().light());
+	//p.drawLine(1,height()-1,wdth,height()-1);
+	//p.drawLine(wdth - 1,1,wdth - 1,height());
+
+#ifdef COMPILE_USE_QT4
+	QPainter qt4SuxBecauseOfThisAdditionalPainter(this);
+	qt4SuxBecauseOfThisAdditionalPainter.drawPixmap(r.left(),r.top(),r.width(),r.height(),*pMemBuffer,r.left(),r.top(),r.width(),r.height());
+#else
 	bitBlt(this,r.left(),r.top(),pMemBuffer,r.left(),r.top(),r.width(),r.height(),Qt::CopyROP,false);
+#endif
 }
 
 void KviUserListViewArea::resizeEvent(QResizeEvent *)
@@ -1690,19 +1751,19 @@ void KviUserListViewArea::resizeEvent(QResizeEvent *)
 void KviUserListViewArea::mousePressEvent(QMouseEvent *e)
 {
 	setFocus();
-	if(e->button() & LeftButton)
+	if(e->button() & Qt::LeftButton)
 	{
 		KviUserListEntry * entry = m_pListView->itemAt(e->pos());
 		if(entry)
 		{
-			if(e->state() & ShiftButton)
+			if(e->state() & Qt::ShiftButton)
 			{
 				// Multiselect mode
 				if(!entry->m_bSelected)m_pListView->m_iSelectedCount++;
 				entry->m_bSelected = true;
 				if(m_pListView->m_iSelectedCount == 1)g_pFrame->childWindowSelectionStateChange(m_pListView->m_pKviWindow,true);
 				update();
-			} else if(e->state() & ControlButton)
+			} else if(e->state() & Qt::ControlButton)
 			{
 				// Invert mode
 				if(!entry->m_bSelected)m_pListView->m_iSelectedCount++;
@@ -1731,14 +1792,24 @@ void KviUserListViewArea::mousePressEvent(QMouseEvent *e)
 			}
 		}
 		m_pLastEntryUnderMouse = entry;
-	} else if(e->button() & RightButton)
+	} else if(e->button() & Qt::RightButton)
 	{
 		KviUserListEntry * entry = m_pListView->itemAt(e->pos());
 		if(entry)
 		{
-			if(!entry->m_bSelected)m_pListView->m_iSelectedCount++;
-			entry->m_bSelected = true;
-			if(m_pListView->m_iSelectedCount == 1)g_pFrame->childWindowSelectionStateChange(m_pListView->m_pKviWindow,true);
+			if(!entry->m_bSelected){
+				entry->m_bSelected = true;
+				m_pListView->m_iSelectedCount=1;
+				KviPointerHashTableIterator<QString,KviUserListEntry> it(*(m_pListView->m_pEntryDict));
+				while(it.current())
+				{
+					if(it.current()!=entry)
+						((KviUserListEntry *)it.current())->m_bSelected = false;
+					++it;
+				}
+			}
+			if(m_pListView->m_iSelectedCount == 1)
+				g_pFrame->childWindowSelectionStateChange(m_pListView->m_pKviWindow,true);
 			update();
 		}
 		m_pListView->emitRightClick();
@@ -1746,38 +1817,44 @@ void KviUserListViewArea::mousePressEvent(QMouseEvent *e)
 }
 void KviUserListViewArea::keyPressEvent( QKeyEvent * e )
 {
-	QString szKey=e->text();
-	if(!szKey.isEmpty())
+	if(e->key()==Qt::Key_Escape)
 	{
-		KviUserListEntry * nick=0;
-		KviUserListEntry * aux = m_pListView->m_pHeadItem;
-		while(aux)
+		if(m_pListView->m_pKviWindow->input())
+			((QWidget*)(m_pListView->m_pKviWindow->input()))->setFocus();
+	} else {
+		QString szKey=e->text();
+		if(!szKey.isEmpty())
 		{
-			//debug("%s %s %i %s %i",__FILE__,__FUNCTION__,__LINE__,aux->nick().utf8().data(),aux->nick().find(szKey,0,0));
-			if(aux->nick().find(szKey,0,0)==0) 
+			KviUserListEntry * nick=0;
+			KviUserListEntry * aux = m_pListView->m_pHeadItem;
+			while(aux)
 			{
-				nick=aux;
-				break;
-			}
-			aux = aux->m_pNext;
-		}
-		if(nick)
-		{
-			bool bThereWasSelection = false;
-			if(m_pListView->m_iSelectedCount > 0)
-			{
-				aux = m_pListView->m_pHeadItem;
-				while(aux)
+				//debug("%s %s %i %s %i",__FILE__,__FUNCTION__,__LINE__,aux->nick().utf8().data(),aux->nick().find(szKey,0,0));
+				if(aux->nick().find(szKey,0,0)==0) 
 				{
-					aux->m_bSelected = false;
-					aux = aux->m_pNext;
+					nick=aux;
+					break;
 				}
-				bThereWasSelection = true;
+				aux = aux->m_pNext;
+			}
+			if(nick)
+			{
+				bool bThereWasSelection = false;
+				if(m_pListView->m_iSelectedCount > 0)
+				{
+					aux = m_pListView->m_pHeadItem;
+					while(aux)
+					{
+						aux->m_bSelected = false;
+						aux = aux->m_pNext;
+					}
+					bThereWasSelection = true;
+				}
+				nick->m_bSelected = true;
+				m_pListView->m_iSelectedCount = 1;
+				if(!bThereWasSelection)g_pFrame->childWindowSelectionStateChange(m_pListView->m_pKviWindow,true);
+				update();
 			}
-			nick->m_bSelected = true;
-			m_pListView->m_iSelectedCount = 1;
-			if(!bThereWasSelection)g_pFrame->childWindowSelectionStateChange(m_pListView->m_pKviWindow,true);
-			update();
 		}
 	}
 }
@@ -1789,12 +1866,12 @@ void KviUserListViewArea::mouseDoubleClickEvent(QMouseEvent *e)
 
 void KviUserListViewArea::mouseMoveEvent(QMouseEvent *e)
 {
-	if(e->state() & LeftButton)
+	if(e->state() & Qt::LeftButton)
 	{
 		KviUserListEntry * entry = m_pListView->itemAt(e->pos());
 		if(entry && (entry != m_pLastEntryUnderMouse))
 		{
-			if(e->state() & ControlButton)
+			if(e->state() & Qt::ControlButton)
 			{
 				if(entry->m_bSelected)m_pListView->m_iSelectedCount--;
 				else m_pListView->m_iSelectedCount++;
@@ -1819,7 +1896,7 @@ void KviUserListViewArea::mouseMoveEvent(QMouseEvent *e)
 					m_pScrollBar->setValue(m_pScrollBar->value() - top->m_iHeight);
 					if(m_pListView->m_pTopItem != top)
 					{
-						if(e->state() & ControlButton)
+						if(e->state() & Qt::ControlButton)
 						{
 							if(m_pListView->m_pTopItem->m_bSelected)m_pListView->m_iSelectedCount--;
 							else m_pListView->m_iSelectedCount++;
@@ -1852,7 +1929,7 @@ void KviUserListViewArea::mouseMoveEvent(QMouseEvent *e)
 						m_pScrollBar->setValue(m_pScrollBar->value() + bottom->m_iHeight);
 						if(bottom != m_pLastEntryUnderMouse)
 						{
-							if(e->state() & ControlButton)
+							if(e->state() & Qt::ControlButton)
 							{
 								if(bottom->m_bSelected)m_pListView->m_iSelectedCount--;
 								else m_pListView->m_iSelectedCount++;
@@ -1881,7 +1958,15 @@ void KviUserListViewArea::mouseReleaseEvent(QMouseEvent *)
 
 void KviUserListViewArea::wheelEvent(QWheelEvent *e)
 {
+#ifdef COMPILE_USE_QT4
+	static bool bHere = false; // Qt4(<= 4.2.2) has a nasty bug that makes the re-sent wheelEvent to cause infinite recursion
+	if(bHere)return;
+	bHere = true;
+#endif
 	g_pApp->sendEvent(m_pScrollBar,e);
+#ifdef COMPILE_USE_QT4
+	bHere = false;
+#endif
 }
 
 #include "kvi_userlistview.moc"
