@@ -4,7 +4,7 @@
 //   Creation date : Tue Jul 6 1999 14:52:11 by Szymon Stefanek
 //
 //   This file is part of the KVirc irc client distribution
-//   Copyright (C) 1999-2000 Szymon Stefanek (pragma at kvirc dot net)
+//   Copyright (C) 1999-2007 Szymon Stefanek (pragma at kvirc dot net)
 //
 //   This program is FREE software. You can redistribute it and/or
 //   modify it under the terms of the GNU General Public License
@@ -54,24 +54,27 @@
 #include "kvi_kvs_script.h"
 
 #include <qpixmap.h>
-#include <qpopupmenu.h>
+#include "kvi_tal_popupmenu.h"
 #include <qcursor.h>
 #include <qtimer.h>
 #include <qsplitter.h>
 #include <qmetaobject.h>
 #include <qdatetime.h>
 #include <qtextcodec.h>
+#include <qevent.h>
 
-#if QT_VERSION >= 0x030005
-        #include <qobjectlist.h>
+// it looks they can't decide :D
+#ifdef COMPILE_USE_QT4
+	#include <QPushButton>
+	#include <qdesktopwidget.h>
 #else
-        #include <qobjcoll.h>
+        #include <qobjectlist.h>
 #endif
 
+
 #include <qvariant.h>
-#include <qaccel.h>
 #include <qtoolbutton.h>
-#include <qtooltip.h>
+#include "kvi_tal_tooltip.h"
 #include <qmessagebox.h>
 
 #ifdef COMPILE_CRYPT_SUPPORT
@@ -90,10 +93,11 @@
 
 KVIRC_API KviWindow * g_pActiveWindow = 0;
 
-static QPopupMenu * g_pMdiWindowSystemMainPopup = 0;
-static QPopupMenu * g_pMdiWindowSystemTextEncodingPopup = 0;
-static QPopupMenu * g_pMdiWindowSystemTextEncodingPopupStandard = 0;
-static QPopupMenu * g_pMdiWindowSystemTextEncodingPopupSmart = 0;
+static KviTalPopupMenu * g_pMdiWindowSystemMainPopup = 0;
+static KviTalPopupMenu * g_pMdiWindowSystemTextEncodingPopup = 0;
+static KviTalPopupMenu * g_pMdiWindowSystemTextEncodingPopupStandard = 0;
+static KviTalPopupMenu * g_pMdiWindowSystemTextEncodingPopupSmart = 0;
+static KviTalPopupMenu * g_pMdiWindowSystemTextEncodingPopupSmartUtf8 = 0;
 
 unsigned long int g_uUniqueWindowId = 1;
 
@@ -140,8 +144,13 @@ KviWindow::KviWindow(int type,KviFrame * lpFrm,const QString &name,KviConsole *
 	m_pTaskBarItem = 0;
 
 	setMinimumSize(KVI_WINDOW_MIN_WIDTH,KVI_WINDOW_MIN_HEIGHT);
+#ifdef COMPILE_USE_QT4
+	//setAutoFillBackground(false);
+	setFocusPolicy(Qt::StrongFocus);
+#else
 	setBackgroundMode(NoBackground);
 	setFocusPolicy(StrongFocus);
+#endif
 	
 	connect(g_pApp,SIGNAL(reloadImages()),this,SLOT(reloadImages()));
 }
@@ -162,6 +171,8 @@ KviWindow::~KviWindow()
 			delete g_pMdiWindowSystemTextEncodingPopupStandard;
 		if(g_pMdiWindowSystemTextEncodingPopupSmart)
 			delete g_pMdiWindowSystemTextEncodingPopupSmart;
+		if(g_pMdiWindowSystemTextEncodingPopupSmartUtf8)
+			delete g_pMdiWindowSystemTextEncodingPopupSmartUtf8;
 	}
 #ifdef COMPILE_CRYPT_SUPPORT
 	if(m_pCryptSessionInfo)
@@ -215,7 +226,6 @@ bool KviWindow::hasAttention()
 		// In this case we assume that the user has the
 		// KVIrc window just below and can see it.
 
-
 		// Handle the special case of the dialogs then
 		QWidget * w = ((QApplication *)g_pApp)->activeWindow();
 		if(w->inherits("QDialog"))
@@ -224,7 +234,7 @@ bool KviWindow::hasAttention()
 			if(!frame()->isVisible())return false;
 			return true;
 		}
-		// any other class is so unfrequent that we 
+		// any other class is so unfrequent that we ignore it
 	} else {
 		// when the window is undocked, instead
 		// it is likely to be covered by KVIrc or other windows...
@@ -278,13 +288,21 @@ bool KviWindow::focusNextPrevChild(bool next)
 	QWidget * w = focusWidget();
 	if(w)
 	{
+#ifdef COMPILE_USE_QT4
+		if(w->focusPolicy() == Qt::StrongFocus)return false;
+#else
 		if(w->focusPolicy() == QWidget::StrongFocus)return false;
+#endif
 		//QVariant v = w->property("KviProperty_FocusOwner");
 		//if(v.isValid())return false; // Do NOT change the focus widget!
 		
 		if(w->parent())
 		{
+#ifdef COMPILE_USE_QT4
+			if(w->parent()->metaObject()->indexOfProperty("KviProperty_ChildFocusOwner") == -1)
+#else
 			if(w->parent()->metaObject()->findProperty("KviProperty_ChildFocusOwner") == -1)
+#endif
 				return false; // Do NOT change the focus widget!
 		}
 	}
@@ -317,7 +335,7 @@ bool KviWindow::setTextEncoding(const QString &szTextEncoding)
 		// and we couldn't find a codec for this
 	} // else it is empty : this means : guess from locale
 	// either empty or not found...
-	m_pTextCodec = defaultTextCodec();
+	m_pTextCodec = 0;
 	m_szTextEncoding = ""; // empty: we're using the default
 	return false;
 }
@@ -333,15 +351,15 @@ QTextCodec * KviWindow::defaultTextCodec()
 	return KviApp::defaultTextCodec();
 }
 
-QCString KviWindow::encodeText(const QString &szText)
+KviQCString KviWindow::encodeText(const QString &szText)
 {
-	if(!m_pTextCodec)return QCString(szText.utf8().data());
+	if(!m_pTextCodec)return defaultTextCodec()->fromUnicode(szText);
 	return m_pTextCodec->fromUnicode(szText);
 }
 
 QString KviWindow::decodeText(const char * szText)
 {
-	if(!m_pTextCodec)return QString(szText);
+	if(!m_pTextCodec)return defaultTextCodec()->toUnicode(szText);
 	return m_pTextCodec->toUnicode(szText);
 }
 
@@ -353,32 +371,32 @@ bool KviWindow::activityMeter(unsigned int *,unsigned int *)
 
 const char * KviWindow::m_typeTable[KVI_WINDOW_NUM_TYPES + 1]=
 {
-        "console",
-        "channel",
-        "query",
-        "help",
-        "terminal",
-        "editor",
-        "dccchat",
-        "dccsend",
-        "socketspy",
-        "links",
-        "tool",
-        "gnutella",
-        "dirbrowser",
-        "dcccanvas",
-        "dccvoice",
-        "list",
-        "offer",
-        "logview",
-        "deadchannel",
-        "deadquery",
-        "scripteditor",
-        "scriptobject",
-        "userwindow",
-		"debug",
-        // <------ NEW TYPES GO HERE!
-        "unknown"
+	"console",
+	"channel",
+	"query",
+	"help",
+	"terminal",
+	"editor",
+	"dccchat",
+	"dccsend",
+	"socketspy",
+	"links",
+	"tool",
+	"gnutella",
+	"dirbrowser",
+	"dcccanvas",
+	"dccvoice",
+	"list",
+	"offer",
+	"logview",
+	"deadchannel",
+	"deadquery",
+	"scripteditor",
+	"scriptobject",
+	"userwindow",
+	"debug",
+	// <------ NEW TYPES GO HERE!
+	"unknown"
 };
 
 const char * KviWindow::typeString()
@@ -409,24 +427,25 @@ void KviWindow::destroyTaskBarItem()
 	//	m_pTaskBarItem = 0; // actually the taskBarItem destructor sets it
 }
 
-QToolButton * KviWindow::createToolButton(QWidget * par,const char * nam,int pixon,int pixoff,const QString & tooltip,bool bOn)
+BUTTON_CLASS * KviWindow::createToolButton(QWidget * par,const char * nam,int pixon,int pixoff,const QString & tooltip,bool bOn)
 {
-	QToolButton * b = new KviStyledToolButton(par,nam);
+#ifdef COMPILE_USE_QT4
+	BUTTON_CLASS * b = new BUTTON_CLASS(par);
+	b->setObjectName(nam);
+	b->setFlat(true);
+	b->setIcon(QIcon(*(g_pIconManager->getSmallIcon(pixon))));
+#else
+	BUTTON_CLASS * b = new BUTTON_CLASS(par,nam);
 	b->setToggleButton(true);
 	b->setUsesBigPixmap(false);
-#if QT_VERSION >= 300
-
 	QIconSet is1;
 	is1.setPixmap(*(g_pIconManager->getSmallIcon(pixon)),QIconSet::Small,QIconSet::Normal,QIconSet::On);
 	is1.setPixmap(*(g_pIconManager->getSmallIcon(pixoff)),QIconSet::Small,QIconSet::Normal,QIconSet::Off);
 	b->setIconSet(is1);
-#else
-
-	b->setOnIconSet(*(g_pIconManager->getSmallIcon(pixon)));
-	b->setOffIconSet(*(g_pIconManager->getSmallIcon(pixoff)));
 #endif
 
-	QToolTip::add
+
+	KviTalToolTip::add
 		(b,tooltip);
 	b->setOn(bOn);
 	return b;
@@ -459,14 +478,14 @@ const QString & KviWindow::lastLineOfText()
 {
 	if(m_pIrcView)
 		return m_pIrcView->lastLineOfText();
-	return QString::null;
+	return KviQString::empty;
 }
 
 const QString & KviWindow::lastMessageText()
 {
 	if(m_pIrcView)
 		return m_pIrcView->lastMessageText();
-	return QString::null;
+	return KviQString::empty;
 }
 
 // The following three have to be here even if the crypt support is disabled...moc does not support conditional compilations
@@ -484,9 +503,7 @@ void KviWindow::toggleCryptController()
 			if(m_pCryptControllerButton->isOn())
 				m_pCryptControllerButton->setOn(false);
 		}
-	}
-	else
-	{
+	} else {
 		if(m_pSplitter && m_pInput)
 		{
 			m_pCryptController = new KviCryptController(m_pSplitter,m_pCryptControllerButton,"crypt_controller",this,m_pCryptSessionInfo);
@@ -582,6 +599,7 @@ void KviWindow::getDefaultLogFileName(QString &buffer)
 	QString base;
 	getBaseLogFileName(base);
 	kvi_encodeFileName(base);
+	base.replace("%%2e","%2e");
 	base=base.lower();
 	QString tmp;
 	if(KVI_OPTION_BOOL(KviOption_boolGzipLogs))
@@ -608,12 +626,24 @@ void KviWindow::saveProperties(KviConfig *cfg)
 	QString szCodec = m_szTextEncoding;
 	QTextCodec * c = defaultTextCodec();
 	if(c && m_pTextCodec)
-		if(KviQString::equalCI(szCodec,c->name()))szCodec = QString::null; // store "default"
+	{
+#ifdef COMPILE_USE_QT4
+		if(KviQString::equalCI(szCodec,c->name().data()))szCodec = KviQString::empty; // store "default"
+#else
+		if(KviQString::equalCI(szCodec,c->name()))szCodec = KviQString::empty; // store "default"
+#endif
+	}
 	QString szKey = "TextEncoding_";
 	szKey += m_szName;
 	cfg->writeEntry(szKey,szCodec);
-	if(m_pInput) cfg->writeEntry("inputToolButtonsHidden",m_pInput->isButtonsHidden());
-	/*if(m_pIrcView && m_iType==KVI_WINDOW_TYPE_CHANNEL)
+	if(m_pInput) {
+		cfg->writeEntry("inputToolButtonsHidden",m_pInput->isButtonsHidden());
+		cfg->writeEntry("commandLineIsUserFriendly",m_pInput->isUserFriendly());
+	}
+
+	//
+	
+		/*if(m_pIrcView && m_iType==KVI_WINDOW_TYPE_CHANNEL)
 		if(m_pIrcView->isLogging())
 			cfg->writeEntry("LoggingEnabled",m_pIrcView->isLogging());*/
 }
@@ -622,8 +652,11 @@ void KviWindow::loadProperties(KviConfig *cfg)
 {
 	QString szKey = "TextEncoding_";
 	szKey += m_szName;
-	setTextEncoding(cfg->readQStringEntry(szKey,QString::null).utf8().data());
-	if(m_pInput) m_pInput->setButtonsHidden(cfg->readBoolEntry("inputToolButtonsHidden",KVI_OPTION_BOOL(KviOption_boolHideInputToolButtons)));
+	setTextEncoding(cfg->readQStringEntry(szKey,KviQString::empty).utf8().data());
+	if(m_pInput) {
+		m_pInput->setButtonsHidden(cfg->readBoolEntry("inputToolButtonsHidden",KVI_OPTION_BOOL(KviOption_boolHideInputToolButtons)));
+		m_pInput->setUserFriendly(cfg->readBoolEntry("commandLineIsUserFriendly",KVI_OPTION_BOOL(KviOption_boolCommandlineInUserFriendlyModeByDefault)));
+	}
 /*	if(m_pIrcView && m_iType==KVI_WINDOW_TYPE_CHANNEL)
 	{
 		bool bEnableLogs=cfg->readBoolEntry("LoggingEnabled",0);
@@ -631,7 +664,7 @@ void KviWindow::loadProperties(KviConfig *cfg)
 		{
 			QString szTmp;
 			getBaseLogFileName(szTmp);
-			m_pIrcView->startLogging(0);
+			m_pIrcView->startLogging();
 		}
 	}*/
 }
@@ -696,14 +729,14 @@ void KviWindow::updateCaption()
 void KviWindow::createSystemTextEncodingPopup()
 {
 	if(!g_pMdiWindowSystemTextEncodingPopup)
-		g_pMdiWindowSystemTextEncodingPopup = new QPopupMenu();
+		g_pMdiWindowSystemTextEncodingPopup = new KviTalPopupMenu();
 	else
 	{
 		g_pMdiWindowSystemTextEncodingPopup->clear();
 	}
 	
 	if(!g_pMdiWindowSystemTextEncodingPopupStandard)
-		g_pMdiWindowSystemTextEncodingPopupStandard = new QPopupMenu();
+		g_pMdiWindowSystemTextEncodingPopupStandard = new KviTalPopupMenu();
 	else
 	{
 		g_pMdiWindowSystemTextEncodingPopupStandard->clear();
@@ -711,13 +744,20 @@ void KviWindow::createSystemTextEncodingPopup()
 	}
 
 	if(!g_pMdiWindowSystemTextEncodingPopupSmart)
-		g_pMdiWindowSystemTextEncodingPopupSmart = new QPopupMenu();
+		g_pMdiWindowSystemTextEncodingPopupSmart = new KviTalPopupMenu();
 	else
 	{
 		g_pMdiWindowSystemTextEncodingPopupSmart->clear();
 		disconnect(g_pMdiWindowSystemTextEncodingPopupSmart,SIGNAL(activated(int)),0,0);
 	}
 
+	if(!g_pMdiWindowSystemTextEncodingPopupSmartUtf8)
+		g_pMdiWindowSystemTextEncodingPopupSmartUtf8 = new KviTalPopupMenu();
+	else
+	{
+		g_pMdiWindowSystemTextEncodingPopupSmartUtf8->clear();
+		disconnect(g_pMdiWindowSystemTextEncodingPopupSmartUtf8,SIGNAL(activated(int)),0,0);
+	}
 
 	QTextCodec * c = defaultTextCodec();
 	QString tmp = __tr2qs("Use Default Encoding");
@@ -733,14 +773,15 @@ void KviWindow::createSystemTextEncodingPopup()
 	g_pMdiWindowSystemTextEncodingPopup->insertSeparator();
 
 	g_pMdiWindowSystemTextEncodingPopup->insertItem(__tr2qs("Standard"),g_pMdiWindowSystemTextEncodingPopupStandard);
-	g_pMdiWindowSystemTextEncodingPopup->insertItem(__tr2qs("Smart"),g_pMdiWindowSystemTextEncodingPopupSmart);
+	g_pMdiWindowSystemTextEncodingPopup->insertItem(__tr2qs("Smart (Send Local)"),g_pMdiWindowSystemTextEncodingPopupSmart);
+	g_pMdiWindowSystemTextEncodingPopup->insertItem(__tr2qs("Smart (Send UTF-8)"),g_pMdiWindowSystemTextEncodingPopupSmartUtf8);
 	
 	int i = 0;
 	KviLocale::EncodingDescription * d = KviLocale::encodingDescription(i);
 	while(d->szName)
 	{
 		KviQString::sprintf(tmp,"%s (%s)",d->szName,d->szDescription);
-		QPopupMenu * ppp = d->bSmart ? g_pMdiWindowSystemTextEncodingPopupSmart : g_pMdiWindowSystemTextEncodingPopupStandard;
+		KviTalPopupMenu * ppp = d->bSmart ? (d->bSendUtf8 ? g_pMdiWindowSystemTextEncodingPopupSmartUtf8 : g_pMdiWindowSystemTextEncodingPopupSmart) : g_pMdiWindowSystemTextEncodingPopupStandard;
 		id = ppp->insertItem(tmp);
 		if(KviQString::equalCI(m_szTextEncoding,d->szName))
 			ppp->setItemChecked(id,true);
@@ -749,6 +790,7 @@ void KviWindow::createSystemTextEncodingPopup()
 	}
 
 	connect(g_pMdiWindowSystemTextEncodingPopupSmart,SIGNAL(activated(int)),this,SLOT(systemTextEncodingPopupSmartActivated(int)));
+	connect(g_pMdiWindowSystemTextEncodingPopupSmartUtf8,SIGNAL(activated(int)),this,SLOT(systemTextEncodingPopupSmartUtf8Activated(int)));
 	connect(g_pMdiWindowSystemTextEncodingPopupStandard,SIGNAL(activated(int)),this,SLOT(systemTextEncodingPopupStandardActivated(int)));
 }
 
@@ -756,7 +798,7 @@ void KviWindow::createSystemTextEncodingPopup()
 void KviWindow::systemPopupRequest(const QPoint &pnt)
 {
 	if(!g_pMdiWindowSystemMainPopup)
-		g_pMdiWindowSystemMainPopup = new QPopupMenu();
+		g_pMdiWindowSystemMainPopup = new KviTalPopupMenu();
 	else
 	{
 		g_pMdiWindowSystemMainPopup->clear();
@@ -815,7 +857,16 @@ void KviWindow::systemTextEncodingPopupSmartActivated(int id)
 	if(!g_pMdiWindowSystemTextEncodingPopupSmart)
 		return;
 	QString tmp = g_pMdiWindowSystemTextEncodingPopupSmart->text(id);
-	KviQString::cutFromFirst(tmp,' ');
+	KviQString::cutFromFirst(tmp," (");
+	setTextEncoding(tmp);
+}
+
+void KviWindow::systemTextEncodingPopupSmartUtf8Activated(int id)
+{
+	if(!g_pMdiWindowSystemTextEncodingPopupSmartUtf8)
+		return;
+	QString tmp = g_pMdiWindowSystemTextEncodingPopupSmartUtf8->text(id);
+	KviQString::cutFromFirst(tmp," (");
 	setTextEncoding(tmp);
 }
 
@@ -824,7 +875,7 @@ void KviWindow::systemTextEncodingPopupStandardActivated(int id)
 	if(!g_pMdiWindowSystemTextEncodingPopupStandard)
 		return;
 	QString tmp = g_pMdiWindowSystemTextEncodingPopupStandard->text(id);
-	KviQString::cutFromFirst(tmp,' ');
+	KviQString::cutFromFirst(tmp," (");
 	setTextEncoding(tmp);
 }
 
@@ -847,7 +898,7 @@ void KviWindow::contextPopup()
 	systemPopupRequest(QCursor::pos());
 }
 
-void KviWindow::fillContextPopup(QPopupMenu *)
+void KviWindow::fillContextPopup(KviTalPopupMenu *)
 {
 	// nothing here
 }
@@ -959,8 +1010,21 @@ void KviWindow::focusInEvent(QFocusEvent *)
 	{
 		// must find one NOW
 		// we probably have no KviInput since it would have been grabbed anyway
+		
 		if(m_pIrcView)m_pFocusHandler = m_pIrcView;
 		else {
+#ifdef COMPILE_USE_QT4
+			QList<QObject *> list = children();
+			for(QList<QObject *>::Iterator it = list.begin();it != list.end();++it)
+			{
+				QObject * c = *it;
+				if(c->isWidgetType())
+				{
+					m_pFocusHandler = (QWidget *)c;
+					break;
+				}
+			}
+#else
 			QObjectList *list = (QObjectList *)(children());
 			if(list)
 			{
@@ -973,6 +1037,7 @@ void KviWindow::focusInEvent(QFocusEvent *)
 					}
 				}
 			}
+#endif
 		}
 		if(m_pFocusHandler)m_pFocusHandler->setFocus();
 		else {
@@ -990,6 +1055,7 @@ void KviWindow::focusInEvent(QFocusEvent *)
 	// we should be already the active window at this point.
 	// If we're not, then run activateSelf() to fix this.
 	if(g_pActiveWindow != this)activateSelf();
+	//else debug("ACTIVE WINDOW IS ALREADY THIS");
 	updateCaption();
 }
 
@@ -1007,8 +1073,13 @@ bool KviWindow::eventFilter(QObject *o,QEvent *e)
 			QApplication::restoreOverrideCursor();
 		break;
 	case QEvent::MouseButtonPress:
+#ifdef COMPILE_USE_QT4
+		if( (((QWidget *)o)->focusPolicy() == Qt::NoFocus) ||
+		        (((QWidget *)o)->focusPolicy() == Qt::TabFocus))
+#else
 		if( (((QWidget *)o)->focusPolicy() == QWidget::NoFocus) ||
 		        (((QWidget *)o)->focusPolicy() == QWidget::TabFocus))
+#endif
 		{
 			// this will not focus our window
 			// set the focus to the focus handler
@@ -1050,12 +1121,27 @@ void KviWindow::childInserted(QWidget * o)
 		m_pFocusHandler = o;
 	else
 	{
+#ifdef COMPILE_USE_QT4
+		if(!m_pFocusHandler && (o->focusPolicy() == Qt::StrongFocus))
+#else
 		if(!m_pFocusHandler && (o->focusPolicy() == QWidget::StrongFocus))
+#endif
 		{
 			m_pFocusHandler = o;
 		}
 	}
 
+#ifdef COMPILE_USE_QT4
+	QList<QObject *> list = o->children();
+	for(QList<QObject *>::Iterator it = list.begin();it != list.end();++it)
+	{
+		QObject * c = *it;
+		if(c->isWidgetType())
+		{
+			childInserted((QWidget *)c);
+		}
+	}
+#else
 	QObjectList *list = (QObjectList *)(o->children());
 	if(list)
 	{
@@ -1065,6 +1151,7 @@ void KviWindow::childInserted(QWidget * o)
 				childInserted((QWidget *)c);
 		}
 	}
+#endif
 }
 
 void KviWindow::childDestroyed()
@@ -1082,6 +1169,17 @@ void KviWindow::childRemoved(QWidget * o)
 	if(o == m_pLastFocusedChild)
 		m_pLastFocusedChild = 0;
 
+#ifdef COMPILE_USE_QT4
+	QList<QObject *> list = o->children();
+	for(QList<QObject *>::Iterator it = list.begin();it != list.end();++it)
+	{
+		QObject * c = *it;
+		if(c->isWidgetType())
+		{
+			childRemoved((QWidget *)c);
+		}
+	}
+#else
 	QObjectList *list = (QObjectList *)(o->children());
 	if(list)
 	{
@@ -1091,7 +1189,7 @@ void KviWindow::childRemoved(QWidget * o)
 				childRemoved((QWidget *)c);
 		}
 	} //else debug("The removed object has no children");
-
+#endif
 }
 
 void KviWindow::childEvent(QChildEvent *e)
@@ -1126,6 +1224,22 @@ void KviWindow::updateBackgrounds(QObject * obj)
 {
 	if(!obj)
 		obj = this;
+#ifdef COMPILE_USE_QT4
+	QList<QObject *> list = obj->children();
+	if (list.count())
+	{
+	
+	for(QList<QObject *>::Iterator it = list.begin();it != list.end();++it)
+	{
+		QObject * child = *it;
+		if(child->metaObject()->indexOfProperty("TransparencyCapable") != -1){
+		//	if (child->isWidgetType())
+			((QWidget *)child)->update();
+		}
+		updateBackgrounds(child);
+	}
+	}
+#else
 	QObjectList * list = (QObjectList *)(obj->children());
 	if(list)
 	{
@@ -1146,6 +1260,7 @@ void KviWindow::updateBackgrounds(QObject * obj)
 			updateBackgrounds(child);
 		}
 	}
+#endif
 }
 
 void KviWindow::moveEvent(QMoveEvent *e)
@@ -1254,8 +1369,7 @@ void KviWindow::internalOutput(KviIrcView * pView,int msg_type,const kvi_wchar_t
 		{
 			if(!pView->hasLineMark())
 			{
-				if(KVI_OPTION_BOOL(KviOption_boolTrackLastReadTextViewLine))
-					iFlags |= KviIrcView::SetLineMark;
+				iFlags |= KviIrcView::SetLineMark;
 			}
 		}
 		pView->appendText(msg_type,pText,iFlags);
@@ -1376,7 +1490,12 @@ void KviWindow::unhighlight()
 
 void KviWindow::preprocessMessage(QString & szMessage)
 {
+	// slow
+#ifdef COMPILE_USE_QT4
+	QStringList strings = szMessage.split(" ");
+#else
 	QStringList strings = QStringList::split(" ",szMessage, TRUE);
+#endif
 	for ( QStringList::Iterator it = strings.begin(); it != strings.end(); ++it ) {
 		QString tmp(*it);
 		if(tmp.contains('\r')) continue;
