@@ -26,6 +26,7 @@
 
 #include "kvi_string.h"
 #include "kvi_qstring.h"
+#include "kvi_qcstring.h"
 #include "kvi_settings.h"
 
 #ifdef COMPILE_ON_WINDOWS
@@ -47,14 +48,17 @@ class KviIrcContext;
 class KviIrcConnection;
 class KviWindowToolPageButton;
 
-class QPopupMenu;
+class KviTalPopupMenu;
 class QPixmap;
 class QSplitter;
-class QHBox;
-class QAccel;
+class KviTalHBox;
 class QToolButton;
 class QTextCodec;
-class QWidgetStack;
+class KviTalWidgetStack;
+
+#include "kvi_tal_hbox.h"
+#include "kvi_tal_widgetstack.h"
+#include "kvi_accel.h"
 
 #ifdef COMPILE_CRYPT_SUPPORT
 	class KviCryptController;
@@ -120,7 +124,12 @@ class QWidgetStack;
 #define KVI_ACTIVITY_VERYHOT 5
 #define KVI_ACTIVITY_FIRE 6
 
-
+#ifdef COMPILE_USE_QT4
+    class QPushButton;
+	#define BUTTON_CLASS QPushButton
+#else
+	#define BUTTON_CLASS QToolButton
+#endif
 
 
 class KVIRC_API KviWindow : public QWidget
@@ -152,7 +161,7 @@ protected: // almost private: don't touch :D
 	KviIrcView                          * m_pIrcView;
 	KviInput                            * m_pInput;
 	QSplitter                           * m_pSplitter;
-	QHBox                               * m_pButtonBox;
+	KviTalHBox                               * m_pButtonBox;
 	unsigned long int                     m_uId;
 	QString                               m_szTextEncoding;
 #ifdef COMPILE_CRYPT_SUPPORT
@@ -160,10 +169,10 @@ protected: // almost private: don't touch :D
 	KviCryptController                  * m_pCryptController;
 	KviCryptSessionInfo                 * m_pCryptSessionInfo;
 #endif
-	QToolButton                         * m_pTextEncodingButton;
+	BUTTON_CLASS                        * m_pTextEncodingButton;
 	QToolButton                         * m_pHideToolsButton;
 	QWidget                             * m_pLastFocusedChild;
-	QAccel                              * m_pAccel;
+	KviAccel                            * m_pAccel;
 	static const char                   * m_typeTable[KVI_WINDOW_NUM_TYPES + 1];
 	// text encoding and decoding
 	//unsigned int                          m_uTextEncoding;
@@ -187,7 +196,7 @@ public:
 	// by THIS implementation is "unknown"
 	virtual const char * typeString();
 
-	QTextCodec * textCodec(){ return m_pTextCodec; };
+	QTextCodec * textCodec(){ return m_pTextCodec ? m_pTextCodec : defaultTextCodec(); };
 	void forceTextCodec(QTextCodec * c);
 
 	// The frame that this window belongs to
@@ -216,9 +225,9 @@ public:
 	KviInput * input(){ return m_pInput; };
 
 	// The target of this window: empty when it makes no sense :D
-	virtual const QString & target(){ return QString::null; };
+	virtual const QString & target(){ return KviQString::empty; };
 	// The local nickname bound to this window: might be empty when a local nickname makes no sense
-	virtual const QString & localNick(){ return QString::null; };
+	virtual const QString & localNick(){ return KviQString::empty; };
 
 #ifdef COMPILE_CRYPT_SUPPORT
 	KviCryptSessionInfo * cryptSessionInfo(){ return m_pCryptSessionInfo; };
@@ -241,7 +250,7 @@ public:
 	// this must return a default text codec suitable for this window
 	virtual QTextCodec * defaultTextCodec();
 	// encode the text from szSource by using m_uTextEncoding
-	QCString encodeText(const QString &szText);
+	KviQCString encodeText(const QString &szText);
 	QString decodeText(const char * szText);
 
 	void contextPopup();
@@ -258,7 +267,7 @@ public:
 	void delayedClose(); // close that jumps out of the current event loop
 
 	// Interesting overridables:
-	virtual void fillContextPopup(QPopupMenu * p);
+	virtual void fillContextPopup(KviTalPopupMenu * p);
 	virtual void getConfigGroupName(QString &buf);
 //	virtual void getBaseLogFileName(KviStr &buffer);
 	virtual void getBaseLogFileName(QString &buffer);
@@ -305,6 +314,7 @@ protected slots:
 	void textEncodingButtonClicked();
 	void systemPopupRequest(const QPoint &pnt);
 	void systemTextEncodingPopupSmartActivated(int id);
+	void systemTextEncodingPopupSmartUtf8Activated(int id);
 	void systemTextEncodingPopupStandardActivated(int id);
 	void systemTextEncodingPopupDefault();
 	void childDestroyed();
@@ -361,7 +371,7 @@ protected:
 	void createTextEncodingButton(QWidget * par);
 	void createSystemTextEncodingPopup();
 
-	QToolButton * createToolButton(QWidget * par,const char * nam,int pixon,int pixoff,const QString & tooltip,bool bOn);
+	BUTTON_CLASS * createToolButton(QWidget * par,const char * nam,int pixon,int pixoff,const QString & tooltip,bool bOn);
 	// This is called by KviInput: actually it links the widgetAdded
 	virtual void childrenTreeChanged(QWidget * widgetAdded);
 	
