@@ -22,9 +22,9 @@
 //   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 //
 
-#include <qtabdialog.h>
+#include <kvi_tal_tabdialog.h>
 
-class KviAboutDialog : public QTabDialog
+class KviAboutDialog : public KviTalTabDialog
 {
 	Q_OBJECT
 public:
