@@ -23,7 +23,6 @@
 //=============================================================================
 #include "actioneditor.h"
 
-#include "kvi_styled_controls.h"
 #include "kvi_iconmanager.h"
 #include "kvi_options.h"
 #include "kvi_locale.h"
@@ -44,7 +43,7 @@
 
 #include <qsplitter.h>
 #include <qlayout.h>
-#include <qvbox.h>
+#include "kvi_tal_vbox.h"
 #include <qtooltip.h>
 #include <qpushbutton.h>
 #include <qdir.h>
@@ -54,12 +53,15 @@
 #include <qtoolbutton.h>
 #include <qcheckbox.h>
 #include <qtooltip.h>
-#include <qsimplerichtext.h>
 #include <qpainter.h>
-#include <qheader.h>
+#ifdef COMPILE_USE_QT4
+	#include <q3header.h>
+#else
+	#include <qheader.h>
+#endif
 #include <qtabwidget.h>
-#include <qgroupbox.h>
-#include <qvaluelist.h>
+#include <kvi_tal_groupbox.h>
+#include "kvi_valuelist.h"
 #include <qlabel.h>
 
 extern KviActionEditorWindow * g_pActionEditorWindow;
@@ -72,8 +74,8 @@ static QString g_szLastEditedAction;
 #define LVI_MINIMUM_TEXT_WIDTH 150
 #define LVI_MINIMUM_CELL_WIDTH (LVI_MINIMUM_TEXT_WIDTH + LVI_BORDER + LVI_ICON_SIZE + LVI_SPACING + LVI_BORDER)
 
-KviActionEditorListViewItem::KviActionEditorListViewItem(QListView * v,KviActionData * a)
-: QListViewItem(v,"")
+KviActionEditorListViewItem::KviActionEditorListViewItem(KviTalListView * v,KviActionData * a)
+: KviTalListViewItem(v,"")
 {
 	m_pActionData = a;
 	m_pListView = v;
@@ -111,7 +113,7 @@ QString KviActionEditorListViewItem::key(int,bool) const
 
 void KviActionEditorListViewItem::setup()
 {
-	QListViewItem::setup();
+	KviTalListViewItem::setup();
 	int iWidth = m_pListView->visibleWidth();
 	if(iWidth < LVI_MINIMUM_CELL_WIDTH)iWidth = LVI_MINIMUM_CELL_WIDTH;
 	iWidth -= LVI_BORDER + LVI_ICON_SIZE + LVI_SPACING + LVI_BORDER;
@@ -322,7 +324,7 @@ KviSingleActionEditor::KviSingleActionEditor(QWidget * par,KviActionEditor * ed)
 	g->setColStretch(1,1);
 
 
-	QDictIterator<KviActionCategory> it(*(KviActionManager::instance()->categories()));
+	KviPointerHashTableIterator<QString,KviActionCategory> it(*(KviActionManager::instance()->categories()));
 	while(KviActionCategory * ac = it.current())
 	{
 		m_pCategoryCombo->insertItem(ac->visibleName() + " (" + ac->name() + ")");
@@ -399,7 +401,7 @@ void KviSingleActionEditor::chooseBigIcon()
 	QString s = d->selectedImage();
 	delete d;
 	if(ret != QDialog::Accepted)return;
-	QPixmap * p = g_pIconManager->getBigIcon(s.utf8().data());
+	QPixmap * p = g_pIconManager->getBigIcon(s);
 	if(!p)return;
 	m_pBigIconEdit->setText(s);
 	m_pBigIconButton->setPixmap(*p);
@@ -617,7 +619,7 @@ void KviSingleActionEditor::commit()
 
 
 KviActionEditorListView::KviActionEditorListView(QWidget * pParent)
-: QListView(pParent)
+: KviTalListView(pParent)
 {
 	setSelectionMode(Extended);
 	int iWidth = visibleWidth();
@@ -633,7 +635,7 @@ KviActionEditorListView::~KviActionEditorListView()
 
 void KviActionEditorListView::resizeEvent(QResizeEvent * e)
 {
-	QListView::resizeEvent(e);
+	KviTalListView::resizeEvent(e);
 	int iWidth = visibleWidth();
 	if(iWidth < LVI_MINIMUM_CELL_WIDTH)iWidth = LVI_MINIMUM_CELL_WIDTH;
 	setColumnWidth(0,iWidth);
@@ -652,17 +654,27 @@ KviActionEditor::KviActionEditor(QWidget * par)
 	
 	QGridLayout * l = new QGridLayout(this,1,1,2,2);
 
+#ifdef COMPILE_USE_QT4
+	m_pSplitter = new QSplitter(Qt::Horizontal,this);
+	m_pSplitter->setOpaqueResize(false);
+
+#else
 	m_pSplitter = new QSplitter(QSplitter::Horizontal,this);
+#endif
 
 	l->addWidget(m_pSplitter,0,0);
 	
 	
-	QVBox * box = new QVBox(m_pSplitter);
+	KviTalVBox * box = new KviTalVBox(m_pSplitter);
 	m_pListView = new KviActionEditorListView(box);
 	//m_pListView->setMultiSelection(false);
 	m_pListView->setShowSortIndicator(true);
+#ifdef COMPILE_USE_QT4
+	m_pListView->setFocusPolicy(Qt::StrongFocus);
+#else
 	m_pListView->setFocusPolicy(QWidget::StrongFocus);
-	connect(m_pListView,SIGNAL(currentChanged(QListViewItem *)),this,SLOT(currentChanged(QListViewItem *)));
+#endif
+	connect(m_pListView,SIGNAL(currentChanged(KviTalListViewItem *)),this,SLOT(currentChanged(KviTalListViewItem *)));
 
 
 	m_pNewActionButton = new QPushButton(__tr2qs("New Action"),box);
@@ -681,7 +693,7 @@ KviActionEditor::KviActionEditor(QWidget * par)
 	KviActionEditorListViewItem * last = 0;
 	KviActionEditorListViewItem * first = 0;
 
-	QDictIterator<KviAction> it(*(KviActionManager::instance()->actions()));
+	KviPointerHashTableIterator<QString,KviAction> it(*(KviActionManager::instance()->actions()));
 	while(KviAction * a = it.current())
 	{
 		if(a->isKviUserActionNeverOverrideThis())
@@ -764,7 +776,7 @@ void KviActionEditor::exportActions()
 
 void KviActionEditor::deleteActions()
 {
-	KviPtrList<KviActionEditorListViewItem> l;
+	KviPointerList<KviActionEditorListViewItem> l;
 	l.setAutoDelete(false);
 
 	KviActionEditorListViewItem * it = (KviActionEditorListViewItem *)m_pListView->firstChild();
@@ -846,7 +858,7 @@ bool KviActionEditor::actionExists(const QString &szName)
 }
 
 
-void KviActionEditor::currentChanged(QListViewItem * i)
+void KviActionEditor::currentChanged(KviTalListViewItem * i)
 {
 	if(m_pSingleActionEditor->actionData())
 	{
@@ -990,7 +1002,7 @@ void KviActionEditorWindow::loadProperties(KviConfig *cfg)
 {
 	int w = width();
 	KviWindow::loadProperties(cfg);
-	QValueList<int> def;
+	KviValueList<int> def;
 	def.append((w * 25) / 100);
 	def.append((w * 75) / 100);
 	m_pEditor->m_pSplitter->setSizes(cfg->readIntListEntry("Splitter",def));
