@@ -27,7 +27,8 @@
 #include "kvi_window.h"
 
 #include <qwidget.h>
-#include <qlistview.h>
+#include "kvi_tal_listview.h"
+#include "kvi_styled_controls.h"
 
 class KviActionEditorListViewItem;
 
@@ -67,20 +68,28 @@ class QLineEdit;
 class QComboBox;
 class KviScriptEditor;
 class QToolButton;
-class KviStyledCheckBox;
 class QSimpleRichText;
 class QPushButton;
 
-class KviActionEditorListViewItem : public QListViewItem
+#ifdef COMPILE_USE_QT4
+	#include <q3simplerichtext.h>
+	#define QSimpleRichText Q3SimpleRichText
+#else
+	#include <qsimplerichtext.h>
+#endif
+
+
+
+class KviActionEditorListViewItem : public KviTalListViewItem
 {
 public:
-	KviActionEditorListViewItem(QListView * v,KviActionData * a);
+	KviActionEditorListViewItem(KviTalListView * v,KviActionData * a);
 	~KviActionEditorListViewItem();
 protected:
 	KviActionData * m_pActionData;
 	QSimpleRichText * m_pText;
 	QPixmap * m_pIcon;
-	QListView * m_pListView;
+	KviTalListView * m_pListView;
 	QString m_szKey;
 public:
 	KviActionData * actionData(){ return m_pActionData; };
@@ -92,7 +101,7 @@ public:
 };
 
 
-class KviActionEditorListView : public QListView
+class KviActionEditorListView : public KviTalListView
 {
 	Q_OBJECT
 public:
@@ -170,7 +179,7 @@ protected:
 	int selectedCount();
 	QString nameForAutomaticAction(const QString &szTemplate);
 protected slots:
-	void currentChanged(QListViewItem * it);
+	void currentChanged(KviTalListViewItem * it);
 	void newAction();
 	void deleteActions();
 	void exportActions();
