@@ -23,9 +23,7 @@
 //=============================================================================
 
 #include "kvi_module.h"
-//#include "kvi_uparser.h"
 #include "kvi_locale.h"
-#include "kvi_command.h"
 #include "kvi_frame.h"
 
 #include "actioneditor.h"
@@ -72,7 +70,7 @@ static bool actioneditor_module_can_unload(KviModule * m)
 static bool actioneditor_module_cleanup(KviModule *m)
 {
 	if(g_pActionEditorWindow)delete g_pActionEditorWindow;
-    g_pActionEditorWindow = 0;
+	g_pActionEditorWindow = 0;
 	return true;
 }
 
