@@ -39,10 +39,11 @@
 #include "kvi_filedialog.h"
 #include "kvi_cmdformatter.h"
 #include "kvi_module.h"
+#include "kvi_valuelist.h"
 
 #include <qsplitter.h>
 #include <qlayout.h>
-#include <qvbox.h>
+#include "kvi_tal_vbox.h"
 #include <qtooltip.h>
 #include <qpushbutton.h>
 #include <qdir.h>
@@ -53,14 +54,14 @@
 extern KviAliasEditorWindow * g_pAliasEditorWindow;
 extern KviModule * g_pAliasEditorModule;
 
-KviAliasEditorListViewItem::KviAliasEditorListViewItem(QListView * pListView,Type eType,const QString &szName)
-: QListViewItem(pListView), m_eType(eType), m_pParentNamespaceItem(0)
+KviAliasEditorListViewItem::KviAliasEditorListViewItem(KviTalListView * pListView,Type eType,const QString &szName)
+: KviTalListViewItem(pListView), m_eType(eType), m_pParentNamespaceItem(0)
 {
 	setName(szName);
 }
 
 KviAliasEditorListViewItem::KviAliasEditorListViewItem(KviAliasNamespaceListViewItem * pParentNamespaceItem,Type eType,const QString &szName)
-: QListViewItem(pParentNamespaceItem), m_eType(eType), m_pParentNamespaceItem(pParentNamespaceItem)
+: KviTalListViewItem(pParentNamespaceItem), m_eType(eType), m_pParentNamespaceItem(pParentNamespaceItem)
 {
 	setName(szName);
 }
@@ -88,7 +89,7 @@ KviAliasListViewItem::KviAliasListViewItem(KviAliasNamespaceListViewItem * pPare
 	m_cPos=QPoint(0,0);
 }
 
-KviAliasListViewItem::KviAliasListViewItem(QListView * pListView,const QString &szName)
+KviAliasListViewItem::KviAliasListViewItem(KviTalListView * pListView,const QString &szName)
 : KviAliasEditorListViewItem(pListView,KviAliasEditorListViewItem::Alias,szName)
 {
 	setPixmap(0,*(g_pIconManager->getSmallIcon(KVI_SMALLICON_ALIAS)));
@@ -96,7 +97,7 @@ KviAliasListViewItem::KviAliasListViewItem(QListView * pListView,const QString &
 }
 
 
-KviAliasNamespaceListViewItem::KviAliasNamespaceListViewItem(QListView * pListView,const QString &szName)
+KviAliasNamespaceListViewItem::KviAliasNamespaceListViewItem(KviTalListView * pListView,const QString &szName)
 : KviAliasEditorListViewItem(pListView,KviAliasEditorListViewItem::Namespace,szName)
 {
 	setPixmap(0,*(g_pIconManager->getSmallIcon(KVI_SMALLICON_NAMESPACE)));
@@ -204,22 +205,29 @@ KviAliasEditor::KviAliasEditor(QWidget * par)
 {
 	m_pLastEditedItem = 0;
 	m_pLastClickedItem = 0;
+	m_szDir = QDir::homeDirPath();
+  
 
 	QGridLayout * l = new QGridLayout(this,1,1,2,2);
 
+#ifdef COMPILE_USE_QT4
+	m_pSplitter = new QSplitter(Qt::Horizontal,this);
+	m_pSplitter->setOpaqueResize(false);
+#else
 	m_pSplitter = new QSplitter(QSplitter::Horizontal,this);
+#endif
 
 	l->addWidget(m_pSplitter,0,0);
 	
-	QVBox * box = new QVBox(m_pSplitter);
-	m_pListView = new QListView(box);
+	KviTalVBox * box = new KviTalVBox(m_pSplitter);
+	m_pListView = new KviTalListView(box);
 	m_pListView->addColumn(__tr2qs("Alias"));
-	m_pListView->setSelectionMode(QListView::Extended);
+	m_pListView->setSelectionMode(KviTalListView::Extended);
 	m_pListView->setShowSortIndicator(true);
 	m_pListView->setRootIsDecorated(true);
 
-	box = new QVBox(m_pSplitter);
-	QHBox * hbox = new QHBox(box);
+	box = new KviTalVBox(m_pSplitter);
+	KviTalHBox * hbox = new KviTalHBox(box);
 	m_pNameLabel = new QLabel(__tr2qs("No item selected"),hbox);
 	m_pRenameButton = new QPushButton(__tr2qs("Rename"),hbox);
 	m_pRenameButton->setEnabled(false);
@@ -229,9 +237,9 @@ KviAliasEditor::KviAliasEditor(QWidget * par)
 	m_pEditor = KviScriptEditor::createInstance(box);
 	m_pEditor->setFocus();
 	connect(m_pEditor,SIGNAL(find(const QString &)),this,SLOT(slotFindWord(const QString &)));
-	//connect(m_pEditor,SIGNAL(replaceAll(const QString &,const QString &)),this,SLOT(slotReplaceAll(const QString &,const QString &)));
+	connect(m_pEditor,SIGNAL(replaceAll(const QString &,const QString &)),this,SLOT(slotReplaceAll(const QString &,const QString &)));
 
-	m_pContextPopup = new QPopupMenu(this);
+	m_pContextPopup = new KviTalPopupMenu(this);
 
 	oneTimeSetup();
 
@@ -363,10 +371,10 @@ KviAliasNamespaceListViewItem * KviAliasEditor::createFullNamespaceItem(const QS
 
 void KviAliasEditor::oneTimeSetup()
 {
-	QDict<KviKvsScript> * a = KviKvsAliasManager::instance()->aliasDict();
+	KviPointerHashTable<QString,KviKvsScript> * a = KviKvsAliasManager::instance()->aliasDict();
 	if(!a)return;
 
-	QDictIterator<KviKvsScript> it(*a);
+	KviPointerHashTableIterator<QString,KviKvsScript> it(*a);
 
 	KviAliasListViewItem * item;
 	while(it.current())
@@ -377,12 +385,12 @@ void KviAliasEditor::oneTimeSetup()
 		++it;
 	}
 		
-	connect(m_pListView,SIGNAL(currentChanged(QListViewItem *)),this,SLOT(currentItemChanged(QListViewItem *)));
-	connect(m_pListView,SIGNAL(rightButtonPressed(QListViewItem *,const QPoint &,int)),
-		this,SLOT(itemPressed(QListViewItem *,const QPoint &,int)));
+	connect(m_pListView,SIGNAL(currentChanged(KviTalListViewItem *)),this,SLOT(currentItemChanged(KviTalListViewItem *)));
+	connect(m_pListView,SIGNAL(rightButtonPressed(KviTalListViewItem *,const QPoint &,int)),
+		this,SLOT(itemPressed(KviTalListViewItem *,const QPoint &,int)));
 }
 
-bool KviAliasEditor::hasSelectedItems(QListViewItem * it)
+bool KviAliasEditor::hasSelectedItems(KviTalListViewItem * it)
 {
 	if(!it)return false;
 	if(it->isSelected())return true;
@@ -393,7 +401,7 @@ bool KviAliasEditor::hasSelectedItems(QListViewItem * it)
 	return hasSelectedItems(it->nextSibling());
 }
 
-bool KviAliasEditor::itemExists(QListViewItem *pSearchFor,QListViewItem * pSearchAt)
+bool KviAliasEditor::itemExists(KviTalListViewItem *pSearchFor,KviTalListViewItem * pSearchAt)
 {
 	if(!pSearchFor)return false;
 	if(!pSearchAt)return false;
@@ -403,7 +411,7 @@ bool KviAliasEditor::itemExists(QListViewItem *pSearchFor,QListViewItem * pSearc
 }
 
 
-void KviAliasEditor::itemPressed(QListViewItem *it,const QPoint &pnt,int col)
+void KviAliasEditor::itemPressed(KviTalListViewItem *it,const QPoint &pnt,int col)
 {
 	m_pContextPopup->clear();
 	
@@ -442,6 +450,13 @@ void KviAliasEditor::itemPressed(QListViewItem *it,const QPoint &pnt,int col)
 			this,SLOT(exportSelected()));
 	m_pContextPopup->setItemEnabled(id,bHasSelected);
 
+	m_pContextPopup->insertItem(
+			*(g_pIconManager->getSmallIcon(KVI_SMALLICON_FOLDER)),
+			__tr2qs("Export Selected in singles files..."),
+			this,SLOT(exportSelectedSepFiles()));
+
+	m_pContextPopup->setItemEnabled(id,bHasSelected);
+
 	m_pContextPopup->insertItem(
 			*(g_pIconManager->getSmallIcon(KVI_SMALLICON_FOLDER)),
 			__tr2qs("Export All..."),
@@ -467,21 +482,22 @@ void KviAliasEditor::itemPressed(QListViewItem *it,const QPoint &pnt,int col)
 	m_pContextPopup->popup(pnt);
 }
 
-void KviAliasEditor::recursiveSearch(const QString &szSearch,KviAliasEditorListViewItem * it)
+void KviAliasEditor::recursiveSearchReplace(const QString &szSearch,KviAliasEditorListViewItem * it,bool bReplace,const QString &szReplace)
 {
 	if(!it)return;
 	if(it->isAlias())
 	{
-		if(((KviAliasListViewItem *)it)->buffer().find(szSearch,false) != -1)
+		if(((KviAliasListViewItem *)it)->buffer().find(szSearch,0,false) != -1)
 		{
 			it->setPixmap(0,*(g_pIconManager->getSmallIcon(KVI_SMALLICON_ALIASHIGHLIGHTED)));
+			if (bReplace) ((QString &)((KviAliasListViewItem *)it)->buffer()).replace(szSearch,szReplace,false);
 			openParentItems(it);
 		} else
 			it->setPixmap(0,*(g_pIconManager->getSmallIcon(KVI_SMALLICON_ALIAS)));
 	} else {
-		recursiveSearch(szSearch,(KviAliasEditorListViewItem *)(it->firstChild()));
+		recursiveSearchReplace(szSearch,(KviAliasEditorListViewItem *)(it->firstChild()),bReplace,szReplace);
 	}
-	recursiveSearch(szSearch,(KviAliasEditorListViewItem *)(it->nextSibling()));
+	recursiveSearchReplace(szSearch,(KviAliasEditorListViewItem *)(it->nextSibling()),bReplace,szReplace);
 }
 
 void KviAliasEditor::slotFind()
@@ -498,12 +514,15 @@ void KviAliasEditor::slotFind()
 	g_pAliasEditorModule->unlock();
 	if(!bOk)return;
 	if(szSearch.isEmpty())return;
+	m_pEditor->setFindText(szSearch);
 	
-	recursiveSearch(szSearch,(KviAliasEditorListViewItem *)m_pListView->firstChild());
+	recursiveSearchReplace(szSearch,(KviAliasEditorListViewItem *)m_pListView->firstChild());
 }
 void KviAliasEditor::slotFindWord(const QString &szSearch)
 {
-	recursiveSearch(szSearch,(KviAliasEditorListViewItem *)m_pListView->firstChild());
+	m_pEditor->setFindText(szSearch);
+	
+	recursiveSearchReplace(szSearch,(KviAliasEditorListViewItem *)m_pListView->firstChild());
 
 }
 void KviAliasEditor::recursiveCollapseNamespaces(KviAliasEditorListViewItem * it)
@@ -522,17 +541,12 @@ void KviAliasEditor::slotCollapseNamespaces()
 	recursiveCollapseNamespaces((KviAliasEditorListViewItem *)m_pListView->firstChild());
 }
 
-/*
+
 void KviAliasEditor::slotReplaceAll(const QString &before,const QString &after)
 {
-	QListViewItemIterator itv( m_pListView );
-    while ( itv.current() ) 
-    {
-	((KviAliasListViewItem*)itv.current())->m_szBuffer.replace(before,after,FALSE);
-	++itv;
-	}
+	recursiveSearchReplace(before,(KviAliasEditorListViewItem *)m_pListView->firstChild(),true,after);
 }
-*/
+
 
 
 void KviAliasEditor::getExportAliasBuffer(QString &buffer,KviAliasListViewItem * it)
@@ -554,22 +568,81 @@ void KviAliasEditor::exportAll()
 	exportAliases(false);
 }
 
+void KviAliasEditor::exportSelectedSepFiles()
+{
+	exportAliases (true,true);
+}
 void KviAliasEditor::exportSelected()
 {
 	exportAliases(true);
 }
 
-void KviAliasEditor::exportAliases(bool bSelectedOnly)
+void KviAliasEditor::exportSelectionInSinglesFiles(KviPointerList<KviAliasListViewItem> *l)
+{
+	if(!m_szDir.endsWith(QString(KVI_PATH_SEPARATOR)))m_szDir += KVI_PATH_SEPARATOR;
+	debug ("dir %s",m_szDir.latin1());
+	if (!l->first())
+	{
+		g_pAliasEditorModule->lock();
+		QMessageBox::warning(this,__tr2qs("Alias Export"),__tr2qs("There is not selection!"),__tr2qs("Ok"));
+		g_pAliasEditorModule->unlock();
+		return;
+	}
+	g_pAliasEditorModule->lock();
+
+	if(!KviFileDialog::askForDirectoryName(m_szDir,__tr2qs("Choose a Directory - KVIrc"),m_szDir)){
+		g_pAliasEditorModule->unlock();
+		return;
+	}
+	
+	if(!m_szDir.endsWith(QString(KVI_PATH_SEPARATOR)))m_szDir += KVI_PATH_SEPARATOR;
+	debug ("dir changed in %s",m_szDir.latin1());
+	
+	bool bReplaceAll=false;
+	
+	for(KviAliasListViewItem * it = l->first();it;it = l->next())
+	{
+		QString tmp;
+		getExportAliasBuffer(tmp,it);
+		QString szFileName=buildFullItemName(it);
+		szFileName += ".kvs";
+		szFileName.replace("::","_");
+		QString szCompletePath=m_szDir+szFileName;
+	
+		if (KviFileUtils::fileExists(szCompletePath) && !bReplaceAll)
+		{
+				QString szMsg;
+				KviQString::sprintf(szMsg,__tr2qs("The file \"%Q\" exists. Do you want to replace it ?"),&szFileName);
+				int ret = QMessageBox::question(this,__tr2qs("Replace file"),szMsg,__tr2qs("Yes"),__tr2qs("Yes to All"),__tr2qs("No"));
+				if (ret!=2){
+					KviFileUtils::writeFile(szCompletePath,tmp);
+					if (ret==1)	bReplaceAll=true;
+				}
+		
+		}
+		else
+		KviFileUtils::writeFile(szCompletePath,tmp);
+		
+	}
+	g_pAliasEditorModule->unlock();
+
+}
+void KviAliasEditor::exportAliases(bool bSelectedOnly,bool bSingleFiles)
 {
 	saveLastEditedItem();
 	
-	KviPtrList<KviAliasListViewItem> l;
+	KviPointerList<KviAliasListViewItem> l;
 	l.setAutoDelete(false);
 
 	QString out;
 
 	appendAliasItems(&l,(KviAliasEditorListViewItem *)(m_pListView->firstChild()),bSelectedOnly);
+	if (bSingleFiles)
+	{ 
+			exportSelectionInSinglesFiles(&l);
+			return;
 
+	}
 	int count=0;
 	KviAliasListViewItem * tempitem=0;
 	for(KviAliasListViewItem * it = l.first();it;it = l.next())
@@ -590,21 +663,26 @@ void KviAliasEditor::exportAliases(bool bSelectedOnly)
 		return;
 	}
 
-	QString szName = QDir::homeDirPath();
+	QString szName = m_szDir;
   
 	if(!szName.endsWith(QString(KVI_PATH_SEPARATOR)))szName += KVI_PATH_SEPARATOR;
+	QString szFile;
+	g_pAliasEditorModule->lock();
+	
 	if (count==1)
 	{
-		QString tmp=buildFullItemName(tempitem);
-		szNameFile = tmp.replace("::","_");
+			QString tmp=buildFullItemName(tempitem);
+			szNameFile = tmp.replace("::","_");
 	}
 	else szNameFile="aliases";
 	szName += szNameFile;
 	szName += ".kvs";
-	QString szFile;
-
-	g_pAliasEditorModule->lock();
-	if(!KviFileDialog::askForSaveFileName(szFile,__tr2qs("Choose a Filename - KVIrc"),szName,"*.kvs",false,true,true))return;
+	if(!KviFileDialog::askForSaveFileName(szFile,__tr2qs("Choose a Filename - KVIrc"),szName,"*.kvs",false,true,true))
+	{
+		g_pAliasEditorModule->unlock();		
+		return;
+	}
+	m_szDir=QFileInfo(szFile).dirPath(TRUE);
 	g_pAliasEditorModule->unlock();
 
 	if(!KviFileUtils::writeFile(szFile,out))
@@ -626,7 +704,7 @@ void KviAliasEditor::saveProperties(KviConfig *cfg)
 
 void KviAliasEditor::loadProperties(KviConfig *cfg)
 {
-	QValueList<int> def;
+	KviValueList<int> def;
 	def.append(20);
 	def.append(80);
 	m_pSplitter->setSizes(cfg->readIntListEntry("Sizes",def));
@@ -637,7 +715,7 @@ void KviAliasEditor::loadProperties(KviConfig *cfg)
 	if(it)activateItem(it);
 }
 
-void KviAliasEditor::appendAliasItems(KviPtrList<KviAliasListViewItem> * l,KviAliasEditorListViewItem * pStartFrom,bool bSelectedOnly)
+void KviAliasEditor::appendAliasItems(KviPointerList<KviAliasListViewItem> * l,KviAliasEditorListViewItem * pStartFrom,bool bSelectedOnly)
 {
 	if(!pStartFrom)return;
 	if(pStartFrom->isAlias())
@@ -663,7 +741,33 @@ void KviAliasEditor::appendAliasItems(KviPtrList<KviAliasListViewItem> * l,KviAl
 	appendAliasItems(l,(KviAliasEditorListViewItem *)(pStartFrom->nextSibling()),bSelectedOnly);
 }
 
-void KviAliasEditor::appendSelectedItems(KviPtrList<KviAliasEditorListViewItem> * l,KviAliasEditorListViewItem * pStartFrom,bool bIncludeChildrenOfSelected)
+void KviAliasEditor::appendNamespaceItems(KviPointerList<KviAliasListViewItem> * l,KviAliasEditorListViewItem * pStartFrom,bool bSelectedOnly)
+{
+	if(!pStartFrom)return;
+	if(pStartFrom->isNamespace())
+	{
+		if(bSelectedOnly)
+		{
+			if(pStartFrom->isSelected())
+				l->append((KviAliasListViewItem *)pStartFrom);
+		} else {
+			l->append((KviAliasListViewItem *)pStartFrom);
+		}
+	} else {
+		if(bSelectedOnly)
+		{
+			if(pStartFrom->isSelected())
+				appendNamespaceItems(l,(KviAliasEditorListViewItem *)(pStartFrom->firstChild()),false); // ALL the items below the selected namespace
+			else
+				appendNamespaceItems(l,(KviAliasEditorListViewItem *)(pStartFrom->firstChild()),true); // only the selected items below
+		} else {
+			appendNamespaceItems(l,(KviAliasEditorListViewItem *)(pStartFrom->firstChild()),false);
+		}
+	}
+	appendNamespaceItems(l,(KviAliasEditorListViewItem *)(pStartFrom->nextSibling()),bSelectedOnly);
+}
+
+void KviAliasEditor::appendSelectedItems(KviPointerList<KviAliasEditorListViewItem> * l,KviAliasEditorListViewItem * pStartFrom,bool bIncludeChildrenOfSelected)
 {
 	if(!pStartFrom)return;
 	if(pStartFrom->isSelected())
@@ -736,7 +840,7 @@ bool KviAliasEditor::removeItem(KviAliasEditorListViewItem *it,bool * pbYesToAll
 
 void KviAliasEditor::removeSelectedItems()
 {
-	KviPtrList<KviAliasEditorListViewItem> l;
+	KviPointerList<KviAliasEditorListViewItem> l;
 	l.setAutoDelete(false);
 	appendSelectedItems(&l,(KviAliasEditorListViewItem *)(m_pListView->firstChild()),false);
 
@@ -886,7 +990,7 @@ QString KviAliasEditor::askForNamespaceName(const QString &szAction,const QStrin
 	return szNewName;
 }
 
-void KviAliasEditor::openParentItems(QListViewItem * it)
+void KviAliasEditor::openParentItems(KviTalListViewItem * it)
 {
 	if(it->parent())
 	{
@@ -896,7 +1000,7 @@ void KviAliasEditor::openParentItems(QListViewItem * it)
 }
 
 
-void KviAliasEditor::selectOneItem(QListViewItem * it,QListViewItem *pStartFrom)
+void KviAliasEditor::selectOneItem(KviTalListViewItem * it,KviTalListViewItem *pStartFrom)
 {
 	if(!pStartFrom)return;
 	if(pStartFrom == it)pStartFrom->setSelected(true);
@@ -906,7 +1010,7 @@ void KviAliasEditor::selectOneItem(QListViewItem * it,QListViewItem *pStartFrom)
 }
 
 
-void KviAliasEditor::activateItem(QListViewItem * it)
+void KviAliasEditor::activateItem(KviTalListViewItem * it)
 {
 	openParentItems(it);
 	selectOneItem(it,m_pListView->firstChild());
@@ -963,6 +1067,37 @@ void KviAliasEditor::newNamespace()
 	activateItem(it);
 }
 
+bool KviAliasEditor::aliasExists(QString &szFullItemName)
+{
+	KviPointerList<KviAliasListViewItem> l;
+	l.setAutoDelete(false);
+
+	appendAliasItems(&l,(KviAliasEditorListViewItem *)(m_pListView->firstChild()),false);
+	for(KviAliasListViewItem * it = l.first();it;it = l.next())
+	{
+		if (KviQString::equalCI(buildFullItemName(it),szFullItemName))
+		{
+			return true;
+		}
+	}
+	return false;
+}
+
+bool KviAliasEditor::namespaceExists(QString &szFullItemName)
+{
+	KviPointerList<KviAliasListViewItem> l;
+	l.setAutoDelete(false);
+	
+	appendNamespaceItems(&l,(KviAliasEditorListViewItem *)(m_pListView->firstChild()),false);
+	for(KviAliasListViewItem * it = l.first();it;it = l.next())
+	{
+		if (KviQString::equalCI(buildFullItemName(it),szFullItemName))
+		{
+			return true;
+		}
+	}
+	return false;
+}
 void KviAliasEditor::renameItem()
 {
 	if(!m_pLastEditedItem)return;
@@ -981,6 +1116,33 @@ void KviAliasEditor::renameItem()
 
 	if(szName == szNewName)return;
 
+	// check if there is already an alias with this name
+	if (bAlias)
+	{
+		if (aliasExists(szNewName))
+		{
+			g_pAliasEditorModule->lock();
+			QMessageBox::information(this,
+						__tr2qs("Alias already exists"),
+						__tr2qs("This name is already in use. Please choose another one."),
+						__tr2qs("Ok, Let me try again..."));
+			g_pAliasEditorModule->unlock();
+			return;
+		}
+	} else {
+	// check if there is already a anmespace with this name
+		if (namespaceExists(szNewName))
+		{
+			g_pAliasEditorModule->lock();
+			QMessageBox::information(this,
+						__tr2qs("Namespace already exists"),
+						__tr2qs("This name is already in use. Please choose another one."),
+						__tr2qs("Ok, let me try again..."));
+			g_pAliasEditorModule->unlock();
+			return;
+		}
+	}
+	
 	QString szCode;
 	QPoint pntCursor;
 	if(bAlias)
@@ -990,9 +1152,9 @@ void KviAliasEditor::renameItem()
 	}
 
 	// take child items, if any
-	KviPtrList<QListViewItem> lChildren;
+	KviPointerList<KviTalListViewItem> lChildren;
 	lChildren.setAutoDelete(false);
-	QListViewItem * it = m_pLastEditedItem->firstChild();
+	KviTalListViewItem * it = m_pLastEditedItem->firstChild();
 	while(it)
 	{
 		lChildren.append(it);
@@ -1044,7 +1206,7 @@ void KviAliasEditor::saveLastEditedItem()
 	((KviAliasListViewItem *)m_pLastEditedItem)->setCursorPosition(m_pEditor->getCursor());
 }
 
-void KviAliasEditor::currentItemChanged(QListViewItem *it)
+void KviAliasEditor::currentItemChanged(KviTalListViewItem *it)
 {
 	saveLastEditedItem();
 
