@@ -23,9 +23,7 @@
 //==========================================================================================
 
 #include "kvi_module.h"
-//#include "kvi_uparser.h"
 #include "kvi_locale.h"
-#include "kvi_command.h"
 #include "kvi_frame.h"
 
 #include "aliaseditor.h"
@@ -76,7 +74,7 @@ static bool aliaseditor_module_can_unload(KviModule * m)
 static bool aliaseditor_module_cleanup(KviModule *m)
 {
 	if(g_pAliasEditorWindow)delete g_pAliasEditorWindow;
-    g_pAliasEditorWindow = 0;
+	g_pAliasEditorWindow = 0;
 	return true;
 }
 
