@@ -25,10 +25,8 @@
 #include "libkviavatar.h"
 
 #include "kvi_module.h"
-//#include "kvi_uparser.h"
 #include "kvi_fileutils.h"
 #include "kvi_locale.h"
-#include "kvi_command.h"
 #include "kvi_malloc.h"
 #include "kvi_app.h"
 #include "kvi_options.h"
@@ -36,26 +34,27 @@
 #include "kvi_iconmanager.h"
 #include "kvi_avatar.h"
 #include "kvi_ircuserdb.h"
-//#include "kvi_uparser.h"
+
 #include "kvi_ircconnection.h"
 #include "kvi_ircconnectionuserinfo.h"
 #include "kvi_console.h"
 #include "kvi_filedialog.h"
-#include "kvi_list.h"
+#include "kvi_pointerlist.h"
 #include "kvi_frame.h"
 #include "kvi_sharedfiles.h"
 #include "kvi_out.h"
 #include "kvi_ircmask.h"
+#include "kvi_qcstring.h"
 
 #include <qlineedit.h>
 #include <qpushbutton.h>
 #include <qmessagebox.h>
 #include <qtimer.h>
 #include <qlabel.h>
-#include <qhbox.h>
+#include "kvi_tal_hbox.h"
 #include <qlayout.h>
 
-static KviPtrList<KviAsyncAvatarSelectionDialog> * g_pAvatarSelectionDialogList = 0;
+static KviPointerList<KviAsyncAvatarSelectionDialog> * g_pAvatarSelectionDialogList = 0;
 extern KVIRC_API KviSharedFilesManager * g_pSharedFilesManager;
 
 KviAsyncAvatarSelectionDialog::KviAsyncAvatarSelectionDialog(QWidget * par,const QString &szInitialPath,KviIrcConnection * c)
@@ -71,10 +70,10 @@ KviAsyncAvatarSelectionDialog::KviAsyncAvatarSelectionDialog(QWidget * par,const
 	
 	QString msg = "<center>";
 	msg += __tr2qs("Please select an avatar image. " \
-				"The full path to a local file or an image on the Web can be used.<br>" \
-				"If you wish to use a local image file, click the \"<b>Browse</b>\"" \
-				"button to browse local folders.<br>" \
-				"The full URL for an image (including <b>http://</b>) can be entered manually.");
+		"The full path to a local file or an image on the Web can be used.<br>" \
+		"If you wish to use a local image file, click the \"<b>Browse</b>\"" \
+		"button to browse local folders.<br>" \
+		"The full URL for an image (including <b>http://</b>) can be entered manually.");
 	msg += "</center><br>";
 
 	QLabel * l = new QLabel(msg,this);
@@ -91,7 +90,7 @@ KviAsyncAvatarSelectionDialog::KviAsyncAvatarSelectionDialog(QWidget * par,const
 	QPushButton * b = new QPushButton(__tr2qs("&Browse..."),this);
 	connect(b,SIGNAL(clicked()),this,SLOT(chooseFileClicked()));
 	g->addWidget(b,1,2);
-	QHBox * h = new QHBox(this);h->setSpacing(8);g->addMultiCellWidget(h,2,2,1,2);
+	KviTalHBox * h = new KviTalHBox(this);h->setSpacing(8);g->addMultiCellWidget(h,2,2,1,2);
 	b = new QPushButton(__tr2qs("&OK"),h);
 	b->setMinimumWidth(80);
 	b->setDefault(true);
@@ -137,7 +136,7 @@ void KviAsyncAvatarSelectionDialog::cancelClicked()
 void KviAsyncAvatarSelectionDialog::chooseFileClicked()
 {
 	QString tmp;
- 	if(KviFileDialog::askForOpenFileName(tmp,__tr2qs("Choose an Image File - KVIrc")))
+	if(KviFileDialog::askForOpenFileName(tmp,__tr2qs("Choose an Image File - KVIrc")))
 	{
 		m_pLineEdit->setText(tmp);
 	}
@@ -403,11 +402,11 @@ static bool avatar_kvs_cmd_notify(KviKvsModuleCommandCall * c)
 	if(!c->switches()->find('q',"quiet"))
 		c->window()->output(KVI_OUT_AVATAR,__tr2qs("Notifying avatar '%Q' to %Q"),&avatar,&szTarget);
 
-	QCString encodedTarget = c->window()->connection()->encodeText(szTarget);
+	KviQCString encodedTarget = c->window()->connection()->encodeText(szTarget);
 
 	if(!avatar.isEmpty())
 	{
-		QCString encodedAvatar = c->window()->connection()->encodeText(avatar);
+		KviQCString encodedAvatar = c->window()->connection()->encodeText(avatar);
 		
 		if(o)
 		{
@@ -441,7 +440,7 @@ static bool avatar_kvs_cmd_notify(KviKvsModuleCommandCall * c)
 		is returned. The returned string is empty if the specified user has no
 		avatar set or there is no such user at all.
 	@seealso:
-		[fnc]$avatar.path[/fnc]()
+		[fnc]$avatar.path[/fnc]
 */
 
 static bool avatar_kvs_fnc_name(KviKvsModuleFunctionCall * c)
@@ -485,7 +484,7 @@ static bool avatar_kvs_fnc_name(KviKvsModuleFunctionCall * c)
 		is returned. The returned string is empty if the specified user has no
 		avatar set or there is no such user at all.
 	@seealso:
-		[fnc]$avatar.name[/fnc]()
+		[fnc]$avatar.name[/fnc]
 */
 
 static bool avatar_kvs_fnc_path(KviKvsModuleFunctionCall * c)
@@ -539,7 +538,7 @@ static bool avatar_kvs_cmd_query(KviKvsModuleCommandCall * c)
 
 	KVSM_REQUIRE_CONNECTION(c)
 
-	QCString target = c->window()->connection()->encodeText(szName);
+	KviQCString target = c->window()->connection()->encodeText(szName);
 	c->window()->connection()->sendFmtData("PRIVMSG %s :%cAVATAR%c",target.data(),0x01,0x01);
 
 	return true;
@@ -547,7 +546,7 @@ static bool avatar_kvs_cmd_query(KviKvsModuleCommandCall * c)
 
 static bool avatar_module_init(KviModule * m)
 {
-	g_pAvatarSelectionDialogList = new KviPtrList<KviAsyncAvatarSelectionDialog>;
+	g_pAvatarSelectionDialogList = new KviPointerList<KviAsyncAvatarSelectionDialog>;
 	g_pAvatarSelectionDialogList->setAutoDelete(false);
 
 	KVSM_REGISTER_SIMPLE_COMMAND(m,"query",avatar_kvs_cmd_query);
