@@ -27,31 +27,30 @@
 #include "kvi_string.h"
 #include "kvi_app.h"
 #include "kvi_channel.h"
-//#include "kvi_uparser.h"
-#include "kvi_command.h"
 #include "kvi_locale.h"
 #include "kvi_topicw.h"
-#include "kvi_datacontainer.h"
 #include "kvi_ircmask.h"
 #include "kvi_maskeditor.h"
+#include "kvi_ircurl.h"
+#include "kvi_ircconnectiontarget.h"
+#include "kvi_ircconnection.h"
 
-
-static KviChannel * chan_kvs_find_channel(KviKvsModuleFunctionCall * c,QString &szChan)
+static KviChannel * chan_kvs_find_channel(KviKvsModuleFunctionCall * c,QString &szChan,bool noWarnings=false)
 {
 	if(szChan.isEmpty())
 	{
 		if(c->window()->type() == KVI_WINDOW_TYPE_CHANNEL)return (KviChannel *)(c->window());
 		if(c->window()->type() == KVI_WINDOW_TYPE_DEADCHANNEL)return (KviChannel *)(c->window());
-		c->warning(__tr2qs("The current window is not a channel"));
+		if(!noWarnings) c->warning(__tr2qs("The current window is not a channel"));
 	} else {
 		KviWindow * w = g_pApp->findWindow(szChan);
 		if(!w)
 		{
-			c->warning(__tr2qs("Can't find the window with id '%Q'"),&szChan);
+			if(!noWarnings) c->warning(__tr2qs("Can't find the window with id '%Q'"),&szChan);
 			return 0;
 		}
 		if(w->type() == KVI_WINDOW_TYPE_CHANNEL)return (KviChannel *)w;
-		c->warning(__tr2qs("The specified window (%Q) is not a channel"),&szChan);
+		if(!noWarnings) c->warning(__tr2qs("The specified window (%Q) is not a channel"),&szChan);
 	}
 	return 0;
 }
@@ -76,13 +75,58 @@ static KviChannel * chan_kvs_find_channel(KviKvsModuleFunctionCall * c,QString &
 */
 
 static bool chan_kvs_fnc_name(KviKvsModuleFunctionCall * c)
-{ 
+{
 	QString szId;
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("window id",KVS_PT_STRING,KVS_PF_OPTIONAL,szId)
 	KVSM_PARAMETERS_END(c)
 	KviChannel * ch = chan_kvs_find_channel(c,szId);
-	if (ch) c->returnValue()->setString(ch->windowName());
+	if (ch) {
+		c->returnValue()->setString(ch->windowName());
+	}
+	return true;
+}
+
+/*
+	@doc: chan.getUrl
+	@type:
+		function
+	@title:
+		$chan.getUrl
+	@short:
+		Returns the URL of a channel
+	@syntax:
+		<string> $chan.getUrl
+		<string> $chan.getUrl(<window_id:string>)
+		<string> $chan.getUrl(<channel_name:string>)
+	@description:
+		Returns IRC URL for this channel
+*/
+
+static bool chan_kvs_fnc_getUrl(KviKvsModuleFunctionCall * c)
+{
+	QString szId,url;
+	KVSM_PARAMETERS_BEGIN(c)
+		KVSM_PARAMETER("channel id",KVS_PT_STRING,KVS_PF_OPTIONAL,szId)
+	KVSM_PARAMETERS_END(c)
+	KviChannel * ch = chan_kvs_find_channel(c,szId,true);
+	if (ch) {
+		KviIrcUrl::join(url,ch->connection()->target()->server());
+		url.append(ch->windowName());
+		if(ch->hasChannelKey())
+		{
+			url.append('?');
+			url.append(ch->channelKey());
+		}
+	} else {
+		if(c->window()->connection()) {
+			KviIrcUrl::join(url,c->window()->connection()->target()->server());
+			url.append(szId);
+		} else {
+			c->error("There is no active IRC connection for current context");
+		}
+	}
+	c->returnValue()->setString(url);
 	return true;
 }
 
@@ -103,7 +147,7 @@ static bool chan_kvs_fnc_name(KviKvsModuleFunctionCall * c)
 */
 
 static bool chan_kvs_fnc_isdead(KviKvsModuleFunctionCall * c)
-{ 
+{
 	QString szId;
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("window id",KVS_PT_STRING,KVS_PF_OPTIONAL,szId)
@@ -137,7 +181,7 @@ static bool chan_kvs_fnc_isdead(KviKvsModuleFunctionCall * c)
 */
 
 static bool chan_kvs_fnc_topic(KviKvsModuleFunctionCall * c)
-{ 
+{
 	QString szId;
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("window id",KVS_PT_STRING,KVS_PF_OPTIONAL,szId)
@@ -171,7 +215,7 @@ static bool chan_kvs_fnc_topic(KviKvsModuleFunctionCall * c)
 */
 
 static bool chan_kvs_fnc_topicsetby(KviKvsModuleFunctionCall * c)
-{ 
+{
 	QString szId;
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("window id",KVS_PT_STRING,KVS_PF_OPTIONAL,szId)
@@ -205,7 +249,7 @@ static bool chan_kvs_fnc_topicsetby(KviKvsModuleFunctionCall * c)
 */
 
 static bool chan_kvs_fnc_topicsetat(KviKvsModuleFunctionCall * c)
-{ 
+{
 	QString szId;
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("window id",KVS_PT_STRING,KVS_PF_OPTIONAL,szId)
@@ -236,7 +280,7 @@ static bool chan_kvs_fnc_topicsetat(KviKvsModuleFunctionCall * c)
 */
 
 static bool chan_kvs_fnc_usercount(KviKvsModuleFunctionCall * c)
-{ 
+{
 	QString szId;
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("window id",KVS_PT_STRING,KVS_PF_OPTIONAL,szId)
@@ -268,7 +312,7 @@ static bool chan_kvs_fnc_usercount(KviKvsModuleFunctionCall * c)
 */
 
 static bool chan_kvs_fnc_ownercount(KviKvsModuleFunctionCall * c)
-{ 
+{
 	QString szId;
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("window id",KVS_PT_STRING,KVS_PF_OPTIONAL,szId)
@@ -300,7 +344,7 @@ static bool chan_kvs_fnc_ownercount(KviKvsModuleFunctionCall * c)
 */
 
 static bool chan_kvs_fnc_admincount(KviKvsModuleFunctionCall * c)
-{ 
+{
 	QString szId;
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("window id",KVS_PT_STRING,KVS_PF_OPTIONAL,szId)
@@ -333,7 +377,7 @@ static bool chan_kvs_fnc_admincount(KviKvsModuleFunctionCall * c)
 */
 
 static bool chan_kvs_fnc_opcount(KviKvsModuleFunctionCall * c)
-{ 
+{
 	QString szId;
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("window id",KVS_PT_STRING,KVS_PF_OPTIONAL,szId)
@@ -365,7 +409,7 @@ static bool chan_kvs_fnc_opcount(KviKvsModuleFunctionCall * c)
 */
 
 static bool chan_kvs_fnc_voicecount(KviKvsModuleFunctionCall * c)
-{ 
+{
 	QString szId;
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("window id",KVS_PT_STRING,KVS_PF_OPTIONAL,szId)
@@ -397,7 +441,7 @@ static bool chan_kvs_fnc_voicecount(KviKvsModuleFunctionCall * c)
 */
 
 static bool chan_kvs_fnc_halfopcount(KviKvsModuleFunctionCall * c)
-{ 
+{
 	QString szId;
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("window id",KVS_PT_STRING,KVS_PF_OPTIONAL,szId)
@@ -429,7 +473,7 @@ static bool chan_kvs_fnc_halfopcount(KviKvsModuleFunctionCall * c)
 */
 
 static bool chan_kvs_fnc_useropcount(KviKvsModuleFunctionCall * c)
-{ 
+{
 	QString szId;
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("window id",KVS_PT_STRING,KVS_PF_OPTIONAL,szId)
@@ -461,7 +505,7 @@ static bool chan_kvs_fnc_useropcount(KviKvsModuleFunctionCall * c)
 */
 
 static bool chan_kvs_fnc_bancount(KviKvsModuleFunctionCall * c)
-{ 
+{
 	QString szId;
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("window id",KVS_PT_STRING,KVS_PF_OPTIONAL,szId)
@@ -493,7 +537,7 @@ static bool chan_kvs_fnc_bancount(KviKvsModuleFunctionCall * c)
 */
 
 static bool chan_kvs_fnc_banexceptioncount(KviKvsModuleFunctionCall * c)
-{ 
+{
 	QString szId;
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("window id",KVS_PT_STRING,KVS_PF_OPTIONAL,szId)
@@ -525,7 +569,7 @@ static bool chan_kvs_fnc_banexceptioncount(KviKvsModuleFunctionCall * c)
 */
 
 static bool chan_kvs_fnc_invitecount(KviKvsModuleFunctionCall * c)
-{ 
+{
 	QString szId;
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("window id",KVS_PT_STRING,KVS_PF_OPTIONAL,szId)
@@ -552,7 +596,7 @@ static bool chan_kvs_fnc_invitecount(KviKvsModuleFunctionCall * c)
 */
 
 static bool chan_kvs_fnc_ison(KviKvsModuleFunctionCall * c)
-{ 
+{
 	QString szId,szNick;
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("nickname",KVS_PT_NONEMPTYSTRING,0,szNick)
@@ -585,20 +629,27 @@ static bool chan_kvs_fnc_ison(KviKvsModuleFunctionCall * c)
 			'+' for voiced users[br]
 			'-' for userops[br]
 		If the user has more than one flag then the highest one is returned.[br]
+		If the user has no flag at all then an empty string is returned.
 */
 
 static bool chan_kvs_fnc_getflag(KviKvsModuleFunctionCall * c)
-{ 
+{
 	QString szId,szNick;
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("nickname",KVS_PT_NONEMPTYSTRING,0,szNick)
 		KVSM_PARAMETER("window id",KVS_PT_STRING,KVS_PF_OPTIONAL,szId)
 	KVSM_PARAMETERS_END(c)
 	KviChannel * ch = chan_kvs_find_channel(c,szId);
-	if (ch)
+	if(ch)
 	{
-		QString szFlag = QChar(ch->userListView()->getUserFlag(szNick));
-		if (szFlag) c->returnValue()->setString(szFlag);
+		QChar cFlag = ch->userListView()->getUserFlag(szNick);
+		if(cFlag != QChar(0))
+		{
+			QString szFlag = cFlag;
+			c->returnValue()->setString(szFlag);
+		} else {
+			c->returnValue()->setNothing();
+		}
 	}
 	return true;
 }
@@ -882,7 +933,7 @@ IS_ME_KVS_FUNC(chan_kvs_fnc_ismeuserop,isMeUserOp)
 */
 
 static bool chan_kvs_fnc_mode(KviKvsModuleFunctionCall * c)
-{ 
+{
 	QString szId;
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("window id",KVS_PT_STRING,KVS_PF_OPTIONAL,szId)
@@ -918,13 +969,13 @@ static bool chan_kvs_fnc_mode(KviKvsModuleFunctionCall * c)
 */
 
 static bool chan_kvs_fnc_key(KviKvsModuleFunctionCall * c)
-{ 
+{
 	QString szId;
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("window id",KVS_PT_STRING,KVS_PF_OPTIONAL,szId)
 	KVSM_PARAMETERS_END(c)
 	KviChannel * ch = chan_kvs_find_channel(c,szId);
-	if (ch) c->returnValue()->setString(ch->channelKey().ptr());
+	if (ch) c->returnValue()->setString(ch->channelKey());
 	return true;
 }
 
@@ -948,7 +999,7 @@ static bool chan_kvs_fnc_key(KviKvsModuleFunctionCall * c)
 */
 
 static bool chan_kvs_fnc_limit(KviKvsModuleFunctionCall * c)
-{ 
+{
 	QString szId;
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("window id",KVS_PT_STRING,KVS_PF_OPTIONAL,szId)
@@ -1026,7 +1077,7 @@ static bool chan_kvs_fnc_limit(KviKvsModuleFunctionCall * c)
 */
 
 static bool chan_kvs_fnc_users(KviKvsModuleFunctionCall * c)
-{ 
+{
 	QString szWinId,szMask,szFlags;
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("window id",KVS_PT_STRING,KVS_PF_OPTIONAL,szWinId)
@@ -1141,7 +1192,7 @@ next_item:
 */
 
 static bool chan_kvs_fnc_banlist(KviKvsModuleFunctionCall * c)
-{ 
+{
 	QString szWinId,szMask,szFlags;
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("window id",KVS_PT_STRING,KVS_PF_OPTIONAL,szWinId)
@@ -1156,7 +1207,7 @@ static bool chan_kvs_fnc_banlist(KviKvsModuleFunctionCall * c)
 
 	int idx = 0;
 
-	KviPtrList<KviMaskEntry> * l = ((KviChannel *)(c->window()))->banList();
+	KviPointerList<KviMaskEntry> * l = ((KviChannel *)(c->window()))->banList();
 
 	for(KviMaskEntry * e = l->first();e;e = l->next())
 	{
@@ -1184,7 +1235,7 @@ static bool chan_kvs_fnc_banlist(KviKvsModuleFunctionCall * c)
 */
 
 static bool chan_kvs_fnc_banexceptionlist(KviKvsModuleFunctionCall * c)
-{ 
+{
 	QString szWinId,szMask,szFlags;
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("window id",KVS_PT_STRING,KVS_PF_OPTIONAL,szWinId)
@@ -1199,7 +1250,7 @@ static bool chan_kvs_fnc_banexceptionlist(KviKvsModuleFunctionCall * c)
 
 	int idx = 0;
 
-	KviPtrList<KviMaskEntry> * l = ((KviChannel *)(c->window()))->banExceptionList();
+	KviPointerList<KviMaskEntry> * l = ((KviChannel *)(c->window()))->banExceptionList();
 
 	for(KviMaskEntry * e = l->first();e;e = l->next())
 	{
@@ -1227,7 +1278,7 @@ static bool chan_kvs_fnc_banexceptionlist(KviKvsModuleFunctionCall * c)
 */
 
 static bool chan_kvs_fnc_invitelist(KviKvsModuleFunctionCall * c)
-{ 
+{
 	QString szWinId,szMask,szFlags;
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("window id",KVS_PT_STRING,KVS_PF_OPTIONAL,szWinId)
@@ -1242,7 +1293,7 @@ static bool chan_kvs_fnc_invitelist(KviKvsModuleFunctionCall * c)
 
 	int idx = 0;
 
-	KviPtrList<KviMaskEntry> * l = ((KviChannel *)(c->window()))->inviteList();
+	KviPointerList<KviMaskEntry> * l = ((KviChannel *)(c->window()))->inviteList();
 
 	for(KviMaskEntry * e = l->first();e;e = l->next())
 	{
@@ -1272,7 +1323,7 @@ static bool chan_kvs_fnc_invitelist(KviKvsModuleFunctionCall * c)
 */
 
 static bool chan_kvs_fnc_matchban(KviKvsModuleFunctionCall * c)
-{ 
+{
 	QString szWinId,szMask;
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("window id",KVS_PT_STRING,0,szWinId)
@@ -1287,7 +1338,7 @@ static bool chan_kvs_fnc_matchban(KviKvsModuleFunctionCall * c)
 		return true;
 	}
 
-	KviPtrList<KviMaskEntry> * l = ((KviChannel *)(c->window()))->banList();
+	KviPointerList<KviMaskEntry> * l = ((KviChannel *)(c->window()))->banList();
 
 	for(KviMaskEntry * e = l->first();e;e = l->next())
 	{
@@ -1321,7 +1372,7 @@ static bool chan_kvs_fnc_matchban(KviKvsModuleFunctionCall * c)
 */
 
 static bool chan_kvs_fnc_matchbanexception(KviKvsModuleFunctionCall * c)
-{ 
+{
 	QString szWinId,szMask;
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("window id",KVS_PT_STRING,0,szWinId)
@@ -1336,7 +1387,7 @@ static bool chan_kvs_fnc_matchbanexception(KviKvsModuleFunctionCall * c)
 		return true;
 	}
 
-	KviPtrList<KviMaskEntry> * l = ((KviChannel *)(c->window()))->banExceptionList();
+	KviPointerList<KviMaskEntry> * l = ((KviChannel *)(c->window()))->banExceptionList();
 
 	for(KviMaskEntry * e = l->first();e;e = l->next())
 	{
@@ -1370,7 +1421,7 @@ static bool chan_kvs_fnc_matchbanexception(KviKvsModuleFunctionCall * c)
 */
 
 static bool chan_kvs_fnc_matchinvite(KviKvsModuleFunctionCall * c)
-{ 
+{
 	QString szWinId,szMask;
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("window id",KVS_PT_STRING,0,szWinId)
@@ -1385,7 +1436,7 @@ static bool chan_kvs_fnc_matchinvite(KviKvsModuleFunctionCall * c)
 		return true;
 	}
 
-	KviPtrList<KviMaskEntry> * l = ((KviChannel *)(c->window()))->inviteList();
+	KviPointerList<KviMaskEntry> * l = ((KviChannel *)(c->window()))->inviteList();
 
 	for(KviMaskEntry * e = l->first();e;e = l->next())
 	{
@@ -1427,7 +1478,7 @@ static bool chan_kvs_fnc_matchinvite(KviKvsModuleFunctionCall * c)
 */
 
 static bool chan_kvs_fnc_usermodelevel(KviKvsModuleFunctionCall * c)
-{ 
+{
 	QString szNick,szWinId;
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("nickname",KVS_PT_STRING,0,szNick)
@@ -1459,11 +1510,11 @@ static bool chan_kvs_fnc_usermodelevel(KviKvsModuleFunctionCall * c)
 		for all the users that were on the channel before the local user has joined it (e.g.
 		you know the join time only for users that YOU see joining).[br]
 	@seealso:
-		[fnc]$unixtime[/fnc], [fnc]$chan.userLastActionTime[/fnc]()
+		[fnc]$unixTime[/fnc], [fnc]$chan.userLastActionTime[/fnc]
 */
 
 static bool chan_kvs_fnc_userjointime(KviKvsModuleFunctionCall * c)
-{ 
+{
 	QString szNick,szWinId;
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("nickname",KVS_PT_STRING,0,szNick)
@@ -1496,11 +1547,11 @@ static bool chan_kvs_fnc_userjointime(KviKvsModuleFunctionCall * c)
 		for all the users that were on the channel before the local user has joined it
 		and have performed no actions since that moment.
 	@seealso:
-		[fnc]$unixtime[/fnc](), [fnc]$chan.userJoinTime[/fnc]()
+		[fnc]$unixTime[/fnc], [fnc]$chan.userJoinTime[/fnc]
 */
 
 static bool chan_kvs_fnc_userlastactiontime(KviKvsModuleFunctionCall * c)
-{ 
+{
 	QString szNick,szWinId;
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("nickname",KVS_PT_STRING,0,szNick)
@@ -1516,7 +1567,6 @@ static bool chan_kvs_fnc_userlastactiontime(KviKvsModuleFunctionCall * c)
 
 static bool chan_module_init(KviModule * m)
 {
-
 	KVSM_REGISTER_FUNCTION(m,"name",chan_kvs_fnc_name);
 	KVSM_REGISTER_FUNCTION(m,"topic",chan_kvs_fnc_topic);
 	KVSM_REGISTER_FUNCTION(m,"topicsetby",chan_kvs_fnc_topicsetby);
@@ -1561,6 +1611,7 @@ static bool chan_module_init(KviModule * m)
 	KVSM_REGISTER_FUNCTION(m,"matchban",chan_kvs_fnc_matchban);
 	KVSM_REGISTER_FUNCTION(m,"matchbanexception",chan_kvs_fnc_matchbanexception);
 	KVSM_REGISTER_FUNCTION(m,"matchinvite",chan_kvs_fnc_matchinvite);
+	KVSM_REGISTER_FUNCTION(m,"getUrl",chan_kvs_fnc_getUrl);
 
 	return true;
 }
