@@ -23,14 +23,12 @@
 
 #include "libkviclock.h"
 #include "kvi_module.h"
-//#include "kvi_uparser.h"
 #include "kvi_console.h"
 #include "kvi_options.h"
-//#include "kvi_ircsocket.h"
 #include "kvi_frame.h"
 #include "kvi_locale.h"
 
-#include "kvi_list.h"
+#include "kvi_pointerlist.h"
 #include <qbitmap.h>
 #include <qtooltip.h>
 #include <qpainter.h>
@@ -87,7 +85,7 @@ extern QPixmap                 * g_pIccMemBuffer;
 //extern HANDLE                      g_hIccMemBuffer;
 
 
-static KviPtrList<KviClockDisplay> * g_pClockWidgetList;
+static KviPointerList<KviClockDisplay> * g_pClockWidgetList;
 
 static QBitmap * g_pClockBitmap = 0;
 
@@ -214,7 +212,7 @@ static bool clock_module_init(KviModule *m)
 	g_pClockBitmap = new QBitmap();
 	QPixmap pix(kvi_clock_digits_xpm);
 	*g_pClockBitmap = pix;
-	g_pClockWidgetList = new KviPtrList<KviClockDisplay>;
+	g_pClockWidgetList = new KviPointerList<KviClockDisplay>;
 	g_pClockWidgetList->setAutoDelete(false);
 	m->registerCommand("add",clock_module_cmd_add);
 #endif
