@@ -28,7 +28,7 @@
 #include "kvi_filedialog.h"
 #include "kvi_fileutils.h"
 #include "kvi_scripteditor.h"
-//#include "kvi_uparser.h"
+
 #include "kvi_app.h"
 #include "kvi_console.h"
 #include "kvi_parameterlist.h"
@@ -39,9 +39,9 @@
 #include <qlayout.h>
 #include <qlabel.h>
 #include <qtoolbutton.h>
-#include <qpopupmenu.h>
+#include "kvi_tal_popupmenu.h"
 
-extern KviPtrList<KviCodeTesterWindow> * g_pCodeTesterWindowList;
+extern KviPointerList<KviCodeTesterWindow> * g_pCodeTesterWindowList;
 
 
 
