@@ -23,15 +23,13 @@
 //===============================================================================
 
 #include "kvi_module.h"
-//#include "kvi_uparser.h"
 #include "kvi_locale.h"
-#include "kvi_command.h"
 #include "kvi_frame.h"
-#include "kvi_list.h"
+#include "kvi_pointerlist.h"
 
 #include "codetester.h"
 
-KviPtrList<KviCodeTesterWindow> * g_pCodeTesterWindowList = 0;
+KviPointerList<KviCodeTesterWindow> * g_pCodeTesterWindowList = 0;
 
 
 /*
@@ -49,7 +47,7 @@ KviPtrList<KviCodeTesterWindow> * g_pCodeTesterWindowList = 0;
 */
 
 static bool codetester_kvs_cmd_open(KviKvsModuleCommandCall * c)
-{ 
+{
 	KviCodeTesterWindow * w = new KviCodeTesterWindow(c->window()->frame());
 	c->window()->frame()->addWindow(w);
 	w->setFocus();
@@ -60,7 +58,7 @@ static bool codetester_module_init(KviModule * m)
 {
 	KVSM_REGISTER_SIMPLE_COMMAND(m,"open",codetester_kvs_cmd_open);
 
-	g_pCodeTesterWindowList = new KviPtrList<KviCodeTesterWindow>();
+	g_pCodeTesterWindowList = new KviPointerList<KviCodeTesterWindow>();
 	g_pCodeTesterWindowList->setAutoDelete(false);
 	return true;
 }
