@@ -26,14 +26,12 @@
 #include "kvi_string.h"
 #include "kvi_config.h"
 #include "kvi_fileutils.h"
-//#include "kvi_uparser.h"
-#include "kvi_command.h"
 #include "kvi_app.h"
 #include "kvi_locale.h"
 
-#include <qdict.h>
+#include "kvi_pointerhashtable.h"
 
-static QDict<KviConfig> * g_pConfigDict = 0;
+static KviPointerHashTable<QString,KviConfig> * g_pConfigDict = 0;
 static int g_iNextConfigId = 0;
 
 /*
@@ -83,7 +81,7 @@ static int g_iNextConfigId = 0;
 
 
 static bool config_kvs_fnc_open(KviKvsModuleFunctionCall * c)
-{ 
+{
 	QString szFile; 
 	QString szMode;
 	
@@ -109,7 +107,7 @@ static bool config_kvs_fnc_open(KviKvsModuleFunctionCall * c)
 	if(KviFileUtils::isAbsolutePath(szFile))szAbsFile = szFile;
 	else g_pApp->getLocalKvircDirectory(szAbsFile,KviApp::ConfigScripts,szFile,true);
 
-	QDictIterator<KviConfig> it(*g_pConfigDict);
+	KviPointerHashTableIterator<QString,KviConfig> it(*g_pConfigDict);
 	while(it.current())
 	{
 		if(KviQString::equalCI(it.current()->fileName(),szAbsFile))
@@ -151,8 +149,8 @@ static bool config_kvs_fnc_open(KviKvsModuleFunctionCall * c)
 */
 
 static bool config_kvs_fnc_id(KviKvsModuleFunctionCall * c)
-{ 
-	QString szFile; 
+{
+	QString szFile;
 	
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("file",KVS_PT_STRING,0,szFile)
@@ -165,7 +163,7 @@ static bool config_kvs_fnc_id(KviKvsModuleFunctionCall * c)
 	if(KviFileUtils::isAbsolutePath(szFile))szAbsFile = szFile;
 	else g_pApp->getLocalKvircDirectory(szAbsFile,KviApp::ConfigScripts,szFile,true);
 
-	QDictIterator<KviConfig> it(*g_pConfigDict);
+	KviPointerHashTableIterator<QString,KviConfig> it(*g_pConfigDict);
 	while(it.current())
 	{
 		if(KviQString::equalCI(it.current()->fileName(),szAbsFile))
@@ -202,8 +200,8 @@ static bool config_kvs_fnc_id(KviKvsModuleFunctionCall * c)
 */
 
 static bool config_kvs_fnc_read(KviKvsModuleFunctionCall * c)
-{ 
-	QString szId; 
+{
+	QString szId;
 	QString szKey;
 	QString szDefault;
 	
@@ -242,8 +240,8 @@ static bool config_kvs_fnc_read(KviKvsModuleFunctionCall * c)
 */
 
 static bool config_kvs_fnc_section(KviKvsModuleFunctionCall * c)
-{ 
-	QString szId; 
+{
+	QString szId;
 	
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("id",KVS_PT_STRING,0,szId)
@@ -280,8 +278,8 @@ static bool config_kvs_fnc_section(KviKvsModuleFunctionCall * c)
 */
 
 static bool config_kvs_fnc_readonly(KviKvsModuleFunctionCall * c)
-{ 
-	QString szId; 
+{
+	QString szId;
 	
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("id",KVS_PT_STRING,0,szId)
@@ -318,8 +316,8 @@ static bool config_kvs_fnc_readonly(KviKvsModuleFunctionCall * c)
 */
 
 static bool config_kvs_fnc_filename(KviKvsModuleFunctionCall * c)
-{ 
-	QString szId; 
+{
+	QString szId;
 	
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("id",KVS_PT_STRING,0,szId)
@@ -353,7 +351,7 @@ static bool config_kvs_fnc_filename(KviKvsModuleFunctionCall * c)
 */
 
 static bool config_kvs_fnc_hassection(KviKvsModuleFunctionCall * c)
-{ 
+{
 	QString szId;
 	QString szSect;
 	
@@ -391,8 +389,8 @@ static bool config_kvs_fnc_hassection(KviKvsModuleFunctionCall * c)
 */
 
 static bool config_kvs_fnc_sectionlist(KviKvsModuleFunctionCall * c)
-{ 
-	QString szId; 
+{
+	QString szId;
 	
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("id",KVS_PT_STRING,0,szId)
@@ -435,8 +433,8 @@ static bool config_kvs_fnc_sectionlist(KviKvsModuleFunctionCall * c)
 */
 
 static bool config_kvs_fnc_keylist(KviKvsModuleFunctionCall * c)
-{ 
-	QString szId; 
+{
+	QString szId;
 	
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("id",KVS_PT_STRING,0,szId)
@@ -483,15 +481,14 @@ static bool config_kvs_fnc_keylist(KviKvsModuleFunctionCall * c)
 */
 
 static bool config_kvs_fnc_filelist(KviKvsModuleFunctionCall * c)
-{ 
-	
+{
 	KVSM_PARAMETERS_BEGIN(c)
 	KVSM_PARAMETERS_END(c)
 	
 	KviKvsArray* pArray = new KviKvsArray();
 	int id=0;
 	
-	QDictIterator<KviConfig> it(*g_pConfigDict);
+	KviPointerHashTableIterator<QString,KviConfig> it(*g_pConfigDict);
 	while(it.current())
 	{
 		pArray->set(id++, new KviKvsVariant(it.currentKey()));
@@ -538,7 +535,7 @@ static bool config_kvs_cmd_close(KviKvsModuleCommandCall * c)
 		if(cfg->dirty() && cfg->readOnly())
 		{
 			if(!c->hasSwitch('q',"quiet"))
-				c->warning(__tr2qs("The config file '%s' has been changed but is opened as read-only: changes will be lost"),&szId);
+				c->warning(__tr2qs("The config file '%Q' has been changed but is opened as read-only: changes will be lost"),&cfg->fileName());
 		}
 		g_pConfigDict->remove(szId); 
 	} else {
@@ -812,16 +809,16 @@ static bool config_kvs_cmd_setsection(KviKvsModuleCommandCall * c)
 		You write entries by using [cmd]config.write[/cmd] and read them by using [fnc]$config.read[/fnc]().[br]
 		You can change the "current" config section by using [cmd]config.setsection[/cmd].[br]
 		Here comes a complete list of commands and functions exported by this module:[br]
-		[fnc]$config.open[/fnc]()[br]
-		[fnc]$config.read[/fnc]()[br]
-		[fnc]$config.section[/fnc]()[br]
-		[fnc]$config.hassection[/fnc]()[br]
-		[fnc]$config.sectionlist[/fnc]()[br]
-		[fnc]$config.keylist[/fnc]()[br]
-		[fnc]$config.filelist[/fnc]()[br]
-		[fnc]$config.filename[/fnc]()[br]
-		[fnc]$config.id[/fnc]()[br]
-		[fnc]$config.readonly[/fnc]()[br]
+		[fnc]$config.open[/fnc][br]
+		[fnc]$config.read[/fnc][br]
+		[fnc]$config.section[/fnc][br]
+		[fnc]$config.hassection[/fnc][br]
+		[fnc]$config.sectionlist[/fnc][br]
+		[fnc]$config.keylist[/fnc][br]
+		[fnc]$config.filelist[/fnc][br]
+		[fnc]$config.filename[/fnc][br]
+		[fnc]$config.id[/fnc][br]
+		[fnc]$config.readonly[/fnc][br]
 		[cmd]config.close[/cmd][br]
 		[cmd]config.flush[/cmd][br]
 		[cmd]config.clear[/cmd][br]
@@ -832,7 +829,7 @@ static bool config_kvs_cmd_setsection(KviKvsModuleCommandCall * c)
 
 static bool config_module_init(KviModule * m)
 {
-	g_pConfigDict = new QDict<KviConfig>;
+	g_pConfigDict = new KviPointerHashTable<QString,KviConfig>;
 	g_pConfigDict->setAutoDelete(true);
 
 	KVSM_REGISTER_FUNCTION(m,"open",config_kvs_fnc_open);
