@@ -24,7 +24,9 @@
 #include "dialogs.h"
 #include "chat.h"
 #include "send.h"
+#ifdef COMPILE_DCC_CANVAS
 #include "canvas.h"
+#endif
 #include "voice.h"
 
 #include "kvi_app.h"
@@ -52,13 +54,13 @@ KviDccBroker::KviDccBroker()
 {
 	KviDccFileTransfer::init();
 
-	m_pBoxList = new KviPtrList<KviDccBox>;
+	m_pBoxList = new KviPointerList<KviDccBox>;
 	m_pBoxList->setAutoDelete(false);
 
-	m_pDccWindowList = new KviPtrList<KviWindow>;
+	m_pDccWindowList = new KviPointerList<KviWindow>;
 	m_pDccWindowList->setAutoDelete(false);
 
-	m_pZeroPortTags = new QDict<KviDccZeroPortTag>(17);
+	m_pZeroPortTags = new KviPointerHashTable<QString,KviDccZeroPortTag>(17);
 	m_pZeroPortTags->setAutoDelete(true);
 }
 
@@ -123,6 +125,12 @@ void KviDccBroker::unregisterDccBox(KviDccBox * box)
 }
 
 
+void KviDccBroker::cancelDcc(KviDccDescriptor * dcc)
+{
+	delete dcc;
+    dcc = 0;
+}
+
 void KviDccBroker::cancelDcc(KviDccBox *box,KviDccDescriptor * dcc)
 {
 	if(box)box->forgetDescriptor();
@@ -144,19 +152,36 @@ void KviDccBroker::rsendManage(KviDccDescriptor * dcc)
 
 void KviDccBroker::rsendAskForFileName(KviDccDescriptor * dcc)
 {
-	KviDccLoadFileBox * box = new KviDccLoadFileBox(this,dcc);
-	m_pBoxList->append(box);
-	connect(box,SIGNAL(accepted(KviDccBox *,KviDccDescriptor *)),
-			this,SLOT(rsendExecute(KviDccBox *,KviDccDescriptor *)));
-	connect(box,SIGNAL(rejected(KviDccBox *,KviDccDescriptor *)),
-			this,SLOT(cancelDcc(KviDccBox *,KviDccDescriptor *)));
-	box->show();
+	QStringList filenames;
+	if(
+		KviFileDialog::askForOpenFileNames(filenames,
+		__tr2qs_ctx("Choose Files to Send - KVIrc","dcc"),"")
+		) {
+			if(filenames.count() > 0)
+			{
+				KviDccDescriptor * d;
+				KviDccDescriptor * templ = dcc;
+				QStringList::Iterator it=filenames.begin();
+				while(it != filenames.end())
+				{
+					d = new KviDccDescriptor(*dcc);
+					d->szLocalFileName = *(it);
+					d->szLocalFileName.stripWhiteSpace();
+					++it;
+					if(d->szLocalFileName.isEmpty()) 
+						cancelDcc(d);
+					else 
+						rsendExecute(d);
+				}
+				delete dcc;
+			}
+	} else {
+			cancelDcc(dcc);
+	}
 }
 
-void KviDccBroker::rsendExecute(KviDccBox * box,KviDccDescriptor * dcc)
+void KviDccBroker::rsendExecute(KviDccDescriptor * dcc)
 {
-	if(box)box->forgetDescriptor();
-
 	if(!g_pApp->windowExists(dcc->console()))
 	{
 		// No way...we NEED the right IRC context...
@@ -194,7 +219,7 @@ void KviDccBroker::rsendExecute(KviDccBox * box,KviDccDescriptor * dcc)
 		szTag = t->m_szTag;
 
 		// DCC [ST]SEND <filename> <fakeipaddress> <zero-port> <filesize> <sessionid>
-		dcc->console()->connection()->sendFmtData("PRIVMSG %s :%cDCC %s %s 0.0.0.0 0 %u %s%c",
+		dcc->console()->connection()->sendFmtData("PRIVMSG %s :%cDCC %s %s 127.0.0.1 0 %u %s%c",
 			dcc->console()->connection()->encodeText(dcc->szNick).data(),
 			0x01,
 			dcc->console()->connection()->encodeText(dcc->szType).data(),
@@ -222,6 +247,12 @@ void KviDccBroker::rsendExecute(KviDccBox * box,KviDccDescriptor * dcc)
 	delete dcc;
 }
 
+void KviDccBroker::rsendExecute(KviDccBox * box,KviDccDescriptor * dcc)
+{
+	if(box)box->forgetDescriptor();
+	rsendExecute(dcc);
+}
+
 
 ///////////////////////////////////////////////////////////////////////////////
 // DCC CHAT
@@ -369,6 +400,8 @@ void KviDccBroker::passiveVoiceExecute(KviDccDescriptor * dcc)
 // ACTIVE CANVAS
 ///////////////////////////////////////////////////////////////////////////////
 
+#ifdef COMPILE_DCC_CANVAS
+
 void KviDccBroker::activeCanvasManage(KviDccDescriptor * dcc)
 {
 	if(!dcc->bAutoAccept)
@@ -394,8 +427,11 @@ void KviDccBroker::activeCanvasManage(KviDccDescriptor * dcc)
 	}
 }
 
+#endif
+
 void KviDccBroker::activeCanvasExecute(KviDccBox *box,KviDccDescriptor * dcc)
 {
+#ifdef COMPILE_DCC_CANVAS
 	if(box)box->forgetDescriptor();
 
 	if(!g_pApp->windowExists(dcc->console()))
@@ -416,12 +452,13 @@ void KviDccBroker::activeCanvasExecute(KviDccBox *box,KviDccDescriptor * dcc)
 	if(bMinimized)cnv->minimize();
 
 	m_pDccWindowList->append(cnv);
+#endif
 }
 
 ///////////////////////////////////////////////////////////////////////////////
 // PASSIVE CANVAS
 ///////////////////////////////////////////////////////////////////////////////
-
+#ifdef COMPILE_DCC_CANVAS
 void KviDccBroker::passiveCanvasExecute(KviDccDescriptor * dcc)
 {
 	KviStr tmp(KviStr::Format,"dcc: canvas %s@%s:%s",dcc->szNick.utf8().data(),dcc->szIp.utf8().data(),dcc->szPort.utf8().data());
@@ -433,6 +470,7 @@ void KviDccBroker::passiveCanvasExecute(KviDccDescriptor * dcc)
 	m_pDccWindowList->append(cnv);
 }
 
+#endif
 
 ///////////////////////////////////////////////////////////////////////////////
 // SEND
@@ -440,6 +478,18 @@ void KviDccBroker::passiveCanvasExecute(KviDccDescriptor * dcc)
 
 void KviDccBroker::recvFileManage(KviDccDescriptor * dcc)
 {
+	if(dcc->bIsIncomingAvatar)
+	{
+		bool bOk;
+		uint size = dcc->szFileSize.toUInt(&bOk);
+		if(bOk) {
+			if(size>=KVI_OPTION_UINT(KviOption_uintMaximumRequestedAvatarSize)) {
+				cancelDcc(0,dcc);
+				return;
+			}
+		}
+	}
+
 	if(!dcc->bAutoAccept)
 	{
 		// need confirmation
@@ -452,11 +502,11 @@ void KviDccBroker::recvFileManage(KviDccDescriptor * dcc)
 						"<b>%1 [%2@%3]</b> " \
 						"wants to send you the file " \
 						"'<b>%4</b>', " \
-						"<b>%5</b> bytes large.<br>" \
+						"<b>%5</b> large.<br>" \
 						"The connection target will be host <b>%6</b> on port <b>%7</b><br>" \
 					,"dcc" \
 				).arg(dcc->szNick).arg(dcc->szUser).arg(dcc->szHost).arg(
-					dcc->szFileName).arg(dcc->szFileSize).arg(
+				dcc->szFileName).arg(KviQString::makeSizeReadable(dcc->szFileSize.toInt())).arg(
 					dcc->szIp).arg(dcc->szPort);
 
 		} else {
@@ -465,11 +515,11 @@ void KviDccBroker::recvFileManage(KviDccDescriptor * dcc)
 						"<b>%1 [%2@%3]</b> "
 						"wants to send you the file " \
 						"'<b>%4</b>', " \
-						"<b>%5</b> bytes large.<br>" \
+						"<b>%5</b> large.<br>" \
 						"You will be the passive side of the connection.<br>" \
 					,"dcc" \
 				).arg(dcc->szNick).arg(dcc->szUser).arg(dcc->szHost).arg(
-					dcc->szFileName).arg(dcc->szFileSize);
+					dcc->szFileName).arg(KviQString::makeSizeReadable(dcc->szFileSize.toInt()));
 		}
 
 		if(dcc->bIsIncomingAvatar)
@@ -558,19 +608,19 @@ void KviDccBroker::chooseSaveFileName(KviDccBox *box,KviDccDescriptor *dcc)
 			}
 		}
 	}
-	int pos = dcc->szLocalFileName.length()-1;
-	dcc->szLocalFileName[pos]!='/';
-	dcc->szLocalFileName+="/";
+	KviFileUtils::adjustFilePath(dcc->szLocalFileName);
+	KviQString::ensureLastCharIs(dcc->szLocalFileName,KVI_PATH_SEPARATOR_CHAR);
 
 	if(!(dcc->bAutoAccept))
 	{
-		KviDccSaveFileBox * box = new KviDccSaveFileBox(this,dcc);
-		m_pBoxList->append(box);
-		connect(box,SIGNAL(accepted(KviDccBox *,KviDccDescriptor *)),
-				this,SLOT(renameOverwriteResume(KviDccBox *,KviDccDescriptor *)));
-		connect(box,SIGNAL(rejected(KviDccBox *,KviDccDescriptor *)),
-				this,SLOT(cancelDcc(KviDccBox *,KviDccDescriptor *)));
-		box->show();
+		dcc->szLocalFileName+=dcc->szFileName;
+		if(KviFileDialog::askForSaveFileName(dcc->szLocalFileName,
+			__tr2qs_ctx("Choose Files to Save - KVIrc","dcc"),dcc->szLocalFileName))
+		{
+			renameOverwriteResume(0,dcc);
+		} else {
+			cancelDcc(dcc);
+		}
 	} else {
 		// auto accept
 		// WE choose the filename
@@ -612,15 +662,14 @@ void KviDccBroker::renameOverwriteResume(KviDccBox *box,KviDccDescriptor * dcc)
 				(iRemoteSize > ((int)(fi.size())))) // or it is larger than the actual size on disk
 			{
 				tmp = __tr2qs_ctx( \
-							"The file '<b>%1</b>' already exists" \
-							"and is <b>%2</b> bytes large.<br>" \
+							"The file '<b>%1</b>' already exists " \
+							"and is <b>%2</b> large.<br>" \
 							"Do you wish to<br>" \
 							"<b>overwrite</b> the existing file,<br> " \
 							"<b>auto-rename</b> the new file, or<br>" \
 							"<b>resume</b> an incomplete download?" \
 						,"dcc" \
-					);
-				tmp.arg(dcc->szLocalFileName).arg(fi.size());
+					).arg(dcc->szLocalFileName).arg(KviQString::makeSizeReadable(fi.size()));
 			} else {
 				bDisableResume = true;
 				// the file on disk is larger or equal to the remote one
@@ -728,13 +777,32 @@ void KviDccBroker::recvFileExecute(KviDccBox *box,KviDccDescriptor * dcc)
 
 void KviDccBroker::sendFileManage(KviDccDescriptor * dcc)
 {
-	KviDccLoadFileBox * box = new KviDccLoadFileBox(this,dcc);
-	m_pBoxList->append(box);
-	connect(box,SIGNAL(accepted(KviDccBox *,KviDccDescriptor *)),
-			this,SLOT(sendFileExecute(KviDccBox *,KviDccDescriptor *)));
-	connect(box,SIGNAL(rejected(KviDccBox *,KviDccDescriptor *)),
-			this,SLOT(cancelDcc(KviDccBox *,KviDccDescriptor *)));
-	box->show();
+	QStringList filenames;
+	if(
+		KviFileDialog::askForOpenFileNames(filenames,
+		__tr2qs_ctx("Choose Files to Send - KVIrc","dcc"),"")
+		) {
+			if(filenames.count() > 0)
+			{
+				KviDccDescriptor * d;
+				KviDccDescriptor * templ = dcc;
+				QStringList::Iterator it=filenames.begin();
+				while(it != filenames.end())
+				{
+					d = new KviDccDescriptor(*dcc);
+					d->szLocalFileName = *(it);
+					d->szLocalFileName.stripWhiteSpace();
+					++it;
+					if(d->szLocalFileName.isEmpty()) 
+						cancelDcc(d);
+					else 
+						sendFileExecute(0,d);
+				}
+				delete dcc;
+			}
+	} else {
+			cancelDcc(dcc);
+	}
 }
 
 void KviDccBroker::sendFileExecute(KviDccBox * box,KviDccDescriptor *dcc)
