@@ -25,11 +25,18 @@
 //=======================================================================================
 
 #include "kvi_settings.h"
+
+#ifdef COMPILE_USE_QT4
+	// #define COMPILE_DCC_CANVAS
+#else
+	#define COMPILE_DCC_CANVAS
+#endif
+
 #include "kvi_string.h"
-#include "kvi_list.h"
+#include "kvi_pointerlist.h"
 #include "kvi_sparser.h"
 
-#include <qdict.h>
+#include "kvi_pointerhashtable.h"
 #include <qdatetime.h>
 #include <qobject.h>
 
@@ -56,9 +63,9 @@ public:
 	KviDccBroker();
 	~KviDccBroker();
 protected:
-	KviPtrList<KviDccBox>         * m_pBoxList;
-	KviPtrList<KviWindow>         * m_pDccWindowList;
-	QDict<KviDccZeroPortTag>      * m_pZeroPortTags;
+	KviPointerList<KviDccBox>         * m_pBoxList;
+	KviPointerList<KviWindow>         * m_pDccWindowList;
+	KviPointerHashTable<QString,KviDccZeroPortTag>      * m_pZeroPortTags;
 public:
 	KviDccZeroPortTag * addZeroPortTag();
 	KviDccZeroPortTag * findZeroPortTag(const QString &szTag);
@@ -75,9 +82,10 @@ public:
 
 	void handleChatRequest(KviDccDescriptor * dcc);
 
-
+#ifdef COMPILE_DCC_CANVAS
 	void activeCanvasManage(KviDccDescriptor * dcc);
 	void passiveCanvasExecute(KviDccDescriptor * dcc);
+#endif
 
 	void activeVoiceManage(KviDccDescriptor * dcc);
 	void passiveVoiceExecute(KviDccDescriptor * dcc);
@@ -90,6 +98,7 @@ public:
 
 public slots:
 	void rsendExecute(KviDccBox * box,KviDccDescriptor * dcc);
+	void rsendExecute(KviDccDescriptor * dcc);
 
 //	void activeChatExecute(KviDccBox * box,KviDccDescriptor * dcc);
 	void executeChat(KviDccBox * box,KviDccDescriptor * dcc);
@@ -106,6 +115,7 @@ public slots:
 	void renameDccSendFile(KviDccBox *box,KviDccDescriptor * dcc);
 
 	void cancelDcc(KviDccBox *box,KviDccDescriptor * dcc);
+	void cancelDcc(KviDccDescriptor * dcc);
 
 public:
 	bool canUnload();
