@@ -22,6 +22,9 @@
 
 #include "canvaswidget.h"
 
+#ifdef COMPILE_DCC_CANVAS
+
+
 #include <qcursor.h>
 #include <qpainter.h>
 #include <qsimplerichtext.h>
@@ -33,6 +36,7 @@
 #include "kvi_string.h"
 
 #include "kvi_locale.h"
+#include "kvi_tal_popupmenu.h"
 
 #include <math.h>
 
@@ -1098,7 +1102,7 @@ void KviCanvasView::contentsMouseMoveEvent(QMouseEvent *e)
 {
 //	QPoint p = inverseWorldMatrix().map(e->pos());
 	QPoint p = e->pos();
-	if(e->state() & LeftButton)
+	if(e->state() & Qt::LeftButton)
 	{
 		if((m_dragMode != None) && (m_pSelectedItem))
 		{
@@ -1172,7 +1176,7 @@ void KviCanvasView::contentsMouseReleaseEvent(QMouseEvent *e)
 
 void KviCanvasView::contentsMousePressEvent(QMouseEvent *e)
 {
-	if(e->button() & LeftButton)
+	if(e->button() & Qt::LeftButton)
 	{
 //	    QPoint p = inverseWorldMatrix().map(e->pos());
 		QPoint p = e->pos();
@@ -1212,7 +1216,7 @@ void KviCanvasView::contentsMousePressEvent(QMouseEvent *e)
 							beginDragLine(((KviCanvasLine *)hit),p);
 						break;
 						case KVI_CANVAS_RTTI_CONTROL_TYPE_POLYGON:
-							beginDragPolygon(((KviCanvasPolygon *)hit),p,e->state() & ShiftButton,e->state() & ControlButton);
+							beginDragPolygon(((KviCanvasPolygon *)hit),p,e->state() & Qt::ShiftButton,e->state() & Qt::ControlButton);
 						break;
 					}
 				} else {
@@ -1552,10 +1556,10 @@ KviCanvasWidget::KviCanvasWidget(QWidget * par)
 
 	connect(m_pPropertiesWidget,SIGNAL(propertyChanged(const QString &,const QVariant &)),m_pCanvasView,SLOT(propertyChanged(const QString &,const QVariant &)));
 
-	QPopupMenu * add = new QPopupMenu(m_pMenuBar);
-	QPopupMenu * shapes = new QPopupMenu(add);
-	QPopupMenu * polygons = new QPopupMenu(add);
-	QPopupMenu * items = new QPopupMenu(add);
+	KviTalPopupMenu * add = new KviTalPopupMenu(m_pMenuBar);
+	KviTalPopupMenu * shapes = new KviTalPopupMenu(add);
+	KviTalPopupMenu * polygons = new KviTalPopupMenu(add);
+	KviTalPopupMenu * items = new KviTalPopupMenu(add);
 	shapes->insertItem(__tr2qs_ctx("&Line","dcc"),m_pCanvasView,SLOT(insertLine()));
 	shapes->insertItem(__tr2qs_ctx("&Rectangle","dcc"),m_pCanvasView,SLOT(insertRectangle()));
 	shapes->insertItem(__tr2qs_ctx("&Ellipse","dcc"),m_pCanvasView,SLOT(insertEllipse()));
@@ -1593,3 +1597,5 @@ void KviCanvasWidget::resizeEvent(QResizeEvent *)
 
 
 #include "m_canvaswidget.moc"
+
+#endif
