@@ -55,6 +55,7 @@
 #include "kvi_ircconnection.h"
 #include "kvi_ircconnectionuserinfo.h"
 #include "kvi_kvs_eventtriggers.h"
+#include "kvi_qcstring.h"
 
 #ifdef COMPILE_CRYPT_SUPPORT
 	#include "kvi_crypt.h"
@@ -64,7 +65,7 @@
 
 #include <qsplitter.h>
 #include <qevent.h>
-#include <qvbox.h>
+#include "kvi_tal_vbox.h"
 
 
 #ifdef COMPILE_SSL_SUPPORT
@@ -88,16 +89,16 @@ extern KviDccBroker * g_pDccBroker;
 KviDccChat::KviDccChat(KviFrame *pFrm,KviDccDescriptor * dcc,const char * name)
 : KviDccWindow(KVI_WINDOW_TYPE_DCCCHAT,pFrm,name,dcc)
 {
-	m_pTopSplitter = new QSplitter(QSplitter::Horizontal,this,"top_splitter");
+	m_pTopSplitter = new QSplitter(Qt::Horizontal,this,"top_splitter");
 	KviThemedLabel * dummy;
 	dummy = new KviThemedLabel(m_pTopSplitter,"dummy_label");
-	QVBox * box = new QVBox(m_pTopSplitter);
+	KviTalVBox * box = new KviTalVBox(m_pTopSplitter);
 
 #ifdef COMPILE_CRYPT_SUPPORT
 	createCryptControllerButton(box);
 #endif
 
-	m_pSplitter = new QSplitter(QSplitter::Horizontal,this,"splitter");
+	m_pSplitter = new QSplitter(Qt::Horizontal,this,"splitter");
 	m_pIrcView  = new KviIrcView(m_pSplitter,pFrm,this);
 	connect(m_pIrcView,SIGNAL(rightClicked()),this,SLOT(textViewRightClicked()));
 	m_pInput    = new KviInput(this);
@@ -106,7 +107,7 @@ KviDccChat::KviDccChat(KviFrame *pFrm,KviDccDescriptor * dcc,const char * name)
 
 	m_pSlaveThread = 0;
 
-	if(KVI_OPTION_BOOL(KviOption_boolAutoLogDccChat))m_pIrcView->startLogging(0);
+	if(KVI_OPTION_BOOL(KviOption_boolAutoLogDccChat))m_pIrcView->startLogging();
 
 	m_pMarshal = new KviDccMarshal(this);
 	connect(m_pMarshal,SIGNAL(error(int)),this,SLOT(handleMarshalError(int)));
@@ -302,7 +303,7 @@ void KviDccChat::ownMessage(const QString &text)
 		return;
 	}
 	
-	QCString szData = encodeText(text);
+	KviQCString szData = encodeText(text);
 	const char * d = szData.data();
 	if(!d)return;
 	
@@ -337,9 +338,12 @@ void KviDccChat::ownMessage(const QString &text)
 					}
 					break;
 					default: // also case KviCryptEngine::EncryptError
+					{
+						QString szErr = cryptSessionInfo()->pEngine->lastError();
 						output(KVI_OUT_SYSTEMERROR,
-							__tr2qs_ctx("The crypto engine was not able to encrypt the current message (%Q): %s, no data was sent to the remote end","dcc"),
-							&text,cryptSessionInfo()->pEngine->lastError());
+							__tr2qs_ctx("The crypto engine was not able to encrypt the current message (%Q): %Q, no data was sent to the remote end","dcc"),
+							&text,&szErr);
+					}
 					break;
 				}
 				return;
@@ -374,7 +378,7 @@ void KviDccChat::ownAction(const QString &text)
 {
 	if(m_pSlaveThread)
 	{
-		QCString szData = encodeText(text);
+		KviQCString szData = encodeText(text);
 		const char * d = szData.data();
 		if(!d)return;
 		KviStr buf(KviStr::Format,"%cACTION %s%c\r\n",0x01,d,0x01);
@@ -437,9 +441,12 @@ bool KviDccChat::event(QEvent *e)
 								break;
 								
 								default: // also case KviCryptEngine::DecryptError
+								{
+									QString szErr = cinf->pEngine->lastError();
 									output(KVI_OUT_SYSTEMERROR,
-										__tr2qs_ctx("The following message appears to be encrypted, but the crypto engine failed to decode it: %s","dcc"),
-										cinf->pEngine->lastError());
+										__tr2qs_ctx("The following message appears to be encrypted, but the crypto engine failed to decode it: %Q","dcc"),
+										&szErr);
+								}
 								break;
 							}
 						}
@@ -532,7 +539,7 @@ void KviDccChat::connected()
 KviDccChatThread::KviDccChatThread(KviWindow *wnd,kvi_socket_t fd)
 : KviDccThread(wnd,fd)
 {
-	m_pOutBuffers = new KviPtrList<KviDataBuffer>;
+	m_pOutBuffers = new KviPointerList<KviDataBuffer>;
 	m_pOutBuffers->setAutoDelete(true);
 }
 
