@@ -34,7 +34,7 @@
 #include "kvi_netutils.h"
 #include "kvi_frame.h"
 #include "kvi_console.h"
-//#include "kvi_uparser.h"
+
 #include "kvi_error.h"
 #include "kvi_options.h"
 #include "kvi_defaults.h"
@@ -297,7 +297,7 @@ static void dccModuleParseDccChat(KviDccRequest *dcc)
 			}
 			d->setZeroPortRequestTag(dcc->szParam4.ptr());
 			QString tmp;
-			if(!dcc_module_get_listen_ip_address(0,d->console(),tmp))d->szListenIp = "0.0.0.0";
+			if(!dcc_kvs_get_listen_ip_address(0,d->console(),tmp))d->szListenIp = "0.0.0.0";
 			else d->szListenIp=tmp;
 			d->szListenPort = "0"; // any port is OK
 			d->bAutoAccept       = KVI_OPTION_BOOL(KviOption_boolAutoAcceptDccChat);
@@ -310,6 +310,13 @@ static void dccModuleParseDccChat(KviDccRequest *dcc)
 			if(!t)
 			{
 				// hum.. not our tag
+				
+				// FIXME: As segnaled by PRAEDO, ezbounce seems to send a fourth parameter in response to /quote ezb log
+				// Pragma: That's a bug in ezbounce, it sends the filesize of the log as a DCC CHAT parameter...
+				//         The author probably copied and pasted the CTCP line from DCC SEND and forgot to remove the filesize.
+				//         We *could* add an option to ignore the last parameter and treat it as a standard dcc chat
+				//         request, but since we don't encourage bugs, we don't do it :D
+				//         Mail me at pragma at kvirc dot net if you really think it's necessary.
 				dcc->ctcpMsg->msg->console()->output(KVI_OUT_DCCMSG,
 					__tr2qs_ctx("The above request is broken: it looks like a zero port tag acknowledge but I have either never seen this tag or it was sent more than 120 seconds ago","dcc"));
 				dcc_module_request_error(dcc,__tr2qs_ctx("It seems that I haven't requested this dcc chat","dcc"));
@@ -420,7 +427,7 @@ static void dccModuleParseDccSend(KviDccRequest *dcc)
 	}
 
 	// First of all we check the transfer limits
-	dcc->szParam1=dcc->pConsole->decodeText(dcc->szParam1).data();
+	dcc->szParam1=dcc->pConsole->decodeText(dcc->szParam1);
 	if(!dcc_module_check_limits(dcc))return;
 	if(!dcc_module_check_concurrent_transfers_limit(dcc))return;
 
@@ -481,7 +488,7 @@ static void dccModuleParseDccSend(KviDccRequest *dcc)
 		}
 		d->setZeroPortRequestTag(dcc->szParam5.ptr());
 		QString tmp;
-		if(!dcc_module_get_listen_ip_address(0,d->console(),tmp))d->szListenIp = "0.0.0.0";
+		if(!dcc_kvs_get_listen_ip_address(0,d->console(),tmp))d->szListenIp = "0.0.0.0";
 		else d->szListenIp=QString(tmp);
 		d->szListenPort = "0"; // any port is OK
 		d->bSendRequest = true;
@@ -709,7 +716,7 @@ static void dccModuleParseDccRSend(KviDccRequest *dcc)
 	//
 	//      DCC [ST]RSEND <filename> <filesize>
 	//
-	dcc->szParam1 = dcc->pConsole->decodeText(dcc->szParam1).data();
+	dcc->szParam1 = dcc->pConsole->decodeText(dcc->szParam1);
 	if(!dcc_module_check_limits(dcc))return;
 	if(!dcc_module_check_concurrent_transfers_limit(dcc))return;
 
@@ -756,7 +763,7 @@ static void dccModuleParseDccRSend(KviDccRequest *dcc)
 	d->szIp              = __tr2qs_ctx("(unknown)","dcc");
 	d->szPort            = d->szIp;
 	QString tmp;
-	if(!dcc_module_get_listen_ip_address(0,d->console(),tmp))
+	if(!dcc_kvs_get_listen_ip_address(0,d->console(),tmp))
 	{
 		d->console()->output(KVI_OUT_DCCMSG,
 			__tr2qs_ctx("No suitable interface to listen on, trying to continue anyway...","dcc"));
@@ -905,7 +912,7 @@ static void dccModuleParseDccGet(KviDccRequest *dcc)
 	dcc_fill_local_nick_user_host(d,dcc);
 	
 	QString tmp;
-	if(!dcc_module_get_listen_ip_address(0,d->console(),tmp))
+	if(!dcc_kvs_get_listen_ip_address(0,d->console(),tmp))
 	{
 		d->console()->output(KVI_OUT_DCCMSG,
 			__tr2qs_ctx("No suitable interface to listen on, trying to continue anyway...","dcc"));
@@ -1050,7 +1057,7 @@ static void dccModuleParseDccCanvas(KviDccRequest *dcc)
 //				__tr("The above request is broken: the second parameter is '%s' and shoud be 'chat'; trying to continue"),dcc->szParam1.ptr());
 //		}
 //	}
-
+#ifdef COMPILE_DCC_CANVAS
 	KviDccDescriptor * d = new KviDccDescriptor(dcc->pConsole);
 	d->szNick            = dcc->ctcpMsg->pSource->nick();
 	d->szUser            = dcc->ctcpMsg->pSource->username();
@@ -1068,6 +1075,7 @@ static void dccModuleParseDccCanvas(KviDccRequest *dcc)
 	dcc_module_set_dcc_type(d,"CANVAS");
 	d->triggerCreationEvent();
 	g_pDccBroker->activeCanvasManage(d);
+#endif
 }
 
 
