@@ -50,7 +50,7 @@
 #include "kvi_memmove.h"
 #include "kvi_thread.h"
 #include "kvi_ircsocket.h"
-//#include "kvi_uparser.h"
+
 #include "kvi_mediatype.h"
 #include "kvi_socket.h"
 #include "kvi_kvs_eventtriggers.h"
@@ -87,7 +87,7 @@ extern KviDccBroker * g_pDccBroker;
 extern KVIRC_API KviMediaManager * g_pMediaManager; // kvi_app.cpp
 
 
-static KviPtrList<KviDccFileTransfer> * g_pDccFileTransfers = 0;
+static KviPointerList<KviDccFileTransfer> * g_pDccFileTransfers = 0;
 static QPixmap * g_pDccFileTransferIcon = 0;
 
 //#warning "The events that have a KviStr data pointer should become real classes, that take care of deleting the data pointer!"
@@ -135,8 +135,10 @@ void KviDccRecvThread::updateStats()
 	m_pMutex->lock();
 	unsigned long uElapsedTime = uCurTime - m_uStartTime;
 	if(uElapsedTime < 1)uElapsedTime = 1;
+
 	m_iFilePosition = m_pFile->at();
 	m_iAverageSpeed = m_iTotalReceivedBytes / uElapsedTime;
+
 	if(m_uInstantSpeedInterval > INSTANT_BANDWIDTH_CHECK_INTERVAL_IN_MSECS)
 	{
 		unsigned int uMSecsOfTheNextInterval = 0;
@@ -236,7 +238,7 @@ void KviDccRecvThread::run()
 			if(bCanRead)
 			{
 				iFailedSelects = 0;
-				
+
 				// Read a data block
 				char buffer[KVI_DCC_RECV_BLOCK_SIZE];
 
@@ -249,7 +251,7 @@ void KviDccRecvThread::run()
 				if(uToRead > 0)
 				{
 					int readLen = kvi_socket_recv(m_fd,buffer,uToRead);
-	
+
 					if(readLen > 0)
 					{
 						// Readed something useful...write back
@@ -257,7 +259,7 @@ void KviDccRecvThread::run()
 						{
 							postMessageEvent(__tr2qs_ctx("WARNING: The peer is sending garbage data past the end of the file","dcc"));
 							postMessageEvent(__tr2qs_ctx("WARNING: Ignoring data past the declared end of file and closing the connection","dcc"));
-	
+
 							readLen = m_pOpt->iTotalFileSize - m_pFile->at();
 							if(readLen > 0)
 							{
@@ -265,7 +267,7 @@ void KviDccRecvThread::run()
 									postErrorEvent(KviError_fileIOError);
 							}
 							break;
-	
+
 						} else {
 							if(m_pFile->writeBlock(buffer,readLen) != readLen)
 							{
@@ -273,11 +275,11 @@ void KviDccRecvThread::run()
 								break;
 							}
 						}
-	
+
 						// Update stats
 						m_iTotalReceivedBytes += readLen;
 						m_iInstantReceivedBytes += readLen;
-	
+
 						updateStats();
 						// Now send the ack
 						if(m_pOpt->bNoAcks)
@@ -298,7 +300,7 @@ void KviDccRecvThread::run()
 							// Must send the ack... the peer must close the connection
 							if(!sendAck(m_pFile->at()))break;
 						}
-						
+
 						// now take care of short reads
 						iShortReadQuantifier += ((KVI_DCC_RECV_75PERCENTOF_BLOCK_SIZE - readLen) / 42);
 						if(iShortReadQuantifier > 10)
@@ -313,7 +315,7 @@ void KviDccRecvThread::run()
 							if(iShortReadQuantifier < -500)
 								iShortReadQuantifier = -500;
 						}
-	
+
 					} else {
 						updateStats();
 						// Read problem...
@@ -332,6 +334,8 @@ void KviDccRecvThread::run()
 						if(!handleInvalidSocketRead(readLen))break;
 					}
 				} else {
+					updateStats();
+
 					// reached the bandwidth limit: slow down a bit
 					if(m_uInstantSpeedInterval < (INSTANT_BANDWIDTH_CHECK_INTERVAL_IN_MSECS - 100))
 						msleep(100);
@@ -373,6 +377,7 @@ void KviDccRecvThread::run()
 			// include the artificial delay if needed
 			if(m_pOpt->iIdleStepLengthInMSec > 0)
 			{
+				debug("LOOP: artificial delay");
 				msleep(m_pOpt->iIdleStepLengthInMSec);
 			}
 		} else {
@@ -441,7 +446,7 @@ void KviDccSendThread::updateStats()
 		// acknowledges : we compute the avg bandwidth based on the acks we receive
 		m_iAverageSpeed = (m_iAckedBytes - m_pOpt->iStartPosition) / uElapsedTime;
 	}
-	
+
 	if(m_uInstantSpeedInterval >= INSTANT_BANDWIDTH_CHECK_INTERVAL_IN_MSECS)
 	{
 		// we often overcount the time interval of 10-20 msecs
@@ -511,7 +516,7 @@ void KviDccSendThread::run()
 	}
 
 	iLastAck = m_pOpt->iStartPosition;
-	
+
 	for(;;)
 	{
 		// Dequeue events
@@ -562,8 +567,8 @@ void KviDccSendThread::run()
 					// update stats
 					m_pMutex->lock(); // is this really necessary ?
 					m_iAckedBytes = iLastAck;
-					m_pMutex->unlock(); 
-	
+					m_pMutex->unlock();
+
 					if(iLastAck >= pFile->size())
 					{
 						KviThreadEvent * e = new KviThreadEvent(KVI_DCC_THREAD_EVENT_SUCCESS);
@@ -648,13 +653,13 @@ void KviDccSendThread::run()
 							// sleep a while
 							if(m_uInstantSpeedInterval < (INSTANT_BANDWIDTH_CHECK_INTERVAL_IN_MSECS - 100))
 							{
-								msleep(100); 
+								msleep(100);
 							} else if(m_uInstantSpeedInterval < (INSTANT_BANDWIDTH_CHECK_INTERVAL_IN_MSECS - 20))
 							{
 								msleep(20);
 							}
 						}
-						
+
 						m_iTotalSentBytes += written;
 						m_iInstantSentBytes += written;
 						m_iFilePosition = pFile->at();
@@ -672,7 +677,7 @@ void KviDccSendThread::run()
 					} else {
 						// upload finished but we're waiting for the last ack
 						// sleep a bit: don't lag the kernie too much while waiting
-						msleep(100); 
+						msleep(100);
 					}
 				}
 			}
@@ -909,7 +914,7 @@ void KviDccFileTransfer::abort()
 			g_pApp->fileDownloadTerminated(false,m_pDescriptor->szFileName.utf8().data(),m_pDescriptor->szLocalFileName.utf8().data(),m_pDescriptor->szNick.utf8().data(),__tr_ctx("Aborted","dcc"));
 
 	KviStr tmp;
-	
+
 	if(m_pSlaveRecvThread)tmp.setNum(m_pSlaveRecvThread->receivedBytes());
 	else if(m_pSlaveSendThread)tmp.setNum(m_pSlaveSendThread->sentBytes());
 	else tmp = '0';
@@ -926,7 +931,7 @@ void KviDccFileTransfer::abort()
 }
 
 
-void KviDccFileTransfer::fillContextPopup(QPopupMenu * m,int column)
+void KviDccFileTransfer::fillContextPopup(KviTalPopupMenu * m,int column)
 {
 	m->insertItem(__tr2qs_ctx("Configure Bandwidth...","dcc"),this,SLOT(configureBandwidth()));
 	m->insertSeparator();
@@ -934,7 +939,7 @@ void KviDccFileTransfer::fillContextPopup(QPopupMenu * m,int column)
 	m->insertItem(__tr2qs_ctx("Resend TDCC","dcc"),this,SLOT(retryTDCC()));
 	m->insertItem(__tr2qs_ctx("Resend RevDCC","dcc"),this,SLOT(retryRevDCC()));
 	/* FIX ME credo che il problema sia che se riavvio un trasferimento, a sua volta gia'
-		   avviato, questo non ha irc contex, perche' la finestra "in cui e' nato"e' sta 
+		   avviato, questo non ha irc contex, perche' la finestra "in cui e' nato"e' sta
 	   quella della dcc. Conservarsi l'id della finestra? */
 	int id = m->insertItem(__tr2qs_ctx("Abort","dcc"),this,SLOT(abort()));
 	if(!active())m->setItemEnabled(id,false);
@@ -956,7 +961,7 @@ void KviDccFileTransfer::retryDCC()
 	QString szFileName = m_pDescriptor->localFileName();
 	QString szId;
 	szId.setNum(m_pDescriptor->id());
-	QString szCommand = "dcc.send -r=" + szId + " " + szRemoteNick + " " + "\"" + szFileName + "\"";
+	QString szCommand = "dcc.send -r=$console($dcc.irccontext(" + szId + ")) " + szRemoteNick + " " + "\"" + szFileName + "\"";
 	KviKvsScript::run(szCommand,g_pActiveWindow);
 }
 
@@ -967,7 +972,7 @@ void KviDccFileTransfer::retryTDCC()
 	QString szFileName = m_pDescriptor->localFileName();
 	QString szId;
 	szId.setNum(m_pDescriptor->id());
-	QString szCommand = "dcc.send -r=" + szId + " -t " + szRemoteNick + " " + "\"" + szFileName + "\"";
+	QString szCommand = "dcc.send -r=$console($dcc.irccontext(" + szId + ")) -t " + szRemoteNick + " " + "\"" + szFileName + "\"";
 	KviKvsScript::run(szCommand,g_pActiveWindow);
 }
 void KviDccFileTransfer::retryRevDCC()
@@ -977,7 +982,7 @@ void KviDccFileTransfer::retryRevDCC()
 	QString szFileName = m_pDescriptor->localFileName();
 	QString szId;
 	szId.setNum(m_pDescriptor->id());
-	QString szCommand = "dcc.rsend -r=" + szId + " " + szRemoteNick + " " + "\"" + szFileName + "\"";
+	QString szCommand = "dcc.rsend -z -r=$console($dcc.irccontext(" + szId + ")) " + szRemoteNick + " " + "\"" + szFileName + "\"";
 	KviKvsScript::run(szCommand,g_pActiveWindow);
 }
 
@@ -1231,18 +1236,18 @@ void KviDccFileTransfer::displayPaint(QPainter * p,int column,int width,int heig
 					if(iW2 > 0)p->fillRect(5 + iL2,5,iW2,10,bIsTerminated ? QColor(150,130,110) : QColor(220,170,100));
 					p->fillRect(5,5,iL2,10,bIsTerminated ? QColor(140,110,110) : QColor(200,100,100));
 
-					txt = QString(__tr2qs_ctx("%1 of %2 bytes (%3%)","dcc")).arg(iAckedBytes).arg(m_uTotalFileSize).arg(dPerc2,0,'f',2);
+					txt = QString(__tr2qs_ctx("%1 of %2 (%3%)","dcc")).arg(KviQString::makeSizeReadable(iAckedBytes)).arg(KviQString::makeSizeReadable(m_uTotalFileSize)).arg(dPerc2,0,'f',2);
 				} else {
 					// we are receiving a file or not sending acks
 					double dPerc = (double)(((double)uTransferred) * 100.0) / (double)m_uTotalFileSize;
 					int iL = (int) ((((double)iW) * dPerc) / 100.0);
 					p->fillRect(5,5,iL,10,bIsTerminated ? QColor(140,110,110) : QColor(200,100,100));
 
-					txt = QString(__tr2qs_ctx("%1 of %2 bytes (%3%)","dcc")).arg(uTransferred).arg(m_uTotalFileSize).arg(dPerc,0,'f',2);
+					txt = QString(__tr2qs_ctx("%1 of %2 (%3%)","dcc")).arg(KviQString::makeSizeReadable(uTransferred)).arg(KviQString::makeSizeReadable(m_uTotalFileSize)).arg(dPerc,0,'f',2);
 				}
 
 			} else {
-				txt = QString(__tr2qs_ctx("%1 bytes","dcc")).arg(uTransferred);
+				txt = QString(__tr2qs_ctx("%1","dcc")).arg(KviQString::makeSizeReadable(uTransferred));
 			}
 
 			p->setPen(Qt::black);
@@ -1269,7 +1274,7 @@ void KviDccFileTransfer::displayPaint(QPainter * p,int column,int width,int heig
 			} else {
 				txt = "";
 			}
-			
+
 			txt += __tr2qs_ctx("Avg:","dcc");
 			txt += " ";
 			if(iAvgBandwidth >= 0)
@@ -1280,7 +1285,7 @@ void KviDccFileTransfer::displayPaint(QPainter * p,int column,int width,int heig
 			} else {
 				txt += "? B/s";
 			}
-			
+
 			if(!bIsTerminated)
 			{
 				txt += "]";
@@ -1354,7 +1359,7 @@ QString KviDccFileTransfer::tipText()
 void KviDccFileTransfer::init()
 {
 	if(g_pDccFileTransfers)return;
-	g_pDccFileTransfers = new KviPtrList<KviDccFileTransfer>;
+	g_pDccFileTransfers = new KviPointerList<KviDccFileTransfer>;
 	g_pDccFileTransfers->setAutoDelete(false);
 
 	QPixmap * pix = g_pIconManager->getImage("kvi_dccfiletransfericons.png");
@@ -1464,7 +1469,7 @@ void KviDccFileTransfer::connectionInProgress()
 	if(m_pDescriptor->bActive)
 	{
 		// ACTIVE CONNECTION
-//		if((kvi_strEqualCS(m_szDccType.ptr(), "RECV")) || (kvi_strEqualCS(m_szDccType.ptr(),"TRECV"))) 
+//		if((kvi_strEqualCS(m_szDccType.ptr(), "RECV")) || (kvi_strEqualCS(m_szDccType.ptr(),"TRECV")))
 //		{
 //			// FIXME: that's not true!... we're NOT connected here
 //			if(TRIGGER_EVENT_5PARAM_RETVALUE(KviEvent_OnDCCGetConnected,this,m_pDescriptor->szPort.ptr(),m_pDescriptor->szFileName.ptr(),m_pDescriptor->szNick.ptr(),m_pDescriptor->szUser.ptr(),m_pDescriptor->szHost.ptr()));
@@ -1512,8 +1517,8 @@ void KviDccFileTransfer::connectionInProgress()
 				}
 			}
 		}
-		
-		KviStr port   = !m_pDescriptor->szFakePort.isEmpty() ? m_pDescriptor->szFakePort.utf8().data() : m_pMarshal->localPort();
+
+		KviStr port   = !m_pDescriptor->szFakePort.isEmpty() ? m_pDescriptor->szFakePort : m_pMarshal->localPort();
 		//#warning "OPTION FOR SENDING 127.0.0.1 and so on (not an unsigned nuumber)"
 		struct in_addr a;
 		if(KviNetUtils::stringIpToBinaryIp(ip,&a))ip.setNum(htonl(a.s_addr));
@@ -1532,7 +1537,7 @@ void KviDccFileTransfer::connectionInProgress()
 		KviServerParser::encodeCtcpParameter(tmp.utf8().data(),fName);
 		// Zero port requests want DCC SEND as back-request
 		KviStr szReq;
-		
+
 		if(m_pDescriptor->isZeroPortRequest())
 		{
 			szReq = "SEND";
@@ -1617,7 +1622,10 @@ bool KviDccFileTransfer::event(QEvent *e)
 				// File Upload/Download terminated, or something like this
 				if(KVI_OPTION_BOOL(KviOption_boolNotifyDccSendSuccessInConsole))
 				{
-					g_pApp->activeConsole()->output(KVI_OUT_DCCMSG,__tr2qs_ctx("DCC %s transfer with %Q@%Q:%Q completed: \r![!dbl]play $0\r%s\r","dcc"),
+					KviConsole *c;
+					if(!g_pApp->windowExists(m_pDescriptor->console())) c=g_pApp->activeConsole();
+					else c=m_pDescriptor->console();
+					c->output(KVI_OUT_DCCMSG,__tr2qs_ctx("DCC %s transfer with %Q@%Q:%Q completed: \r![!dbl]play $0\r%s\r","dcc"),
 						m_pDescriptor->bIsTdcc ? (m_pDescriptor->bRecvFile ? "TRECV" : "TSEND") : (m_pDescriptor->bRecvFile ? "RECV" : "SEND"),
 						&(m_pDescriptor->szNick),&(m_pDescriptor->szIp),&(m_pDescriptor->szPort),
 						&(m_pDescriptor->szLocalFileName));
@@ -1632,10 +1640,6 @@ bool KviDccFileTransfer::event(QEvent *e)
 				}
 				*/
 				if(m_pDescriptor->bRecvFile)g_pApp->fileDownloadTerminated(true,m_pDescriptor->szFileName.utf8().data(),m_pDescriptor->szLocalFileName.utf8().data(),m_pDescriptor->szNick.utf8().data());
-/*
-				FIXME: Autoclear ?
-				if(KVI_OPTION_BOOL(KviOption_boolAutoCloseDccSendOnSuccess))close();
-*/
 				m_szStatusString = __tr2qs_ctx("Transfer completed","dcc");
 				outputAndLog(m_szStatusString);
 				m_eGeneralStatus = Success;
@@ -1647,6 +1651,8 @@ bool KviDccFileTransfer::event(QEvent *e)
 					m_pDescriptor->idString());
 
 				displayUpdate();
+
+				if(KVI_OPTION_BOOL(KviOption_boolAutoCloseDccSendOnSuccess))die();
 				return true;
 			}
 			break;
@@ -1795,11 +1801,11 @@ bool KviDccFileTransfer::doResume(const char * filename,const char * port,unsign
 			outputAndLog(KVI_OUT_DCCERROR,__tr2qs_ctx("Accepting RESUME request, transfer will begin at position %1","dcc").arg(filePos));
 
 			m_pDescriptor->szFileSize.setNum(filePos);
-			
-			
+
+
 			KviStr szBuffy;
 			KviServerParser::encodeCtcpParameter(filename,szBuffy);
-			
+
 			m_pDescriptor->console()->connection()->sendFmtData("PRIVMSG %s :%cDCC ACCEPT %s %s %u%c",
 				m_pDescriptor->console()->connection()->encodeText(m_pDescriptor->szNick).data(),
 				0x01,
@@ -1820,7 +1826,7 @@ KviDccFileTransferBandwidthDialog::KviDccFileTransferBandwidthDialog(QWidget * p
 : QDialog(pParent)
 {
 	QGridLayout * g = new QGridLayout(this,3,3,4,4);
-	
+
 	m_pTransfer = t;
 	int iVal = m_pTransfer->bandwidthLimit();
 
@@ -1828,10 +1834,10 @@ KviDccFileTransferBandwidthDialog::KviDccFileTransferBandwidthDialog(QWidget * p
 	setCaption(szText);
 
 	szText = t->isFileUpload() ? __tr2qs_ctx("Limit upload bandwidth to","dcc") : __tr2qs_ctx("Limit download bandwidth to","dcc");
-	
+
 	m_pEnableLimitCheck = new KviStyledCheckBox(szText,this);
 	g->addWidget(m_pEnableLimitCheck,0,0);
-	
+
 	m_pEnableLimitCheck->setChecked((iVal >= 0) && (iVal < MAX_DCC_BANDWIDTH_LIMIT));
 
 	m_pLimitBox = new QSpinBox(0,MAX_DCC_BANDWIDTH_LIMIT-1,1,this);
