@@ -33,12 +33,12 @@
 
 #include "kvi_sockettype.h"
 
-#include "kvi_list.h"
+#include "kvi_pointerlist.h"
 #include <qlabel.h>
 #include <qprogressbar.h>
-#include <qpopupmenu.h>
-#include <qhbox.h>
-#include <qvbox.h>
+#include "kvi_tal_popupmenu.h"
+#include "kvi_tal_hbox.h"
+#include "kvi_tal_vbox.h"
 #include <qfile.h>
 #include <qdialog.h>
 
@@ -143,10 +143,11 @@ protected:
 };
 
 class KviDccFileTransfer;
-class KviStyledCheckBox;
 class QSpinBox;
 class QTimer;
 
+#include "kvi_styled_controls.h"
+
 class KviDccFileTransferBandwidthDialog : public QDialog
 {
 	Q_OBJECT
@@ -167,7 +168,7 @@ protected slots:
 
 class KviDccMarshal;
 class QPainter;
-class QPopupMenu;
+class KviTalPopupMenu;
 
 class KviDccFileTransfer : public KviFileTransfer, public KviDccMarshalOutputContext
 {
@@ -219,7 +220,7 @@ public:
 
 	virtual void displayPaint(QPainter * p,int column,int width,int height);
 	virtual int displayHeight(int iLineSpacing);
-	virtual void fillContextPopup(QPopupMenu * m,int column);
+	virtual void fillContextPopup(KviTalPopupMenu * m,int column);
 	virtual void fillStatusString(QString &szBuffer);
 	virtual bool active();
 	virtual void die();
