@@ -30,7 +30,7 @@
 #include "kvi_ircsocket.h"
 #include "kvi_qstring.h"
 
-
+/*
 bool dcc_module_get_listen_ip_address(KviCommand *c,KviConsole * pConsole,QString &szListenIp)
 {
 	//
@@ -97,10 +97,9 @@ bool dcc_module_get_listen_ip_address(KviCommand *c,KviConsole * pConsole,QStrin
 
 	return true;
 }
+*/
 
 
-
-#ifdef COMPILE_NEW_KVS
 bool dcc_kvs_get_listen_ip_address(KviKvsModuleCommandCall *c,KviConsole * pConsole,QString &szListenIp)
 {
 	//
@@ -167,4 +166,4 @@ bool dcc_kvs_get_listen_ip_address(KviKvsModuleCommandCall *c,KviConsole * pCons
 
 	return true;
 }
-#endif
+
