@@ -24,15 +24,11 @@
 
 #include "kvi_settings.h"
 #include "kvi_string.h"
-#include "kvi_command.h"
 #include "kvi_console.h"
 #include "kvi_kvs_moduleinterface.h"
 
 #ifndef _UTILS_CPP_
-	extern bool dcc_module_get_listen_ip_address(KviCommand *c,KviConsole * pConsole,QString &szListenIp);
-#ifdef COMPILE_NEW_KVS
 	extern bool dcc_kvs_get_listen_ip_address(KviKvsModuleCommandCall *c,KviConsole * pConsole,QString &szListenIp);
 #endif
-#endif
 
 #endif //_UTILS_H_
