@@ -42,7 +42,7 @@
 
 #include <qframe.h>
 #include <qsplitter.h>
-#include <qvbox.h>
+#include "kvi_tal_vbox.h"
 #include <qslider.h>
 #include <qtooltip.h>
 
@@ -652,12 +652,12 @@ KviDccVoice::KviDccVoice(KviFrame *pFrm,KviDccDescriptor * dcc,const char * name
 	m_pDescriptor = dcc;
 	m_pSlaveThread = 0;
 
-	m_pSplitter = new QSplitter(QSplitter::Horizontal,this,"splitter");
+	m_pSplitter = new QSplitter(Qt::Horizontal,this,"splitter");
 	m_pIrcView = new KviIrcView(m_pSplitter,pFrm,this);
 
-	m_pHBox = new QHBox(this,"h_box");
+	m_pHBox = new KviTalHBox(this);
 
-	QVBox * vbox = new QVBox(m_pHBox,"v_box");
+	KviTalVBox * vbox = new KviTalVBox(m_pHBox);
 
 	m_pInputLabel = new QLabel(__tr2qs_ctx("Input buffer","dcc"),vbox);
 	m_pInputLabel->setFrameStyle(QFrame::Sunken | QFrame::Panel);
@@ -665,7 +665,7 @@ KviDccVoice::KviDccVoice(KviFrame *pFrm,KviDccDescriptor * dcc,const char * name
 	m_pOutputLabel->setFrameStyle(QFrame::Sunken | QFrame::Panel);
 	vbox->setSpacing(1);
 	
-	QVBox * vbox2 = new QVBox(m_pHBox,"v_box_2");
+	KviTalVBox * vbox2 = new KviTalVBox(m_pHBox);
 
 	m_pRecordingLabel = new QLabel(vbox2);
 	m_pRecordingLabel->setPixmap(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_RECORD)));
@@ -767,7 +767,7 @@ void KviDccVoice::connectionInProgress()
 		if(m_pDescriptor->bSendRequest)
 		{
 			KviStr ip     = !m_pDescriptor->szFakeIp.isEmpty() ? m_pDescriptor->szFakeIp : m_pDescriptor->szListenIp;
-			KviStr port   = !m_pDescriptor->szFakePort.isEmpty() ? m_pDescriptor->szFakePort.utf8().data() : m_pMarshal->localPort();
+			KviStr port   = !m_pDescriptor->szFakePort.isEmpty() ? m_pDescriptor->szFakePort : m_pMarshal->localPort();
 //#warning "OPTION FOR SENDING 127.0.0.1 and so on (not an unsigned nuumber)"
 			struct in_addr a;
 			if(kvi_stringIpToBinaryIp(ip.ptr(),&a))ip.setNum(htonl(a.s_addr));
