@@ -27,17 +27,22 @@
 
 #include <qmessagebox.h>
 #include <qlayout.h>
-#include <qhbox.h>
+#include "kvi_tal_hbox.h"
 #include <qlineedit.h>
-#include <qmultilineedit.h>
+#ifdef COMPILE_USE_QT4
+	#include <q3multilineedit.h>
+	#define QMultiLineEdit Q3MultiLineEdit
+	#include <qdesktopwidget.h>
+#else
+	#include <qmultilineedit.h>
+#endif
+#include <qevent.h>
 #include <qlabel.h>
 #include <qpushbutton.h>
 
 #include "kvi_locale.h"
-//#include "kvi_uparser.h"
 #include "kvi_module.h"
 #include "kvi_modulemanager.h"
-#include "kvi_command.h"
 #include "kvi_error.h"
 #include "kvi_app.h"
 #include "kvi_iconmanager.h"
@@ -46,28 +51,32 @@
 #include "kvi_kvs_script.h"
 #include "kvi_msgbox.h"
 
+static KviPointerList<QWidget> * g_pDialogModuleDialogList;
 
 KviKvsCallbackMessageBox::KviKvsCallbackMessageBox(
-		const QString &szCaption,
-		const QString &szText,
-		const QString &szIcon,
-		const QString &szButton0,
-		const QString &szButton1,
-		const QString &szButton2,
-		const QString &szCode,
-		KviKvsVariantList * pMagicParams,
-		KviWindow * pWindow,bool modal)
-	: QMessageBox(
-		szCaption,
-		szText,
-		QMessageBox::NoIcon,
-		szButton0.isEmpty() ? QMessageBox::NoButton : QMessageBox::Ok | QMessageBox::Default,
-		szButton1.isEmpty() ? QMessageBox::NoButton : (szButton2.isEmpty() ? QMessageBox::No | QMessageBox::Escape : QMessageBox::No),
-		szButton2.isEmpty() ? QMessageBox::NoButton : QMessageBox::Cancel | QMessageBox::Escape,
-		0,0,modal) ,
+	const QString &szCaption,
+	const QString &szText,
+	const QString &szIcon,
+	const QString &szButton0,
+	const QString &szButton1,
+	const QString &szButton2,
+	const QString &szCode,
+	KviKvsVariantList * pMagicParams,
+	KviWindow * pWindow,bool modal)
+: QMessageBox(
+	szCaption,
+	szText,
+	QMessageBox::NoIcon,
+	szButton0.isEmpty() ? QMessageBox::NoButton : QMessageBox::Ok | QMessageBox::Default,
+	szButton1.isEmpty() ? QMessageBox::NoButton : (szButton2.isEmpty() ? QMessageBox::No | QMessageBox::Escape : QMessageBox::No),
+	szButton2.isEmpty() ? QMessageBox::NoButton : QMessageBox::Cancel | QMessageBox::Escape,
+	0,0,modal) ,
 	KviKvsCallbackObject("dialog.message",pWindow,szCode,pMagicParams,0)
 {
+	g_pDialogModuleDialogList->append(this);
+#ifndef COMPILE_USE_QT4
 	setIcon(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_KVIRC)));
+#endif
 
 	QPixmap * pix = g_pIconManager->getImage(szIcon);
 
@@ -84,6 +93,7 @@ KviKvsCallbackMessageBox::KviKvsCallbackMessageBox(
 
 KviKvsCallbackMessageBox::~KviKvsCallbackMessageBox()
 {
+	g_pDialogModuleDialogList->removeRef(this);
 }
 
 void KviKvsCallbackMessageBox::done(int code)
@@ -199,6 +209,7 @@ KviKvsCallbackTextInput::KviKvsCallbackTextInput(
 		KviWindow * pWindow,bool modal)
 	: QDialog(), KviKvsCallbackObject("dialog.textinput",pWindow,szCode,pMagicParams,0)
 {
+	g_pDialogModuleDialogList->append(this);
 	setIcon(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_KVIRC)));
 	setModal(modal);
 	setCaption(szCaption);
@@ -211,7 +222,7 @@ KviKvsCallbackTextInput::KviKvsCallbackTextInput(
 	{
 		QLabel * il = new QLabel(this);
 		il->setPixmap(*pix);
-		il->setAlignment(AlignCenter);
+		il->setAlignment(Qt::AlignCenter);
 		g->addWidget(il,0,0);
 		QLabel * tl = new QLabel(szLabel,this);
 		g->addWidget(tl,0,1);
@@ -235,7 +246,7 @@ KviKvsCallbackTextInput::KviKvsCallbackTextInput(
 
 	g->addMultiCellWidget(m_pEdit,1,1,0,1);
 
-	QHBox * box = new QHBox(this);
+	KviTalHBox * box = new KviTalHBox(this);
 	g->addMultiCellWidget(box,2,2,0,1);
 
 	m_iEscapeButton = 0;
@@ -302,6 +313,7 @@ KviKvsCallbackTextInput::KviKvsCallbackTextInput(
 
 KviKvsCallbackTextInput::~KviKvsCallbackTextInput()
 {
+	g_pDialogModuleDialogList->removeRef(this);
 }
 
 void KviKvsCallbackTextInput::b0Clicked()
@@ -477,11 +489,13 @@ KviKvsCallbackFileDialog::KviKvsCallbackFileDialog(
 		KviWindow * pWindow,bool modal)
 	: KviFileDialog(szInitialSelection,szFilter,0,0,modal), KviKvsCallbackObject("dialog.file",pWindow,szCode,pMagicParams,0)
 {
+	g_pDialogModuleDialogList->append(this);
 	setCaption(szCaption);
 }
 
 KviKvsCallbackFileDialog::~KviKvsCallbackFileDialog()
 {
+	g_pDialogModuleDialogList->removeRef(this);
 }
 
 void KviKvsCallbackFileDialog::done(int code)
@@ -624,10 +638,12 @@ KviKvsCallbackImageDialog::KviKvsCallbackImageDialog(
 		KviWindow * pWindow,bool modal)
 	: KviImageDialog(0,szCaption,iType,0,szInitialSelection,iMaxSize,modal), KviKvsCallbackObject("dialog.image",pWindow,szCode,pMagicParams,0)
 {
+	g_pDialogModuleDialogList->append(this);
 }
 
 KviKvsCallbackImageDialog::~KviKvsCallbackImageDialog()
 {
+	g_pDialogModuleDialogList->removeRef(this);
 }
 
 void KviKvsCallbackImageDialog::done(int code)
@@ -718,7 +734,7 @@ static bool dialog_kvs_cmd_image(KviKvsModuleCallbackCommandCall * c)
 		KVSM_PARAMETER("maxsize",KVS_PT_UINT,KVS_PF_OPTIONAL,iMaxSize)
 		KVSM_PARAMETER("magic",KVS_PT_VARIANTLIST,KVS_PF_OPTIONAL,params)
 	KVSM_PARAMETERS_END(c)
-bool modal;
+	bool modal;
 	if(c->hasSwitch('b',"modal")) modal=true;
 	else modal=false;
 	QString szCmd = c->callback()->code();
@@ -757,7 +773,7 @@ bool modal;
 */
 
 static bool dialog_kvs_fnc_yesno(KviKvsModuleFunctionCall * c)
-{ 
+{
 	QString szCaption;
 	QString szText;
 	KVSM_PARAMETERS_BEGIN(c)
@@ -766,7 +782,7 @@ static bool dialog_kvs_fnc_yesno(KviKvsModuleFunctionCall * c)
 	KVSM_PARAMETERS_END(c)
 	
 	c->enterBlockingSection();
-	bool yes=KviMessageBox::yesNo(szCaption,szText);
+	bool yes=KviMessageBox::yesNo(szCaption,szText); // this will happily crash on quit ?
 	if(!c->leaveBlockingSection())return true; // just die
 	c->returnValue()->setBoolean(yes);
 	return true;
@@ -862,9 +878,8 @@ static bool dialog_module_fnc_textline(KviModule *m,KviCommand *c,KviParameterLi
 
 static bool dialog_module_init(KviModule * m)
 {
-//	g_pDialogModuleDialogList = new KviPtrList<KviScriptCallbackDialog>;
-//	g_pDialogModuleDialogList->setAutoDelete(false);
-
+	g_pDialogModuleDialogList = new KviPointerList<QWidget>;
+	g_pDialogModuleDialogList->setAutoDelete(false);
 
 	KVSM_REGISTER_CALLBACK_COMMAND(m,"message",dialog_kvs_cmd_message);
 	KVSM_REGISTER_CALLBACK_COMMAND(m,"textinput",dialog_kvs_cmd_textinput);
@@ -873,32 +888,32 @@ static bool dialog_module_init(KviModule * m)
 
 	KVSM_REGISTER_FUNCTION(m,"yesno",dialog_kvs_fnc_yesno);
 
-    return true;
+	return true;
 }
 
 static bool dialog_module_cleanup(KviModule *m)
 {
 	// Here we get a tragedy if g_iLocalEventLoops > 0!
-//	while(g_pDialogModuleDialogList->first())delete g_pDialogModuleDialogList->first();
-//	delete g_pDialogModuleDialogList;
-//    g_pDialogModuleDialogList = 0;
+	while(g_pDialogModuleDialogList->first())delete g_pDialogModuleDialogList->first();
+	delete g_pDialogModuleDialogList;
+	g_pDialogModuleDialogList = 0;
 	return true;
 }
 
 static bool dialog_module_can_unload(KviModule *m)
 {
-	return 1;
+	return g_pDialogModuleDialogList->isEmpty();
 }
 
 
 KVIRC_MODULE(
-    "KVIrc script dialogs",
+	"KVIrc script dialogs",
 	"1.0.0",
 	"Szymon Stefanek <pragma at kvirc dot net>" ,
 	"Adds the /dialog.* commands functionality\n",
-    dialog_module_init ,
-    dialog_module_can_unload,
-    0,
+	dialog_module_init ,
+	dialog_module_can_unload,
+	0,
 	dialog_module_cleanup
 )
 
