@@ -27,11 +27,16 @@
 
 #include <qlayout.h>
 #include <qtoolbutton.h>
-#include <qgroupbox.h>
-#include <qpopupmenu.h>
+#include <kvi_tal_groupbox.h>
+#include "kvi_tal_popupmenu.h"
+#include "kvi_tal_scrollview.h"
 #include <qmessagebox.h>
 #include <qtimer.h>
-#include <qobjectlist.h>
+#ifdef COMPILE_USE_QT4
+	//#define QSyntaxHighlighter Q3SyntaxHighlighter
+#else
+	#include <qobjectlist.h>
+#endif
 #include <qcursor.h>
 #include <qfont.h>
 #include <qrect.h>
@@ -42,8 +47,8 @@
 #include "kvi_qstring.h"
 #include "kvi_config.h"
 #include "kvi_module.h"
-#include "kvi_list.h"
-////#include "kvi_uparser.h"
+#include "kvi_pointerlist.h"
+//
 #include "kvi_app.h"
 #include "kvi_console.h"
 #include "kvi_window.h"
@@ -53,41 +58,45 @@
 #include <qlayout.h>
 
 
-extern KviPtrList<KviScriptEditorImplementation> * g_pScriptEditorWindowList;
+extern KviPointerList<KviScriptEditorImplementation> * g_pScriptEditorWindowList;
 extern KviModule * g_pEditorModulePointer;
 
 
-static QColor g_clrBackground(0,0,0);
-static QColor g_clrNormalText(100,255,0);
+static QColor g_clrBackground(255,255,255);
+static QColor g_clrNormalText(0,0,0);
 static QColor g_clrBracket(255,0,0);
 static QColor g_clrComment(0,120,0);
-static QColor g_clrFunction(255,255,0);
-static QColor g_clrKeyword(120,120,150);
-static QColor g_clrVariable(200,200,200);
+static QColor g_clrFunction(0,17,255);
+static QColor g_clrKeyword(85,85,255);
+static QColor g_clrVariable(255,0,0);
 static QColor g_clrPunctuation(180,180,0);
-static QColor g_clrFind(187,221,255);
+static QColor g_clrFind(0,0,0);
 
-static QFont g_fntNormal("Fixed",12);
+static QFont g_fntNormal("Courier New",8);
 
-KviCompletionBox::KviCompletionBox(QWidget * parent = 0, const char * name = 0, WFlags f = 0)
-: QListBox(parent,name,f)
+KviCompletionBox::KviCompletionBox(QWidget * parent = 0)
+: KviTalListBox(parent)
 {
 	setPaletteForegroundColor(QColor(0,0,0));
 	setPaletteBackgroundColor(QColor(255,255,255));
+#ifdef COMPILE_USE_QT4
+	setHScrollBarMode(KviTalListBox::AlwaysOff);
+#else
 	setHScrollBarMode(QScrollView::AlwaysOff);
+#endif
 	QFont listfont=font();
 	listfont.setPointSize(8);
 	setFont(listfont);
 	setVariableWidth(false);
 	setFixedWidth(200);
-	//completelistbox->setColumnMode(QListBox::Variable);
+	//completelistbox->setColumnMode(KviTalListBox::Variable);
 	hide();
 }
 
 void KviCompletionBox::updateContents(QString buffer)
 {
 	buffer=buffer.stripWhiteSpace();
-	KviPtrList<QString> list;
+	KviPointerList<QString> list;
 	clear();
 	
 	QString szModule;
@@ -152,13 +161,13 @@ void KviCompletionBox::keyPressEvent(QKeyEvent * e)
 			}
 		
 	}
-	QListBox::keyPressEvent(e);
+	KviTalListBox::keyPressEvent(e);
 }
 
 KviScriptEditorWidgetColorOptions::KviScriptEditorWidgetColorOptions(QWidget * pParent)
 : QDialog(pParent)
 {
-	m_pSelectorInterfaceList = new KviPtrList<KviSelectorInterface>;
+	m_pSelectorInterfaceList = new KviPointerList<KviSelectorInterface>;
         m_pSelectorInterfaceList->setAutoDelete(false);
 	setCaption(__tr2qs_ctx("Preferences","editor"));
 	QGridLayout * g = new QGridLayout(this,3,3,4,4);
@@ -166,7 +175,7 @@ KviScriptEditorWidgetColorOptions::KviScriptEditorWidgetColorOptions(QWidget * p
 	KviFontSelector * f = new KviFontSelector(this,__tr2qs_ctx("Font:","editor"),&g_fntNormal,true);
 	g->addMultiCellWidget(f,0,0,0,2);
 	m_pSelectorInterfaceList->append(f);
-	QGroupBox * gbox = new QGroupBox(1,QGroupBox::Horizontal,__tr2qs("Colors" ),this);
+	KviTalGroupBox * gbox = new KviTalGroupBox(1,Qt::Horizontal,__tr2qs("Colors" ),this);
 	g->addMultiCellWidget(gbox,1,1,0,2);
 	KviColorSelector * s = addColorSelector(gbox,__tr2qs_ctx("Background:","editor"),&g_clrBackground,true);
 	s = addColorSelector(gbox,__tr2qs_ctx("Normal text:","editor"),&g_clrNormalText,true);
@@ -216,14 +225,14 @@ void KviScriptEditorWidgetColorOptions::okClicked()
 
 
 KviScriptEditorWidget::KviScriptEditorWidget(QWidget * pParent)
-: QTextEdit(pParent)
+: KviTalTextEdit(pParent)
 {
-	setWordWrap(QTextEdit::NoWrap);
+	setWordWrap(KviTalTextEdit::NoWrap);
 	m_pParent=pParent;
 	m_szHelp="Nothing";
 	updateOptions();
 	m_szFind="";
-	completelistbox=new KviCompletionBox(this,"completelistbox");
+	completelistbox=new KviCompletionBox(this);
 	connect (completelistbox,SIGNAL(selected(const QString &)),this,SLOT(slotComplete(const QString &)));
 }
 
@@ -232,11 +241,19 @@ KviScriptEditorWidget::~KviScriptEditorWidget()
 
 }
 
+#ifdef COMPILE_USE_QT4
+Q3PopupMenu * KviScriptEditorWidget::createPopupMenu( const QPoint& pos )
+#else
 QPopupMenu * KviScriptEditorWidget::createPopupMenu( const QPoint& pos )
+#endif
 {
-	QPopupMenu *pop=QTextEdit::createPopupMenu(pos);
-	pop->insertItem(__tr2qs("Context sensitive help"),this,SLOT(slotHelp()),CTRL+Key_H);
-	pop->insertItem(__tr2qs("&Replace"),this,SLOT(slotReplace()),CTRL+Key_R);
+#ifdef COMPILE_USE_QT4
+	Q3PopupMenu *pop=KviTalTextEdit::createPopupMenu(pos);
+#else
+	QPopupMenu *pop=KviTalTextEdit::createPopupMenu(pos);
+#endif
+	pop->insertItem(__tr2qs("Context sensitive help"),this,SLOT(slotHelp()),Qt::CTRL+Qt::Key_H);
+	pop->insertItem(__tr2qs("&Replace"),this,SLOT(slotReplace()),Qt::CTRL+Qt::Key_R);
 	return pop;
 }
 
@@ -271,7 +288,11 @@ void KviScriptEditorWidget::updateOptions()
 	p.setColor(QColorGroup::Text,g_clrNormalText);
 	setPalette(p);
 	
-	setTextFormat(QTextEdit::PlainText);
+#ifdef COMPILE_USE_QT4
+	setTextFormat(Qt::PlainText);
+#else
+	setTextFormat(KviTalTextEdit::PlainText);
+#endif
 	
 	// this will rehighlight everything
 	setText(text()); // an "hack" to ensure Update all in the editor
@@ -340,7 +361,7 @@ void KviScriptEditorWidget::keyPressEvent(QKeyEvent * e)
 			}
 			break;
 		case Qt::Key_Return:
-			QTextEdit::keyPressEvent(e);
+			KviTalTextEdit::keyPressEvent(e);
 			int para,pos;
 			getCursorPosition(&para,&pos);
 			if(para > 0)
@@ -370,7 +391,7 @@ void KviScriptEditorWidget::keyPressEvent(QKeyEvent * e)
 			setFocus();
 			break;
 	}
-	QTextEdit::keyPressEvent(e);
+	KviTalTextEdit::keyPressEvent(e);
 	emit keyPressed();
 	if(completelistbox->isVisible()) 
 		completition(0);
@@ -388,7 +409,7 @@ void KviScriptEditorWidget::contentsMousePressEvent(QMouseEvent *e)
 	buffer=this->text(para);
 	getWordOnCursor(buffer,index);
 	QString tmp=buffer;
-	KviPtrList<QString> l;
+	KviPointerList<QString> l;
 	if (tmp.left(1) == "$")
 	{	
 		tmp.remove(0,1);
@@ -405,7 +426,7 @@ void KviScriptEditorWidget::contentsMousePressEvent(QMouseEvent *e)
 	//debug (buffer);
 	m_szHelp=buffer;
 	}
-	QTextEdit::contentsMousePressEvent(e);
+	KviTalTextEdit::contentsMousePressEvent(e);
 
 }
 
@@ -420,7 +441,7 @@ bool KviScriptEditorWidget::contextSensitiveHelp() const
 
 	/*
 	QString tmp=buffer;
-	KviPtrList<QString> * l;
+	KviPointerList<QString> * l;
 	if(tmp.left(1) == "$")
 	{
 		tmp.remove(0,1);
@@ -447,6 +468,7 @@ bool KviScriptEditorWidget::contextSensitiveHelp() const
 
 	QString parse;
 	KviQString::sprintf(parse,"timer -s (help,0){ help -s %Q; }",&buffer);
+	debug ("parsing %s",parse.latin1());
 	KviKvsScript::run(parse,(KviWindow*)g_pApp->activeConsole());
 	
 	return true;
@@ -668,7 +690,30 @@ int KviScriptSyntaxHighlighter::highlightParagraph(const QString &text,int endSt
 						continue;
 					}
 				}
-				// not an else... FIXME: should check for callbacks.. but that's prolly too difficult :)
+				else
+				if(pBegin->unicode() == 'f')
+				{
+					if(c - pBegin == 8)
+					{
+						// might be "function"
+						QString tmp(pBegin,8);
+						if(tmp.lower() == "function")bNewCommand = true;
+						continue;
+					}
+				}
+
+				if(pBegin->unicode() == 'i')
+				{
+					if(c - pBegin == 8)
+					{
+						// might be "internal"
+						QString tmp(pBegin,8);
+						if(tmp.lower() == "internal")bNewCommand = true;
+						continue;
+					}
+				}
+
+				// not an else or special command function... FIXME: should check for callbacks.. but that's prolly too difficult :)
 				continue;
 			}
 		}
@@ -802,7 +847,9 @@ KviScriptEditorImplementation::KviScriptEditorImplementation(QWidget * par)
 	QGridLayout * g = new QGridLayout(this,2,3,0,0);
 
 	m_pFindLineedit = new QLineEdit(" ",this);
+#ifndef COMPILE_USE_QT4
 	m_pFindLineedit->setFrameStyle(QFrame::Sunken | QFrame::Panel);
+#endif
 	m_pFindLineedit->setText("");
 	m_pFindLineedit->setPaletteForegroundColor(g_clrFind);
 
@@ -810,11 +857,15 @@ KviScriptEditorImplementation::KviScriptEditorImplementation(QWidget * par)
 	g->addMultiCellWidget(m_pEditor,0,0,0,3);
 	g->setRowStretch(0,1);
 
+#ifdef COMPILE_USE_QT4
+	QToolButton * b = new QToolButton(Qt::DownArrow,this,"dsa2");
+#else
 	QToolButton * b = new QToolButton(DownArrow,this);
+#endif
 	b->setMinimumWidth(24);
 	g->addWidget(b,1,0);
 
-	QPopupMenu * pop = new QPopupMenu(b);
+	KviTalPopupMenu * pop = new KviTalPopupMenu(b);
 	pop->insertItem(__tr2qs_ctx("&Open...","editor"),this,SLOT(loadFromFile()));
 	pop->insertItem(__tr2qs_ctx("&Save As...","editor"),this,SLOT(saveToFile()));
 	pop->insertSeparator();
@@ -952,16 +1003,20 @@ void KviScriptEditorImplementation::saveToFile()
 	}
 }
 
-void KviScriptEditorImplementation::setText(const QCString &txt)
+void KviScriptEditorImplementation::setText(const KviQCString &txt)
 {
 	m_pEditor->setText(txt.data());
-	m_pEditor->setTextFormat(QTextEdit::PlainText);
-	m_pEditor->moveCursor(QTextEdit::MoveEnd,false);
+#ifdef COMPILE_USE_QT4
+	m_pEditor->setTextFormat(Qt::PlainText);
+#else
+	m_pEditor->setTextFormat(KviTalTextEdit::PlainText);
+#endif
+	m_pEditor->moveCursor(KviTalTextEdit::MoveEnd,false);
 	m_pEditor->setModified(false);
 	updateRowColLabel();
 }
 
-void KviScriptEditorImplementation::getText(QCString &txt)
+void KviScriptEditorImplementation::getText(KviQCString &txt)
 {
 	txt = m_pEditor->text();
 }
@@ -972,8 +1027,12 @@ QLineEdit * KviScriptEditorImplementation::getFindlineedit()
 void KviScriptEditorImplementation::setText(const QString &txt)
 {
 	m_pEditor->setText(txt);
-	m_pEditor->setTextFormat(QTextEdit::PlainText);
-	m_pEditor->moveCursor(QTextEdit::MoveEnd,false);
+#ifdef COMPILE_USE_QT4
+	m_pEditor->setTextFormat(Qt::PlainText);
+#else
+	m_pEditor->setTextFormat(KviTalTextEdit::PlainText);
+#endif
+	m_pEditor->moveCursor(KviTalTextEdit::MoveEnd,false);
 	m_pEditor->setModified(false);
 	updateRowColLabel();
 }
@@ -1037,7 +1096,7 @@ void KviScriptEditorImplementation::loadFromFile()
 		if(KviFileUtils::loadFile(fName,buffer))
 		{
 			m_pEditor->setText(buffer);
-			m_pEditor->moveCursor(QTextEdit::MoveEnd,false);
+			m_pEditor->moveCursor(KviTalTextEdit::MoveEnd,false);
 			updateRowColLabel();
 		} else {
 			QString tmp;
@@ -1068,30 +1127,36 @@ KviScriptEditorReplaceDialog::KviScriptEditorReplaceDialog( QWidget* parent, con
 	QGridLayout *layout = new QGridLayout( this, 1, 1, 11, 6, "replace layout"); 
  
 	m_pFindlineedit = new QLineEdit( this, "findlineedit" );
+#ifndef COMPILE_USE_QT4
 	m_pFindlineedit->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)7, (QSizePolicy::SizeType)0, 0, 0, m_pFindlineedit->sizePolicy().hasHeightForWidth() ) );
 	m_pFindlineedit->setFrameShape( QLineEdit::LineEditPanel );
 	m_pFindlineedit->setFrameShadow( QLineEdit::Sunken );
+#endif
 
 	layout->addMultiCellWidget( m_pFindlineedit, 2, 2, 1, 2 );
 
 	m_pReplacelineedit = new QLineEdit( this, "replacelineedit" );
+#ifndef COMPILE_USE_QT4
 	m_pReplacelineedit->setFrameShape( QLineEdit::LineEditPanel );
 	m_pReplacelineedit->setFrameShadow( QLineEdit::Sunken );
-
+#endif
 	layout->addMultiCellWidget( m_pReplacelineedit, 3, 3, 1, 2 );
 
    	m_pFindlineedit->setFocus();
 
     QLabel *findlabel = new QLabel( this, "findlabel" );
 	findlabel->setText(tr("Word to Find"));
+#ifndef COMPILE_USE_QT4
 	findlabel->setAutoResize(true);
+#endif
 
 	layout->addWidget( findlabel, 2, 0 );
 
     QLabel *replacelabel = new QLabel( this, "replacelabel" );
 	replacelabel->setText(tr("Replace with"));
+#ifndef COMPILE_USE_QT4
 	replacelabel->setAutoResize(true);
-
+#endif
 	layout->addWidget( replacelabel, 3, 0 );
 
     QPushButton *cancelbutton = new QPushButton( this, "cancelButton" );
@@ -1117,9 +1182,10 @@ KviScriptEditorReplaceDialog::KviScriptEditorReplaceDialog( QWidget* parent, con
 	layout->addWidget( replace, 3, 3 );
 	replace->setEnabled(false);
 
+#ifndef COMPILE_USE_QT4
     clearWState( WState_Polished );
-
 	setTabOrder(m_pFindlineedit,m_pReplacelineedit);
+#endif
 	// signals and slots connections
 	connect( replacebutton, SIGNAL( clicked() ), this, SLOT( slotReplace() ) );
 	connect( findNext, SIGNAL( clicked() ),this,SLOT( slotNextFind()));
@@ -1143,8 +1209,9 @@ void KviScriptEditorReplaceDialog::slotReplace()
 {
 	QString txt=((KviScriptEditorWidget *)m_pParent)->text();
 	if (checkReplaceAll->isChecked()) emit replaceAll(m_pFindlineedit->text(),m_pReplacelineedit->text());
-	else txt.replace(m_pFindlineedit->text(),m_pReplacelineedit->text(),false);
+	txt.replace(m_pFindlineedit->text(),m_pReplacelineedit->text(),false);
 	((KviScriptEditorWidget *)m_pParent)->setText(txt);
+	((KviScriptEditorWidget *)m_pParent)->setModified(true);
 	m_pFindlineedit->setText("");
 	m_pReplacelineedit->setText("");
 	setTabOrder(m_pFindlineedit,m_pReplacelineedit);
