@@ -28,23 +28,25 @@
 #include "kvi_scripteditor.h"
 
 #include <qlabel.h>
-#include <qcstring.h>
-#include <qtextedit.h>
+#include <kvi_tal_textedit.h>
 #include <qsyntaxhighlighter.h>
 #include <qdialog.h>
 #include <qcheckbox.h>
-#include <qlistbox.h>
+#include "kvi_tal_listbox.h"
 #include <qevent.h> 
+#include "kvi_qcstring.h"
 
-#include "kvi_list.h"
+#include "kvi_tal_popupmenu.h"
+
+#include "kvi_pointerlist.h"
 #include "kvi_selectors.h"
-typedef KviPtrList<int> ColumnList;
+typedef KviPointerList<int> ColumnList;
 
-class KviCompletionBox: public QListBox
+class KviCompletionBox: public KviTalListBox
 {
 	Q_OBJECT
 public:
-	KviCompletionBox(QWidget * parent, const char * name, WFlags f);
+	KviCompletionBox(QWidget * parent);
 	~KviCompletionBox(){};
 	
 	void updateContents(QString word);
@@ -52,7 +54,7 @@ protected:
 	virtual void keyPressEvent(QKeyEvent * e);
 };
 
-class KviScriptEditorWidget : public QTextEdit
+class KviScriptEditorWidget : public KviTalTextEdit
 {
 	Q_OBJECT
 	Q_PROPERTY(bool contextSensitiveHelp READ contextSensitiveHelp)
@@ -79,13 +81,22 @@ signals:
 protected:
 	virtual void keyPressEvent(QKeyEvent * e);
 	void contentsMousePressEvent(QMouseEvent *);
+#ifdef COMPILE_USE_QT4
+	Q3PopupMenu *createPopupMenu( const QPoint& pos );
+#else
 	QPopupMenu *createPopupMenu( const QPoint& pos );
+#endif
 	QWidget *m_pParent;
 	QString m_szHelp;
 
 };
 
-
+#ifdef COMPILE_USE_QT4
+	#include <q3syntaxhighlighter.h>
+	#define QSyntaxHighlighter Q3SyntaxHighlighter
+#else
+	#include <qobjectlist.h>
+#endif
 class KviScriptSyntaxHighlighter : public QSyntaxHighlighter
 {
 public:
@@ -102,7 +113,7 @@ public:
 	KviScriptEditorWidgetColorOptions(QWidget * pParent);
 	~KviScriptEditorWidgetColorOptions();
 private:
-	KviPtrList<KviSelectorInterface> * m_pSelectorInterfaceList;
+	KviPointerList<KviSelectorInterface> * m_pSelectorInterfaceList;
 protected:
 	KviColorSelector * addColorSelector(QWidget * pParent,const QString & txt,QColor * pOption,bool bEnabled);
 
@@ -125,8 +136,8 @@ protected:
 public:
 	virtual void setText(const QString &txt);
 	virtual void getText(QString &txt);
-	virtual void setText(const QCString &txt);
-	virtual void getText(QCString &txt);
+	virtual void setText(const KviQCString &txt);
+	virtual void getText(KviQCString &txt);
 	virtual void setFindText(const QString & text);
 	virtual void setEnabled(bool bEnabled);
 	virtual void setFocus();
