@@ -21,9 +21,7 @@
 //
 
 #include "kvi_module.h"
-//#include "kvi_uparser.h"
 #include "kvi_locale.h"
-#include "kvi_command.h"
 #include "kvi_frame.h"
 
 #include "eventeditor.h"
@@ -46,7 +44,7 @@ KviEventEditorWindow * g_pEventEditorWindow = 0;
 */
 
 static bool eventeditor_kvs_cmd_open(KviKvsModuleCommandCall * c)
-{ 
+{
 	if(!g_pEventEditorWindow)
 	{
 		g_pEventEditorWindow = new KviEventEditorWindow(c->window()->frame());
@@ -57,8 +55,6 @@ static bool eventeditor_kvs_cmd_open(KviKvsModuleCommandCall * c)
 	return true;
 }
 
-
-
 static bool eventeditor_module_init(KviModule * m)
 {
 
@@ -76,7 +72,7 @@ static bool eventeditor_module_can_unload(KviModule * m)
 static bool eventeditor_module_cleanup(KviModule *m)
 {
 	if(g_pEventEditorWindow)delete g_pEventEditorWindow;
-    g_pEventEditorWindow = 0;
+	g_pEventEditorWindow = 0;
 	return true;
 }
 
