@@ -23,19 +23,19 @@
 //=============================================================================
 
 #include "kvi_module.h"
-//#include "kvi_uparser.h"
 #include "kvi_fileutils.h"
 #include "kvi_locale.h"
-#include "kvi_command.h"
 #include "kvi_malloc.h"
 #include "kvi_app.h"
 #include "kvi_options.h"
+#include "kvi_qcstring.h"
 
 #include "kvi_kvs_arraycast.h"
 
 #include <qfileinfo.h>
-#include <qfile.h>
+#include "kvi_file.h"
 #include <qdir.h>
+#include <qtextstream.h>
 
 /*
 	@doc: file.copy
@@ -61,7 +61,7 @@
 		is running on so you don't have to bother about portability: it *should* be automatically
 		guaranteed. Just use UNIX style paths for them.[br]
 	@seealso:
-		[cmd]file.rename[/cmd], [fnc]$file.exists[/fnc]()
+		[cmd]file.rename[/cmd], [fnc]$file.exists[/fnc]
 */
 
 static bool file_kvs_cmd_copy(KviKvsModuleCommandCall * c)
@@ -181,7 +181,7 @@ static bool file_kvs_cmd_delimagepath(KviKvsModuleCommandCall * c)
 		The file is saved in utf8 unless the -l switch is specified (in that case the local 8 bit encoding is used).
 		Please note that uf8 is the only character set that preserves ALL the possible characters.
 	@seealso:
-		[cmd]file.rename[/cmd], [fnc]$file.exists[/fnc]()
+		[cmd]file.rename[/cmd], [fnc]$file.exists[/fnc]
 */
 
 static bool file_kvs_cmd_write(KviKvsModuleCommandCall * c)
@@ -226,7 +226,7 @@ static bool file_kvs_cmd_write(KviKvsModuleCommandCall * c)
 		is running on so you don't have to bother about portability: it *should* be automatically
 		guaranteed.Just use UNIX style paths for them.[br]
 	@seealso:
-		[cmd]file.copy[/cmd], [fnc]$file.exists[/fnc]()
+		[cmd]file.copy[/cmd], [fnc]$file.exists[/fnc]
 */
 
 static bool file_kvs_cmd_rename(KviKvsModuleCommandCall * c)
@@ -267,7 +267,7 @@ static bool file_kvs_cmd_rename(KviKvsModuleCommandCall * c)
 		is running on so you don't have to bother about portability: it *should* be automatically
 		guaranteed. Just use an UNIX style path.[br]
 	@seealso:
-		[fnc]$file.exists[/fnc]()
+		[fnc]$file.exists[/fnc]
 */
 
 static bool file_kvs_cmd_mkdir(KviKvsModuleCommandCall * c)
@@ -306,7 +306,7 @@ static bool file_kvs_cmd_mkdir(KviKvsModuleCommandCall * c)
 		is running on so you don't have to bother about portability: it *should* be automatically
 		guaranteed. Just use an UNIX style path.[br]
 	@seealso:
-		[fnc]$file.exists[/fnc]()
+		[fnc]$file.exists[/fnc]
 */
 
 static bool file_kvs_cmd_remove(KviKvsModuleCommandCall * c)
@@ -348,7 +348,7 @@ static bool file_kvs_cmd_remove(KviKvsModuleCommandCall * c)
 		is running on so you don't have to bother about portability: it *should* be automatically
 		guaranteed. Just use an UNIX style path.[br]
 	@seealso:
-		[fnc]$file.exists[/fnc]()
+		[fnc]$file.exists[/fnc]
 		[cmd]file.remove[/cmd]
 */
 
@@ -452,6 +452,58 @@ static bool file_kvs_fnc_size(KviKvsModuleFunctionCall * c)
 	KviFileUtils::adjustFilePath(szName);
 	QFileInfo f(szName);
 	c->returnValue()->setInteger(f.size());
+	return true;
+}
+/*
+	@doc: file.allSizese
+	@type:
+		function
+	@title:
+		$file.allSizes
+	@short:
+		Returns all sizes of a specified directory.
+	@syntax:
+	<array> $file.allSize(<dirname:string>)
+	@description:
+	Returns the size of every files of the specified directory as an array.[br]
+*/
+
+static bool file_kvs_fnc_allSizes(KviKvsModuleFunctionCall * c)
+{
+	QString szDir;
+	KVSM_PARAMETERS_BEGIN(c)
+		KVSM_PARAMETER("directory",KVS_PT_NONEMPTYSTRING,0,szDir)
+	KVSM_PARAMETERS_END(c)
+	KviFileUtils::adjustFilePath(szDir);
+	
+	QDir d(szDir);
+	if(!d.exists())
+	{
+		c->warning(__tr2qs("The specified directory does not exist '%Q'"),&szDir);
+		return true;
+	}
+
+	QStringList sl;
+	sl = d.entryList(QDir::Files);
+
+	KviKvsArray * a = new KviKvsArray();
+	QString szFile;
+	if(!sl.isEmpty())
+	{
+		int idx = 0;
+		for(QStringList::Iterator it = sl.begin();it != sl.end();++it)
+		{
+			szFile=szDir+(*it);
+			QFileInfo f(szFile);
+			a->set(idx,new KviKvsVariant((kvs_int_t)f.size()));
+			idx++;
+		}
+	}
+	c->returnValue()->setArray(a);
+
+
+
+
 	return true;
 }
 
@@ -577,7 +629,11 @@ static bool file_kvs_fnc_ls(KviKvsModuleFunctionCall * c)
 		return true;
 	}
 
+#ifdef COMPILE_USE_QT4
+	QFlags<QDir::Filter> iFlags = 0;
+#else
 	int iFlags = 0;
+#endif
 	if(szFlags.isEmpty())iFlags = QDir::Dirs | QDir::Files | QDir::NoSymLinks | QDir::Readable | QDir::Writable | QDir::Executable | QDir::Hidden | QDir::System;
 	else {
 		if(szFlags.find('d',false) != -1)iFlags |= QDir::Dirs;
@@ -589,7 +645,11 @@ static bool file_kvs_fnc_ls(KviKvsModuleFunctionCall * c)
 		if(szFlags.find('h',false) != -1)iFlags |= QDir::Hidden;
 		if(szFlags.find('s',false) != -1)iFlags |= QDir::System;
 	}
+#ifdef COMPILE_USE_QT4
+	QFlags<QDir::SortFlag> iSort = 0;
+#else
 	int iSort = 0;
+#endif
 	if(szFlags.isEmpty())iSort = QDir::Unsorted;
 	else {
 		if(szFlags.find('n',false) != -1)iSort |= QDir::Name;
@@ -739,7 +799,7 @@ static bool file_kvs_fnc_read(KviKvsModuleFunctionCall * c)
 			echo $file.readLines(/proc/cpuinfo)
 		[/example]
 	@seealso:
-		[fnc]$file.read[/fnc](), [cmd]file.writeLines[/fnc], [fnc]$lf[/fnc]
+		[fnc]$file.read[/fnc], [cmd]file.writeLines[/cmd], [fnc]$lf[/fnc]
 */
 
 
@@ -747,7 +807,6 @@ static bool file_kvs_fnc_read(KviKvsModuleFunctionCall * c)
 static bool file_kvs_fnc_readLines(KviKvsModuleFunctionCall * c)
 {
 	QString szName;
-	kvs_uint_t uSize;
 	QString szFlags;
 	kvs_int_t iStartLine;
 	kvs_int_t iCount;
@@ -769,41 +828,32 @@ static bool file_kvs_fnc_readLines(KviKvsModuleFunctionCall * c)
 	if(c->params()->count() < 2)iStartLine = 0;
 	if(c->params()->count() < 3)iCount = -1;
 
-	bool bLocal8Bit = szFlags.find('l',false) != -1;
+	bool bLocal8Bit = szFlags.find('l',0,false) != -1;
 
 	KviKvsArray * a = new KviKvsArray();
 
-	int i = 0;
-	int idx = 0;
-	while(idx < iStartLine)
-	{
-		QString szDummy;
-		KviFileUtils::readLine(&f,szDummy);
-		idx++;
-	}
+	int iIndex=0;
 
-	QString szBuf;
+	QTextStream stream( &f );
 
-	if(iCount > 0)
+	stream.setEncoding(bLocal8Bit ? QTextStream::Locale : QTextStream::UnicodeUTF8);
+	for(int i=0;i<iStartLine;i++)
+		stream.readLine();
+
+	if(iCount>0)
 	{
-		int iEndLine = iStartLine + iCount;
-		while(idx < iEndLine)
-		{
-			if(KviFileUtils::readLine(&f,szBuf,!bLocal8Bit))
-				a->set(i,new KviKvsVariant(szBuf));
-			else
-				break;
-			i++;
-			idx++;
-		}
+		for(; (iCount>0 && !stream.atEnd()) ; iCount-- )
+			a->set(iIndex,new KviKvsVariant(stream.readLine()));
+			iIndex++;
 	} else {
-		while(KviFileUtils::readLine(&f,szBuf,!bLocal8Bit))
-		{
-			a->set(i,new KviKvsVariant(szBuf));
-			i++;
+		while(!stream.atEnd()) {
+			a->set(iIndex,new KviKvsVariant(stream.readLine()));
+			iIndex++;
 		}
 	}
 
+	f.close();
+	
 	c->returnValue()->setArray(a);
 
 	return true;
@@ -861,11 +911,10 @@ static bool file_kvs_cmd_writeLines(KviKvsModuleCommandCall * c)
 
 	KviFileUtils::adjustFilePath(szFile);
 
-	QFile f(szFile);
+	KviFile f(szFile);
 	int iFlags = IO_WriteOnly;
-	if(c->switches()->find('a',"append"))iFlags |= IO_Append;
 
-	if(!f.open(iFlags))
+	if(!f.openForWriting(c->switches()->find('a',"append")))
 	{
 		if(!c->switches()->find('q',"quiet"))
 			c->warning(__tr2qs("Can't open the file \"%Q\" for writing"),&szFile);
@@ -880,12 +929,12 @@ static bool file_kvs_cmd_writeLines(KviKvsModuleCommandCall * c)
 	while(u < a.array()->size())
 	{
 		KviKvsVariant * v = a.array()->at(u);
-		QCString dat;
+		KviQCString dat;
 		if(v)
 		{
 			QString szDat;
 			v->asString(szDat);
-			QCString dat = bLocal8Bit ? szDat.local8Bit() : szDat.utf8();
+			KviQCString dat = bLocal8Bit ? szDat.local8Bit() : szDat.utf8();
 		}
 		if(!bNoSeparator)
 		{
@@ -1111,7 +1160,7 @@ static bool file_kvs_fnc_globaldir(KviKvsModuleFunctionCall * c)
 		For example, if <filepath> is /usr/arch/mp3/Carisma_SuonoDelSilenzio.mp3 then
 		this function will return /usr/arch/mp3 on UNIX and C:\usr\arch\mp3 on Windows.
 	@seealso:
-		[fnc]$file.extractfilename[/fnc]
+		[fnc]$file.extractFileName[/fnc]
 */
 
 static bool file_kvs_fnc_extractpath(KviKvsModuleFunctionCall * c)
@@ -1141,7 +1190,7 @@ static bool file_kvs_fnc_extractpath(KviKvsModuleFunctionCall * c)
 		For example, if <filepath> is /usr/arch/mp3/Carisma_SuonoDelSilenzio.mp3 then
 		this function will return Carisma_SuonoDelSilenzio.mp3
 	@seealso:
-		[fnc]$file.extractpath[/fnc]
+		[fnc]$file.extractPath[/fnc]
 */
 
 static bool file_kvs_fnc_extractfilename(KviKvsModuleFunctionCall * c)
@@ -1150,7 +1199,7 @@ static bool file_kvs_fnc_extractfilename(KviKvsModuleFunctionCall * c)
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("filepath",KVS_PT_NONEMPTYSTRING,0,szName)
 	KVSM_PARAMETERS_END(c)
-	KviFileUtils::adjustFilePath(szName);
+	KviFileUtils::extractFileName(szName);
 	KviQString::cutToLast(szName,KVI_PATH_SEPARATOR_CHAR);
 	c->returnValue()->setString(szName);
 	return true;
@@ -1174,6 +1223,9 @@ static bool file_module_init(KviModule * m)
 	KVSM_REGISTER_FUNCTION(m,"exists",file_kvs_fnc_exists);
 	KVSM_REGISTER_FUNCTION(m,"type",file_kvs_fnc_type);
 	KVSM_REGISTER_FUNCTION(m,"size",file_kvs_fnc_size);
+	
+	KVSM_REGISTER_FUNCTION(m,"allsizes",file_kvs_fnc_allSizes);
+	
 	KVSM_REGISTER_FUNCTION(m,"fixpath",file_kvs_fnc_fixpath);
 	KVSM_REGISTER_FUNCTION(m,"ps",file_kvs_fnc_ps);
 	KVSM_REGISTER_FUNCTION(m,"read",file_kvs_fnc_read);
