@@ -38,8 +38,12 @@
 
 #include <qsplitter.h>
 #include <qtooltip.h>
-#include <qhbox.h>
-#include <qheader.h>
+#include "kvi_tal_hbox.h"
+#ifdef COMPILE_USE_QT4
+	#include <q3header.h>
+#else
+	#include <qheader.h>
+#endif
 #include <qpainter.h>
 #include <qmessagebox.h>
 #include <qclipboard.h>
@@ -47,6 +51,7 @@
 #include <qfile.h>
 #include <qlabel.h>
 #include <qfontmetrics.h>
+#include <qevent.h>
 
 #ifdef COMPILE_KDE_SUPPORT
 	#include <kurl.h>
@@ -58,8 +63,8 @@
 extern KviFileTransferWindow * g_pFileTransferWindow;
 
 
-KviFileTransferItem::KviFileTransferItem(QListView * v,KviFileTransfer * t)
-: QListViewItem(v)
+KviFileTransferItem::KviFileTransferItem(KviTalListView * v,KviFileTransfer * t)
+: KviTalListViewItem(v)
 {
 	m_pTransfer = t;
 	m_pTransfer->setDisplayItem(this);
@@ -130,7 +135,7 @@ void KviFileTransferItem::paintCell(QPainter * p,const QColorGroup &cg,int colum
 
 void KviFileTransferItem::setHeight(int h)
 {
-	QListViewItem::setHeight(m_pTransfer->displayHeight(g_pFileTransferWindow->lineSpacing()));
+	KviTalListViewItem::setHeight(m_pTransfer->displayHeight(g_pFileTransferWindow->lineSpacing()));
 }
 
 
@@ -150,10 +155,10 @@ KviFileTransferWindow::KviFileTransferWindow(KviModuleExtensionDescriptor * d,Kv
 
 	m_pInput   = new KviInput(this,0);
 
-	m_pSplitter = new QSplitter(QSplitter::Horizontal,this,"splitter");
-	m_pVertSplitter = new QSplitter(QSplitter::Vertical,m_pSplitter,"vsplitter");
+	m_pSplitter = new QSplitter(Qt::Horizontal,this,"splitter");
+	m_pVertSplitter = new QSplitter(Qt::Vertical,m_pSplitter,"vsplitter");
 
-	m_pListView  = new QListView(m_pVertSplitter);
+	m_pListView  = new KviTalListView(m_pVertSplitter);
 	//m_pListView->header()->hide();
 	m_pListView->setAllColumnsShowFocus(true);
 	m_pListView->addColumn(__tr2qs_ctx("Type","filetransferwindow"),56);
@@ -166,16 +171,17 @@ KviFileTransferWindow::KviFileTransferWindow(KviModuleExtensionDescriptor * d,Kv
 	//m_pListView->setFocusPolicy(NoFocus);
 	//m_pListView->viewport()->setFocusPolicy(NoFocus);
 
-	//connect(m_pListView,SIGNAL(rightButtonPressed(QListViewItem *,const QPoint &,int)),
-	// this,SLOT(showHostPopup(QListViewItem *,const QPoint &,int)));
+	//connect(m_pListView,SIGNAL(rightButtonPressed(KviTalListViewItem *,const QPoint &,int)),
+	// this,SLOT(showHostPopup(KviTalListViewItem *,const QPoint &,int)));
 
 	QFontMetrics fm(font());
 	m_iLineSpacing = fm.lineSpacing();
 
 	m_pIrcView = new KviIrcView(m_pVertSplitter,lpFrm,this);
 
-	connect(m_pListView,SIGNAL(rightButtonPressed(QListViewItem *,const QPoint &,int)),this,SLOT(rightButtonPressed(QListViewItem *,const QPoint &,int)));
-	connect(m_pListView,SIGNAL(doubleClicked(QListViewItem *,const QPoint &,int)),this,SLOT(doubleClicked(QListViewItem *,const QPoint &,int)));
+	m_pListView->installEventFilter(this);
+	connect(m_pListView,SIGNAL(rightButtonPressed(KviTalListViewItem *,const QPoint &,int)),this,SLOT(rightButtonPressed(KviTalListViewItem *,const QPoint &,int)));
+	connect(m_pListView,SIGNAL(doubleClicked(KviTalListViewItem *,const QPoint &,int)),this,SLOT(doubleClicked(KviTalListViewItem *,const QPoint &,int)));
 	fillTransferView();
 
 	connect(KviFileTransferManager::instance(),SIGNAL(transferRegistered(KviFileTransfer *)),this,SLOT(transferRegistered(KviFileTransfer *)));
@@ -195,6 +201,25 @@ KviFileTransferWindow::~KviFileTransferWindow()
 	delete m_pMemPixmap;
 }
 
+bool KviFileTransferWindow::eventFilter( QObject *obj, QEvent *ev )
+{
+	if( (obj==m_pListView) && ( ev->type() == QEvent::KeyPress ) )
+	{
+		QKeyEvent *keyEvent = (QKeyEvent*)ev;
+		switch(keyEvent->key())
+		{
+			case Qt::Key_Delete:
+				if(m_pListView->currentItem())
+				{
+					delete m_pListView->currentItem();
+					return TRUE;
+				}
+				break;
+		}
+	}
+	return KviWindow::eventFilter( obj, ev );
+}
+
 void KviFileTransferWindow::fontChange(const QFont &oldFont)
 {
 	QFontMetrics fm(font());
@@ -213,7 +238,7 @@ void KviFileTransferWindow::tipRequest(KviDynamicToolTip * tip,const QPoint &pnt
 
 void KviFileTransferWindow::fillTransferView()
 {
-	KviPtrList<KviFileTransfer> * l = KviFileTransferManager::instance()->transferList();
+	KviPointerList<KviFileTransfer> * l = KviFileTransferManager::instance()->transferList();
 	if(!l)return;
 	KviFileTransferItem * it;
 	for(KviFileTransfer * t = l->first();t;t = l->next())
@@ -248,19 +273,19 @@ void KviFileTransferWindow::transferUnregistering(KviFileTransfer * t)
     it = 0;
 }
 
-void KviFileTransferWindow::doubleClicked(QListViewItem *it,const QPoint &pnt,int col)
+void KviFileTransferWindow::doubleClicked(KviTalListViewItem *it,const QPoint &pnt,int col)
 {
 	if(it)
 		openLocalFile();
 }
 
-void KviFileTransferWindow::rightButtonPressed(QListViewItem *it,const QPoint &pnt,int col)
+void KviFileTransferWindow::rightButtonPressed(KviTalListViewItem *it,const QPoint &pnt,int col)
 {
-	if(!m_pContextPopup)m_pContextPopup = new QPopupMenu(this);
-	if(!m_pLocalFilePopup)m_pLocalFilePopup = new QPopupMenu(this);
+	if(!m_pContextPopup)m_pContextPopup = new KviTalPopupMenu(this);
+	if(!m_pLocalFilePopup)m_pLocalFilePopup = new KviTalPopupMenu(this);
 	if(!m_pOpenFilePopup)
 	{
-		m_pOpenFilePopup= new QPopupMenu(this);
+		m_pOpenFilePopup= new KviTalPopupMenu(this);
 		connect(m_pOpenFilePopup,SIGNAL(activated(int)),this,SLOT(openFilePopupActivated(int)));
 	}
 
@@ -288,7 +313,7 @@ void KviFileTransferWindow::rightButtonPressed(QListViewItem *it,const QPoint &p
 				if(fi.exists())
 				{
 					tmp += "<nobr>";
-					tmp += __tr2qs_ctx("Size: %1 bytes","filetransferwindow").arg(fi.size());
+					tmp += __tr2qs_ctx("Size: %1","filetransferwindow").arg(KviQString::makeSizeReadable(fi.size()));
 					tmp += "</nobr><br>";
 				}
 
@@ -344,16 +369,16 @@ void KviFileTransferWindow::rightButtonPressed(QListViewItem *it,const QPoint &p
 				m_pLocalFilePopup->insertItem(__tr2qs_ctx("Open &Location","filetransferwindow"),this,SLOT(openLocalFileFolder()));
 				m_pLocalFilePopup->insertItem(__tr2qs_ctx("MS-DOS Prompt at Location","filetransferwindow"),this,SLOT(openLocalFileTerminal()));
 				m_pLocalFilePopup->insertSeparator();
-#endif //COMPILE_ON_WINDOWS			
-// G&N end			
+#endif //COMPILE_ON_WINDOWS
+// G&N end
 
 				m_pLocalFilePopup->insertItem(__tr2qs_ctx("&Copy Path to Clipboard","filetransferwindow"),this,SLOT(copyLocalFileToClipboard()));
-				
+
 				id = m_pLocalFilePopup->insertItem(__tr2qs_ctx("&Delete file","filetransferwindow"),this,SLOT(deleteLocalFile()));
 				m_pLocalFilePopup->setItemEnabled(id,i->transfer()->terminated());
 				m_pContextPopup->insertItem(__tr2qs_ctx("Local &File","filetransferwindow"),m_pLocalFilePopup);
 
-			
+
 			}
 
 			i->transfer()->fillContextPopup(m_pContextPopup,col);
@@ -376,7 +401,7 @@ void KviFileTransferWindow::rightButtonPressed(QListViewItem *it,const QPoint &p
 
 	id = m_pContextPopup->insertItem(__tr2qs_ctx("&Clear Terminated","filetransferwindow"),this,SLOT(clearTerminated()));
 	m_pContextPopup->setItemEnabled(id,bHaveTerminated);
-	
+
 	bool bAreTransfersActive = false;
 	if(m_pListView->childCount() >= 1)
 		bAreTransfersActive = true;
@@ -390,7 +415,7 @@ void KviFileTransferWindow::rightButtonPressed(QListViewItem *it,const QPoint &p
 
 KviFileTransfer * KviFileTransferWindow::selectedTransfer()
 {
-	QListViewItem * it = m_pListView->selectedItem();
+	KviTalListViewItem * it = m_pListView->selectedItem();
 	if(!it)return 0;
 	KviFileTransferItem * i = (KviFileTransferItem *)it;
 	return i->transfer();
@@ -450,14 +475,14 @@ void KviFileTransferWindow::openLocalFileTerminal()
 		if(!t)return;
 		QString tmp = t->localFileName();
 		if(tmp.isEmpty())return;
-	
+
 		int idx = tmp.findRev("/");
 		if(idx == -1)return;
 		tmp = tmp.left(idx);
-	
+
 		tmp.prepend("konsole --workdir=\"");
 		tmp.append("\"");
-	
+
 		KRun::runCommand(tmp);
 	#endif //COMPILE_KDE_SUPPORT
 #endif //!COMPILE_ON_WINDOWS
@@ -502,7 +527,7 @@ void KviFileTransferWindow::openLocalFile()
 		if(!t)return;
 		QString tmp = t->localFileName();
 		if(tmp.isEmpty())return;
-	
+
 		QString mimetype = KMimeType::findByPath(tmp)->name();  //KMimeType
 		KService::Ptr offer = KServiceTypeProfile::preferredService(mimetype,"Application");
 		if(!offer)
@@ -510,7 +535,7 @@ void KviFileTransferWindow::openLocalFile()
 			openLocalFileWith();
 			return;
 		}
-	
+
 		KURL::List lst;
 		KURL url;
 		url.setPath(tmp);
@@ -522,11 +547,11 @@ void KviFileTransferWindow::openLocalFile()
 
 void KviFileTransferWindow::openLocalFileWith()
 {
-//-| Grifisx & Noldor |-  
+//-| Grifisx & Noldor |-
 #ifdef COMPILE_ON_WINDOWS
 	KviFileTransfer * t = selectedTransfer();
 	if(!t)return;
-	QString tmp = t->localFileName();	
+	QString tmp = t->localFileName();
 	if(tmp.isEmpty())return;
 	tmp.replace("/","\\");
 	tmp.prepend("rundll32.exe shell32.dll,OpenAs_RunDLL "); // this if to show the 'open with...' window
@@ -538,7 +563,7 @@ void KviFileTransferWindow::openLocalFileWith()
 		if(!t)return;
 		QString tmp = t->localFileName();
 		if(tmp.isEmpty())return;
-	
+
 		KURL::List lst;
 		KURL url;
 		url.setPath(tmp);
@@ -554,10 +579,14 @@ void KviFileTransferWindow::copyLocalFileToClipboard()
 	if(!t)return;
 	QString tmp = t->localFileName();
 	if(tmp.isEmpty())return;
+#ifdef COMPILE_USE_QT4
+	QApplication::clipboard()->setText(tmp);
+#else
 	QApplication::clipboard()->setSelectionMode(false);
 	QApplication::clipboard()->setText(tmp);
 	QApplication::clipboard()->setSelectionMode(true);
 	QApplication::clipboard()->setText(tmp);
+#endif
 }
 
 void KviFileTransferWindow::openLocalFileFolder()
@@ -579,15 +608,15 @@ void KviFileTransferWindow::openLocalFileFolder()
 		if(!t)return;
 		QString tmp = t->localFileName();
 		if(tmp.isEmpty())return;
-	
+
 		int idx = tmp.findRev("/");
 		if(idx == -1)return;
 		tmp = tmp.left(idx);
-	
+
 		QString mimetype = KMimeType::findByPath(tmp)->name(); // inode/directory
 		KService::Ptr offer = KServiceTypeProfile::preferredService(mimetype,"Application");
 		if(!offer)return;
-	
+
 		KURL::List lst;
 		KURL url;
 		url.setPath(tmp);
@@ -602,8 +631,8 @@ void KviFileTransferWindow::heartbeat()
 {
 	if(m_pListView->childCount() < 1)return;
 
-	QListViewItem * i1;
-	QListViewItem * i2;
+	KviTalListViewItem * i1;
+	KviTalListViewItem * i2;
 
 	i1 = m_pListView->itemAt(QPoint(1,1));
 	if(!i1)
@@ -628,11 +657,25 @@ void KviFileTransferWindow::clearAll()
 {
 	QString tmp;
 
+	bool bHaveAllTerminated = true;
+	KviFileTransferItem * item = (KviFileTransferItem *)m_pListView->firstChild();
+	while(item)
+	{
+		if(!item->transfer()->terminated())
+		{
+			bHaveAllTerminated = false;
+			break;
+		}
+		item = (KviFileTransferItem *)item->nextSibling();
+	}
+
 	KviQString::sprintf(tmp,__tr2qs_ctx("Clear all transfers, including any in progress?","filetransferwindow"));
 
-	if(QMessageBox::warning(this,__tr2qs_ctx("Clear All Transfers? - KVIrc","filetransferwindow"),
-			tmp,__tr2qs_ctx("Yes","filetransferwindow"),__tr2qs_ctx("No","filetransferwindow")) != 0)
-		return;
+	// If any transfer is active asks for confirm
+	if(!bHaveAllTerminated)
+		if(QMessageBox::warning(this,__tr2qs_ctx("Clear All Transfers? - KVIrc","filetransferwindow"), tmp,__tr2qs_ctx("Yes","filetransferwindow"),__tr2qs_ctx("No","filetransferwindow")) != 0)
+			return;
+
 	KviFileTransferManager::instance()->killAllTransfers();
 }
 
