@@ -33,18 +33,18 @@
 #include "kvi_filetransfer.h"
 #include "kvi_dynamictooltip.h"
 
-#include <qlistview.h>
-#include <qpopupmenu.h>
+#include "kvi_tal_listview.h"
+#include "kvi_tal_popupmenu.h"
 #include <qtoolbutton.h>
 #include <qtimer.h>
 #include <qpixmap.h>
 
 
 
-class KviFileTransferItem : public QListViewItem
+class KviFileTransferItem : public KviTalListViewItem
 {
 public:
-	KviFileTransferItem(QListView * v,KviFileTransfer * t);
+	KviFileTransferItem(KviTalListView * v,KviFileTransfer * t);
 	~KviFileTransferItem();
 protected:
 	KviFileTransfer * m_pTransfer;
@@ -65,10 +65,10 @@ public:
 	~KviFileTransferWindow();
 protected:
 	QSplitter           * m_pVertSplitter;
-	QListView           * m_pListView;
-	QPopupMenu          * m_pContextPopup;
-	QPopupMenu          * m_pLocalFilePopup;
-	QPopupMenu          * m_pOpenFilePopup;
+	KviTalListView           * m_pListView;
+	KviTalPopupMenu          * m_pContextPopup;
+	KviTalPopupMenu          * m_pLocalFilePopup;
+	KviTalPopupMenu          * m_pOpenFilePopup;
 	QTimer              * m_pTimer;
 	QPixmap             * m_pMemPixmap;
 	int                   m_iLineSpacing; // cached fm value
@@ -85,14 +85,15 @@ protected:
 	void fillTransferView();
 	KviFileTransfer * selectedTransfer();
 	virtual void fontChange(const QFont &oldFont);
+	bool eventFilter( QObject *obj, QEvent *ev );
 public:
 	virtual QSize sizeHint() const;
 	int lineSpacing(){ return m_iLineSpacing; };
 protected slots:
 	void transferRegistered(KviFileTransfer *t);
 	void transferUnregistering(KviFileTransfer *t);
-	void rightButtonPressed(QListViewItem *it,const QPoint &pnt,int col);
-	void doubleClicked(QListViewItem *it,const QPoint &pnt,int col);
+	void rightButtonPressed(KviTalListViewItem *it,const QPoint &pnt,int col);
+	void doubleClicked(KviTalListViewItem *it,const QPoint &pnt,int col);
 	void heartbeat();
 	void clearTerminated();
 	void clearAll();
