@@ -22,7 +22,7 @@
 //==================================================================================
 
 #include "kvi_module.h"
-//#include "kvi_uparser.h"
+
 
 #include "filetransferwindow.h"
 
@@ -105,7 +105,7 @@ static bool filetransferwindow_kvs_cmd_open(KviKvsModuleCommandCall * c)
 
 	if(d)
 	{
-		QDict<QVariant> dict(17,true);
+		KviPointerHashTable<QString,QVariant> dict(17,true);
 		dict.setAutoDelete(true);
 		QString dummy;
 		dict.replace("bCreateMinimized",new QVariant(c->hasSwitch('m',dummy)));
@@ -121,9 +121,9 @@ static bool filetransferwindow_kvs_cmd_open(KviKvsModuleCommandCall * c)
 static bool filetransferwindow_module_init(KviModule * m)
 {
 	KviModuleExtensionDescriptor * d = m->registerExtension("tool",
-							KVI_FILE_TRANSFER_WINDOW_EXTENSION_NAME,
-							__tr2qs("Manage File &Transfers"),
-							filetransferwindow_extension_alloc);
+		KVI_FILE_TRANSFER_WINDOW_EXTENSION_NAME,
+		__tr2qs("Manage File &Transfers"),
+		filetransferwindow_extension_alloc);
 
 	if(d)d->setIcon(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_FILETRANSFER)));
 
