@@ -39,8 +39,8 @@
 #include <qclipboard.h>
 
 extern Index        * g_pDocIndex;
-extern KviPtrList<KviHelpWindow> * g_pHelpWindowList;
-extern KviPtrList<KviHelpWidget> * g_pHelpWidgetList;
+extern KviPointerList<KviHelpWindow> * g_pHelpWindowList;
+extern KviPointerList<KviHelpWidget> * g_pHelpWidgetList;
 
 KviHelpWidget::KviHelpWidget(QWidget * par,KviFrame * lpFrm,bool bIsStandalone)
 : QWidget(par,"help_widget")
@@ -52,8 +52,10 @@ KviHelpWidget::KviHelpWidget(QWidget * par,KviFrame * lpFrm,bool bIsStandalone)
 //#warning "Re enable this when using Qt 3.0 : QProcess "
 	m_pTextBrowser = new QTextBrowser(this,"text_browser");
 	m_pTextBrowser->setFrameStyle(QFrame::StyledPanel|QFrame::Sunken);
+#ifndef COMPILE_USE_QT4
 	m_pTextBrowser->setFocusPolicy(QWidget::NoFocus);
-	m_pToolBar = new QHBox(this,"help_tool_bar");
+#endif
+	m_pToolBar = new KviTalHBox(this);
 
 	m_pBtnIndex = new KviStyledToolButton(m_pToolBar);
 	m_pBtnIndex->setIconSet(*g_pIconManager->getBigIcon(KVI_BIGICON_HELPINDEX));
@@ -97,7 +99,11 @@ KviHelpWidget::~KviHelpWidget()
 
 void KviHelpWidget::showIndex()
 {
+#ifdef COMPILE_USE_QT4
+	m_pTextBrowser->setSource(QUrl("index.html"));
+#else
 	m_pTextBrowser->setSource("index.html");
+#endif
 }
 
 void KviHelpWidget::resizeEvent(QResizeEvent *e)
