@@ -22,7 +22,7 @@
 //   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 //
 
-#include <qhbox.h>
+#include "kvi_tal_hbox.h"
 #include <qtextbrowser.h>
 #include "index.h"
 #include <qprogressbar.h> 
@@ -42,7 +42,7 @@ private:
 	QToolButton  * m_pBtnIndex;
 	QToolButton  * m_pBtnBackward;
 	QToolButton  * m_pBtnForward;
-	QHBox        * m_pToolBar;
+	KviTalHBox        * m_pToolBar;
 	QTextBrowser * m_pTextBrowser;
 	bool           m_bIsStandalone;
 protected:
