@@ -29,6 +29,7 @@
 #include "kvi_options.h"
 #include "kvi_locale.h"
 #include "kvi_module.h"
+#include "kvi_config.h"
 #include "kvi_styled_controls.h"
 
 #include <qfileinfo.h>
@@ -37,10 +38,13 @@
 #include <qmessagebox.h>
 #include <qregexp.h>
 #include <qtooltip.h>
+#include "kvi_valuelist.h"
+
+#include "kvi_sourcesdate.h"
 
 extern Index        * g_pDocIndex;
-extern KviPtrList<KviHelpWindow> * g_pHelpWindowList;
-extern KviPtrList<KviHelpWidget> * g_pHelpWidgetList;
+extern KviPointerList<KviHelpWindow> * g_pHelpWindowList;
+extern KviPointerList<KviHelpWidget> * g_pHelpWidgetList;
 
 bool g_bIndexingDone = FALSE;
 KviHelpWindow::KviHelpWindow(KviFrame * lpFrm,const char * name)
@@ -51,13 +55,17 @@ KviHelpWindow::KviHelpWindow(KviFrame * lpFrm,const char * name)
 	{
 		QString szDoclist,szDict;
 		
-		g_pApp->getLocalKvircDirectory(szDoclist,KviApp::Help,"help.doclist");
-		g_pApp->getLocalKvircDirectory(szDict,KviApp::Help,"help.dict");
+		g_pApp->getLocalKvircDirectory(szDoclist,KviApp::Help,"help.doclist." KVI_SOURCES_DATE);
+		g_pApp->getLocalKvircDirectory(szDict,KviApp::Help,"help.dict." KVI_SOURCES_DATE);
 		
 		if ( QFileInfo( szDoclist ).exists() && QFileInfo( szDict ).exists() ) {
 			g_pDocIndex->readDict();
 		} else {
+#ifdef COMPILE_USE_QT4
+			QProgressDialog* pProgressDialog = new QProgressDialog( __tr2qs("Indexing help files"), __tr2qs("Cancel"), 0,100 );
+#else
 			QProgressDialog* pProgressDialog = new QProgressDialog( __tr2qs("Indexing help files"), __tr2qs("Cancel"), 100 );
+#endif
 			connect(g_pDocIndex,SIGNAL(indexingProgress(int)), pProgressDialog, SLOT(setProgress(int)) );
 			g_pDocIndex->makeIndex();
 			g_pDocIndex->writeDict();
@@ -68,17 +76,17 @@ KviHelpWindow::KviHelpWindow(KviFrame * lpFrm,const char * name)
 	}
 	
 	g_pHelpWindowList->append(this);
-	m_pSplitter = new QSplitter(QSplitter::Horizontal,this,"main_splitter");
+	m_pSplitter = new QSplitter(Qt::Horizontal,this,"main_splitter");
 	m_pHelpWidget = new KviHelpWidget(m_pSplitter,lpFrm);
 
-	m_pToolBar=new QVBox(m_pSplitter);
+	m_pToolBar=new KviTalVBox(m_pSplitter);
 
 	m_pTabWidget = new QTabWidget(m_pToolBar);
 	
-	m_pIndexTab  = new QVBox(m_pTabWidget);
+	m_pIndexTab  = new KviTalVBox(m_pTabWidget);
 	m_pTabWidget->insertTab(m_pIndexTab,__tr2qs("Index"));
 	
-	QHBox* pSearchBox = new QHBox(m_pIndexTab);
+	KviTalHBox* pSearchBox = new KviTalHBox(m_pIndexTab);
 	m_pIndexSearch = new QLineEdit(pSearchBox);
 	connect( m_pIndexSearch, SIGNAL( textChanged(const QString&) ),
 	     this, SLOT( searchInIndex(const QString&) ) );
@@ -90,13 +98,13 @@ KviHelpWindow::KviHelpWindow(KviFrame * lpFrm,const char * name)
 	connect(pBtnRefreshIndex,SIGNAL(clicked()),this,SLOT(refreshIndex()));
 	QToolTip::add( pBtnRefreshIndex, __tr2qs("Refresh index") );
 	
-	m_pIndexListBox = new QListBox(m_pIndexTab);
+	m_pIndexListBox = new KviTalListBox(m_pIndexTab);
 	QStringList docList=g_pDocIndex->titlesList();
 	m_pIndexListBox->insertStringList(docList);
 	connect(m_pIndexListBox,SIGNAL(selected(int)),this,SLOT(indexSelected ( int )));
 	m_pIndexListBox->sort();
 	
-	m_pSearchTab  = new QVBox(m_pTabWidget);
+	m_pSearchTab  = new KviTalVBox(m_pTabWidget);
 	m_pTabWidget->insertTab(m_pSearchTab,__tr2qs("Search"));
 	
 	m_pTermsEdit = new QLineEdit(m_pSearchTab);
@@ -105,10 +113,10 @@ KviHelpWindow::KviHelpWindow(KviFrame * lpFrm,const char * name)
 	connect( m_pTermsEdit, SIGNAL( returnPressed() ),
 	     this, SLOT( startSearch() ) );
 	     
-	m_pResultBox = new QListBox(m_pSearchTab);
+	m_pResultBox = new KviTalListBox(m_pSearchTab);
 	connect(m_pResultBox,SIGNAL(selected(int)),this,SLOT(searchSelected ( int )));
 	
-	QValueList<int> li;
+	KviValueList<int> li;
 	li.append(width()-80);
 	li.append(80);
 	m_pSplitter->setSizes(li);
@@ -120,10 +128,31 @@ KviHelpWindow::~KviHelpWindow()
 	g_pHelpWindowList->removeRef(this);
 }
 
+void KviHelpWindow::saveProperties(KviConfig *cfg)
+{
+	KviWindow::saveProperties(cfg);
+	cfg->writeEntry("Splitter",m_pSplitter->sizes());
+}
+
+void KviHelpWindow::loadProperties(KviConfig *cfg)
+{
+	KviValueList<int> def;
+	int w = width();
+	def.append((w * 82) / 100);
+	def.append((w * 18) / 100);
+	m_pSplitter->setSizes(cfg->readIntListEntry("Splitter",def));
+	KviWindow::loadProperties(cfg);
+}
+
+
 void KviHelpWindow::refreshIndex()
 {
 	m_pIndexListBox->clear();
+#ifdef COMPILE_USE_QT4
+	QProgressDialog* pProgressDialog = new QProgressDialog( __tr2qs("Indexing help files"), __tr2qs("Cancel"), 0,100 );
+#else
 	QProgressDialog* pProgressDialog = new QProgressDialog( __tr2qs("Indexing help files"), __tr2qs("Cancel"), 100 );
+#endif
 	connect(g_pDocIndex,SIGNAL(indexingProgress(int)), pProgressDialog, SLOT(setProgress(int)) );
 	g_pDocIndex->makeIndex();
 	g_pDocIndex->writeDict();
@@ -154,7 +183,11 @@ void KviHelpWindow::startSearch()
 	(*it) = (*it).replace( "\"", "" );
     }
     if ( str.contains( '\"' ) ) {
+#ifdef COMPILE_USE_QT4
+	if ( (str.count( '\"' ))%2 == 0 ) {
+#else
 	if ( (str.contains( '\"' ))%2 == 0 ) {
+#endif
 	    int beg = 0;
 	    int end = 0;
 	    QString s;
@@ -180,7 +213,11 @@ void KviHelpWindow::startSearch()
 	    return;
 	}
     }
+#ifdef COMPILE_USE_QT4
+    setCursor( Qt::WaitCursor );
+#else
     setCursor( waitCursor );
+#endif
     m_foundDocs.clear();
     m_foundDocs = g_pDocIndex->query( m_terms, termSeq, seqWords );
  
@@ -209,7 +246,11 @@ void KviHelpWindow::startSearch()
     if ( !s.isEmpty() )
 	m_terms << s;
 
+#ifdef COMPILE_USE_QT4
+    setCursor( Qt::ArrowCursor );
+#else
     setCursor( arrowCursor );
+#endif
 }
 
 QTextBrowser * KviHelpWindow::textBrowser()
@@ -226,7 +267,7 @@ void KviHelpWindow::showIndexTopic()
 
 void KviHelpWindow::searchInIndex( const QString &s )
 {
-    QListBoxItem *i = m_pIndexListBox->firstItem();
+    KviTalListBoxItem *i = m_pIndexListBox->firstItem();
     QString sl = s.lower();
     while ( i ) {
 	QString t = i->text();
