@@ -24,9 +24,9 @@
 
 #include "kvi_window.h"
 #include "kvi_string.h"
-#include "qvbox.h"
+#include "kvi_tal_vbox.h"
 #include <qtabwidget.h> 
-#include <qlistbox.h>
+#include "kvi_tal_listbox.h"
 #include <qlineedit.h>
 #include <qprogressdialog.h>
 
@@ -41,16 +41,16 @@ public:
 	~KviHelpWindow();
 protected:
 	KviHelpWidget * m_pHelpWidget;
-	QVBox	      * m_pToolBar;
+	KviTalVBox	      * m_pToolBar;
 	QTabWidget    * m_pTabWidget;
-	QVBox         * m_pIndexTab;
-	QVBox         * m_pSearchTab;
+	KviTalVBox         * m_pIndexTab;
+	KviTalVBox         * m_pSearchTab;
 	
-	QListBox     * m_pIndexListBox;
+	KviTalListBox     * m_pIndexListBox;
 	QLineEdit    * m_pIndexSearch;
 	QStringList    m_foundDocs;
 	QStringList    m_terms;
-	QListBox     * m_pResultBox;
+	KviTalListBox     * m_pResultBox;
 	QLineEdit    * m_pTermsEdit;
 public:
 	KviHelpWidget * helpWidget(){ return m_pHelpWidget; };
@@ -58,6 +58,8 @@ protected:
 	virtual QPixmap * myIconPtr();
 	virtual void fillCaptionBuffers();
 	virtual void resizeEvent(QResizeEvent *e);
+	virtual void saveProperties(KviConfig * cfg);
+	virtual void loadProperties(KviConfig * cfg);
 public:
 	virtual QSize sizeHint() const;
 	QTextBrowser * textBrowser();
