@@ -23,7 +23,8 @@
 //#include "libkvihelp.h"
 
 #include "kvi_module.h"
-//#include "kvi_uparser.h"
+
+#include "kvi_sourcesdate.h"
 
 #include "helpwidget.h"
 #include "helpwindow.h"
@@ -32,10 +33,15 @@
 
 #include "kvi_frame.h"
 
+#ifdef COMPILE_USE_QT4
+	#include <q3mimefactory.h>
+#endif
+
+
 #include <qsplitter.h>
 Index        * g_pDocIndex = 0;
-KviPtrList<KviHelpWidget> * g_pHelpWidgetList = 0;
-KviPtrList<KviHelpWindow> * g_pHelpWindowList = 0;
+KviPointerList<KviHelpWidget> * g_pHelpWidgetList = 0;
+KviPointerList<KviHelpWindow> * g_pHelpWindowList = 0;
 
 /*
 	@doc: help.search
@@ -135,13 +141,16 @@ static bool help_kvs_cmd_search(KviKvsModuleCommandCall * c)
 
 static bool help_kvs_cmd_open(KviKvsModuleCommandCall * c)
 { 
-
 	QString doc;
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("document",KVS_PT_STRING,KVS_PF_OPTIONAL,doc)
 	KVSM_PARAMETERS_END(c)
 	if(doc.isEmpty())doc = "index.html";
+#ifdef COMPILE_USE_QT4
+	Q3MimeSourceFactory * f = Q3MimeSourceFactory::defaultFactory();
+#else
 	QMimeSourceFactory * f = QMimeSourceFactory::defaultFactory();
+#endif
 	if(f)
 	{
 		if(!f->data(doc))
@@ -150,12 +159,11 @@ static bool help_kvs_cmd_open(KviKvsModuleCommandCall * c)
 
 	if(!c->switches()->find('n',"new"))
 	{
-		KviHelpWidget * w = (KviHelpWidget *)c->window()->frame()->child(
-			"help_widget","KviHelpWidget");
-
+		KviHelpWidget * w = (KviHelpWidget *)c->window()->frame()->child("help_widget","KviHelpWidget");
 		if(w)
 		{
 			w->textBrowser()->setSource(doc);
+			return true;
 		}
 	}
 	if(c->switches()->find('m',"mdi")) 
@@ -179,20 +187,18 @@ static bool help_module_init(KviModule * m)
 {
 	QString szHelpDir,szDocList;
 	
-	g_pApp->getLocalKvircDirectory(szDocList,KviApp::Help,"help.doclist");
+	g_pApp->getLocalKvircDirectory(szDocList,KviApp::Help,"help.doclist." KVI_SOURCES_DATE);
 	g_pApp->getGlobalKvircDirectory(szHelpDir,KviApp::Help);
 	
 	g_pDocIndex = new Index(szHelpDir,szDocList);
 	g_pDocIndex->setDocListFile(szDocList);
 	
-	g_pApp->getLocalKvircDirectory(szHelpDir,KviApp::Help,"help.dict");
+	g_pApp->getLocalKvircDirectory(szHelpDir,KviApp::Help,"help.dict." KVI_SOURCES_DATE);
 	g_pDocIndex->setDictionaryFile(szHelpDir);
-	
 
-	
-	g_pHelpWidgetList = new KviPtrList<KviHelpWidget>;
+	g_pHelpWidgetList = new KviPointerList<KviHelpWidget>;
 	g_pHelpWidgetList->setAutoDelete(false);
-	g_pHelpWindowList = new KviPtrList<KviHelpWindow>;
+	g_pHelpWindowList = new KviPointerList<KviHelpWindow>;
 	g_pHelpWindowList->setAutoDelete(false);
 
 	KVSM_REGISTER_SIMPLE_COMMAND(m,"open",help_kvs_cmd_open);
@@ -206,10 +212,10 @@ static bool help_module_cleanup(KviModule *m)
 	if(g_pDocIndex) delete g_pDocIndex;
 	while(g_pHelpWidgetList->first())delete g_pHelpWidgetList->first();
 	delete g_pHelpWidgetList;
-    g_pHelpWidgetList = 0;
+	g_pHelpWidgetList = 0;
 	while(g_pHelpWindowList->first())g_pHelpWindowList->first()->close();
 	delete g_pHelpWindowList;
-    g_pHelpWindowList = 0;
+	g_pHelpWindowList = 0;
 	return true;
 }
 
