@@ -34,10 +34,10 @@
 
 #include "kvi_kvs_script.h"
 
-#include <qpopupmenu.h>
+#include "kvi_tal_popupmenu.h"
 #include <qpainter.h>
 
-static KviPtrList<KviHttpFileTransfer> * g_pHttpFileTransfers = 0;
+static KviPointerList<KviHttpFileTransfer> * g_pHttpFileTransfers = 0;
 static QPixmap * g_pHttpIcon = 0;
 
 
@@ -58,13 +58,13 @@ KviHttpFileTransfer::KviHttpFileTransfer()
 
 	m_pHttpRequest = new KviHttpRequest();
 
-	connect(m_pHttpRequest,SIGNAL(status(const char *)),this,SLOT(statusMessage(const char *)));
+	connect(m_pHttpRequest,SIGNAL(status(const QString &)),this,SLOT(statusMessage(const QString &)));
 	connect(m_pHttpRequest,SIGNAL(terminated(bool)),this,SLOT(transferTerminated(bool)));
-	connect(m_pHttpRequest,SIGNAL(header(QAsciiDict<KviStr> *)),this,SLOT(headersReceived(QAsciiDict<KviStr> *)));
-	connect(m_pHttpRequest,SIGNAL(resolvingHost(const char *)),this,SLOT(resolvingHost(const char *)));
+	connect(m_pHttpRequest,SIGNAL(header(KviPointerHashTable<const char *,KviStr> *)),this,SLOT(headersReceived(KviPointerHashTable<const char *,KviStr> *)));
+	connect(m_pHttpRequest,SIGNAL(resolvingHost(const QString &)),this,SLOT(resolvingHost(const QString &)));
 	connect(m_pHttpRequest,SIGNAL(requestSent(const QStringList &)),this,SLOT(requestSent(const QStringList &)));
-	connect(m_pHttpRequest,SIGNAL(contactingHost(const char *)),this,SLOT(contactingHost(const char *)));
-	connect(m_pHttpRequest,SIGNAL(receivedResponse(const char *)),this,SLOT(receivedResponse(const char *)));
+	connect(m_pHttpRequest,SIGNAL(contactingHost(const QString &)),this,SLOT(contactingHost(const QString &)));
+	connect(m_pHttpRequest,SIGNAL(receivedResponse(const QString &)),this,SLOT(receivedResponse(const QString &)));
 	connect(m_pHttpRequest,SIGNAL(connectionEstabilished()),this,SLOT(connectionEstabilished()));
 	
 	m_eGeneralStatus = Initializing;
@@ -102,7 +102,7 @@ void KviHttpFileTransfer::abort()
 	m_pHttpRequest->abort();
 }
 
-void KviHttpFileTransfer::fillContextPopup(QPopupMenu * m,int column)
+void KviHttpFileTransfer::fillContextPopup(KviTalPopupMenu * m,int column)
 {
 	int id = m->insertItem(__tr2qs_ctx("Abort","http"),this,SLOT(abort()));
 	if(!active())m->setItemEnabled(id,false);
@@ -211,9 +211,10 @@ void KviHttpFileTransfer::displayPaint(QPainter * p,int column,int width,int hei
 				//iR = iW - iL;
 				p->fillRect(5,5,iL,10,bIsTerminated ? QColor(140,110,110) : QColor(200,100,100));
 
-				txt = QString(__tr2qs_ctx("%1 of %2 bytes (%3 %)","http")).arg(uRecvd).arg(uTotal).arg(dPerc,0,'f',2);
+				txt = QString(__tr2qs_ctx("%1 of %2 (%3 %)","http")).arg(KviQString::makeSizeReadable(uRecvd))
+					.arg(KviQString::makeSizeReadable(uTotal)).arg(dPerc,0,'f',2);
 			} else {
-				txt = QString(__tr2qs_ctx("%1 bytes","http")).arg(m_pHttpRequest->receivedSize());
+				txt = KviQString::makeSizeReadable(m_pHttpRequest->receivedSize());
 			}
 
 			p->setPen(Qt::black);
@@ -336,7 +337,7 @@ QString KviHttpFileTransfer::tipText()
 void KviHttpFileTransfer::init()
 {
 	if(g_pHttpFileTransfers)return;
-	g_pHttpFileTransfers = new KviPtrList<KviHttpFileTransfer>;
+	g_pHttpFileTransfers = new KviPointerList<KviHttpFileTransfer>;
 	g_pHttpFileTransfers->setAutoDelete(false);
 
 	QPixmap * pix = g_pIconManager->getImage("kvi_httpicons.png");
@@ -387,19 +388,19 @@ void KviHttpFileTransfer::connectionEstabilished()
 	displayUpdate();
 }
 
-void KviHttpFileTransfer::resolvingHost(const char *hostname)
+void KviHttpFileTransfer::resolvingHost(const QString &hostname)
 {
 	m_szStatusString = __tr2qs_ctx("Resolving host %1","http").arg(hostname);
 	displayUpdate();
 }
 
-void KviHttpFileTransfer::contactingHost(const char *ipandport)
+void KviHttpFileTransfer::contactingHost(const QString &ipandport)
 {
 	m_szStatusString = __tr2qs_ctx("Contacting host %1","http").arg(ipandport);
 	displayUpdate();
 }
 
-void KviHttpFileTransfer::receivedResponse(const char * response)
+void KviHttpFileTransfer::receivedResponse(const QString &response)
 {
 	m_lHeaders.clear();
 	m_lHeaders.append(response);
@@ -409,11 +410,11 @@ void KviHttpFileTransfer::receivedResponse(const char * response)
 	displayUpdate();
 }
 
-void KviHttpFileTransfer::statusMessage(const char *txt)
+void KviHttpFileTransfer::statusMessage(const QString &txt)
 {
 	KviWindow * out = transferWindow();
 	if(out && (!m_bNoOutput))
-		out->output(KVI_OUT_GENERICSTATUS,"[HTTP %d]: %s",id(),txt);
+		out->output(KVI_OUT_GENERICSTATUS,"[HTTP %d]: %Q",id(),&txt);
 }
 
 void KviHttpFileTransfer::transferTerminated(bool bSuccess)
@@ -461,13 +462,13 @@ void KviHttpFileTransfer::transferTerminated(bool bSuccess)
 	}
 }
 
-void KviHttpFileTransfer::headersReceived(QAsciiDict<KviStr> *h)
+void KviHttpFileTransfer::headersReceived(KviPointerHashTable<const char *,KviStr> *h)
 {
 	if(!h)return;
 	KviWindow * out = transferWindow();
 
 	if(out && (!m_bNoOutput))out->output(KVI_OUT_GENERICSTATUS,__tr2qs_ctx("[HTTP %d]: Response headers:","http"),id());
-	QAsciiDictIterator<KviStr> it(*h);
+	KviPointerHashTableIterator<const char *,KviStr> it(*h);
 	while(KviStr * s = it.current())
 	{
 		QString szHeader = it.currentKey();
