@@ -34,7 +34,7 @@
 #include <qtimer.h>
 
 class QPainter;
-class QPopupMenu;
+class KviTalPopupMenu;
 
 class KviHttpFileTransfer : public KviFileTransfer
 {
@@ -79,20 +79,20 @@ public:
 
 	virtual void displayPaint(QPainter * p,int column,int width,int height);
 	virtual int displayHeight(int iLineSpacing);
-	virtual void fillContextPopup(QPopupMenu * m,int column);
+	virtual void fillContextPopup(KviTalPopupMenu * m,int column);
 	virtual bool active();
 	virtual void die();
 	virtual QString tipText();
 	virtual QString localFileName();
 protected slots:
-	void statusMessage(const char * txt);
+	void statusMessage(const QString &txt);
 	void transferTerminated(bool bSuccess);
-	void headersReceived(QAsciiDict<KviStr> *h);
+	void headersReceived(KviPointerHashTable<const char *,KviStr> *h);
 	void requestSent(const QStringList &sl);
 
-	void resolvingHost(const char * hostname);
-	void contactingHost(const char * ipandport);
-	void receivedResponse(const char * response);
+	void resolvingHost(const QString &hostname);
+	void contactingHost(const QString &ipandport);
+	void receivedResponse(const QString &response);
 	void connectionEstabilished();
 
 	void abort();
