@@ -24,8 +24,8 @@
 
 #include "kvi_module.h"
 #include "kvi_string.h"
-//#include "kvi_uparser.h"
-#include "kvi_command.h"
+
+
 #include "kvi_app.h"
 #include "kvi_locale.h"
 #include "kvi_filedialog.h"
@@ -165,6 +165,7 @@ static bool http_kvs_complete_get(KviKvsModuleCommandCall * c,QString &szUrl,QSt
 		The event OnHTTPGetTerminated is triggered upon the download completion (both
 		in case of success or failure). If you want a callback command to be triggered
 		instead please use [cmd]http.asyncGet[/cmd].
+		If the url contains a https:// prefix then a SSL connection will be used.
 	@switches:
 		!sw: -a=<auto_file_name> | --auto-file-name=<auto_file_name>
 		Don't show the savefile dialog but determine automatically a file name.
@@ -273,6 +274,7 @@ static bool http_kvs_cmd_get(KviKvsModuleCommandCall * c)
 		The only difference is that asyncGet triggers the <callback command> upon completion
 		instead of the global OnHTTPGetTerminated event.
 		The parameters passed to the callback are exactly the same.
+		If the url contains a https:// prefix then a SSL connection will be used.
 	@seealso:
 		[cmd]http.get[/cmd]
 */
