@@ -30,7 +30,7 @@
 #include "kvi_netutils.h"
 #include "kvi_locale.h"
 #include "kvi_window.h"
-//#include "kvi_uparser.h"
+
 #include "kvi_options.h"
 #include "kvi_defaults.h"
 
@@ -43,7 +43,7 @@
 static KviIdentDaemon * g_pIdentDaemon = 0;
 static KviIdentSentinel * g_pIdentSentinel = 0;
 
-extern KVIRC_API bool g_bIdentDaemonRunning;
+extern KVIRC_API int g_iIdentDaemonRunningUsers;
 
 void startIdentService()
 {
@@ -81,33 +81,47 @@ KviIdentSentinel::~KviIdentSentinel()
 
 bool KviIdentSentinel::event(QEvent *e)
 {
+	if(KVI_OPTION_UINT(KviOption_uintIdentdOutputMode)==KviIdentdOutputMode::Quiet || !g_pActiveWindow)
+		return QObject::event(e);
+
+	KviWindow * pTarget = KVI_OPTION_UINT(KviOption_uintIdentdOutputMode)==KviIdentdOutputMode::ToActiveWindow ?
+		(KviWindow *)g_pActiveWindow : (KviWindow *)g_pApp->activeConsole();
+
 	if(e->type() == KVI_THREAD_EVENT)
 	{
 		if(((KviThreadEvent *)e)->id() == KVI_THREAD_EVENT_DATA)
 		{
 			KviIdentMessageData * d = ((KviThreadDataEvent<KviIdentMessageData> *)e)->getData();
-			if(g_pActiveWindow)
+			if(pTarget)
 			{
 				if(d->szHost.hasData())
 				{
 					if(d->szAux.hasData())
 					{
-						g_pActiveWindow->output(KVI_OUT_IDENT,__tr_no_xgettext("[IDENT]: (%s:%u) %s (%s)"),d->szHost.ptr(),d->uPort,d->szMessage.ptr(),d->szAux.ptr());
+						if(_OUTPUT_PARANOIC)
+							pTarget->output(KVI_OUT_IDENT,__tr("%s (%s) (%s:%u)"),d->szMessage.ptr(),d->szAux.ptr(),d->szHost.ptr(),d->uPort);
+						else
+							pTarget->output(KVI_OUT_IDENT,__tr("%s (%s)"),d->szMessage.ptr(),d->szAux.ptr());
 					} else {
-						g_pActiveWindow->output(KVI_OUT_IDENT,__tr_no_xgettext("[IDENT]: (%s:%u) %s"),d->szHost.ptr(),d->uPort,d->szMessage.ptr());
+						if(_OUTPUT_PARANOIC)
+							pTarget->output(KVI_OUT_IDENT,__tr("%s (%s:%u)"),d->szMessage.ptr(),d->szHost.ptr(),d->uPort);
+						else
+							pTarget->output(KVI_OUT_IDENT,__tr("%s"),d->szMessage.ptr());
 					}
 				} else {
-					g_pActiveWindow->output(KVI_OUT_IDENT,__tr_no_xgettext("[IDENT]: %s"),d->szMessage.ptr());
+						pTarget->output(KVI_OUT_IDENT,__tr("[IDENT]: %s"),d->szMessage.ptr());
 				}
 			}
 			delete d;
 		} else if(((KviThreadEvent *)e)->id() == KVI_IDENT_THREAD_EVENT_EXITING)
 		{
-			if(g_pActiveWindow)g_pActiveWindow->outputNoFmt(KVI_OUT_IDENT,__tr("[IDENT]: Service shutdown (spontaneous)"));
+			if(_OUTPUT_VERBOSE)
+				if(pTarget)pTarget->outputNoFmt(KVI_OUT_IDENT,__tr("Shutting down identd service (spontaneous action)"));
 			stopIdentService();
 		} else if(((KviThreadEvent *)e)->id() == KVI_IDENT_THREAD_EVENT_EXITING_ON_REQUEST)
 		{
-			if(g_pActiveWindow)g_pActiveWindow->outputNoFmt(KVI_OUT_IDENT,__tr("[IDENT]: Service shutdown (on request)"));
+			if(_OUTPUT_VERBOSE)
+				if(pTarget)pTarget->outputNoFmt(KVI_OUT_IDENT,__tr("Shutting down identd service (requested action)"));
 		}
 
 		return true;
@@ -145,7 +159,6 @@ KviIdentDaemon::KviIdentDaemon()
 	m_bEnableIpV6 = false;
 #endif
 	m_bIpV6ContainsIpV4 = KVI_OPTION_BOOL(KviOption_boolIdentdIpV6ContainsIpV4);
-	g_bIdentDaemonRunning = true;
 //	debug("Thread constructor done");
 }
 
@@ -153,7 +166,7 @@ KviIdentDaemon::~KviIdentDaemon()
 {
 //	debug("Thread destructor");
 	terminate();
-	g_bIdentDaemonRunning = false;
+	g_iIdentDaemonRunningUsers = 0;
 
 	g_pIdentDaemon = 0;
 //	debug("Destructor gone");
@@ -185,10 +198,10 @@ void KviIdentDaemon::run()
 	m_sock6 = KVI_INVALID_SOCKET;
 	bool bEventPosted = false;
 
-	m_pRequestList = new KviPtrList<KviIdentRequest>;
+	m_pRequestList = new KviPointerList<KviIdentRequest>;
 	m_pRequestList->setAutoDelete(true);
 
-	KviPtrList<KviIdentRequest> dying;
+	KviPointerList<KviIdentRequest> dying;
 	dying.setAutoDelete(false);
 
 #ifdef COMPILE_IPV6_SUPPORT
@@ -209,31 +222,31 @@ void KviIdentDaemon::run()
 
 	if(m_sock == KVI_INVALID_SOCKET)
 	{
-		postMessage(__tr_no_xgettext("Can't start the ident service : socket() failed"),0);
+		postMessage(__tr("Can't start the ident service : socket() failed"),0);
 		goto exit_thread;
 	}
 
 	if(!kvi_socket_setNonBlocking(m_sock))
 	{
-		postMessage(__tr_no_xgettext("Can't start the ident service : async setting failed"),0);
+		postMessage(__tr("Can't start the ident service : async setting failed"),0);
 		goto exit_thread;
 	}
 
 	if(!sa.socketAddress())
 	{
-		postMessage(__tr_no_xgettext("Can't enable the ident service : can't setup the listen address"),0);
+		postMessage(__tr("Can't enable the ident service : can't setup the listen address"),0);
 		goto exit_thread;
 	}
 
 	if(!kvi_socket_bind(m_sock,sa.socketAddress(),((int)(sa.addressLength()))))
 	{
-		postMessage(__tr_no_xgettext("Can't start the ident service : bind() failed"),0);
+		postMessage(__tr("Can't start the ident service : bind() failed"),0);
 		goto exit_thread;
 	}
 
 	if(!kvi_socket_listen(m_sock,128))
 	{
-		postMessage(__tr_no_xgettext("Can't start the ident service : listen() failed"),0);
+		postMessage(__tr("Can't start the ident service : listen() failed"),0);
 		goto exit_thread;
 	}
 
@@ -247,13 +260,13 @@ void KviIdentDaemon::run()
 
 		if(m_sock6 == KVI_INVALID_SOCKET)
 		{
-			postMessage(__tr_no_xgettext("Can't start the ident service on IpV6 : socket() failed"),0);
+			postMessage(__tr("Can't start the ident service on IpV6 : socket() failed"),0);
 			goto ipv6_failure;
 		}
 
 		if(!kvi_socket_setNonBlocking(m_sock6))
 		{
-			postMessage(__tr_no_xgettext("Can't start the ident service on IpV6 : async setting failed"),0);
+			postMessage(__tr("Can't start the ident service on IpV6 : async setting failed"),0);
 			kvi_socket_close(m_sock6);
 			m_sock6 = KVI_INVALID_SOCKET;
 			goto ipv6_failure;
@@ -261,7 +274,7 @@ void KviIdentDaemon::run()
 
 		if(!sa6.socketAddress())
 		{
-			postMessage(__tr_no_xgettext("Can't enable the ident service on IpV6 : can't setup the listen address"),0);
+			postMessage(__tr("Can't enable the ident service on IpV6 : can't setup the listen address"),0);
 			kvi_socket_close(m_sock6);
 			m_sock6 = KVI_INVALID_SOCKET;
 			goto ipv6_failure;
@@ -269,7 +282,7 @@ void KviIdentDaemon::run()
 	
 		if(!kvi_socket_bind(m_sock6,sa6.socketAddress(),((int)(sa6.addressLength()))))
 		{
-			postMessage(__tr_no_xgettext("Can't start the ident service on IpV6 : bind() failed"),0);
+			postMessage(__tr("Can't start the ident service on IpV6 : bind() failed"),0);
 			kvi_socket_close(m_sock6);
 			m_sock6 = KVI_INVALID_SOCKET;
 			goto ipv6_failure;
@@ -278,7 +291,7 @@ void KviIdentDaemon::run()
 	
 		if(!kvi_socket_listen(m_sock6,128))
 		{
-			postMessage(__tr_no_xgettext("Can't start the ident service on IpV6 : listen() failed"),0);
+			postMessage(__tr("Can't start the ident service on IpV6 : listen() failed"),0);
 			kvi_socket_close(m_sock6);
 			m_sock6 = KVI_INVALID_SOCKET;
 			goto ipv6_failure;
@@ -292,16 +305,21 @@ ipv6_failure:
 #ifdef COMPILE_IPV6_SUPPORT
 	if(m_bEnableIpV6)
 	{
-		if(m_sock6 != KVI_INVALID_SOCKET)
-			postMessage(__tr_no_xgettext("Service startup (IpV4/V6 on separate namespaces)"),0);
-		else
-			postMessage(__tr_no_xgettext("Service startup (IpV4/V6 in IpV6 namespace)"),0);
+		if(m_sock6 != KVI_INVALID_SOCKET) {
+			if(_OUTPUT_PARANOIC)
+				postMessage(__tr("Starting identd service (IpV4/V6 on separate namespaces)"),0);
+		} else {
+			if(_OUTPUT_PARANOIC)
+				postMessage(__tr("Starting identd service (IpV4/V6 in IpV6 namespace)"),0);
+		}
 
 	} else {
-		postMessage(__tr_no_xgettext("Service startup (IpV4)"),0);
+		if(_OUTPUT_PARANOIC)
+			postMessage(__tr("Starting identd service (IpV4)"),0);
 	}
 #else //!COMPILE_IPV6_SUPPORT
-	postMessage(__tr_no_xgettext("Service startup (IpV4)"),0);
+	if(_OUTPUT_PARANOIC)
+		postMessage(__tr("Service startup (IpV4)"),0);
 #endif //!COMPILE_IPV6_SUPPORT
 
 
@@ -371,7 +389,7 @@ ipv6_failure:
 						if(!satmp.getStringAddress(szHost))szHost = "unknown";
 						KviIdentRequest * r = new KviIdentRequest(t,szHost.utf8().data(),satmp.port());
 						m_pRequestList->append(r);
-						postMessage(__tr_no_xgettext("Accepting connection"),r);
+						postMessage(__tr("Identd accepting connection"),r);
 					}
 				}
 			}
@@ -391,7 +409,7 @@ ipv6_failure:
 						if(!satmp.getStringAddress(szHost))szHost = "unknown";
 						KviIdentRequest * r = new KviIdentRequest(t,szHost.utf8().data(),satmp.port());
 						m_pRequestList->append(r);
-						postMessage(__tr_no_xgettext("Accepting connection"),r);
+						postMessage(__tr("Identd accepting connection"),r);
 					}
 				}
 			}
@@ -414,12 +432,12 @@ ipv6_failure:
 							int err = kvi_socket_error();
 							if(!kvi_socket_recoverableConnectError(err))
 							{
-								postMessage(__tr_no_xgettext("Socket error : dropping connection"),r);
+								postMessage(__tr("Identd socket error : dropping connection"),r);
 								dying.append(r);
 							}
 						} else {
 							// connection closed
-							postMessage(__tr_no_xgettext("Connection closed by remote host"),r);
+							postMessage(__tr("Identd connection closed by remote host"),r);
 							dying.append(r);
 						}
 					}
@@ -440,7 +458,7 @@ ipv6_failure:
 	
 					if(szReq.hasData())
 					{
-						postMessage(__tr_no_xgettext("Processing request"),r,szReq.ptr());
+						postMessage(__tr("Identd processing request"),r,szReq.ptr());
 
 						if(kvi_strEqualCI("VERSION",szReq.ptr()))
 						{
@@ -455,7 +473,7 @@ ipv6_failure:
 	
 					} else {
 	
-						postMessage(__tr_no_xgettext("Empty request (EOT ?)"),r,szReq.ptr());
+						postMessage(__tr("Empty request (EOT ?)"),r,szReq.ptr());
 	
 						dying.append(r);
 					}
@@ -466,7 +484,7 @@ ipv6_failure:
 					{
 						// request too long...kill it
 						dying.append(r);
-						postMessage(__tr_no_xgettext("Dropping connection (request too long)"),r);
+						postMessage(__tr("Dropping connection (request too long)"),r);
 					}
 				}
 	
@@ -479,7 +497,7 @@ ipv6_failure:
 		{
 			if((unsigned int)(curTime - r->m_tStart) > 30)
 			{
-				postMessage(__tr_no_xgettext("Timed out while waiting for the request : dropping connection"),r);
+				postMessage(__tr("Timed out while waiting for the request : dropping connection"),r);
 				dying.append(r);
 			}
 		}
@@ -531,8 +549,10 @@ exit_thread:
 */
 
 static bool ident_kvs_cmd_start(KviKvsModuleCommandCall * c)
-{ 
-	startIdentService();
+{
+	if(!g_iIdentDaemonRunningUsers)
+		startIdentService();
+	g_iIdentDaemonRunningUsers++;
 	return true;
 }
 
@@ -553,8 +573,9 @@ static bool ident_kvs_cmd_start(KviKvsModuleCommandCall * c)
 */
 
 static bool ident_kvs_cmd_stop(KviKvsModuleCommandCall * c)
-{ 
-	stopIdentService();
+{
+	if(g_iIdentDaemonRunningUsers) g_iIdentDaemonRunningUsers--;
+	if(!g_iIdentDaemonRunningUsers) stopIdentService();
 	return true;
 }
 
@@ -570,7 +591,7 @@ static bool ident_module_cleanup(KviModule *m)
 {
 	stopIdentService();
 	delete g_pIdentSentinel;
-    g_pIdentSentinel = 0;
+	g_pIdentSentinel = 0;
 
 	return true;
 }
