@@ -21,7 +21,7 @@
 
 
 #include "kvi_module.h"
-//#include "kvi_uparser.h"
+
 
 #include "linkswindow.h"
 
@@ -31,7 +31,7 @@
 
 #include <qsplitter.h>
 
-KviPtrList<KviLinksWindow> * g_pLinksWindowList = 0;
+KviPointerList<KviLinksWindow> * g_pLinksWindowList = 0;
 
 
 /*
@@ -61,7 +61,7 @@ KviPtrList<KviLinksWindow> * g_pLinksWindowList = 0;
 
 
 static bool links_kvs_cmd_open(KviKvsModuleCommandCall * c)
-{ 
+{
 	
 	// FIND ME
 	if(!c->window()->console())return c->context()->errorNoIrcContext();
@@ -82,7 +82,7 @@ static bool links_kvs_cmd_open(KviKvsModuleCommandCall * c)
 
 static bool links_module_init(KviModule * m)
 {
-	g_pLinksWindowList = new KviPtrList<KviLinksWindow>;
+	g_pLinksWindowList = new KviPointerList<KviLinksWindow>;
 	g_pLinksWindowList->setAutoDelete(false);
 
 
@@ -95,7 +95,7 @@ static bool links_module_cleanup(KviModule *m)
 {
 	while(g_pLinksWindowList->first())g_pLinksWindowList->first()->die();
 	delete g_pLinksWindowList;
-    g_pLinksWindowList = 0;
+	g_pLinksWindowList = 0;
 	return true;
 }
 
