@@ -38,15 +38,22 @@
 #include "kvi_ircconnection.h"
 #include "kvi_ircconnection.h"
 #include "kvi_qstring.h"
+#include "kvi_qcstring.h"
+#include "kvi_topicw.h"
+#include "kvi_config.h"
+#include "kvi_filedialog.h"
 
+#include "kvi_styled_controls.h"
 #include <qtimer.h>
 #include <qpainter.h>
 #include <qfontmetrics.h>
 #include <qsplitter.h>
 #include <qtooltip.h>
-#include <qhbox.h>
+#include <qdatetime.h>
+#include "kvi_tal_hbox.h"
+#include "kvi_msgbox.h"
 
-extern KviPtrList<KviListWindow> * g_pListWindowList;
+extern KviPointerList<KviListWindow> * g_pListWindowList;
 
 // kvi_ircview.cpp
 //extern KVIRC_API const char * getColorBytes(const char *data_ptr,unsigned char *byte_1,unsigned char *byte_2);
@@ -68,8 +75,8 @@ KviChannelListViewItemData::~KviChannelListViewItemData()
 
 
 
-KviChannelListViewItem::KviChannelListViewItem(QListView * v,KviChannelListViewItemData * pData)
-: QListViewItem(v)
+KviChannelListViewItem::KviChannelListViewItem(KviTalListView * v,KviChannelListViewItemData * pData)
+: KviTalListViewItem(v)
 {
 	m_pData = pData;
 }
@@ -79,158 +86,69 @@ KviChannelListViewItem::~KviChannelListViewItem()
 {
 	delete m_pData;
 }
-
-int KviChannelListViewItem::width ( const QFontMetrics & fm, const QListView * lv, int c )
+#ifdef COMPILE_USE_QT4
+int KviChannelListViewItem::width ( const QFontMetrics & fm, const KviTalListView * lv, int column ) const
+#else
+int KviChannelListViewItem::width ( const QFontMetrics & fm, const QListView * lv, int column ) const
+#endif
 {
-	if(c==2) return fm.width(KviMircCntrl::stripControlBytes(m_pData->m_szTopic));
-	return QListViewItem::width(fm,lv,c);
+	debug("width request");
+	QString szText;
+
+	switch(column)
+	{
+		case 0:  szText = m_pData->m_szChan;   break;
+		case 1:  szText = m_pData->m_szUsers;  break;
+		default: szText = m_pData->m_szTopic;  break;
+	}
+	if(column==2) return fm.width(KviMircCntrl::stripControlBytes(szText));
+	else return fm.width(szText);
 }
 
 #define KVI_LABEL_DEF_BACK 100
 #define KVI_LABEL_DEF_FORE 101
 
-void KviChannelListViewItem::paintCell(QPainter * p,const QColorGroup &cg,int col,int wdth,int align)
+void KviChannelListViewItem::paintCell(QPainter * p,const QColorGroup &cg,int column,int width,int align)
 {
-	QFontMetrics fm(p->font());
+	QString szText;
 
-	p->fillRect(0, 0, wdth, height(), cg.brush( QColorGroup::Base ));
-	const QChar * t;
-
-	switch(col)
+	switch(column)
 	{
-		case 0:  t = KviQString::nullTerminatedArray(m_pData->m_szChan);   break;
-		case 1:  t = KviQString::nullTerminatedArray(m_pData->m_szUsers);  break;
-		default: t = KviQString::nullTerminatedArray(m_pData->m_szTopic);  break;
+		case 0:  szText = m_pData->m_szChan;   break;
+		case 1:  szText = m_pData->m_szUsers;  break;
+		default: szText = m_pData->m_szTopic;  break;
 	}
 
-	if(!t)return;
+	KviTalListView* lv = (KviTalListView *)listView();
+	int marg = lv->itemMargin();
+	int r = marg;
 
+#ifdef COMPILE_USE_QT4
 
-	bool curBold      = false;
-	bool curUnderline = false;
-	unsigned char curFore      = KVI_LABEL_DEF_FORE; //default fore
-	unsigned char curBack      = KVI_LABEL_DEF_BACK; //default back
+	p->fillRect( 0, 0, width, height(), cg.brush(lv->viewport()->backgroundRole()) );
+#else
+	const QColorGroup::ColorRole crole = QPalette::backgroundRoleFromMode(lv->viewport()->backgroundMode());
+	
+	p->fillRect( 0, 0, width, height(), cg.brush( crole ) );
+#endif
 
-	int baseline = ((height() + fm.ascent() - fm.descent() + 1) >> 1);
-	int curX = 2; //2 is the margin
-
-
-	while(t->unicode() && (curX < wdth))
-	{
-		const QChar * aux = t;
-		int len = 0;
-		while(aux->unicode() && (aux->unicode() != KVI_TEXT_COLOR) && (aux->unicode() != KVI_TEXT_BOLD) &&
-					(aux->unicode() != KVI_TEXT_UNDERLINE) && (aux->unicode() != KVI_TEXT_REVERSE) &&
-					(aux->unicode() != KVI_TEXT_RESET) && len < 150) // need to put this length limit: see the BUG below
-		{
-			++len;
-			++aux;
-		}
-		int www;
-
-		if(len > 0)
-		{
-			QString txt(t,len);
-			www = 10;
-			www = fm.width(txt);
-			if(curFore == KVI_LABEL_DEF_FORE)
-			{
-				p->setPen(cg.text());
-			} else {
-				if(curFore > 15)p->setPen(cg.base());
-				else p->setPen(KVI_OPTION_MIRCCOLOR(curFore));
-			}
-			if(curBack != KVI_LABEL_DEF_BACK)
-			{
-				if(curBack > 15)
-				{
-					p->fillRect(curX,2,wdth,height() - 4,cg.text());
-				} else {
-					p->fillRect(curX,2,wdth,height() - 4,KVI_OPTION_MIRCCOLOR(curBack));
-				}
-			}
-			
-			// 13/12/2003: I REALLY CAN'T UNDERSTAND WHY
-			// QT/XLib crashes when painting THIS string (253 chars long)
-			// "#IRC6 - IPv6 version of QPlug for Netscape/Mozilla now released; http://q6stat.actiongal.com/ - Minor bugfixes in Q6Stat, possible pending release of the currently closed source Q6Master (with qw/q3a support), and coming soon, x0rfb server/viewer + ipv6"
-			// probably a buffer problem.
-			// Sometimes it gets just locked and other times spits out this
-			// before killing the app...
-			
-			// X Error: BadLength (poly request too large or internal Xlib length error) 16
-			//  Major opcode:  33
-			//  Minor opcode:  0
-			//  Resource id:  0x28007f7
-			// X Error: BadRequest (invalid request code or no such operation) 1
-			//  Major opcode:  179
-			//  Minor opcode:  0
-			//  Resource id:  0x28007f7
-			
-			// The interesting thing is that it crashes ONLY in this listview widget
-			// the KviIrcView does not crash on this, for example...
-			// maybe because it gets wrapped on several lines anyway...
-			// don't know.
-			// 253 unicode chars would give 506 bytes. it MIGHT be that the max request size is 512 and
-			// 504 is the usable request size.
-			// the crash happens also for any size bigger than 253
-			
-			// 17.12.2003 : update : qt 3.2.3 solves this problem
-
-			p->drawText(curX,baseline,txt);
-			
-			if(curBold)p->drawText(curX+1,baseline,txt);
-			if(curUnderline)p->drawLine(curX,baseline + 1,curX+wdth,baseline + 1);
-		} else {
-			www = 0;
-		}
-
-		switch(aux->unicode())
-		{
-			case KVI_TEXT_BOLD: curBold = !curBold; ++aux; break;
-			case KVI_TEXT_UNDERLINE: curUnderline = !curUnderline; ++aux; break;
-			case KVI_TEXT_REVERSE:
-				{
-					char auxBack = curBack;
-					curBack = curFore;
-					curFore = auxBack;
-				}
-				++aux;
-			break;
-			case KVI_TEXT_RESET:
-				curFore = KVI_LABEL_DEF_FORE;
-				curBack = KVI_LABEL_DEF_BACK;
-				curBold = false;
-				curUnderline = false;
-				++aux;
-			break;
-			case KVI_TEXT_COLOR:
-			{
-				++aux;
-				unsigned char fore;
-				unsigned char back;
-				aux = getUnicodeColorBytes(aux,&fore,&back);
-				if(fore != KVI_NOCHANGE)
-				{
-					curFore = fore;
-					if(back != KVI_NOCHANGE)curBack = back;
-				} else {
-					// only a CTRL+K
-					curFore = KVI_LABEL_DEF_FORE;
-					curBack = KVI_LABEL_DEF_BACK;
-				}
-			}
-			break;
-		}
-
-		t = aux;
-		curX += www;
-	}
-	if(isSelected())
-	{
-		p->setRasterOp(Qt::NotROP);
-		p->fillRect(0,0,wdth,height(),Qt::black);
-		p->setRasterOp(Qt::CopyROP);
+	if ( isSelected() &&
+		(column == 0 || lv->allColumnsShowFocus()) ) {
+		p->fillRect( r - marg, 0, width - r + marg, height(),
+		cg.brush( QColorGroup::Highlight ) );
+		
+		if ( isEnabled() || !lv )
+			p->setPen( cg.highlightedText() );
+		else if ( !isEnabled() && lv)
+			p->setPen( lv->palette().disabled().highlightedText() );
+	} else {
+		if ( isEnabled() || !lv )
+			p->setPen( cg.text() );
+		else if ( !isEnabled() && lv)
+			p->setPen( lv->palette().disabled().text() );
 	}
+	
+	KviTopicWidget::paintColoredText(p,szText,cg,height(),width);
 }
 	
 QString KviChannelListViewItem::key(int col,bool) const
@@ -260,22 +178,29 @@ KviListWindow::KviListWindow(KviFrame * lpFrm,KviConsole * lpConsole)
 
 	m_pFlushTimer = 0;
 
-	m_pItemList = new KviPtrList<KviChannelListViewItemData>;
+	m_pItemList = new KviPointerList<KviChannelListViewItemData>;
 	m_pItemList->setAutoDelete(false);
 
-	m_pSplitter = new QSplitter(QSplitter::Horizontal,this,"splitter");
-	m_pTopSplitter = new QSplitter(QSplitter::Horizontal,this,"top_splitter");
-	m_pVertSplitter = new QSplitter(QSplitter::Vertical,m_pSplitter,"vsplitter");
+	m_pSplitter = new QSplitter(Qt::Horizontal,this,"splitter");
+	m_pTopSplitter = new QSplitter(Qt::Horizontal,this,"top_splitter");
+	m_pVertSplitter = new QSplitter(Qt::Vertical,m_pSplitter,"vsplitter");
 
-	QHBox * box = new QHBox(m_pTopSplitter);
+	KviTalHBox * box = new KviTalHBox(m_pTopSplitter);
+	m_pOpenButton = new KviStyledToolButton(box);
+	m_pOpenButton->setPixmap(*(g_pIconManager->getBigIcon(KVI_BIGICON_OPEN)));
+	connect(m_pOpenButton,SIGNAL(clicked()),this,SLOT(importList()));	
 
-	m_pRequestButton = new QToolButton(box,"request_button");
+	m_pSaveButton = new KviStyledToolButton(box);
+	m_pSaveButton->setPixmap(*(g_pIconManager->getBigIcon(KVI_BIGICON_SAVE)));
+	connect(m_pSaveButton,SIGNAL(clicked()),this,SLOT(exportList()));	
+
+	m_pRequestButton = new KviStyledToolButton(box,"request_button");
 	m_pRequestButton->setUsesBigPixmap(false);
 	m_pRequestButton->setPixmap(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_LIST)));
 	connect(m_pRequestButton,SIGNAL(clicked()),this,SLOT(requestList()));	
 	QToolTip::add(m_pRequestButton,__tr2qs("Request List"));
 	
-	m_pStopListDownloadButton = new QToolButton(box,"stoplistdownload_button");
+	m_pStopListDownloadButton = new KviStyledToolButton(box,"stoplistdownload_button");
 	m_pStopListDownloadButton->setUsesBigPixmap(false);
 	m_pStopListDownloadButton->setPixmap(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_NICKNAMEPROBLEM)));
 	connect(m_pStopListDownloadButton,SIGNAL(clicked()),this,SLOT(stoplistdownload()));
@@ -290,13 +215,16 @@ KviListWindow::KviListWindow(KviFrame * lpFrm,KviConsole * lpConsole)
 
 	m_pInfoLabel = new KviThemedLabel(m_pTopSplitter,"info_label");
 
-	m_pListView  = new QListView(m_pVertSplitter);
-	m_pListView->addColumn(__tr2qs("Channel"),150);
-	m_pListView->addColumn(__tr2qs("Users"),70);
-	m_pListView->addColumn(__tr2qs("Topic"),400);
+	m_pListView  = new KviTalListView(m_pVertSplitter);
+	m_pListView->addColumn(__tr2qs("Channel"));
+	m_pListView->addColumn(__tr2qs("Users"));
+	m_pListView->addColumn(__tr2qs("Topic"));
+	m_pListView->setAllColumnsShowFocus(TRUE);
+	m_pListView->setColumnWidthMode(2,KviTalListView::Maximum);
+	m_pListView->setColumnWidthMode(3,KviTalListView::Maximum);
 	m_pListView->setSorting(100);
 	
-	connect(m_pListView,SIGNAL(doubleClicked(QListViewItem *)),this,SLOT(itemDoubleClicked(QListViewItem *)));
+	connect(m_pListView,SIGNAL(doubleClicked(KviTalListViewItem *)),this,SLOT(itemDoubleClicked(KviTalListViewItem *)));
 
 	m_pIrcView = new KviIrcView(m_pVertSplitter,lpFrm,this);
 
@@ -407,6 +335,80 @@ void KviListWindow::die()
 	close();
 }
 
+void KviListWindow::exportList()
+{
+	if(!m_pListView->firstChild())
+	{
+		KviMessageBox::warning(__tr2qs("You cannot export an empty list"));
+		return;
+	}
+		
+	QString szFile;
+	if(connection())
+	{
+		QString szDate = QDateTime::currentDateTime().toString("d MMM yyyy hh-mm");
+		KviQString::sprintf(szFile,__tr2qs("Channel list for %Q - %Q"),
+			&(connection()->networkName()),&(szDate));
+	} else {
+		szFile = __tr2qs("Channel list");
+	}
+	if(KviFileDialog::askForSaveFileName(szFile,__tr2qs("Choose filename"),szFile,
+		__tr2qs("Configuration files (*.kvc)"),false,
+		false,true,this))
+	{
+		if(QFileInfo(szFile).extension()!="kvc")
+			szFile.append(".kvc");
+		KviConfig cfg(szFile,KviConfig::Write);
+		cfg.clear();
+		KviTalListViewItemIterator it(m_pListView);
+
+		while(it.current())
+		{
+			KviChannelListViewItemData* pData= ((KviChannelListViewItem*) ( it.current() ))->m_pData;
+			cfg.setGroup(pData->m_szChan);
+			// Write properties
+			cfg.writeEntry("topic",pData->m_szTopic);
+			cfg.writeEntry("users",pData->m_szUsers);
+//			cfg.writeEntry("usersKey",pData->m_szUsersKey);
+			++it;
+		}
+	}
+}
+
+void KviListWindow::importList()
+{
+	
+	QString szFile;
+	if(KviFileDialog::askForOpenFileName(szFile,__tr2qs("Choose filename"),QString::null,
+		__tr2qs("Configuration files (*.kvc)"),false,
+		false,this))
+	{
+		if(m_pConsole->isConnected())
+		{
+			m_pConsole->connection()->sendFmtData("list stoplistdownloadnow");
+			outputNoFmt(KVI_OUT_SYSTEMMESSAGE,__tr2qs("Stopping the list download...")); //G&N mar 2005
+		}
+
+		m_pItemList->clear();
+
+		KviConfig cfg(szFile,KviConfig::Read);
+		KviConfigIterator it(*cfg.dict());
+		while(it.current())
+		{
+			cfg.setGroup(it.currentKey());
+			m_pItemList->append( 
+					new KviChannelListViewItemData(
+						it.currentKey(),
+						cfg.readQStringEntry("users","0"),
+						cfg.readQStringEntry("topic","")
+					)
+				);
+			++it;
+		}
+		flush();
+	}
+}
+
 void KviListWindow::control(int message)
 {
 	switch(message)
@@ -483,12 +485,12 @@ void KviListWindow::flush()
 	m_pListView->viewport()->update();
 }
 
-void KviListWindow::itemDoubleClicked(QListViewItem *it)
+void KviListWindow::itemDoubleClicked(KviTalListViewItem *it)
 {
 	QString sz = ((KviChannelListViewItem *)it)->channel();
 	if(sz.isEmpty())return;
 	if(!connection())return;
-	QCString dat = connection()->encodeText(sz);
+	KviQCString dat = connection()->encodeText(sz);
 	if(!dat.data())return;
 	m_pConsole->connection()->sendFmtData("join %s",dat.data());
 }
