@@ -27,13 +27,13 @@
 #include "kvi_window.h"
 #include "kvi_string.h"
 #include "kvi_ircsocket.h"
-#include "kvi_list.h"
+#include "kvi_pointerlist.h"
 #include "kvi_sparser.h"
 #include "kvi_console.h"
 #include "kvi_irccontext.h"
 
-#include <qlistview.h>
-#include <qpopupmenu.h>
+#include "kvi_tal_listview.h"
+#include "kvi_tal_popupmenu.h"
 #include <qtoolbutton.h>
 #include <qlineedit.h>
 
@@ -42,6 +42,7 @@ class KviThemedLabel;
 class KviChannelListViewItemData
 {
 	friend class KviChannelListViewItem;
+	friend class KviListWindow;
 public:
 	KviChannelListViewItemData(const QString &szChan,const QString &szUsers,const QString &szTopic);
 	~KviChannelListViewItemData();
@@ -52,16 +53,21 @@ protected:
 	QString m_szUsersKey;
 };
 
-class KviChannelListViewItem : public QListViewItem
+class KviChannelListViewItem : public KviTalListViewItem
 {
+	friend class KviListWindow;
 public:
-	KviChannelListViewItem(QListView * v,KviChannelListViewItemData * pData);
+	KviChannelListViewItem(KviTalListView * v,KviChannelListViewItemData * pData);
 	~KviChannelListViewItem();
 protected:
 	KviChannelListViewItemData * m_pData;
 public:
 	const QString & channel(){ return m_pData->m_szChan; };
-	virtual int width ( const QFontMetrics & fm, const QListView * lv, int c );
+#ifdef COMPILE_USE_QT4
+	int width ( const QFontMetrics & fm, const KviTalListView * lv, int column ) const;
+#else
+	int width ( const QFontMetrics & fm, const QListView * lv, int column ) const;
+#endif
 protected:
 	virtual void paintCell(QPainter * p,const QColorGroup &cg,int col,int wdth,int align);
 	virtual QString key(int col,bool) const;
@@ -78,13 +84,15 @@ public:
 protected:
 	QSplitter                              * m_pVertSplitter;
 	QSplitter                              * m_pTopSplitter;
-	QListView                              * m_pListView;
+	KviTalListView                         * m_pListView;
 	QLineEdit                              * m_pParamsEdit;
 	QToolButton                            * m_pRequestButton;
 	QToolButton							   * m_pStopListDownloadButton;
+	QToolButton							   * m_pOpenButton;
+	QToolButton							   * m_pSaveButton;
 	KviThemedLabel                         * m_pInfoLabel;
 	QTimer                                 * m_pFlushTimer;
-	KviPtrList<KviChannelListViewItemData> * m_pItemList;
+	KviPointerList<KviChannelListViewItemData> * m_pItemList;
 public: // Methods
 	virtual void control(int msg);
 	virtual void processData(KviIrcMessage * msg);
@@ -97,10 +105,12 @@ protected:
 	virtual void getBaseLogFileName(KviStr &buffer);
 protected slots:
 	void flush();
-	void itemDoubleClicked(QListViewItem *it);
+	void itemDoubleClicked(KviTalListViewItem *it);
 	void requestList();
 	void stoplistdownload();
 	void connectionStateChange();
+	void exportList();
+	void importList();
 public:
 	virtual QSize sizeHint() const;
 private:
