@@ -27,16 +27,17 @@
 #include "mp_xmmsinterface.h"
 #include "mp_amarokinterface.h"
 #include "mp_winampinterface.h"
+#include "mp_amipinterface.h"
 #include "mp_jukinterface.h"
 
 #include "kvi_module.h"
 #include "kvi_options.h"
-#include "kvi_command.h"
-//#include "kvi_uparser.h"
+
+
 #include "kvi_locale.h"
 #include "kvi_out.h"
 
-static KviPtrList<KviMediaPlayerInterfaceDescriptor> * g_pDescriptorList = 0;
+static KviPointerList<KviMediaPlayerInterfaceDescriptor> * g_pDescriptorList = 0;
 
 static KviMediaPlayerInterface * g_pMPInterface = 0;
 
@@ -183,8 +184,12 @@ static KviMediaPlayerInterface * auto_detect_player(KviWindow * pOut = 0)
 		for more details about how it works.[br]
 	@seealso:
 		[module:mediaplayer]media player module documentation[/module],
-		[cmd]mediaplayer.stop[/cmd], [cmd]mediaplayer.pause[/cmd], [cmd]mediaplayer.prev[/cmd],
-		[cmd]mediaplayer.next[/cmd], [fnc]$mediaplayer.nowPlaying()[/fnc], [fnc]$mediaplayer.status()[/fnc]
+		[cmd]mediaplayer.stop[/cmd],
+		[cmd]mediaplayer.pause[/cmd],
+		[cmd]mediaplayer.prev[/cmd],
+		[cmd]mediaplayer.next[/cmd],
+		[fnc]$mediaplayer.nowPlaying[/fnc],
+		[fnc]$mediaplayer.status[/fnc]
 */
 
 MP_KVS_SIMPLE_COMMAND(play,play)
@@ -205,7 +210,9 @@ MP_KVS_SIMPLE_COMMAND(play,play)
 		for more details about how it works.[br]
 	@seealso:
 		[module:mediaplayer]media player module documentation[/module],
-		[cmd]mediaplayer.quit[/cmd],[cmd]mediaplayer.show[/cmd],[cmd]mediaplayer.minimize[/cmd]
+		[cmd]mediaplayer.quit[/cmd],
+		[cmd]mediaplayer.show[/cmd],
+		[cmd]mediaplayer.minimize[/cmd]
 */
 
 MP_KVS_SIMPLE_COMMAND(hide,hide)
@@ -228,7 +235,9 @@ MP_KVS_SIMPLE_COMMAND(hide,hide)
 		for more details about how it works.[br]
 	@seealso:
 		[module:mediaplayer]media player module documentation[/module],
-		[cmd]mediaplayer.quit[/cmd],[cmd]mediaplayer.hide[/cmd],[cmd]mediaplayer.minimize[/cmd]
+		[cmd]mediaplayer.quit[/cmd],
+		[cmd]mediaplayer.hide[/cmd],
+		[cmd]mediaplayer.minimize[/cmd]
 */
 
 MP_KVS_SIMPLE_COMMAND(show,show)
@@ -249,7 +258,9 @@ MP_KVS_SIMPLE_COMMAND(show,show)
 		for more details about how it works.[br]
 	@seealso:
 		[module:mediaplayer]media player module documentation[/module],
-		[cmd]mediaplayer.quit[/cmd],[cmd]mediaplayer.hide[/cmd],[cmd]mediaplayer.show[/cmd]
+		[cmd]mediaplayer.quit[/cmd],
+		[cmd]mediaplayer.hide[/cmd],
+		[cmd]mediaplayer.show[/cmd]
 */
 
 MP_KVS_SIMPLE_COMMAND(minimize,minimize)
@@ -270,8 +281,12 @@ MP_KVS_SIMPLE_COMMAND(minimize,minimize)
 		for more details about how it works.[br]
 	@seealso:
 		[module:mediaplayer]media player module documentation[/module],
-		[cmd]mediaplayer.play[/cmd], [cmd]mediaplayer.pause[/cmd], [cmd]mediaplayer.prev[/cmd],
-		[cmd]mediaplayer.next[/cmd], [fnc]$mediaplayer.nowPlaying()[/fnc], [fnc]$mediaplayer.status()[/fnc]
+		[cmd]mediaplayer.play[/cmd],
+		[cmd]mediaplayer.pause[/cmd],
+		[cmd]mediaplayer.prev[/cmd],
+		[cmd]mediaplayer.next[/cmd],
+		[fnc]$mediaplayer.nowPlaying[/fnc],
+		[fnc]$mediaplayer.status[/fnc]
 */
 
 MP_KVS_SIMPLE_COMMAND(stop,stop)
@@ -292,8 +307,12 @@ MP_KVS_SIMPLE_COMMAND(stop,stop)
 		for more details about how it works.[br]
 	@seealso:
 		[module:mediaplayer]media player module documentation[/module]
-		[cmd]mediaplayer.stop[/cmd], [cmd]mediaplayer.pause[/cmd], [cmd]mediaplayer.prev[/cmd],
-		[cmd]mediaplayer.play[/cmd], [fnc]$mediaplayer.nowPlaying()[/fnc], [fnc]$mediaplayer.status()[/fnc]
+		[cmd]mediaplayer.stop[/cmd],
+		[cmd]mediaplayer.pause[/cmd],
+		[cmd]mediaplayer.prev[/cmd],
+		[cmd]mediaplayer.play[/cmd],
+		[fnc]$mediaplayer.nowPlaying[/fnc],
+		[fnc]$mediaplayer.status[/fnc]
 */
 
 MP_KVS_SIMPLE_COMMAND(next,next)
@@ -314,8 +333,12 @@ MP_KVS_SIMPLE_COMMAND(next,next)
 		for more details about how it works.[br]
 	@seealso:
 		[module:mediaplayer]media player module documentation[/module]
-		[cmd]mediaplayer.stop[/cmd], [cmd]mediaplayer.pause[/cmd], [cmd]mediaplayer.play[/cmd],
-		[cmd]mediaplayer.next[/cmd], [fnc]$mediaplayer.nowPlaying()[/fnc], [fnc]$mediaplayer.status()[/fnc]
+		[cmd]mediaplayer.stop[/cmd],
+		[cmd]mediaplayer.pause[/cmd],
+		[cmd]mediaplayer.play[/cmd],
+		[cmd]mediaplayer.next[/cmd],
+		[fnc]$mediaplayer.nowPlaying[/fnc],
+		[fnc]$mediaplayer.status[/fnc]
 */
 
 MP_KVS_SIMPLE_COMMAND(prev,prev)
@@ -336,8 +359,12 @@ MP_KVS_SIMPLE_COMMAND(prev,prev)
 		for more details about how it works.[br]
 	@seealso:
 		[module:mediaplayer]media player module documentation[/module]
-		[cmd]mediaplayer.stop[/cmd], [cmd]mediaplayer.pause[/cmd], [cmd]mediaplayer.prev[/cmd],
-		[cmd]mediaplayer.next[/cmd], [fnc]$mediaplayer.nowPlaying()[/fnc], [fnc]$mediaplayer.status()[/fnc]
+		[cmd]mediaplayer.stop[/cmd],
+		[cmd]mediaplayer.pause[/cmd],
+		[cmd]mediaplayer.prev[/cmd],
+		[cmd]mediaplayer.next[/cmd],
+		[fnc]$mediaplayer.nowPlaying[/fnc],
+		[fnc]$mediaplayer.status[/fnc]
 */
 
 MP_KVS_SIMPLE_COMMAND(quit,quit)
@@ -358,8 +385,12 @@ MP_KVS_SIMPLE_COMMAND(quit,quit)
 		for more details about how it works.[br]
 	@seealso:
 		[module:mediaplayer]media player module documentation[/module]
-		[cmd]mediaplayer.stop[/cmd], [cmd]mediaplayer.pause[/cmd], [cmd]mediaplayer.prev[/cmd],
-		[cmd]mediaplayer.next[/cmd], [fnc]$mediaplayer.nowPlaying()[/fnc], [fnc]$mediaplayer.status()[/fnc]
+		[cmd]mediaplayer.stop[/cmd],
+		[cmd]mediaplayer.pause[/cmd],
+		[cmd]mediaplayer.prev[/cmd],
+		[cmd]mediaplayer.next[/cmd],
+		[fnc]$mediaplayer.nowPlaying[/fnc],
+		[fnc]$mediaplayer.status[/fnc]
 */
 
 MP_KVS_SIMPLE_COMMAND(pause,pause)
@@ -386,9 +417,13 @@ MP_KVS_SIMPLE_COMMAND(pause,pause)
 		for more details about how it works.[br]
 	@seealso:
 		[module:mediaplayer]media player module documentation[/module]
-		[cmd]mediaplayer.stop[/cmd], [cmd]mediaplayer.pause[/cmd], [cmd]mediaplayer.prev[/cmd],
-		[cmd]mediaplayer.next[/cmd], [fnc]$mediaplayer.nowPlaying()[/fnc], [fnc]$mediaplayer.status()[/fnc],
-		[cmd]mediaplayer.setPlayer[/cmd], [fnc]$mediaplayer.player()[/fnc]
+		[cmd]mediaplayer.stop[/cmd], [cmd]mediaplayer.pause[/cmd],
+		[cmd]mediaplayer.prev[/cmd],
+		[cmd]mediaplayer.next[/cmd],
+		[fnc]$mediaplayer.nowPlaying[/fnc],
+		[fnc]$mediaplayer.status[/fnc],
+		[cmd]mediaplayer.setPlayer[/cmd],
+		[fnc]$mediaplayer.player[/fnc]
 */
 
 MP_KVS_COMMAND(detect)
@@ -415,7 +450,7 @@ MP_KVS_COMMAND(detect)
 		for more details about how it works.[br]
 	@seealso:
 		[module:mediaplayer]media player module documentation[/module],
-		[cmd]mediaplayer.detect[/cmd], [fnc]$mediaplayer.player()[/fnc]
+		[cmd]mediaplayer.detect[/cmd], [fnc]$mediaplayer.player[/fnc]
 */
 
 MP_KVS_COMMAND(setPlayer)
@@ -479,7 +514,7 @@ MP_KVS_FUNCTION(player)
 		Take a look at the [module:mediaplayer]mediaplayer module documentation[/module]
 		for more details about how it works.[br]
 	@seealso:
-		[module:mediaplayer]media player module documentation[/module]m
+		[module:mediaplayer]media player module documentation[/module]
 		[cmd]mediaplayer.detect[/cmd], [cmd]mediaplayer.setPlayer[/cmd],
 		[fnc]$mediaplayer.player[/fnc]
 */
@@ -515,7 +550,8 @@ MP_KVS_FUNCTION(playerList)
 		for more details about how it works.[br]
 	@seealso:
 		[module:mediaplayer]media player module documentation[/module],
-		[fnc]$mediaplayer.mrl()[/fnc], [fnc]$mediaplayer.localFile()[/fnc],
+		[fnc]$mediaplayer.mrl[/fnc],
+		[fnc]$mediaplayer.localFile[/fnc],
 		[cmd]mediaplayer.play[/cmd]
 */
 
@@ -542,6 +578,29 @@ MP_KVS_COMMAND(playMrl)
 	return true;
 }
 
+MP_KVS_COMMAND(amipExec)
+{
+	QString szMrl;
+
+	KVSM_PARAMETERS_BEGIN(c)
+		KVSM_PARAMETER("player",KVS_PT_STRING,0,szMrl)
+	KVSM_PARAMETERS_END(c)
+
+	MP_KVS_FAIL_ON_NO_INTERFACE
+	if(!g_pMPInterface->amipExec(szMrl))
+	{
+		if(!c->hasSwitch('q',"quiet"))
+		{
+			c->warning(__tr2qs_ctx("The selected media player interface failed to execute the requested function","mediaplayer"));
+			QString tmp = __tr2qs_ctx("Last interface error: ","mediaplayer");
+			tmp += g_pMPInterface->lastError();
+			c->warning(tmp);
+		}
+	}
+
+	return true;
+}
+
 
 /*
 	@doc: mediaplayer.jumpTo
@@ -557,7 +616,8 @@ MP_KVS_COMMAND(playMrl)
 		Sets the position in seconds of the current song .
 	@seealso:
 		[module:mediaplayer]media player module documentation[/module],
-		[fnc]$mediaplayer.position()[/fnc], [fnc]$mediaplayer.lenght()[/fnc],
+		[fnc]$mediaplayer.position[/fnc],
+		[fnc]$mediaplayer.lenght[/fnc],
 */
 
 MP_KVS_COMMAND(jumpTo)
@@ -596,12 +656,12 @@ MP_KVS_COMMAND(jumpTo)
 		Set the media player volume to <vol> (the valid range is from 0 to ....)
 	@seealso:
 		[module:mediaplayer]media player module documentation[/module],
-		[fnc]$mediaplayer.getVol()[/fnc]
+		[fnc]$mediaplayer.getVol[/fnc]
 */
 
 MP_KVS_COMMAND(setVol)
 {
-	int iVol;
+	kvs_int_t iVol;
 
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("volume",KVS_PT_INT,0,iVol)
@@ -659,8 +719,11 @@ MP_KVS_SIMPLE_INT_FUNCTION(getVol,getVol)
 		for more details about how it works.[br]
 	@seealso:
 		[module:mediaplayer]media player module documentation[/module],
-		[cmd]mediaplayer.play[/cmd], [cmd]mediaplayer.pause[/cmd], [cmd]mediaplayer.prev[/cmd],
-		[cmd]mediaplayer.next[/cmd], [fnc]$mediaplayer.nowPlaying()[/fnc], [fnc]$mediaplayer.status()[/fnc]
+		[cmd]mediaplayer.play[/cmd], [cmd]mediaplayer.pause[/cmd],
+		[cmd]mediaplayer.prev[/cmd],
+		[cmd]mediaplayer.next[/cmd],
+		[fnc]$mediaplayer.nowPlaying[/fnc],
+		[fnc]$mediaplayer.status[/fnc]
 */
 
 MP_KVS_SIMPLE_COMMAND(mute,mute)
@@ -689,7 +752,8 @@ MP_KVS_SIMPLE_COMMAND(mute,mute)
 		for more details about how it works.[br]
 	@seealso:
 		[module:mediaplayer]media player module documentation[/module],
-		[cmd]mediaplayer.playMrl[/cmd], [fnc]$mediaplayer.localFile()[/fnc]
+		[cmd]mediaplayer.playMrl[/cmd],
+		[fnc]$mediaplayer.localFile[/fnc]
 */
 
 MP_KVS_SIMPLE_STRING_FUNCTION(mrl,mrl)
@@ -717,13 +781,15 @@ MP_KVS_SIMPLE_STRING_FUNCTION(mrl,mrl)
 		for more details about how it works.[br]
 	@seealso:
 		[module:mediaplayer]media player module documentation[/module],
-		[fnc]$mediaplayer.mrl()[/fnc], [cmd]mediaplayer.playMrl[/cmd],
-		[cmd]mediaplayer.play[/cmd], [fnc]$mediaplayer.title()[/fnc],
-		[fnc]$mediaplayer.artist()[/fnc], [fnc]$mediaplayer.genre()[/fnc],
-		[fnc]$mediaplayer.year()[/fnc], [fnc]$mediaplayer.comment()[/fnc],
-		[fnc]$mediaplayer.mediaType()[/fnc], [fnc]$mediaplayer.bitRate()[/fnc],
-		[fnc]$mediaplayer.sampleRate()[/fnc],
-		[fnc]$mediaplayer.length()[/fnc], [fnc]$mediaplayer.position()[/fnc]
+		[fnc]$mediaplayer.mrl[/fnc], [cmd]mediaplayer.playMrl[/cmd],
+		[cmd]mediaplayer.play[/cmd], [fnc]$mediaplayer.title[/fnc],
+		[fnc]$mediaplayer.artist[/fnc], [fnc]$mediaplayer.genre[/fnc],
+		[fnc]$mediaplayer.year[/fnc], [fnc]$mediaplayer.comment[/fnc],
+		[fnc]$mediaplayer.mediaType[/fnc],
+		[fnc]$mediaplayer.bitRate[/fnc],
+		[fnc]$mediaplayer.sampleRate[/fnc],
+		[fnc]$mediaplayer.length[/fnc],
+		[fnc]$mediaplayer.position[/fnc]
 */
 
 MP_KVS_SIMPLE_STRING_FUNCTION(nowPlaying,nowPlaying)
@@ -748,11 +814,11 @@ MP_KVS_SIMPLE_STRING_FUNCTION(nowPlaying,nowPlaying)
 		for more details about how it works.[br]
 	@seealso:
 		[module:mediaplayer]media player module documentation[/module],
-		[fnc]$mediaplayer.mrl()[/fnc], [cmd]mediaplayer.playMrl[/cmd],
-		[cmd]mediaplayer.play[/cmd], [fnc]$mediaplayer.nowPlaying()[/fnc],
-		[fnc]$mediaplayer.artist()[/fnc], [fnc]$mediaplayer.genre()[/fnc],
-		[fnc]$mediaplayer.year()[/fnc], [fnc]$mediaplayer.comment()[/fnc],
-		[fnc]$mediaplayer.mediaType()[/fnc]
+		[fnc]$mediaplayer.mrl[/fnc], [cmd]mediaplayer.playMrl[/cmd],
+		[cmd]mediaplayer.play[/cmd], [fnc]$mediaplayer.nowPlaying[/fnc],
+		[fnc]$mediaplayer.artist[/fnc], [fnc]$mediaplayer.genre[/fnc],
+		[fnc]$mediaplayer.year[/fnc], [fnc]$mediaplayer.comment[/fnc],
+		[fnc]$mediaplayer.mediaType[/fnc]
 */
 
 MP_KVS_SIMPLE_STRING_FUNCTION(title,title)
@@ -777,12 +843,14 @@ MP_KVS_SIMPLE_STRING_FUNCTION(title,title)
 		for more details about how it works.[br]
 	@seealso:
 		[module:mediaplayer]media player module documentation[/module],
-		[fnc]$mediaplayer.mrl()[/fnc], [cmd]mediaplayer.playMrl[/cmd],
-		[cmd]mediaplayer.play[/cmd], [fnc]$mediaplayer.nowPlaying()[/fnc],
-		[fnc]$mediaplayer.title()[/fnc], [fnc]$mediaplayer.genre()[/fnc],
-		[fnc]$mediaplayer.year()[/fnc], [fnc]$mediaplayer.comment()[/fnc],
-		[fnc]$mediaplayer.mediaType()[/fnc], [fnc]$mediaplayer.album()[/fnc],
-		[fnc]$mediaplayer.length()[/fnc], [fnc]$mediaplayer.position()[/fnc]
+		[fnc]$mediaplayer.mrl[/fnc], [cmd]mediaplayer.playMrl[/cmd],
+		[cmd]mediaplayer.play[/cmd], [fnc]$mediaplayer.nowPlaying[/fnc],
+		[fnc]$mediaplayer.title[/fnc], [fnc]$mediaplayer.genre[/fnc],
+		[fnc]$mediaplayer.year[/fnc], [fnc]$mediaplayer.comment[/fnc],
+		[fnc]$mediaplayer.mediaType[/fnc],
+		[fnc]$mediaplayer.album[/fnc],
+		[fnc]$mediaplayer.length[/fnc],
+		[fnc]$mediaplayer.position[/fnc]
 */
 
 MP_KVS_SIMPLE_STRING_FUNCTION(artist,artist)
@@ -807,12 +875,12 @@ MP_KVS_SIMPLE_STRING_FUNCTION(artist,artist)
 		for more details about how it works.[br]
 	@seealso:
 		[module:mediaplayer]media player module documentation[/module],
-		[fnc]$mediaplayer.mrl()[/fnc], [cmd]mediaplayer.playMrl[/cmd],
-		[cmd]mediaplayer.play[/cmd], [fnc]$mediaplayer.nowPlaying()[/fnc],
-		[fnc]$mediaplayer.artist()[/fnc], [fnc]$mediaplayer.artist()[/fnc],
-		[fnc]$mediaplayer.year()[/fnc], [fnc]$mediaplayer.comment()[/fnc],
-		[fnc]$mediaplayer.mediaType()[/fnc], [fnc]$mediaplayer.album()[/fnc],
-		[fnc]$mediaplayer.length()[/fnc], [fnc]$mediaplayer.position()[/fnc]
+		[fnc]$mediaplayer.mrl[/fnc], [cmd]mediaplayer.playMrl[/cmd],
+		[cmd]mediaplayer.play[/cmd], [fnc]$mediaplayer.nowPlaying[/fnc],
+		[fnc]$mediaplayer.artist[/fnc], [fnc]$mediaplayer.artist[/fnc],
+		[fnc]$mediaplayer.year[/fnc], [fnc]$mediaplayer.comment[/fnc],
+		[fnc]$mediaplayer.mediaType[/fnc], [fnc]$mediaplayer.album[/fnc],
+		[fnc]$mediaplayer.length[/fnc], [fnc]$mediaplayer.position[/fnc]
 */
 
 MP_KVS_SIMPLE_STRING_FUNCTION(genre,genre)
@@ -837,12 +905,12 @@ MP_KVS_SIMPLE_STRING_FUNCTION(genre,genre)
 		for more details about how it works.[br]
 	@seealso:
 		[module:mediaplayer]media player module documentation[/module],
-		[fnc]$mediaplayer.mrl()[/fnc], [cmd]mediaplayer.playMrl[/cmd],
-		[cmd]mediaplayer.play[/cmd], [fnc]$mediaplayer.nowPlaying()[/fnc],
-		[fnc]$mediaplayer.artist()[/fnc], [fnc]$mediaplayer.artist()[/fnc],
-		[fnc]$mediaplayer.genre()[/fnc], [fnc]$mediaplayer.comment()[/fnc],
-		[fnc]$mediaplayer.mediaType()[/fnc], [fnc]$mediaplayer.album()[/fnc],
-		[fnc]$mediaplayer.length()[/fnc], [fnc]$mediaplayer.position()[/fnc]
+		[fnc]$mediaplayer.mrl[/fnc], [cmd]mediaplayer.playMrl[/cmd],
+		[cmd]mediaplayer.play[/cmd], [fnc]$mediaplayer.nowPlaying[/fnc],
+		[fnc]$mediaplayer.artist[/fnc], [fnc]$mediaplayer.artist[/fnc],
+		[fnc]$mediaplayer.genre[/fnc], [fnc]$mediaplayer.comment[/fnc],
+		[fnc]$mediaplayer.mediaType[/fnc], [fnc]$mediaplayer.album[/fnc],
+		[fnc]$mediaplayer.length[/fnc], [fnc]$mediaplayer.position[/fnc]
 */
 
 MP_KVS_SIMPLE_STRING_FUNCTION(year,year)
@@ -867,12 +935,12 @@ MP_KVS_SIMPLE_STRING_FUNCTION(year,year)
 		for more details about how it works.[br]
 	@seealso:
 		[module:mediaplayer]media player module documentation[/module],
-		[fnc]$mediaplayer.mrl()[/fnc], [cmd]mediaplayer.playMrl[/cmd],
-		[cmd]mediaplayer.play[/cmd], [fnc]$mediaplayer.nowPlaying()[/fnc],
-		[fnc]$mediaplayer.artist()[/fnc], [fnc]$mediaplayer.artist()[/fnc],
-		[fnc]$mediaplayer.year()[/fnc], [fnc]$mediaplayer.year()[/fnc],
-		[fnc]$mediaplayer.mediaType()[/fnc], [fnc]$mediaplayer.album()[/fnc],
-		[fnc]$mediaplayer.length()[/fnc], [fnc]$mediaplayer.position()[/fnc]
+		[fnc]$mediaplayer.mrl[/fnc], [cmd]mediaplayer.playMrl[/cmd],
+		[cmd]mediaplayer.play[/cmd], [fnc]$mediaplayer.nowPlaying[/fnc],
+		[fnc]$mediaplayer.artist[/fnc], [fnc]$mediaplayer.artist[/fnc],
+		[fnc]$mediaplayer.year[/fnc], [fnc]$mediaplayer.year[/fnc],
+		[fnc]$mediaplayer.mediaType[/fnc], [fnc]$mediaplayer.album[/fnc],
+		[fnc]$mediaplayer.length[/fnc], [fnc]$mediaplayer.position[/fnc]
 */
 
 MP_KVS_SIMPLE_STRING_FUNCTION(comment,comment)
@@ -897,13 +965,15 @@ MP_KVS_SIMPLE_STRING_FUNCTION(comment,comment)
 		for more details about how it works.[br]
 	@seealso:
 		[module:mediaplayer]media player module documentation[/module],
-		[fnc]$mediaplayer.mrl()[/fnc], [cmd]mediaplayer.playMrl[/cmd],
-		[cmd]mediaplayer.play[/cmd], [fnc]$mediaplayer.nowPlaying()[/fnc],
-		[fnc]$mediaplayer.artist()[/fnc], [fnc]$mediaplayer.artist()[/fnc],
-		[fnc]$mediaplayer.year()[/fnc], [fnc]$mediaplayer.comment()[/fnc],
-		[fnc]$mediaplayer.mediaType()[/fnc], [fnc]$mediaplayer.bitRate()[/fnc],
-		[fnc]$mediaplayer.sampleRate()[/fnc], [fnc]$mediaplayer.length()[/fnc],
-		[fnc]$mediaplayer.position()[/fnc]
+		[fnc]$mediaplayer.mrl[/fnc], [cmd]mediaplayer.playMrl[/cmd],
+		[cmd]mediaplayer.play[/cmd], [fnc]$mediaplayer.nowPlaying[/fnc],
+		[fnc]$mediaplayer.artist[/fnc], [fnc]$mediaplayer.artist[/fnc],
+		[fnc]$mediaplayer.year[/fnc], [fnc]$mediaplayer.comment[/fnc],
+		[fnc]$mediaplayer.mediaType[/fnc],
+		[fnc]$mediaplayer.bitRate[/fnc],
+		[fnc]$mediaplayer.sampleRate[/fnc],
+		[fnc]$mediaplayer.length[/fnc],
+		[fnc]$mediaplayer.position[/fnc]
 */
 
 MP_KVS_SIMPLE_STRING_FUNCTION(album,album)
@@ -926,10 +996,11 @@ MP_KVS_SIMPLE_STRING_FUNCTION(album,album)
 		for more details about how it works.[br]
 	@seealso:
 		[module:mediaplayer]media player module documentation[/module]
-		[fnc]$mediaplayer.mrl()[/fnc], [cmd]mediaplayer.playMrl[/cmd],
-		[cmd]mediaplayer.play[/cmd], [fnc]$mediaplayer.nowPlaying()[/fnc],
-		[fnc]$mediaplayer.artist()[/fnc], [fnc]$mediaplayer.artist()[/fnc],
-		[fnc]$mediaplayer.year()[/fnc], [fnc]$mediaplayer.comment()[/fnc]
+		[fnc]$mediaplayer.mrl[/fnc], [cmd]mediaplayer.playMrl[/cmd],
+		[cmd]mediaplayer.play[/cmd], [fnc]$mediaplayer.nowPlaying[/fnc],
+		[fnc]$mediaplayer.artist[/fnc],
+		[fnc]$mediaplayer.artist[/fnc],
+		[fnc]$mediaplayer.year[/fnc], [fnc]$mediaplayer.comment[/fnc]
 */
 
 MP_KVS_SIMPLE_STRING_FUNCTION(mediaType,mediaType)
@@ -953,12 +1024,13 @@ MP_KVS_SIMPLE_STRING_FUNCTION(mediaType,mediaType)
 		for more details about how it works.[br]
 	@seealso:
 		[module:mediaplayer]media player module documentation[/module]
-		[fnc]$mediaplayer.mrl()[/fnc], [cmd]mediaplayer.playMrl[/cmd],
-		[cmd]mediaplayer.play[/cmd], [fnc]$mediaplayer.nowPlaying()[/fnc],
-		[fnc]$mediaplayer.artist()[/fnc], [fnc]$mediaplayer.artist()[/fnc],
-		[fnc]$mediaplayer.year()[/fnc], [fnc]$mediaplayer.comment()[/fnc],
-		[fnc]$mediaplayer.sampleRate()[/fnc], [fnc]$mediaplayer.length()[/fnc],
-		[fnc]$mediaplayer.position()[/fnc]
+		[fnc]$mediaplayer.mrl[/fnc], [cmd]mediaplayer.playMrl[/cmd],
+		[cmd]mediaplayer.play[/cmd], [fnc]$mediaplayer.nowPlaying[/fnc],
+		[fnc]$mediaplayer.artist[/fnc], [fnc]$mediaplayer.artist[/fnc],
+		[fnc]$mediaplayer.year[/fnc], [fnc]$mediaplayer.comment[/fnc],
+		[fnc]$mediaplayer.sampleRate[/fnc],
+		[fnc]$mediaplayer.length[/fnc],
+		[fnc]$mediaplayer.position[/fnc]
 */
 
 MP_KVS_SIMPLE_INT_FUNCTION(bitRate,bitRate)
@@ -983,12 +1055,12 @@ MP_KVS_SIMPLE_INT_FUNCTION(bitRate,bitRate)
 		for more details about how it works.[br]
 	@seealso:
 		[module:mediaplayer]media player module documentation[/module]
-		[fnc]$mediaplayer.mrl()[/fnc], [cmd]mediaplayer.playMrl[/cmd],
-		[cmd]mediaplayer.play[/cmd], [fnc]$mediaplayer.nowPlaying()[/fnc],
-		[fnc]$mediaplayer.artist()[/fnc], [fnc]$mediaplayer.artist()[/fnc],
-		[fnc]$mediaplayer.year()[/fnc], [fnc]$mediaplayer.comment()[/fnc],
-		[fnc]$mediaplayer.bitRate()[/fnc], [fnc]$mediaplayer.length()[/fnc],
-		[fnc]$mediaplayer.position()[/fnc], [fnc]$mediaplayer.channels()[/fnc]
+		[fnc]$mediaplayer.mrl[/fnc], [cmd]mediaplayer.playMrl[/cmd],
+		[cmd]mediaplayer.play[/cmd], [fnc]$mediaplayer.nowPlaying[/fnc],
+		[fnc]$mediaplayer.artist[/fnc], [fnc]$mediaplayer.artist[/fnc],
+		[fnc]$mediaplayer.year[/fnc], [fnc]$mediaplayer.comment[/fnc],
+		[fnc]$mediaplayer.bitRate[/fnc], [fnc]$mediaplayer.length[/fnc],
+		[fnc]$mediaplayer.position[/fnc], [fnc]$mediaplayer.channels[/fnc]
 */
 
 MP_KVS_SIMPLE_INT_FUNCTION(sampleRate,sampleRate)
@@ -1011,12 +1083,14 @@ MP_KVS_SIMPLE_INT_FUNCTION(sampleRate,sampleRate)
 		for more details about how it works.[br]
 	@seealso:
 		[module:mediaplayer]media player module documentation[/module],
-		[fnc]$mediaplayer.mrl()[/fnc], [cmd]mediaplayer.playMrl[/cmd],
-		[cmd]mediaplayer.play[/cmd], [fnc]$mediaplayer.nowPlaying()[/fnc],
-		[fnc]$mediaplayer.artist()[/fnc], [fnc]$mediaplayer.artist()[/fnc],
-		[fnc]$mediaplayer.year()[/fnc], [fnc]$mediaplayer.comment()[/fnc],
-		[fnc]$mediaplayer.sampleRate()[/fnc], [fnc]$mediaplayer.bitRate()[/fnc],
-		[fnc]$mediaplayer.position()[/fnc]
+		[fnc]$mediaplayer.mrl[/fnc], [cmd]mediaplayer.playMrl[/cmd],
+		[cmd]mediaplayer.play[/cmd], [fnc]$mediaplayer.nowPlaying[/fnc],
+		[fnc]$mediaplayer.artist[/fnc],
+		[fnc]$mediaplayer.artist[/fnc],
+		[fnc]$mediaplayer.year[/fnc], [fnc]$mediaplayer.comment[/fnc],
+		[fnc]$mediaplayer.sampleRate[/fnc],
+		[fnc]$mediaplayer.bitRate[/fnc],
+		[fnc]$mediaplayer.position[/fnc]
 */
 
 MP_KVS_SIMPLE_INT_FUNCTION(length,length)
@@ -1039,12 +1113,13 @@ MP_KVS_SIMPLE_INT_FUNCTION(length,length)
 		for more details about how it works.[br]
 	@seealso:
 		[module:mediaplayer]media player module documentation[/module]
-		[fnc]$mediaplayer.mrl()[/fnc], [cmd]mediaplayer.playMrl[/cmd],
-		[cmd]mediaplayer.play[/cmd], [fnc]$mediaplayer.nowPlaying()[/fnc],
-		[fnc]$mediaplayer.artist()[/fnc], [fnc]$mediaplayer.artist()[/fnc],
-		[fnc]$mediaplayer.year()[/fnc], [fnc]$mediaplayer.comment()[/fnc],
-		[fnc]$mediaplayer.sampleRate()[/fnc], [fnc]$mediaplayer.length()[/fnc],
-		[fnc]$mediaplayer.bitRate()[/fnc], [fnc]$mediaplayer.channels()[/fnc]
+		[fnc]$mediaplayer.mrl[/fnc], [cmd]mediaplayer.playMrl[/cmd],
+		[cmd]mediaplayer.play[/cmd], [fnc]$mediaplayer.nowPlaying[/fnc],
+		[fnc]$mediaplayer.artist[/fnc], [fnc]$mediaplayer.artist[/fnc],
+		[fnc]$mediaplayer.year[/fnc], [fnc]$mediaplayer.comment[/fnc],
+		[fnc]$mediaplayer.sampleRate[/fnc],
+		[fnc]$mediaplayer.length[/fnc],
+		[fnc]$mediaplayer.bitRate[/fnc], [fnc]$mediaplayer.channels[/fnc]
 */
 
 MP_KVS_SIMPLE_INT_FUNCTION(position,position)
@@ -1151,7 +1226,6 @@ MP_KVS_SIMPLE_INT_FUNCTION(getPlayListPos,getPlayListPos)
 		for more details about how it works.[br]
 	@seealso:
 		[module:mediaplayer]media player module documentation[/module],
-		[cmd]
 */
 
 MP_KVS_SIMPLE_INT_FUNCTION(getListLength,getListLength)
@@ -1174,7 +1248,7 @@ MP_KVS_SIMPLE_INT_FUNCTION(getListLength,getListLength)
 	@seealso:
 		[module:mediaplayer]media player module documentation[/module],
 		[cmd]mediaplayer.setRepeat[/cmd], [cmd]mediaplayer.setShuffle[/cmd],
-		[fnc]mediaplayer.getShuffle[/cmd]
+		[fnc]$mediaplayer.getShuffle[/fnc]
 */
 
 MP_KVS_SIMPLE_INT_FUNCTION(getRepeat,getRepeat)
@@ -1197,7 +1271,7 @@ MP_KVS_SIMPLE_INT_FUNCTION(getRepeat,getRepeat)
 	@seealso:
 		[module:mediaplayer]media player module documentation[/module],
 		[cmd]mediaplayer.setShuffle[/cmd], [cmd]mediaplayer.setRepeat[/cmd],
-		[fnc]mediaplayer.getRepeat[/cmd]
+		[fnc]$mediaplayer.getRepeat[/fnc]
 */
 
 MP_KVS_SIMPLE_BOOL_FUNCTION(getShuffle,getShuffle)
@@ -1220,7 +1294,7 @@ MP_KVS_SIMPLE_BOOL_FUNCTION(getShuffle,getShuffle)
 	@seealso:
 		[module:mediaplayer]media player module documentation[/module],
 		[cmd]mediaplayer.setShuffle[/cmd], [cmd]mediaplayer.setRepeat[/cmd],
-		[fnc]mediaplayer.getRepeat[/cmd]
+		[fnc]$mediaplayer.getRepeat[/fnc]
 
 */
 
@@ -1315,7 +1389,7 @@ MP_KVS_COMMAND(setEqData)
 		for more details about how it works.[br]
 	@seealso:
 		[module:mediaplayer]media player module documentation[/module],
-		[fnc]$mediaplayer.mrl()[/fnc], [cmd]mediaplayer.play[/cmd]
+		[fnc]$mediaplayer.mrl[/fnc], [cmd]mediaplayer.play[/cmd]
 */
 
 MP_KVS_FUNCTION(localFile)
@@ -1335,6 +1409,23 @@ MP_KVS_FUNCTION(localFile)
 	return true;
 }
 
+MP_KVS_FUNCTION(amipEval)
+{
+	QString szMrl;
+
+	KVSM_PARAMETERS_BEGIN(c)
+		KVSM_PARAMETER("player",KVS_PT_STRING,0,szMrl)
+	KVSM_PARAMETERS_END(c)
+
+	MP_KVS_FAIL_ON_NO_INTERFACE
+	QString szRet = g_pMPInterface->amipEval(szMrl);
+	if(szRet.isEmpty())return true;
+
+	c->returnValue()->setString(szRet);
+
+	return true;
+}
+
 /*
 	@doc: mediaplayer.status
 	@type:
@@ -1396,7 +1487,7 @@ MP_KVS_FUNCTION(status)
 		the informations about the currently played media (in order to implement the nice /playing
 		scripts). The module has replaced the old mediaplayer module which after
 		years of development had developed some design flaws and needed a complete rewrite.
-		At the moment of writing the supported players are: xmms (unix), winamp (windows),
+		At the moment of writing the supported players are: xmms (unix), audacious (unix), winamp (windows),
 		amarok (kde) and juk (kde). You choose the player interface by either setting
 		the option in the settings dialog, by manually setting [cmd]option[/cmd] stringPreferredMediaPlayer
 		or by running [cmd]mediaplayer.detect[/cmd] that will guess the media player interface for you.[br]
@@ -1511,14 +1602,16 @@ MP_KVS_COMMAND(setShuffle)
 
 static bool mediaplayer_module_init( KviModule * m )
 {
-	g_pDescriptorList = new KviPtrList<KviMediaPlayerInterfaceDescriptor>;
+	g_pDescriptorList = new KviPointerList<KviMediaPlayerInterfaceDescriptor>;
 	g_pDescriptorList->setAutoDelete(true);
 
 #ifndef COMPILE_ON_WINDOWS
 	g_pDescriptorList->append(MP_CREATE_DESCRIPTOR(KviXmmsInterface));
+	g_pDescriptorList->append(MP_CREATE_DESCRIPTOR(KviAudaciousInterface));
 #endif
 
 #ifdef COMPILE_ON_WINDOWS
+	g_pDescriptorList->append(MP_CREATE_DESCRIPTOR(KviAmipInterface));
 	g_pDescriptorList->append(MP_CREATE_DESCRIPTOR(KviWinampInterface));
 #endif
 
@@ -1556,6 +1649,7 @@ static bool mediaplayer_module_init( KviModule * m )
 	MP_KVS_REGCMD(pause,"pause");
 	MP_KVS_REGCMD(detect,"detect");
 	MP_KVS_REGCMD(playMrl,"playMrl");
+	MP_KVS_REGCMD(amipExec,"amipExec");
 	MP_KVS_REGCMD(hide,"hide");
 	MP_KVS_REGCMD(show,"show");
 	MP_KVS_REGCMD(minimize,"minimize");
@@ -1585,6 +1679,7 @@ static bool mediaplayer_module_init( KviModule * m )
 	MP_KVS_REGFNC(player,"player");
 	MP_KVS_REGFNC(playerList,"playerList");
 	MP_KVS_REGFNC(localFile,"localFile");
+	MP_KVS_REGFNC(amipEval,"amipEval");
 	MP_KVS_REGFNC(channels,"channels");
 	MP_KVS_REGFNC(getListLength,"getListLength");
 	MP_KVS_REGFNC(getPlayListPos,"getPlayListPos");
@@ -1640,13 +1735,14 @@ static bool mediaplayer_module_ctrl(KviModule * m,const char * operation,void *
 
 
 KVIRC_MODULE(
-	"mpediaplayer",
-	"1.0.0",
-	"Copyright (C) 2001-2005 Szymon Stefanek (pragma at kvirc dot net), " \
+	"mediaplayer",
+	"1.1.0",
+	"Copyright (C) 2001-2007 Szymon Stefanek (pragma at kvirc dot net), " \
 		"Christoph Thielecke (crissi99 at gmx dot de)," \
 		"Tonino Imbesi (grifisx at barmes dot org)," \
-		"Alessandro Carbone (noldor at barmes dot org),", \
-		"Alexey Uzhva (wizard at opendoor dot ru)"
+		"Alessandro Carbone (noldor at barmes dot org)," \
+		"Alexey Uzhva (wizard at opendoor dot ru), " \
+		"Serge Baranov (sbaranov at gmail dot com)",
 	"Interface to various media players",
 	mediaplayer_module_init,
 	mediaplayer_module_can_unload,
