@@ -22,17 +22,19 @@
 
 #include "libkvimircimport.h"
 #include "kvi_module.h"
-//#include "kvi_uparser.h"
+
 #include "kvi_filedialog.h"
+#include "kvi_fileutils.h"
 #include "kvi_locale.h"
 #include "kvi_config.h"
 #include "kvi_app.h"
+#include "kvi_qstring.h"
 
 
 #include <qmessagebox.h>
 #include <qdir.h>
 #include <qpushbutton.h>
-#include <qvbox.h>
+#include "kvi_tal_vbox.h"
 
 KviMircServersIniImport * g_pMircServersIniImport = 0;
 KviRemoteMircServersIniImport * g_pRemoteMircServersIniImport = 0;
@@ -48,42 +50,42 @@ KviMircServersIniImport::~KviMircServersIniImport()
 	g_pMircServersIniImport = 0;
 }
 
-int KviMircServersIniImport::doImport(const char * filename)
+int KviMircServersIniImport::doImport(const QString& filename)
 {
-	KviConfig cfg(filename,KviConfig::Read);
+	KviConfig cfg(filename,KviConfig::Read,true);
 	int iCount = 0;
 	if(cfg.hasGroup("servers"))
 	{
 		cfg.setGroup("servers");
 		int i = 0;
-		KviStr key;
-		KviStr entry;
+		QString key;
+		QString entry;
 		do {
-			key.sprintf("n%d",i);
-			entry = cfg.readEntry(key.ptr(),"");
-			if(entry.hasData())
+			KviQString::sprintf(key,"n%d",i);
+			entry = cfg.readEntry(key,"");
+			if(!entry.isEmpty())
 			{
-				KviStr description;
-				KviStr serv;
-				KviStr port;
+				QString description;
+				QString serv;
+				QString port;
 				kvi_u32_t uPort = 0;
 				// <description>SERVER:<server:port>GROUP:<network>
-				int idx = entry.findFirstIdx("SERVER:");
+				int idx = KviQString::find(entry,"SERVER:");
 				if(idx != -1)
 				{
 					description = entry.left(idx);
-					entry.cutLeft(idx + 7);
-					idx = entry.findFirstIdx("GROUP:");
+					entry.remove(0,idx + 7);
+					idx = KviQString::find(entry,"GROUP:");
 					if(idx != -1)
 					{
 						port = entry.left(idx);
-						entry.cutLeft(idx + 6);
+						entry.remove(0,idx + 6);
 					}
-					idx = port.findFirstIdx(':');
+					idx = KviQString::find(port,':');
 					if(idx != -1)
 					{
 						serv = port.left(idx);
-						port.cutLeft(idx + 1);
+						port.remove(0,idx + 1);
 						bool bOk;
 						uPort = port.toUInt(&bOk);
 						if(!bOk)uPort = 6667;
@@ -93,21 +95,22 @@ int KviMircServersIniImport::doImport(const char * filename)
 					}
 				}
 				if(entry.isEmpty())entry = __tr("Standalone Servers");
-				if(serv.hasData())
+				if(!serv.isEmpty())
 				{
 					KviIrcServer s;
 					s.m_szHostname = serv;
 					s.m_szDescription = description;
 					s.m_uPort = uPort;
 					iCount++;
-					emit server(s,entry.ptr());
+					emit server(s,entry);
 				}
 				++i;
 			}
-		} while(entry.hasData());
+		} while(!entry.isEmpty());
 	} else {
-		KviStr tmp(KviStr::Format,__tr("%s doesn't look like a servers.ini file.\nImport failed."),filename);
-		QMessageBox::warning(0,__tr2qs("Warning - KVIrc"),__tr2qs(tmp.ptr()));
+		QString tmp;
+		KviQString::sprintf(tmp,__tr2qs("%Q doesn't look like a servers.ini file.\nImport failed."),&filename);
+		QMessageBox::warning(0,__tr2qs("Warning - KVIrc"),tmp);
 	}
 	return iCount;
 }
@@ -138,7 +141,7 @@ void KviMircServersIniImport::die()
 
 
 KviRemoteMircServerImportWizard::KviRemoteMircServerImportWizard(KviRemoteMircServersIniImport * f)
-: QWizard(0)
+: KviTalWizard(0)
 {
 	QString capt = __tr2qs("Remote mIRC servers.ini Import Wizard");
 	setCaption(capt);
@@ -153,7 +156,7 @@ KviRemoteMircServerImportWizard::KviRemoteMircServerImportWizard(KviRemoteMircSe
 	addPage(l,capt);
 
 
-	QVBox * vb = new QVBox(this);
+	KviTalVBox * vb = new KviTalVBox(this);
 	l = new QLabel(vb);
 	l->setText(__tr2qs("<center>Here you can modify the URL that the list will be downloaded from. In most cases the default URL is acceptable.</center>"));
 
@@ -165,7 +168,7 @@ KviRemoteMircServerImportWizard::KviRemoteMircServerImportWizard(KviRemoteMircSe
 
 	addPage(vb,__tr2qs("URL Selection"));
 
-	vb = new QVBox(this);
+	vb = new KviTalVBox(this);
 
 	l = new QLabel(__tr2qs("Please wait while the list is being downloaded"),vb);
 	vb->setStretchFactor(l,1);
@@ -208,7 +211,7 @@ void KviRemoteMircServerImportWizard::done(int r)
 
 void KviRemoteMircServerImportWizard::start()
 {
-	KviStr url = m_pUrlEdit->text();
+	QString url = m_pUrlEdit->text();
 	if(url.isEmpty())url = KVI_WWWMIRCCOUK_SERVERSINI;
 
 	finishButton()->setEnabled(false);
@@ -216,10 +219,10 @@ void KviRemoteMircServerImportWizard::start()
 
 	m_pRequest = new KviHttpRequest();
 	connect(m_pRequest,SIGNAL(terminated(bool)),this,SLOT(getListTerminated(bool)));
-	connect(m_pRequest,SIGNAL(status(const char *)),this,SLOT(getListMessage(const char *)));
+	connect(m_pRequest,SIGNAL(status(const QString &)),this,SLOT(getListMessage(const QString &)));
 
 	g_pApp->getTmpFileName(m_szTmpFileName,"servers.ini");
-	if(!m_pRequest->get(KviUrl(url.ptr()),KviHttpRequest::StoreToFile,m_szTmpFileName.ptr()))
+	if(!m_pRequest->get(KviUrl(url),KviHttpRequest::StoreToFile,m_szTmpFileName))
 	{
 		delete m_pRequest;
 		m_pRequest = 0;
@@ -228,9 +231,9 @@ void KviRemoteMircServerImportWizard::start()
 	}
 }
 
-void KviRemoteMircServerImportWizard::getListMessage(const char * message)
+void KviRemoteMircServerImportWizard::getListMessage(const QString &message)
 {
-	if(message)m_pOutput->setText(message);
+	if(!message.isEmpty())m_pOutput->setText(message);
 }
 
 
@@ -245,7 +248,7 @@ void KviRemoteMircServerImportWizard::getListTerminated(bool bSuccess)
 		g_pApp->syncX();
 #endif //!COMPILE_ON_WINDOWS
 
-		int iCount = m_pFilter->doImport(m_szTmpFileName.ptr());
+		int iCount = m_pFilter->doImport(m_szTmpFileName);
 
 		QString tmp;
 		if(iCount > 0)
@@ -255,7 +258,7 @@ void KviRemoteMircServerImportWizard::getListTerminated(bool bSuccess)
 		m_pOutput->setText(tmp);
 
 		QDir d;
-		d.remove(QString(m_szTmpFileName.ptr()));
+		d.remove(m_szTmpFileName);
 	} else m_pOutput->setText(m_pRequest->lastError());
 
 	delete m_pRequest;
@@ -306,12 +309,11 @@ static KviModuleExtension * mircimport_remote_filter_alloc(KviModuleExtensionAll
 
 static bool mircimport_module_init(KviModule * m)
 {
-
-	KviStr szPath;
+	QString szPath;
 	QPixmap * pix = 0;
 	if(g_pApp->findImage(szPath,"kvi_mircimport.png"))
 	{
-		pix = new QPixmap(szPath.ptr());
+		pix = new QPixmap(szPath);
 		if(pix->isNull())
 		{
 			delete pix;
@@ -341,8 +343,8 @@ static bool mircimport_module_cleanup(KviModule *m)
 {
 	if(g_pMircServersIniImport)delete g_pMircServersIniImport;
 	if(g_pRemoteMircServersIniImport)delete g_pRemoteMircServersIniImport;
-    g_pMircServersIniImport = 0;
-    g_pRemoteMircServersIniImport = 0;
+	g_pMircServersIniImport = 0;
+	g_pRemoteMircServersIniImport = 0;
 
 	return true;
 }
@@ -367,6 +369,8 @@ KVIMODULEEXPORTFUNC KviIrcServerImport * mircimport_module_createIrcServerImport
 }
 */
 
+
+
 KVIRC_MODULE(
 	"File",                                                 // module name
 	"1.0.0",                                                // module version
