@@ -21,14 +21,15 @@
 //
 
 #include "kvi_module.h"
-//#include "kvi_uparser.h"
+
 #include "kvi_console.h"
-#include "kvi_command.h"
+
 #include "kvi_app.h"
 #include "kvi_locale.h"
 #include "kvi_ircconnection.h"
 #include "kvi_ircconnectionuserinfo.h"
 #include "kvi_ircconnectionserverinfo.h"
+#include "kvi_ircserver.h"
 #include "idle.h"
 Idle* g_pIdle;
 #ifdef COMPILE_NEW_KVS
@@ -69,7 +70,7 @@ Idle* g_pIdle;
 
 
 static bool my_kvs_fnc_nick(KviKvsModuleFunctionCall * c)
-{ 
+{
 	GET_KVS_CONSOLE
 	if(wnd)
 	{
@@ -94,7 +95,7 @@ static bool my_kvs_fnc_nick(KviKvsModuleFunctionCall * c)
 */
 
 static bool my_kvs_cmd_startIdleTimer(KviKvsModuleCommandCall * c)
-{ 
+{
 	if(!g_pIdle)
 		g_pIdle = new Idle();
 	g_pIdle->start();
@@ -116,10 +117,10 @@ static bool my_kvs_cmd_startIdleTimer(KviKvsModuleCommandCall * c)
 */
 
 static bool my_kvs_cmd_stopIdleTimer(KviKvsModuleCommandCall * c)
-{ 
+{
 	if(!g_pIdle) return true;
 	g_pIdle->stop();
-	delete g_pIdle;
+	//delete g_pIdle;
 	return true;
 }
 
@@ -166,7 +167,7 @@ static bool my_kvs_fnc_globalIdle(KviKvsModuleFunctionCall * c)
 */
 
 static bool my_kvs_fnc_umode(KviKvsModuleFunctionCall * c)
-{ 
+{
 	GET_KVS_CONSOLE
 	if(wnd)
 	{
@@ -194,7 +195,7 @@ static bool my_kvs_fnc_umode(KviKvsModuleFunctionCall * c)
 */
 
 static bool my_kvs_fnc_user(KviKvsModuleFunctionCall * c)
-{ 
+{
 	GET_KVS_CONSOLE
 	if(wnd)
 	{
@@ -223,7 +224,7 @@ static bool my_kvs_fnc_user(KviKvsModuleFunctionCall * c)
 
 
 static bool my_kvs_fnc_host(KviKvsModuleFunctionCall * c)
-{ 
+{
 	GET_KVS_CONSOLE
 	if(wnd)
 	{
@@ -255,7 +256,7 @@ static bool my_kvs_fnc_host(KviKvsModuleFunctionCall * c)
 
 
 static bool my_kvs_fnc_ip(KviKvsModuleFunctionCall * c)
-{ 
+{
 	GET_KVS_CONSOLE
 	if(wnd)
 	{
@@ -265,6 +266,65 @@ static bool my_kvs_fnc_ip(KviKvsModuleFunctionCall * c)
 	return true;
 }
 
+/*
+	@doc: my.serverIsIPV6
+	@type:
+		function
+	@title:
+		$my.serverIsSSL
+	@short:
+		Returns 1 if the current server connection use IPV6.
+	@syntax:
+		<boolean> $my.serverIsIPV6([irc_context_id:uint])
+	@description:
+		Returns 1 if the server connection use IPV6.[br]
+		If the irc context is not connected then an empty string is returned.[br]
+		If <irc_context_id> is specified this function returns acts as it was called
+		in that irc_context.[br]
+*/
+
+static bool my_kvs_fnc_serverIsIPV6(KviKvsModuleFunctionCall * c)
+{
+	
+	GET_KVS_CONSOLE
+	if(wnd)
+	{
+		if(wnd->connection())
+			c->returnValue()->setBoolean(wnd->connection()->server()->isIpV6());
+	}
+	return true;
+}
+
+
+/*
+	@doc: my.serverIsSSL
+	@type:
+		function
+	@title:
+		$my.serverIsSSL
+	@short:
+		Returns 1 if the current server connection use SSL.
+	@syntax:
+		<boolean> $my.serverIsSSL([irc_context_id:uint])
+	@description:
+		Returns 1 if the server connection use SSL.[br]
+		If the irc context is not connected then an empty string is returned.[br]
+		If <irc_context_id> is specified this function returns acts as it was called
+		in that irc_context.[br]
+*/
+
+static bool my_kvs_fnc_serverIsSSL(KviKvsModuleFunctionCall * c)
+{
+	
+	GET_KVS_CONSOLE
+	if(wnd)
+	{
+		if(wnd->connection())
+			c->returnValue()->setBoolean(wnd->connection()->socket()->usingSSL());
+	}
+	return true;
+}
+
 /*
 	@doc: my.server
 	@type:
@@ -280,10 +340,14 @@ static bool my_kvs_fnc_ip(KviKvsModuleFunctionCall * c)
 		If the irc context is not connected then an empty string is returned.[br]
 		If <irc_context_id> is specified this function returns acts as it was called
 		in that irc_context.[br]
+		Please note that this function returns the name of the server as reported
+		by the server itself. Some servers report a bogus value for this field.
+		You should take a look at $context.serverIpAddress or $context.serverHostName
+		if you want a value that can be used to really reconnect to this server.
 */
 
 static bool my_kvs_fnc_server(KviKvsModuleFunctionCall * c)
-{ 
+{
 	GET_KVS_CONSOLE
 	if(wnd)
 	{
@@ -311,7 +375,7 @@ static bool my_kvs_fnc_server(KviKvsModuleFunctionCall * c)
 */
 
 static bool my_kvs_fnc_network(KviKvsModuleFunctionCall * c)
-{ 
+{
 	GET_KVS_CONSOLE
 	if(wnd)
 	{
@@ -320,6 +384,7 @@ static bool my_kvs_fnc_network(KviKvsModuleFunctionCall * c)
 	}
 	return true;
 }
+
 static bool my_module_init(KviModule * m)
 {
 	g_pIdle = 0;
@@ -330,8 +395,9 @@ static bool my_module_init(KviModule * m)
 	KVSM_REGISTER_FUNCTION(m,"server",my_kvs_fnc_server);
 	KVSM_REGISTER_FUNCTION(m,"network",my_kvs_fnc_network);
 	KVSM_REGISTER_FUNCTION(m,"umode",my_kvs_fnc_umode);
-	KVSM_REGISTER_FUNCTION(m,"globalIdle",my_kvs_fnc_globalIdle);
-	
+	KVSM_REGISTER_FUNCTION(m,"serverIsSSL",my_kvs_fnc_serverIsSSL);
+	KVSM_REGISTER_FUNCTION(m,"serverIsIPV6",my_kvs_fnc_serverIsIPV6);
+
 	KVSM_REGISTER_SIMPLE_COMMAND(m,"stopIdleTimer",my_kvs_cmd_stopIdleTimer);
 	KVSM_REGISTER_SIMPLE_COMMAND(m,"startIdleTimer",my_kvs_cmd_startIdleTimer);
 	return true;
