@@ -29,7 +29,7 @@
 #include "kvi_config.h"
 #include "kvi_app.h"
 #include "kvi_window.h"
-//#include "kvi_uparser.h"
+
 #include "kvi_locale.h"
 #include "kvi_frame.h"
 #include "kvi_mirccntrl.h"
@@ -45,13 +45,18 @@
 #endif
 */
 
-#include <qpopupmenu.h>
 #include <qapplication.h>
 #include <qpainter.h>
 #include <qimage.h>
 #include <qdesktopwidget.h>
 #include <qtooltip.h>
 
+#ifdef COMPILE_USE_QT4
+	#define QPopupMenu Q3PopupMenu
+	#include <q3popupmenu.h>
+#else
+	#include <qpopupmenu.h>
+#endif
 
 extern kvi_time_t g_tNotifierDisabledUntil;
 
