@@ -21,6 +21,20 @@
 //   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 //
 //==================================================================================
+#include "kvi_settings.h"
+
+#ifdef COMPILE_USE_QT4
+	#define QPopupMenu Q3PopupMenu
+	#define QSimpleRichText Q3SimpleRichText
+
+	#include <q3popupmenu.h>
+	#include <q3simplerichtext.h>
+#else
+	#include <qpopupmenu.h>
+	#include <qsimplerichtext.h>
+#endif
+
+	#include <qpainter.h>
 
 #include "notifiermessage.h"
 #include "notifierwindow.h"
@@ -29,28 +43,26 @@
 #include "kvi_config.h"
 #include "kvi_app.h"
 #include "kvi_window.h"
-//#include "kvi_uparser.h"
+
 #include "kvi_locale.h"
 #include "kvi_frame.h"
 #include "kvi_mirccntrl.h"
 #include "kvi_options.h"
 #include "kvi_userinput.h"
 
-#include <qpopupmenu.h>
 #include <qapplication.h>
-#include <qpainter.h>
 #include <qimage.h>
 #include <qdesktopwidget.h>
 #include <qtooltip.h>
 #include <qevent.h>
-#include <qpainter.h>
 #include <qpen.h>
-#include <qfontmetrics.h> 
+#include <qfontmetrics.h>    
 #include <qregexp.h> 
 
-#include "notifierwindowtabs.h"
 #include "notifierwindowbody.h"
 #include "notifierwindowborder.h"
+#include "notifierwindowprogressbar.h"
+#include "notifierwindowtabs.h"
 
 extern KviNotifierWindow * g_pNotifierWindow;
 
@@ -114,8 +126,12 @@ KviNotifierWindow::KviNotifierWindow()
 	m_iInputHeight = cfg.readIntEntry("InputHeight",20);
 	if(m_iInputHeight < 10)m_iInputHeight = 10;
 
-	setBackgroundMode(QWidget::NoBackground);
+	setBackgroundMode(Qt::NoBackground);
+#ifdef COMPILE_USE_QT4
+	setFocusPolicy(Qt::NoFocus);
+#else
 	setFocusPolicy(QWidget::NoFocus);
+#endif
 	setMouseTracking(true);
 	//setCursor(m_cursor);
 	
@@ -302,20 +318,21 @@ void KviNotifierWindow::doShow(bool bDoAnimate)
 		case Hidden:
 			stopShowHideTimer();
 			stopBlinkTimer();
-			computeRect();
+		
 			m_bDragging = false;
 			m_bCloseDown = false;
 			m_bPrevDown = false;
 			m_bNextDown = false;
 			m_bWriteDown = false;
 			m_bBlinkOn = false;
+		#if (!defined COMPILE_USE_QT4) || !(defined(COMPILE_USE_QT4) && (defined(COMPILE_ON_WINDOWS) || defined(Q_OS_MACX)))
 			m_imgDesktop = QPixmap::grabWindow(
 						QApplication::desktop()->winId(),
 						m_wndRect.x(),
 						m_wndRect.y(),
 						m_wndRect.width(),
 						m_wndRect.height()).convertToImage();
-						
+		#endif
 			// QPixmap tmp = QPixmap::grabWindow( QApplication::desktop()->winId(),m_wndRect.x(), m_wndRect.y(), m_wndRect.width(), m_wndRect.height());
 			// tmp.save("/root/pix.png","PNG");
 			m_pixForeground.resize(m_pixBackground.size());
@@ -326,8 +343,20 @@ void KviNotifierWindow::doShow(bool bDoAnimate)
 				connect(m_pShowHideTimer,SIGNAL(timeout()),this,SLOT(heartbeat()));
 				m_dOpacity = OPACITY_STEP;
 				m_eState = Showing;
+				m_bCrashShowWorkAround=true;
+				#if defined(COMPILE_USE_QT4) && (defined(COMPILE_ON_WINDOWS) || defined(Q_OS_MACX)) 
+				setWindowOpacity(m_dOpacity);
+				#endif	
 				show();
+				#if defined(COMPILE_USE_QT4) && (defined(COMPILE_ON_WINDOWS) || defined(Q_OS_MACX)) 
+				m_pShowHideTimer->start(40);
+				#else
 				m_pShowHideTimer->start(100);
+				#endif
+				computeRect();
+				m_bCrashShowWorkAround=false;
+				//show();
+
 			} else {
 				m_dOpacity = 1.0;
 				m_eState = Visible;
@@ -350,7 +379,10 @@ bool KviNotifierWindow::shouldHideIfMainWindowGotAttention()
 
 
 void KviNotifierWindow::heartbeat()
+
 {
+	bool bIncreasing;
+	double targetOpacity = 0; //qt4
 	switch(m_eState)
 	{
 		case Hidden:
@@ -369,21 +401,74 @@ void KviNotifierWindow::heartbeat()
 				m_eState = Hiding;
 			} else {
 				m_dOpacity += OPACITY_STEP;
+#ifdef COMPILE_USE_QT4
+				targetOpacity = isActiveWindow() ? KVI_OPTION_UINT(KviOption_uintNotifierActiveTransparency) : KVI_OPTION_UINT(KviOption_uintNotifierInactiveTransparency);
+
+				targetOpacity/=100;
+				if(m_dOpacity >= targetOpacity)
+				{
+					m_dOpacity = targetOpacity;
+#else
 				if(m_dOpacity >= 1.0)
 				{
 					m_dOpacity = 1.0;
+#endif
 					m_eState = Visible;
 					stopShowHideTimer();
 					startBlinking();
 					startAutoHideTimer();
 				}
+
 				if(!isVisible())show(); //!!!
 				if(m_pLineEdit->isVisible())m_pLineEdit->hide();
+				#if defined(COMPILE_USE_QT4) && (defined(COMPILE_ON_WINDOWS) || defined(Q_OS_MACX)) 
+				setWindowOpacity(m_dOpacity);
+				#endif
 				update();
+
 			}
 		break;
+#ifdef COMPILE_USE_QT4
+		case FocusingOn:
+			targetOpacity = KVI_OPTION_UINT(KviOption_uintNotifierActiveTransparency);
+			targetOpacity/=100;
+			bIncreasing = targetOpacity>m_dOpacity;
+			m_dOpacity += bIncreasing?
+				OPACITY_STEP : -(OPACITY_STEP);
+			if( (bIncreasing && (m_dOpacity >= targetOpacity) ) ||
+				(!bIncreasing && (m_dOpacity <= targetOpacity) )
+				)
+			{
+				m_dOpacity = targetOpacity;
+				m_eState = Visible;
+				stopShowHideTimer();
+			}
+
+			setWindowOpacity(m_dOpacity);
+			break;
+		case FocusingOff:
+			targetOpacity = KVI_OPTION_UINT(KviOption_uintNotifierInactiveTransparency);
+			targetOpacity/=100;
+			bIncreasing = targetOpacity>m_dOpacity;
+			m_dOpacity += bIncreasing ? OPACITY_STEP : -(OPACITY_STEP);
+			//debug("%f %f %i %i",m_dOpacity,targetOpacity,bIncreasing,(m_dOpacity >= targetOpacity));
+			if( (bIncreasing && (m_dOpacity >= targetOpacity) ) ||
+				(!bIncreasing && (m_dOpacity <= targetOpacity) )
+				)
+			{
+				m_dOpacity = targetOpacity;
+				m_eState = Visible;
+				stopShowHideTimer();
+			}
+
+			setWindowOpacity(m_dOpacity);
+			break;
+#endif
 		case Hiding:
 			m_dOpacity -= OPACITY_STEP;
+			#if defined(COMPILE_USE_QT4) && (defined(COMPILE_ON_WINDOWS) || defined(Q_OS_MACX)) 
+				setWindowOpacity(m_dOpacity);
+			#endif
 			if(m_pLineEdit->isVisible())m_pLineEdit->hide();
 			if(m_dOpacity <= 0.0)hideNow();
 			else update();
@@ -407,7 +492,6 @@ void KviNotifierWindow::hideNow()
 void KviNotifierWindow::doHide(bool bDoAnimate)
 {
 	stopAutoHideTimer();
-
 	switch(m_eState)
 	{
 	case Hiding:
@@ -434,17 +518,28 @@ void KviNotifierWindow::doHide(bool bDoAnimate)
 		if(m_pLineEdit->isVisible())m_pLineEdit->hide();
 		if((!bDoAnimate) || (x() != m_pWndBorder->x()) || (y() != m_pWndBorder->y()))
 		{
+
+			//debug ("just hide quickly with notifier x() %d and notifier y() % - WBorderx() %d and WBordery() %d and bDoanimate %d",x(),y(),m_pWndBorder->x(),m_pWndBorder->y(),bDoAnimate);
 			// the user asked to not animate or
 			// the window has been moved and the animation would suck anyway
 			// just hide quickly
 			hideNow();
 		} else {
+			//debug ("starting hide animation notifier x() %d and notifier y() % - WBorderx() %d and WBordery() %d and bDoanimate %d",x(),y(),m_pWndBorder->x(),m_pWndBorder->y(),bDoAnimate);
 			m_pShowHideTimer = new QTimer();
 			connect(m_pShowHideTimer,SIGNAL(timeout()),this,SLOT(heartbeat()));
 			m_dOpacity = 1.0 - OPACITY_STEP;
 			m_eState = Hiding;
+			#if defined(COMPILE_USE_QT4) && (defined(COMPILE_ON_WINDOWS) || defined(Q_OS_MACX)) 
+			setWindowOpacity(m_dOpacity);
 			update();
+			m_pShowHideTimer->start(40);
+			#else
+			update();		
 			m_pShowHideTimer->start(100);
+			#endif
+			
+
 		}
 		break;
 	}
@@ -454,10 +549,12 @@ void KviNotifierWindow::showEvent(QShowEvent *e)
 {
 	computeRect();
 	setGeometry(m_wndRect); // w_win = w_wndRect
+	
 }
 
 void KviNotifierWindow::hideEvent(QHideEvent * e)
 {
+	if (m_bCrashShowWorkAround) return;
 	stopBlinkTimer();
 	stopShowHideTimer();
 	stopAutoHideTimer();
@@ -471,6 +568,8 @@ void KviNotifierWindow::startBlinking()
 {
 	stopBlinkTimer();
 	m_bBlinkOn = false;
+	
+
 	if(!KVI_OPTION_BOOL(KviOption_boolDisableNotifierFlashing))
 	{
 		m_pBlinkTimer = new QTimer();
@@ -529,6 +628,7 @@ void KviNotifierWindow::blink()
 
 void KviNotifierWindow::markAllMessagesAsHistoric()
 {
+	if (!m_pWndTabs) return;
 	m_pWndTabs->markAllMessagesAsHistoric();
 }
 
@@ -570,20 +670,27 @@ void KviNotifierWindow::paintEvent(QPaintEvent * e)
 
 	QPainter p(&m_pixForeground);
 */
-
 	redrawWindow();
 	redrawText();
-	
 	if(m_dOpacity < 1.0)
 	{
-		QPainter px(this);
+			QPainter px(this);
+	
+	#if defined(COMPILE_USE_QT4) && (defined(COMPILE_ON_WINDOWS) || defined(Q_OS_MACX))
+		px.drawPixmap(0,0,m_pixForeground);
+	#else
 		QImage temp_image = m_pixForeground.convertToImage();
 		blend_images(m_imgBuffer,m_imgDesktop,temp_image,m_dOpacity);
 		px.drawImage(0,0,m_imgBuffer);
+	#endif
 		px.end();
 	} else {
-		//px.drawPixmap(0,0,m_pixForeground);
+#ifdef COMPILE_USE_QT4
+		QPainter px(this);
+		px.drawPixmap(0,0,m_pixForeground);
+#else
 		bitBlt(this,QPoint(0,0),&m_pixForeground);
+#endif
 	}
 }
 
@@ -596,7 +703,7 @@ void KviNotifierWindow::redrawText()
 	if(!tab)return;
 	
 	// it's message list
-	KviPtrList<KviNotifierMessage> * l = tab->messageList();
+	KviPointerList<KviNotifierMessage> * l = tab->messageList();
 	if(!l)return;
 	if(l->isEmpty())return;
 	
@@ -750,11 +857,11 @@ void KviNotifierWindow::mousePressEvent(QMouseEvent * e)
 
 	m_pntClick = e->pos();
 
-	if(e->button() == RightButton)
+	if(e->button() == Qt::RightButton)
 	{
 		contextPopup(mapToGlobal(e->pos()));
 		return;
-	} else if(e->button() == LeftButton) {
+	} else if(e->button() == Qt::LeftButton) {
 		m_bLeftButtonIsPressed = true;
 	}
 
@@ -843,6 +950,7 @@ void KviNotifierWindow::mouseReleaseEvent(QMouseEvent * e)
 	if(m_pWndBorder->captionRect().contains(e->pos())) {
 	
 		if(m_pWndBorder->closeRect().contains(e->pos())) {
+			//debug ("hide now from release event");
 			hideNow();
 		} else {
 			update();
@@ -922,7 +1030,7 @@ void KviNotifierWindow::delayedRaiseSlot()
 			m_pWindowToRaise->frame()->show();
 
 		m_pWindowToRaise->frame()->raise();
-		((QWidget *)(m_pWindowToRaise->frame()))->setActiveWindow();
+		//((QWidget *)(m_pWindowToRaise->frame()))->setActiveWindow();
 		m_pWindowToRaise->frame()->setFocus();
 	}
 
@@ -1008,31 +1116,31 @@ void KviNotifierWindow::resize(QPoint p, bool up)
 	//QPoint aux = mapToGlobal(p);
 
 	if (m_whereResizing==WDG_UPSX || m_whereResizing==WDG_SX || m_whereResizing==WDG_DWNSX) {
-		if ( x()+width()-cursor().pos().x()<WDG_MIN_WIDTH )
-			m_wndRect.setLeft(x()+width()-WDG_MIN_WIDTH);
+		if ((x() + width() - cursor().pos().x()) < WDG_MIN_WIDTH)
+			m_wndRect.setLeft(x() + width() - WDG_MIN_WIDTH);
 		else
 			m_wndRect.setLeft(cursor().pos().x());
 	}
 	
-	if (m_whereResizing==WDG_UPSX || m_whereResizing==WDG_UP || m_whereResizing==WDG_UPDX) {
-		if ( y()+height()-cursor().pos().y()<WDG_MIN_HEIGHT )
-			m_wndRect.setTop(y()+height()-WDG_MIN_HEIGHT);
+	if (m_whereResizing == WDG_UPSX || m_whereResizing == WDG_UP || m_whereResizing == WDG_UPDX) {
+		if (y()+height()-cursor().pos().y() < WDG_MIN_HEIGHT)
+			m_wndRect.setTop(y() + height() - WDG_MIN_HEIGHT);
 		else
 			m_wndRect.setTop(cursor().pos().y());
 	}
 
-	if (m_whereResizing==WDG_DX || m_whereResizing==WDG_UPDX || m_whereResizing==WDG_DWNDX) {
-		if ( cursor().pos().x()-x()>WDG_MIN_WIDTH )
+	if (m_whereResizing == WDG_DX || m_whereResizing == WDG_UPDX || m_whereResizing == WDG_DWNDX) {
+		if ((cursor().pos().x() - x()) > WDG_MIN_WIDTH)
 			m_wndRect.setRight(cursor().pos().x());
 		else
-			m_wndRect.setRight(x()+WDG_MIN_WIDTH);
+			m_wndRect.setRight(x() + WDG_MIN_WIDTH);
 	}
 
-	if (m_whereResizing==WDG_DWN || m_whereResizing==WDG_DWNDX || m_whereResizing==WDG_DWNSX) {
-		if ( cursor().pos().y()-y()>WDG_MIN_HEIGHT )
+	if (m_whereResizing == WDG_DWN || m_whereResizing == WDG_DWNDX || m_whereResizing == WDG_DWNSX) {
+		if ((cursor().pos().y() - y()) > WDG_MIN_HEIGHT)
 			m_wndRect.setBottom(cursor().pos().y());
 		else
-			m_wndRect.setBottom(y()+WDG_MIN_HEIGHT);
+			m_wndRect.setBottom(y() + WDG_MIN_HEIGHT);
 	}
 
 	showLineEdit(m_pLineEdit->isVisible());
@@ -1051,6 +1159,7 @@ void KviNotifierWindow::redrawWindow()
 		m_pWndBorder->resize( m_wndRect.size() );
 		m_pWndTabs->setWidth( m_pWndBorder->tabsRect().width() );
 		m_pWndBody->resize( m_pWndBorder->bodyRect() );
+		m_pProgressBar->setHeight(m_pWndBorder->bodyRect().height() + m_pWndBorder->tabsRect().height());
 	}
 	
 	QPainter paint;
@@ -1082,14 +1191,26 @@ void KviNotifierWindow::redrawWindow()
 }
 
 inline void KviNotifierWindow::setCursor(int cur) {
-	if (m_cursor.shape()!=cur) {
+	if (m_cursor.shape() != cur) {
 		if(QApplication::overrideCursor()) QApplication::restoreOverrideCursor();
-		m_cursor.setShape(cur);
+		m_cursor.setShape((Qt::CursorShape)cur);
 		QApplication::setOverrideCursor(m_cursor);
 	} else if (cur==-1)
 		if(QApplication::overrideCursor()) QApplication::restoreOverrideCursor();
 }
 
+void KviNotifierWindow::enterEvent(QEvent * e)
+{
+#ifdef COMPILE_USE_QT4
+	if(!m_pShowHideTimer) {
+		m_pShowHideTimer = new QTimer();
+		connect(m_pShowHideTimer,SIGNAL(timeout()),this,SLOT(heartbeat()));
+	}
+	m_eState = FocusingOn;
+	m_pShowHideTimer->start(40);
+#endif
+}
+
 void KviNotifierWindow::leaveEvent(QEvent * e)
 {
 	// Leaving the widget area, restore default cursor
@@ -1097,6 +1218,14 @@ void KviNotifierWindow::leaveEvent(QEvent * e)
 	m_pWndTabs->resetIcons();
 	if (!m_bResizing)
 		setCursor(-1);
+#ifdef COMPILE_USE_QT4
+	if(!m_pShowHideTimer) {
+		m_pShowHideTimer = new QTimer();
+		connect(m_pShowHideTimer,SIGNAL(timeout()),this,SLOT(heartbeat()));
+	}
+	m_eState = FocusingOff;
+	m_pShowHideTimer->start(40);
+#endif
 }
 
 void KviNotifierWindow::contextPopup(const QPoint &pos)
