@@ -26,21 +26,20 @@
 
 #include "kvi_settings.h"
 
-#include <qwidget.h>
+#include <qbitmap.h>
+#include <qcolor.h>
+#include <qcursor.h>
+#include <qdatetime.h> 
+#include <qfont.h>
+#include <qimage.h>
+#include <qlineedit.h>
+#include <qpixmap.h>
 #include <qrect.h>
 #include <qtimer.h>
-#include <qpixmap.h>
-#include <qimage.h>
-#include <qsimplerichtext.h>
-#include <qfont.h>
-#include <qcolor.h>
-#include <qlineedit.h>
-#include <qcursor.h>
-#include <qbitmap.h>
-#include <qdatetime.h> 
+#include <qwidget.h>
 
 #include "kvi_qstring.h"
-#include "kvi_list.h"
+#include "kvi_pointerlist.h"
 #include "kvi_time.h"
 
 #include "notifiersettings.h"
@@ -48,11 +47,12 @@
 class KviWindow;
 class KviNotifierMessage;
 
-class KviNotifierWindowTabs;
 class KviNotifierWindowBody;
 class KviNotifierWindowBorder;
 class KviNotifierWindowProgressBar;
+class KviNotifierWindowTabs;
 
+class QPainter;
 class QPopupMenu;
 
 extern kvi_time_t g_tNotifierDisabledUntil;
@@ -85,6 +85,7 @@ protected:
 	bool    m_bPrevDown;
 	bool    m_bNextDown;
 	bool    m_bWriteDown;
+	bool m_bCrashShowWorkAround;
 
 	bool	m_bKeyShiftPressed;
 
@@ -147,6 +148,7 @@ protected:
 	virtual void mouseReleaseEvent(QMouseEvent * e);
 	virtual void mouseMoveEvent(QMouseEvent * e);
 	virtual void leaveEvent(QEvent * e);
+	virtual void enterEvent(QEvent * e);
 	virtual void mouseDoubleClickEvent(QMouseEvent * e);
 	virtual void wheelEvent(QWheelEvent * e);
 	virtual bool eventFilter(QObject * pEdit,QEvent * e);
