@@ -23,11 +23,20 @@
 //=============================================================================
 
 #include "notifierwindowbody.h"
+
 #include "kvi_iconmanager.h"
 
-#include <qpainter.h>
 #include <qbrush.h>
 #include <qcolor.h>
+#include <qpainter.h>
+
+/*
+#ifdef QT3_SUPPORT
+	#include <Q3Painter>
+#else
+	#include <qpainter.h>
+#endif
+*/
 
 KviNotifierWindowBody::KviNotifierWindowBody(QRect r)
 {
@@ -187,18 +196,18 @@ void KviNotifierWindowBody::draw(QPainter * p) {
 		p->fillRect(QRect(m_pnt,m_rct.size()),m_mac_bkgColor);
 		
 		// Autotiled borders
-		p->drawTiledPixmap(m_pnt.x(), m_pnt.y(), m_pixSX.width(), m_rct.height()-m_pixDWNSX.height()-m_pixKVIrcSX.height(), m_pixSX);
-		p->drawTiledPixmap(m_pnt.x()+m_rct.width()-m_pixDX.width(), m_pnt.y(),m_pixDX.width(), m_rct.height()-m_pixDWNDX.height(), m_pixDX);
-		p->drawTiledPixmap(m_pnt.x()+m_pixKVIrcDWN.width()+m_pixDWNSX.width(), m_pnt.y()+m_rct.height()-m_pixDWN.height(),  m_rct.width()-m_pixKVIrcDWN.width()-m_pixDWNSX.width()-m_pixDWNDX.width(), m_pixDWN.height(), m_pixDWN);
+		p->drawTiledPixmap(m_pnt.x(), m_pnt.y(), m_pixSX.width(), m_rct.height() - m_pixDWNSX.height() - m_pixKVIrcSX.height(), m_pixSX);
+		p->drawTiledPixmap(m_pnt.x() + m_rct.width() - m_pixDX.width(), m_pnt.y(),m_pixDX.width(), m_rct.height() - m_pixDWNDX.height(), m_pixDX);
+		p->drawTiledPixmap(m_pnt.x() + m_pixKVIrcDWN.width() + m_pixDWNSX.width(), m_pnt.y() + m_rct.height() - m_pixDWN.height(),  m_rct.width() - m_pixKVIrcDWN.width() - m_pixDWNSX.width() - m_pixDWNDX.width(), m_pixDWN.height(), m_pixDWN);
 	
 		// Bottom corners
-		p->drawPixmap(m_pnt.x(), m_pnt.y()+m_rct.height()-m_pixDWNSX.height(), m_pixDWNSX);
-		p->drawPixmap(m_pnt.x()+m_rct.width()-m_pixDWNSX.width(), m_pnt.y()+m_rct.height()-m_pixDWNDX.height(), m_pixDWNDX);
+		p->drawPixmap(m_pnt.x(), m_pnt.y() + m_rct.height() - m_pixDWNSX.height(), m_pixDWNSX);
+		p->drawPixmap(m_pnt.x() + m_rct.width() - m_pixDWNSX.width(), m_pnt.y() + m_rct.height() - m_pixDWNDX.height(), m_pixDWNDX);
 		
 		// KVIrc image
-		p->drawPixmap(m_pnt.x(), m_pnt.y()+m_rct.height()-m_pixKVIrcSX.height()-m_pixDWNSX.height(), m_pixKVIrcSX);
-		p->drawPixmap(m_pnt.x()+m_pixKVIrcSX.width(), m_pnt.y()+m_rct.height()-m_pixKVIrcDWN.height(), m_pixKVIrcDWN);
-		p->drawPixmap(m_pnt.x()+m_pixKVIrcSX.width(), m_pnt.y()+m_rct.height()-m_pixKVIrc.height()-m_pixKVIrcDWN.height(), m_pixKVIrc, 0, 0);
+		p->drawPixmap(m_pnt.x(), m_pnt.y() + m_rct.height() - m_pixKVIrcSX.height() - m_pixDWNSX.height(), m_pixKVIrcSX);
+		p->drawPixmap(m_pnt.x() + m_pixKVIrcSX.width(), m_pnt.y() + m_rct.height() - m_pixKVIrcDWN.height(), m_pixKVIrcDWN);
+		p->drawPixmap(m_pnt.x() + m_pixKVIrcSX.width(), m_pnt.y() + m_rct.height() - m_pixKVIrc.height() - m_pixKVIrcDWN.height(), m_pixKVIrc, 0, 0, m_pixKVIrc.width(), m_pixKVIrc.height());
 		
 		// Draw Icons
 		p->drawPixmap(m_rctPrevIcon.x(), m_rctPrevIcon.y(), m_pixIconPrev);
@@ -221,29 +230,3 @@ void KviNotifierWindowBody::mousePressEvent(QMouseEvent * e) {
 void KviNotifierWindowBody::mouseReleaseEvent(QMouseEvent * e) {
 
 }
-
-KviNotifierWindowProgressBar::KviNotifierWindowProgressBar(QRect r)
-:m_rect(r)
-{
-
-}
-
-KviNotifierWindowProgressBar::~KviNotifierWindowProgressBar()
-{
-	m_dProgress=0;
-}
-
-void KviNotifierWindowProgressBar::draw(QPainter *p)
-{
-	p->fillRect(m_rect,QColor(236,233,216));
-	p->fillRect(
-		QRect(
-			m_rect.x()+1,
-			m_rect.y()+1+m_rect.height()*(1-m_dProgress),
-			m_rect.width()-2,
-			(m_rect.height()-2)*m_dProgress
-			),
-		QColor(175,28,95)
-		);
-	p->drawRect(m_rect);
-}
\ No newline at end of file
