@@ -31,6 +31,14 @@
 
 #include "notifiersettings.h"
 
+/*
+#ifdef QT3_SUPPORT
+	#define QPainter Q3Painter
+#endif
+*/
+
+class QPainter;
+
 class KviNotifierWindowBody
 {
 public:
@@ -136,16 +144,4 @@ protected:
 
 };
 
-class KviNotifierWindowProgressBar
-{
-public:
-	KviNotifierWindowProgressBar(QRect r);
-	~KviNotifierWindowProgressBar();
-protected:
-	QRect 	m_rect;
-	double	m_dProgress;
-public:
-	void setProgress(double progress) { m_dProgress=progress; };
-	void draw(QPainter *);
-};
 #endif //!_KVINOTIFIERWINDOWBODY_H_
