@@ -49,7 +49,7 @@ KviNotifierWindowTab::KviNotifierWindowTab(KviWindow * pWnd, QString label)
 {
 	m_pWnd = pWnd;
 	m_label = label;
-	m_pMessageList = new KviPtrList<KviNotifierMessage>;
+	m_pMessageList = new KviPointerList<KviNotifierMessage>;
 	m_pMessageList->setAutoDelete(true);
 	m_bFocused = false;
 	m_pCurrentMessage = 0;
@@ -77,7 +77,7 @@ KviNotifierWindowTab::~KviNotifierWindowTab()
 void KviNotifierWindowTab::setNextMessageAsCurrent()
 {
 	if(!m_pCurrentMessage)return;
-	m_pMessageList->findRef(m_pCurrentMessage);
+	if(m_pMessageList->findRef(m_pCurrentMessage) == -1)return;
 	m_pCurrentMessage = m_pMessageList->next();
 	if(!m_pCurrentMessage)m_pCurrentMessage = m_pMessageList->last();
 }
@@ -85,7 +85,7 @@ void KviNotifierWindowTab::setNextMessageAsCurrent()
 void KviNotifierWindowTab::setPrevMessageAsCurrent()
 {
 	if(!m_pCurrentMessage)return;
-	m_pMessageList->findRef(m_pCurrentMessage);
+	if(!m_pMessageList->findRef(m_pCurrentMessage) == -1)return;
 	m_pCurrentMessage = m_pMessageList->prev();
 	if(!m_pCurrentMessage)m_pCurrentMessage = m_pMessageList->first();
 }
@@ -185,7 +185,8 @@ KviNotifierWindowTabs::KviNotifierWindowTabs(QRect r)
 	m_pWndTabFocused = 0;
 	m_iTabToStartFrom = 0;
 
-	m_tabPtrList.clear();
+	m_tabPtrList.setAutoDelete(false); // FIXME: should take a closer look at this
+	m_lastVisitedTabPtrList.setAutoDelete(false);
 
 	loadImages();
 	initConfig();
@@ -371,15 +372,17 @@ void KviNotifierWindowTabs::prev()
 	if(!m_pTabFocused)return;
 
 	KviNotifierWindowTab * tab;
-	QPtrListIterator<KviNotifierWindowTab> tabIterator (m_tabPtrList);
+	KviPointerListIterator<KviNotifierWindowTab> tabIterator (m_tabPtrList);
 
 	tab = m_tabMap[m_pTabFocused->wnd()];
-	tabIterator.atFirst();
+	
+	tabIterator.moveFirst();
+	
 	while ((tabIterator.current()) != tab) {
 		++tabIterator;
 	}
 	
-	if (!tabIterator.atFirst()) {
+	if (!tabIterator.moveFirst()) {
 		--tabIterator;
 		tab = tabIterator.current();
 		setFocusOn(tab);
@@ -392,15 +395,15 @@ void KviNotifierWindowTabs::next()
 	if(!m_pTabFocused)return;
 	
 	KviNotifierWindowTab * tab;
-	QPtrListIterator<KviNotifierWindowTab> tabIterator (m_tabPtrList);
+	KviPointerListIterator<KviNotifierWindowTab> tabIterator (m_tabPtrList);
 
 	tab = m_tabMap[m_pTabFocused->wnd()];
-	tabIterator.atFirst();
+	tabIterator.moveFirst();
 	while ((tabIterator.current()) != tab) {
 		++tabIterator;
 	}
 	
-	if (!tabIterator.atLast()) {
+	if (!tabIterator.moveLast()) {
 		++tabIterator;
 		tab = tabIterator.current();
 		setFocusOn(tab);
@@ -512,9 +515,7 @@ void KviNotifierWindowTabs::setFocusOn(KviNotifierWindowTab * tab)
 	m_pTabFocused = tab;
 	if(m_pTabFocused)m_pTabFocused->setFocused();
 
-	if (m_lastVisitedTabPtrList.containsRef(tab)) {
-		m_lastVisitedTabPtrList.removeRef(tab);
-	}
+	m_lastVisitedTabPtrList.removeRef(tab);
 	
 	m_lastVisitedTabPtrList.insert(0, tab);
 
@@ -552,14 +553,14 @@ void KviNotifierWindowTabs::draw(QPainter * p)
 	m_pPainter->drawPixmap(m_rct.width()-m_pixDX.width(),0,m_pixDX);
 	m_pPainter->drawTiledPixmap(m_pixSX.width(),0,m_rct.width()-m_pixSX.width()-m_pixDX.width(),m_rct.height(),m_pixBKG);
 
-	QPtrListIterator<KviNotifierWindowTab> tabIterator (m_tabPtrList);
+	KviPointerListIterator<KviNotifierWindowTab> tabIterator (m_tabPtrList);
 	
 	//m_tabPtrList.findRef(m_tabMap[m_pTabFocused->wnd()]);
 
 //	QMap<KviWindow *, KviNotifierWindowTab *>::Iterator tab;
 	KviNotifierWindowTab * tab;
 	//for (tab = m_tabMap.begin(); tab != m_tabMap.end() && !isBigger; tab++ )
-	tabIterator.toFirst();
+	tabIterator.moveFirst();
 	
 	int i = 0;
 	while(m_iTabToStartFrom!=i) {
@@ -632,18 +633,23 @@ void KviNotifierWindowTabs::draw(QPainter * p)
 
 void KviNotifierWindowTabs::markAllMessagesAsHistoric()
 {
+/*
 	QMap<KviWindow *, KviNotifierWindowTab *>::Iterator tab;
 	// Iterating every tab
-	for (tab = m_tabMap.begin(); tab != m_tabMap.end(); tab++ )
-	{
-		// Setting all messages of the current tab as historic
-		// tab.data()->expireMessages();
-		KviPtrList<KviNotifierMessage> * tmpMessageList = tab.data()->messageList();
-		for(KviNotifierMessage * m = tmpMessageList->last();m;m = tmpMessageList->prev()) {
-			if(m->historic())break;
+	for (tab = m_tabMap.begin(); tab != m_tabMap.end(); ++tab) {
+	
+		if (!tab.value()) break;
+		
+		KviPointerList<KviNotifierMessage> * tmpMessageList = tab.value()->messageList();
+		
+		if (!tmpMessageList) break;
+		
+		for(KviNotifierMessage * m = tmpMessageList->last(); m; m = tmpMessageList->prev()) {
+			if(m->historic()) break;;
 			m->setHistoric();
 		}
 	}
+*/
 }
 
 void KviNotifierWindowTabs::closeTab(KviWindow * pWnd)
@@ -687,9 +693,9 @@ void KviNotifierWindowTabs::closeTab(KviWindow * pWnd, KviNotifierWindowTab * pT
 	} else {
 	
 		if (m_lastVisitedTabPtrList.count()) {
-			m_pTabFocused = m_lastVisitedTabPtrList.getFirst();
+			m_pTabFocused = m_lastVisitedTabPtrList.first();
 		} else {
-			m_pTabFocused = m_tabPtrList.getLast();
+			m_pTabFocused = m_tabPtrList.last();
 		}
 			
 		m_pTabFocused->setFocused(true);
