@@ -20,10 +20,10 @@
 //   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 //
 
-#include "kvi_command.h"
+
 #include "kvi_error.h"
 #include "kvi_debug.h"
-#include "kvi_scriptobject.h"
+
 #include "kvi_locale.h"
 #include "kvi_styled_controls.h"
 
@@ -82,6 +82,7 @@ bool KviKvsObject_checkbox::init(KviKvsRunTimeContext * pContext,KviKvsVariantLi
 	KviStyledCheckBox  * cb = new KviStyledCheckBox(parentScriptWidget(), name());
 	setObject(cb, true);
 	connect(cb,SIGNAL(toggled(bool)),this,SLOT(toggled(bool)));
+	connect(widget(),SIGNAL(clicked()),this,SLOT(slotClicked()));
 	return true;
 }
 
