@@ -20,11 +20,11 @@
 //   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 //
 
-#include "kvi_command.h"
+
 #include "kvi_error.h"
 #include "kvi_locale.h"
 #include "kvi_debug.h"
-#include "kvi_scriptobject.h"
+
 
 #include "class_list.h"
 #include "class_combobox.h"
@@ -71,10 +71,10 @@
 		If the parameter is ommited, it is assumed to be false.
 		!fn: <boolean> $editable()
 		Returns whether the combobox is editable or not.
-		!fn: $setEditText(<text:string>)
+		!fn: $setEditText(<text:string>,[<quiet:bool>])
 		Sets the text in the embedded line edit to newText without
 		changing the combo's contents. Does nothing if the combo
-		isn't editable.
+		isn't editable. If the optional quiet parameter is true no warning will be print if text will be empty.
 		!fn: $clear()
 		Removes all the items from the combo box
 		!fn: $textAt(<index:uint>)
@@ -274,18 +274,20 @@ bool KviKvsObject_combobox::functioneditable(KviKvsObjectFunctionCall *c)
 bool KviKvsObject_combobox::functionsetEditText(KviKvsObjectFunctionCall *c)
 {
 	QString szText;
+	bool bQuiet=false;
 	KVSO_PARAMETERS_BEGIN(c)
 		KVSO_PARAMETER("text",KVS_PT_STRING,0,szText)
+		KVSO_PARAMETER("quiet",KVS_PT_BOOLEAN,KVS_PF_OPTIONAL,bQuiet)
 	KVSO_PARAMETERS_END(c)
 	if(!widget()) return true;
-	if (szText.isEmpty()) c->warning("No string parameter given - using empty string");
+	if (szText.isEmpty() && !bQuiet) c->warning("No string parameter given - using empty string");
 	((QComboBox *)widget())->setEditText(szText);
 	return true;
 }
 bool KviKvsObject_combobox::functiontextAt(KviKvsObjectFunctionCall *c)
 {
 
-	kvs_int_t uIndex;
+	kvs_uint_t uIndex;
 	KVSO_PARAMETERS_BEGIN(c)
 		KVSO_PARAMETER("index",KVS_PT_UNSIGNEDINTEGER,0,uIndex)
 	KVSO_PARAMETERS_END(c)
@@ -328,7 +330,7 @@ bool KviKvsObject_combobox::functionsetInsertionPolicy(KviKvsObjectFunctionCall
 			((QComboBox *)widget())->setInsertionPolicy(QComboBox::AfterCurrent);
 	else if(KviQString::equalCI(szPolicy,"BeforeCurrent"))
 			((QComboBox *)widget())->setInsertionPolicy(QComboBox::BeforeCurrent);
-	else c->warning(__tr2qs("Invalid insertion Policy"),szPolicy);
+	else c->warning(__tr2qs("Invalid insertion Policy %Q"),&szPolicy);
 	return true;
 }
 
