@@ -27,9 +27,10 @@
 #include <qfile.h>
 #include <qtextstream.h>
 #include "kvi_string.h"
-#include "kvi_scriptobject.h"
 
-class KviCommand;
+
+/*
+//class KviCommand;
 class KviParameterList;
 
 class KviScriptFileObject : public KviScriptObject
@@ -72,7 +73,7 @@ protected:
 	QFile * m_pFile;
 };
 
-
+*/
 
 #include "object_macros.h"
 
