@@ -25,7 +25,7 @@
 
 
 
-#include <qgroupbox.h>
+#include <kvi_tal_groupbox.h>
 #include "class_widget.h"
 #include "object_macros.h"
 
