@@ -21,11 +21,24 @@
 //
 #define _KVI_DEBUG_CHECK_RANGE_
 #include "kvi_debug.h"
-#include "kvi_command.h"
+
 #include "kvi_locale.h"
 
 #include "class_layout.h"
 
+#ifdef COMPILE_USE_QT4
+#define QLAYOUT_AUTO_CONSTRAINT QLayout::SetDefaultConstraint
+#define QLAYOUT_FIXED QLayout::SetFixedSize
+#define QLAYOUT_FREE_RESIZE QLayout::SetNoConstraint
+#define QLAYOUT_MINIMUM QLayout::SetMinimumSize
+#else
+#define QLAYOUT_AUTO_CONSTRAINT QLayout::Auto
+#define QLAYOUT_FIXED QLayout::Fixed
+#define QLAYOUT_FREE_RESIZE QLayout::FreeResize
+#define QLAYOUT_MINIMUM QLayout::Minimum
+#endif 
+
+
 /*
 	@doc: layout
 	@keyterms:
@@ -117,8 +130,8 @@ bool KviKvsObject_layout::functionAddWidget(KviKvsObjectFunctionCall *c)
 	kvs_uint_t uCol,uRow;
 	KVSO_PARAMETERS_BEGIN(c)
 		KVSO_PARAMETER("widget",KVS_PT_HOBJECT,0,hObject)
-		KVSO_PARAMETER("col",KVS_PT_UNSIGNEDINTEGER,0,uCol)
 		KVSO_PARAMETER("row",KVS_PT_UNSIGNEDINTEGER,0,uRow)
+		KVSO_PARAMETER("col",KVS_PT_UNSIGNEDINTEGER,0,uCol)
 	KVSO_PARAMETERS_END(c)
 	pObject=KviKvsKernel::instance()->objectController()->lookupObject(hObject);
 	if(!widget())return true;
@@ -137,7 +150,7 @@ bool KviKvsObject_layout::functionAddWidget(KviKvsObjectFunctionCall *c)
 		c->warning(__tr2qs("Can't add a non-widget object"));
 		return true;
 	}
-	((QGridLayout *)object())->addWidget(((QWidget *)(pObject->object())),uCol,uRow);
+	((QGridLayout *)object())->addWidget(((QWidget *)(pObject->object())),uRow,uCol);
 	return true;
 }
 bool KviKvsObject_layout::functionAddMultiCellWidget(KviKvsObjectFunctionCall *c)
@@ -147,10 +160,10 @@ bool KviKvsObject_layout::functionAddMultiCellWidget(KviKvsObjectFunctionCall *c
 	kvs_uint_t uStartCol,uStartRow,uEndCol,uEndRow;
 	KVSO_PARAMETERS_BEGIN(c)
 		KVSO_PARAMETER("widget",KVS_PT_HOBJECT,0,hObject)
-		KVSO_PARAMETER("start_column",KVS_PT_UNSIGNEDINTEGER,0,uStartCol)
-		KVSO_PARAMETER("end_column",KVS_PT_UNSIGNEDINTEGER,0,uEndCol)
 		KVSO_PARAMETER("start_row",KVS_PT_UNSIGNEDINTEGER,0,uStartRow)
 		KVSO_PARAMETER("end_row",KVS_PT_UNSIGNEDINTEGER,0,uEndRow)
+		KVSO_PARAMETER("start_column",KVS_PT_UNSIGNEDINTEGER,0,uStartCol)
+		KVSO_PARAMETER("end_column",KVS_PT_UNSIGNEDINTEGER,0,uEndCol)
 	KVSO_PARAMETERS_END(c)
 	pObject=KviKvsKernel::instance()->objectController()->lookupObject(hObject);
 	if(!widget())return true;
@@ -169,7 +182,7 @@ bool KviKvsObject_layout::functionAddMultiCellWidget(KviKvsObjectFunctionCall *c
 		c->warning(__tr2qs("Can't add a non-widget object"));
 		return true;
 	}
-	((QGridLayout *)object())->addMultiCellWidget(((QWidget *)(pObject->object())),uStartCol,uEndCol,uStartRow,uEndRow);
+	((QGridLayout *)object())->addMultiCellWidget(((QWidget *)(pObject->object())),uStartRow,uEndRow,uStartCol,uEndCol);
 	return true;
 }
 bool KviKvsObject_layout::functionSetRowStretch(KviKvsObjectFunctionCall *c)
@@ -245,12 +258,17 @@ bool KviKvsObject_layout::functionSetResizeMode(KviKvsObjectFunctionCall *c)
 		KVSO_PARAMETER("resize_mode",KVS_PT_STRING,0,szMode)
 	KVSO_PARAMETERS_END(c)
 	if(!widget())return true;
-	QLayout::ResizeMode r = QLayout::Auto;
-	if(KviQString::equalCI(szMode,"FreeResize")) r = QLayout::FreeResize;
-	else if(KviQString::equalCI(szMode,"Minimum")) r = QLayout::Minimum;
-	else if(KviQString::equalCI(szMode,"Fixed"))r = QLayout::Fixed;
+#ifdef COMPILE_USE_QT4
+	QLayout::SizeConstraint r = QLAYOUT_AUTO_CONSTRAINT;
+#else
+	QLayout::ResizeMode r = QLAYOUT_AUTO_CONSTRAINT;
+#endif
+	if(KviQString::equalCI(szMode,"FreeResize")) r = QLAYOUT_FREE_RESIZE;
+	else if(KviQString::equalCI(szMode,"Minimum")) r = QLAYOUT_MINIMUM;
+	else if(KviQString::equalCI(szMode,"Fixed"))r = QLAYOUT_FIXED;
 	else c->warning(__tr2qs("Invalid resize mode defaulting to Auto"));
 	((QGridLayout *)object())->setResizeMode(r);
 	return true;
+
 }
 
