@@ -20,10 +20,10 @@
 //   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 //
 
-#include "kvi_command.h"
+
 #include "kvi_error.h"
 #include "kvi_debug.h"
-#include "kvi_scriptobject.h"
+
 #include "kvi_locale.h"
 
 #include "class_lineedit.h"
