@@ -2,7 +2,7 @@
 //   File : class_listbox.cpp
 //   Creation date : Sat Oct 2 03:40:28 CET 2004 by Szymon Stefanek
 //
-//   This file is part of the KVirc irc client distribution
+//    This file is part of the KVirc irc client distribution
 //   Copyright (C) 2004 Szymon Stefanek (pragma at kvirc dot net)
 //
 //   This program is FREE software. You can redistribute it and/or
@@ -20,13 +20,13 @@
 //   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 //
 
-#include "kvi_command.h"
+
 #include "kvi_error.h"
 #include "kvi_locale.h"
 #include "kvi_debug.h"
-#include "kvi_scriptobject.h"
 
-#include <qlistbox.h>
+
+#include "kvi_tal_listbox.h"
 
 #include "class_list.h"
 #include "class_listbox.h"
@@ -98,10 +98,18 @@
 		This function is called by KVIrc when the selection in the listbox changes.
 		!fn: $currentItemChangeEvent()
 		This function is called by KVIrc when the current item changes.
+		!fn: <index:integer> $onItemEvent()
+		This function is called by KVIrc when the current item pointed by the mouse changes and gives in $0 the item index.
+		!fn: <array:x,y,width,height> $itemRect(<item:index>)
+		Returns the rectangle on the screen that item occupies, or an invalid rectangle if item is 0 or is not currently visible. 
+
 		@signals:
 		!sg: <string> $currentItemChange()
 		This signal is emitted by the default implementation of [classfnc]$currentItemChangeEvent[/classfnc]().[br]
-*/
+		!sg: <string> $onItem()
+		This signal is emitted by the default implementation of [classfnc]$onItemEvent[/classfnc]().[br]
+
+		*/
 
 
 KVSO_BEGIN_REGISTERCLASS(KviKvsObject_listbox,"listbox","widget")
@@ -113,6 +121,8 @@ KVSO_BEGIN_REGISTERCLASS(KviKvsObject_listbox,"listbox","widget")
 	KVSO_REGISTER_HANDLER(KviKvsObject_listbox,"currentText", functioncurrentText)
 	KVSO_REGISTER_HANDLER(KviKvsObject_listbox,"currentItem", functioncurrentItem)
 	KVSO_REGISTER_HANDLER(KviKvsObject_listbox,"textAt", functiontextAt);
+	KVSO_REGISTER_HANDLER(KviKvsObject_listbox,"itemAt", functionitemAt);
+	KVSO_REGISTER_HANDLER(KviKvsObject_listbox,"itemRect", functionitemRect);
 	KVSO_REGISTER_HANDLER(KviKvsObject_listbox,"setCurrentItem", functionsetCurrentItem);
 
 
@@ -121,6 +131,8 @@ KVSO_BEGIN_REGISTERCLASS(KviKvsObject_listbox,"listbox","widget")
 	KVSO_REGISTER_HANDLER(KviKvsObject_listbox,"setSelected",functionsetSelected);
 	KVSO_REGISTER_HANDLER(KviKvsObject_listbox,"isSelected",functionisSelected);
 	KVSO_REGISTER_HANDLER(KviKvsObject_listbox,"currentItemChangeEvent",functioncurrentItemChangeEvent);
+	KVSO_REGISTER_HANDLER(KviKvsObject_listbox,"onItemEvent",functiononItemEvent);
+
 
 	KVSO_REGISTER_STANDARD_NOTHINGRETURN_HANDLER(KviKvsObject_listbox,"selectionChangeEvent")
 
@@ -138,10 +150,13 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_listbox)
 
 bool KviKvsObject_listbox::init(KviKvsRunTimeContext * pContext,KviKvsVariantList *pParams)
 {
-	QListBox * b = new QListBox(parentScriptWidget(), name());
-	b->setSelectionMode(QListBox::Single);
+	KviTalListBox * b = new KviTalListBox(parentScriptWidget());
+	b->setSelectionMode(KviTalListBox::Single);
 	connect(b,SIGNAL(selectionChanged()),this,SLOT(selectionChanged()));
-	connect(b,SIGNAL(currentChanged(QListBoxItem *)),this,SLOT(currentItemChanged(QListBoxItem *)));
+	connect(b,SIGNAL(currentChanged(KviTalListBoxItem *)),this,SLOT(currentItemChanged(KviTalListBoxItem *)));
+	
+	connect(b,SIGNAL(onItem(KviTalListBoxItem *)),this,SLOT(onItem(KviTalListBoxItem *)));
+
 	setObject(b,true);;
 	return true;
 }
@@ -155,12 +170,12 @@ bool KviKvsObject_listbox::functioninsertItem(KviKvsObjectFunctionCall *c)
 		KVSO_PARAMETER("index",KVS_PT_INT,KVS_PF_OPTIONAL,iIndex)
 	KVSO_PARAMETERS_END(c)
 	if(widget())
-		((QListBox *)widget())->insertItem(szItem, iIndex);
+		((KviTalListBox *)widget())->insertItem(szItem, iIndex);
 	return true;
 }
 bool KviKvsObject_listbox::functionclear(KviKvsObjectFunctionCall *c)
 {
-	if (widget()) ((QListBox *)widget())->clear();
+	if (widget()) ((KviTalListBox *)widget())->clear();
 	return true;
 }
 bool KviKvsObject_listbox::functionchangeItem(KviKvsObjectFunctionCall *c)
@@ -174,14 +189,14 @@ bool KviKvsObject_listbox::functionchangeItem(KviKvsObjectFunctionCall *c)
 	KVSO_PARAMETERS_END(c)
 	if(!widget()) return true;
 	if (szText.isEmpty()) c->warning(__tr2qs("No string parameter given - using empty string"));
-	if(uIndex >= (cnt = ((QListBox *)widget())->count()))
+	if(uIndex >= (cnt = ((KviTalListBox *)widget())->count()))
 	{
 		c->warning(__tr2qs("Item index [%d] is too big - defaulting to " \
 			"$count() - 1 [%d]"), uIndex, cnt);
 		uIndex = cnt - 1;
 	}
 
-	((QListBox *)widget())->changeItem(szText, uIndex);
+	((KviTalListBox *)widget())->changeItem(szText, uIndex);
 
 	return true;
 
@@ -194,14 +209,14 @@ bool KviKvsObject_listbox::functionremoveItem(KviKvsObjectFunctionCall *c)
 		KVSO_PARAMETER("index",KVS_PT_UNSIGNEDINTEGER,0,uIndex)
 	KVSO_PARAMETERS_END(c)
 	if(!widget()) return true;
-	if(uIndex >= (cnt = ((QListBox *)widget())->count()))
+	if(uIndex >= (cnt = ((KviTalListBox *)widget())->count()))
 	{
 		c->warning(__tr2qs("Item index [%d] is too big - defaulting to " \
 			"$count() - 1 [%d]"), uIndex, cnt);
 		uIndex = cnt - 1;
 	}
 
-	((QListBox *)widget())->removeItem(uIndex);
+	((KviTalListBox *)widget())->removeItem(uIndex);
 
 	return true;
 
@@ -209,17 +224,17 @@ bool KviKvsObject_listbox::functionremoveItem(KviKvsObjectFunctionCall *c)
 
 bool KviKvsObject_listbox::functioncount(KviKvsObjectFunctionCall *c)
 {
-	if (widget()) c->returnValue()->setInteger(((QListBox *)widget())->count());
+	if (widget()) c->returnValue()->setInteger(((KviTalListBox *)widget())->count());
 	return true;
 }
 bool KviKvsObject_listbox::functioncurrentText(KviKvsObjectFunctionCall *c)
 {
-	if (widget()) c->returnValue()->setString(((QListBox *)widget())->currentText().local8Bit().data());
+	if (widget()) c->returnValue()->setString(((KviTalListBox *)widget())->currentText().local8Bit().data());
 	return true;
 }
 bool KviKvsObject_listbox::functioncurrentItem(KviKvsObjectFunctionCall *c)
 {
-	if (widget()) c->returnValue()->setInteger(((QListBox *)widget())->currentItem());
+	if (widget()) c->returnValue()->setInteger(((KviTalListBox *)widget())->currentItem());
 	return true;
 }
 
@@ -231,7 +246,7 @@ bool KviKvsObject_listbox::functiontextAt(KviKvsObjectFunctionCall *c)
 		KVSO_PARAMETER("index",KVS_PT_UNSIGNEDINTEGER,0,uIndex)
 	KVSO_PARAMETERS_END(c)
 	if(widget())
-		c->returnValue()->setString(((QListBox *)widget())->text(uIndex));
+		c->returnValue()->setString(((KviTalListBox *)widget())->text(uIndex));
 	return true;
 }
 bool KviKvsObject_listbox::functionsetCurrentItem(KviKvsObjectFunctionCall *c)
@@ -241,7 +256,7 @@ bool KviKvsObject_listbox::functionsetCurrentItem(KviKvsObjectFunctionCall *c)
 		KVSO_PARAMETER("index",KVS_PT_UNSIGNEDINTEGER,0,uIndex)
 	KVSO_PARAMETERS_END(c)
 	if(widget())
-		((QListBox *)widget())->setCurrentItem(uIndex);
+		((KviTalListBox *)widget())->setCurrentItem(uIndex);
 	return true;
 }
 bool KviKvsObject_listbox::functionsetSelectionMode(KviKvsObjectFunctionCall *c)
@@ -251,18 +266,18 @@ bool KviKvsObject_listbox::functionsetSelectionMode(KviKvsObjectFunctionCall *c)
 		KVSO_PARAMETER("selection_mode",KVS_PT_STRING,0,szMode)
 	KVSO_PARAMETERS_END(c)
 	if(!widget()) return true;
-	QListBox::SelectionMode iMode = QListBox::Single;
+	KviTalListBox::SelectionMode iMode = KviTalListBox::Single;
 
-	if(KviQString::equalCI(szMode,"single")) iMode = QListBox::Single;
+	if(KviQString::equalCI(szMode,"single")) iMode = KviTalListBox::Single;
 
-	else if(KviQString::equalCI(szMode,"multi")) iMode = QListBox::Multi;
+	else if(KviQString::equalCI(szMode,"multi")) iMode = KviTalListBox::Multi;
 
-	else if(KviQString::equalCI(szMode,"extended")) iMode = QListBox::Extended;
+	else if(KviQString::equalCI(szMode,"extended")) iMode = KviTalListBox::Extended;
 
-	else if(KviQString::equalCI(szMode,"none")) iMode = QListBox::NoSelection;
+	else if(KviQString::equalCI(szMode,"none")) iMode = KviTalListBox::NoSelection;
 
 	else  c->warning(__tr2qs("Invalid selection mode '%Q' assuming single"),&szMode);
-	((QListBox *)widget())->setSelectionMode(iMode);
+	((KviTalListBox *)widget())->setSelectionMode(iMode);
 
 	return true;
 }
@@ -270,12 +285,12 @@ bool KviKvsObject_listbox::functionselectionMode(KviKvsObjectFunctionCall *c)
 {
 
 	if(!widget()) return true;
-	switch(((QListBox *)widget())->selectionMode())
+	switch(((KviTalListBox *)widget())->selectionMode())
 	{
-		case QListBox::Single: c->returnValue()->setString("single"); break;
-		case QListBox::Multi: c->returnValue()->setString("multi"); break;
-		case QListBox::Extended: c->returnValue()->setString("extended"); break;
-		case QListBox::NoSelection: c->returnValue()->setString("none"); break;
+		case KviTalListBox::Single: c->returnValue()->setString("single"); break;
+		case KviTalListBox::Multi: c->returnValue()->setString("multi"); break;
+		case KviTalListBox::Extended: c->returnValue()->setString("extended"); break;
+		case KviTalListBox::NoSelection: c->returnValue()->setString("none"); break;
 		default: c->returnValue()->setString("single"); break;
 	}
 	return true;
@@ -288,7 +303,7 @@ bool KviKvsObject_listbox::functionisSelected(KviKvsObjectFunctionCall *c)
 	KVSO_PARAMETERS_BEGIN(c)
 		KVSO_PARAMETER("index",KVS_PT_UNSIGNEDINTEGER,0,uIndex)
 	KVSO_PARAMETERS_END(c)
-	if(widget())c->returnValue()->setBoolean(((QListBox *)widget())->isSelected(uIndex));
+	if(widget())c->returnValue()->setBoolean(((KviTalListBox *)widget())->isSelected(uIndex));
 	return true;
 }
 bool KviKvsObject_listbox::functionsetSelected(KviKvsObjectFunctionCall *c)
@@ -299,7 +314,18 @@ bool KviKvsObject_listbox::functionsetSelected(KviKvsObjectFunctionCall *c)
 		KVSO_PARAMETER("index",KVS_PT_UNSIGNEDINTEGER,0,uIndex)
 		KVSO_PARAMETER("benabled",KVS_PT_BOOLEAN,0,bSel)
 	KVSO_PARAMETERS_END(c)
-	if(widget()) ((QListBox *)widget())->setSelected(uIndex,bSel);
+	if(widget()) ((KviTalListBox *)widget())->setSelected(uIndex,bSel);
+	return true;
+}
+bool KviKvsObject_listbox::functionitemAt(KviKvsObjectFunctionCall *c)
+{
+	kvs_uint_t uX,uY;
+	KVSO_PARAMETERS_BEGIN(c)
+		KVSO_PARAMETER("uX",KVS_PT_UNSIGNEDINTEGER,0,uX)
+		KVSO_PARAMETER("uY",KVS_PT_UNSIGNEDINTEGER,0,uY)
+	KVSO_PARAMETERS_END(c)
+	if(widget()) 
+		c->returnValue()->setInteger(((KviTalListBox *)widget())->index(((KviTalListBox *)widget())->itemAt(QPoint(uX,uY))));
 	return true;
 }
 
@@ -316,7 +342,7 @@ void KviKvsObject_listbox::selectionChanged()
 	callFunction(this,"selectionChangeEvent",0,0);
 }
 
-void KviKvsObject_listbox::currentItemChanged(QListBoxItem *item)
+void KviKvsObject_listbox::currentItemChanged(KviTalListBoxItem *item)
 {
 	if (!item) callFunction(this,"currentItemChangeEvent",0,0);
 	else
@@ -326,9 +352,39 @@ void KviKvsObject_listbox::currentItemChanged(QListBoxItem *item)
 	}
 
 }
+bool KviKvsObject_listbox::functiononItemEvent(KviKvsObjectFunctionCall *c)
+{
+	emitSignal("onItem",c,c->params());
+
+	return true;
+}
+
+void KviKvsObject_listbox::onItem(KviTalListBoxItem *item)
+{
+		KviTalListBox *lbx = (KviTalListBox *)(item->listBox());
+		KviKvsVariantList params(new KviKvsVariant((kvs_int_t)lbx->index(item)));
+		callFunction(this,"onItemEvent",0,&params);
+}
 
 
-
+bool KviKvsObject_listbox::functionitemRect(KviKvsObjectFunctionCall *c)
+{
+kvs_uint_t uIndex;
+	KVSO_PARAMETERS_BEGIN(c)
+		KVSO_PARAMETER("uIndex",KVS_PT_UNSIGNEDINTEGER,0,uIndex)
+	KVSO_PARAMETERS_END(c)
+	if(widget())
+	{
+		QRect rect=((KviTalListBox *)widget())->itemRect(((KviTalListBox *)widget())->item(uIndex));
+		KviKvsArray * a = new KviKvsArray();
+		a->set(0,new KviKvsVariant((kvs_int_t)rect.left()));
+		a->set(1,new KviKvsVariant((kvs_int_t)rect.top()));
+		a->set(2,new KviKvsVariant((kvs_int_t)rect.width()));
+		a->set(3,new KviKvsVariant((kvs_int_t)rect.height()));
+		c->returnValue()->setArray(a);
+	}
+		return true;
+}
 
 
 #include "m_class_listbox.moc"
