@@ -26,8 +26,8 @@
 
 #include "class_widget.h"
 
-class QListBox;
-class QListBoxItem;
+class KviTalListBox;
+class KviTalListBoxItem;
 
 #include "object_macros.h"
 
@@ -56,9 +56,14 @@ protected:
 	bool functionsetSelected(KviKvsObjectFunctionCall *c);
 	bool functionisSelected(KviKvsObjectFunctionCall *c);
 	bool functioncurrentItemChangeEvent(KviKvsObjectFunctionCall *c);
+	bool functiononItemEvent(KviKvsObjectFunctionCall *c);
+
+	bool functionitemAt(KviKvsObjectFunctionCall *c);
+	bool functionitemRect(KviKvsObjectFunctionCall *c);
 protected slots:
 	void selectionChanged();
-	void currentItemChanged(QListBoxItem *);
+	void currentItemChanged(KviTalListBoxItem *);
+	void onItem(KviTalListBoxItem *);
 };
 
 
