@@ -24,22 +24,17 @@
 
 #include <qmenubar.h>
 #include "class_widget.h"
+#include "object_macros.h"
 
-class KviScriptMenuBarObject : public KviScriptWidgetObject
+class KviKvsObject_menubar : public KviKvsObject_widget
 {
-	Q_OBJECT
 public:
-	KviScriptMenuBarObject(KviScriptObjectClass * c, KviScriptObject * p, 
-		const char * n);
-	virtual ~KviScriptMenuBarObject();
-
-	static void registerSelf();
-	static void unregisterSelf();
-
+	KVSO_DECLARE_OBJECT(KviKvsObject_menubar)
+public:
+	QWidget * widget() { return (QWidget *)object(); };
 protected:
-	virtual bool init(KviCommand *);
+	virtual bool init(KviKvsRunTimeContext * pContext,KviKvsVariantList *pParams);
 
-	bool functionInsertItem(KviCommand *, KviParameterList *, KviStr &);
+	bool functionInsertItem(KviKvsObjectFunctionCall *c);
 };
-
 #endif	// !_CLASS_MENUBAR_H_
