@@ -25,7 +25,7 @@
 #include "class_pixmap.h"
 #include "class_widget.h"
 #include "kvi_debug.h"
-#include "kvi_command.h"
+
 #include "kvi_locale.h"
 #include "kvi_error.h"
 #include "kvi_iconmanager.h"
@@ -85,28 +85,28 @@
 		}[br]
 		%aa=$new(wdg)[br]
 		%aa->$show()[br]
-		!fn: $drawRect(<x>,<y>,<w>,<h>)
+		!fn: $drawRect(<x:integer>,<y:integer>,<w:unsigned integer>,<h:unsigned integer>)
 		Draws a rectangle with upper left corner at (x, y) and with width w and height h.
-		!fn: $drawWinFocusRect(<x>,<y>,<w>,<h>)
+		!fn: $drawWinFocusRect(<x:integer>,<y:integer>,<w:unsigned integer>,<h:unsigned integer>)
 		Draws a Windows focus rectangle with upper left corner at (x, y) and with width w and height h.[br]
 		This function draws nothing if the coordinate system has been rotated or sheared.
-		!fn: $drawRoundRect(<x>,<y>,<w>,<h>,<xCor>,<yCor>)
+		!fn: $drawRoundRect(<x:integer>,<y:integer>,<w:unsigned integer>,<h:unsigned integer>,<xCor:integer>,<yCor:integer>)
 		Draws a rectangle with rounded corners at (x, y), with width w and height h.[rb]
 		The xCor and yCor arguments specify how rounded the corners should be (range is 0->99).
-		!fn: $drawPie(<x>,<y>,<w>,<h>,<angle>,<alen>)
+		!fn: $drawPie(<x:integer>,<y:integer>,<w:unsigned integer>,<h:unsigned integer>,<angle:integer>,<alen:integer>)
 		Draws a pie defined by the rectangle (x, y, w, h), the start angle a and the arc length alen.[br]
 		The angles <angle> and <alen> are 1/16th of a degree, i.e. a full circle equals 5760 (16*360).
-		!fn: $drawArc(<x>,<y>,<w>,<h>,<angle>,<alen>)
+		!fn: $drawArc(<x:integer>,<y:integer>,<w:unsigned integer>,<h:unsigned integer>,<angle:integer>,<alen:integer>)
 		Draws an arc defined by the rectangle (x, y, w, h), the start angle a and the arc length alen.[br]
 		The angles <angle> and <alen> are 1/16th of a degree, i.e. a full circle equals 5760 (16*360).
-		!fn: $drawPoint(<x>,<y>)
+		!fn: $drawPoint(<x:integer>,<y:integer>)
 		Draws a point at x and y coordinates.
-		!fn: $drawEllipse(<x>,<y>,<sizew>,<sizeh>)
+		!fn: $drawEllipse(<x:integer>,<y:integer>,<sizew:unsigned integer>,<sizeh:unsigned integer>)
 		Draws an ellipse with center at (x + w/2, y + h/2) and size (w, h).
-		!fn: $drawChord(<x>,<y>,<w>,<h>,<angle>,<alen>)
+		!fn: $drawChord(<x:integer>,<y:integer>,<w:unsigned integer>,<h:unsigned integer>,<angle:integer>,<alen:integer>)
 		Draws a chord defined by the rectangle (x, y, w, h), the start angle a and the arc length alen.[br]
 		The angles <angle> and <alen> are 1/16th of a degree, i.e. a full circle equals 5760 (16*360).
-		!fn: $drawText(<x>,<y>,<text>,<nr chars>,<dir>)
+		!fn: $drawText(<x:integer>,<y:integer>,<text:string>,<nr chars:integer>,<dir:enum>)
 		Draws the given <text> at position <x>, <y>.[br]
 		If <len> is -1 (the default) all the text is drawn, otherwise the first <len> characters are drawn.
 		The text's direction is given by <dir>, valid flag are:[br]
@@ -115,8 +115,9 @@
 		RTL (right to left) [br]
 		LTR (left to right) [br]
 		[/pre]
-		!fn: $drawPixmap(<x>,<y>,<image id>,<sx>,<sy>,<ex>,<ey>)
-		!fn: $setFont(<size>,<family>,<style>)[br]
+		!fn: $drawPixmap(<x:integer>,<y:integer>,<pixmap:hobject>,<sx:integer>,<sy:integer>,<ex:integer>,<ey:integer>)
+		Draws a pixmap at x,y coordinates[br]
+		!fn: $setFont(<size:unsigned integer>,<family:string>,<style:enum>)[br]
 		Set the font's size, family and stile, valid flag for style are:[br]
 		[pre]
 		italic     [br]
@@ -128,28 +129,38 @@
 		[/pre]
 		!fn: $setFontSize(<size:unsigned integer>)[br]
 		Set the current painter font's size.[br]
-		!fn: $fontAscent()
+		!fn: <integer>$fontAscent()
 		Return the distance from the baseline to the highest position characters extend to.
-		!fn: $fontDescent()
+		!fn: <integer>$fontDescent()
 		Return the distance from the baseline to the lowest point characters extend to.
-		!fn: $fontMetricsWidth(<text:string>)
+		!fn: <integer>$fontMetricsWidth(<text:string>)
 		Returns the font metrics width for the painter's current font.
-		!fn: $fontMetricsHeight()
+		!fn: <integer>$fontMetricsHeight()
 		Returns the font metrics height for the painter's current font.
-		!fn: $rotate(<angle>)
+		!fn: $rotate(<angle:real>)
 		Rotates the coordinate system a degrees counterclockwise.
-		!fn: $translate(<dx>,<dy>)
+		!fn: $translate(<dx:real>,<dy:real>)
 		Translates the coordinate system by <dx>, <dy>.
-		!fn: $shear(<dh>,<dv>)
+		!fn: $shear(<dh:real>,<dv:real>)
 		Shears the coordinate system by <dh>, <dv>.
-		!fn: $scale(<dh>,<dw>)
+		!fn: $scale(<dh:real>,<dw:real>)
 		Scales the coordinate system by <dh>, <dv>.
-		!fn: $setNewWorld()
-		Update the world transformation.
-		!fn: $setBackgroundMode(<bgMode>)
+		!fn: $setBackgroundMode(<bgMode:enum>)
 		Sets the background mode of the painter to <bgMode>: valid values are:[br]
 		- Transparent	(that is the default value);[br]
 		- Opaque.[br]
+		!fn: $setOpacity(<opacity_factor:real>) [QT4 ONLY] 
+		Sets the painter opacity that affects all painter operations (drawpixmap, drawtext...). Valid values range are from 0 (total transparency) to 1 (total opacity)[br]
+		You must invoke the [classfnc]$begin[/classfnc] before using it.
+		!fn: $setTextAntialiasing(<boolean>) [QT4 ONLY] 
+		Enable/disable antialias in text if possible.
+		You must call the [classfnc]$begin[/classfnc] before using it.
+		!fn: $setAntialiasing(<boolean>) [QT4 ONLY] 
+		Enable/disable antialias in edges of primitives if possible.
+		You must call the [classfnc]$begin[/classfnc] before using it.
+		!fn: $setSmoothPixmapTransform(<boolean>) [QT4 ONLY] 
+		Enable/disable smooth bilinear pixmap transformation algorithm (such as bilinear).
+		You must call the [classfnc]$begin[/classfnc] before using it.
 		Example:[br]
 		[br]
 		class (hello,widget)[br] 
@@ -338,6 +349,7 @@ KVSO_BEGIN_REGISTERCLASS(KviKvsObject_painter,"painter","object")
 	KVSO_REGISTER_HANDLER(KviKvsObject_painter,"fontMetricsHeight",functionfontMetricsHeight)
 	KVSO_REGISTER_HANDLER(KviKvsObject_painter,"fontMetricsWidth",functionfontMetricsWidth)
 	// Draws
+	KVSO_REGISTER_HANDLER(KviKvsObject_painter,"setBackGroundMode",functionsetBackGroundMode)
 	KVSO_REGISTER_HANDLER(KviKvsObject_painter,"drawRect",functiondrawRect)
 	KVSO_REGISTER_HANDLER(KviKvsObject_painter,"drawLine",functiondrawLine)
 	KVSO_REGISTER_HANDLER(KviKvsObject_painter,"drawRoundRect",functiondrawRoundRect)
@@ -351,6 +363,7 @@ KVSO_BEGIN_REGISTERCLASS(KviKvsObject_painter,"painter","object")
 	KVSO_REGISTER_HANDLER(KviKvsObject_painter,"drawText",functiondrawText)
 	KVSO_REGISTER_HANDLER(KviKvsObject_painter,"drawPixmap",functiondrawPixmap)
 
+
 	// MAtrix Operation
 	KVSO_REGISTER_HANDLER(KviKvsObject_painter,"rotate",functionrotateMatrix)
 	KVSO_REGISTER_HANDLER(KviKvsObject_painter,"shear",functionshearMatrix)
@@ -358,6 +371,12 @@ KVSO_BEGIN_REGISTERCLASS(KviKvsObject_painter,"painter","object")
 	KVSO_REGISTER_HANDLER(KviKvsObject_painter,"translate",functiontranslateMatrix)
 	KVSO_REGISTER_HANDLER(KviKvsObject_painter,"reset",functionresetMatrix)
 
+#ifdef COMPILE_USE_QT4
+	KVSO_REGISTER_HANDLER(KviKvsObject_painter,"setOpacity",functionsetOpacity)
+	KVSO_REGISTER_HANDLER(KviKvsObject_painter,"setTextAntialiasing",functionsetTextAntialiasing)
+	KVSO_REGISTER_HANDLER(KviKvsObject_painter,"setAntialiasing",functionsetAntialiasing)
+	KVSO_REGISTER_HANDLER(KviKvsObject_painter,"setSmoothPixmapTransform",functionsetSmoothPixmapTransform)
+#endif
 
 	KVSO_REGISTER_HANDLER(KviKvsObject_painter,"begin",functionbegin)
 	KVSO_REGISTER_HANDLER(KviKvsObject_painter,"end",functionend)
@@ -369,6 +388,7 @@ KVSO_END_REGISTERCLASS(KviKvsObject_painter)
 KVSO_BEGIN_CONSTRUCTOR(KviKvsObject_painter,KviKvsObject)
 
 	m_pPainter = new QPainter();
+
 	m_pDeviceObject=0;
 	
 KVSO_END_CONSTRUCTOR(KviKvsObject_painter)
@@ -376,6 +396,7 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_painter)
 KVSO_BEGIN_DESTRUCTOR(KviKvsObject_painter)
 
 	if (m_pPainter) delete m_pPainter;
+	m_pPainter = 0;
 
 KVSO_END_CONSTRUCTOR(KviKvsObject_painter)
 
@@ -508,7 +529,7 @@ bool KviKvsObject_painter::functionSetFont(KviKvsObjectFunctionCall *c)
 }
 bool KviKvsObject_painter::functionSetFontSize(KviKvsObjectFunctionCall *c)
 {
-	kvs_int_t uSize;
+	kvs_uint_t uSize;
 	KVSO_PARAMETERS_BEGIN(c)
 		KVSO_PARAMETER("size",KVS_PT_UNSIGNEDINTEGER,0,uSize)
 	KVSO_PARAMETERS_END(c)
@@ -562,6 +583,7 @@ bool KviKvsObject_painter::functiondrawRect(KviKvsObjectFunctionCall *c)
 	if(m_pPainter)	m_pPainter->drawRect(iX,iY,iW,iH);
 	return true;
 }
+// FIX ME: REMOVE functiondrawWinFocusRect
 bool KviKvsObject_painter::functiondrawWinFocusRect(KviKvsObjectFunctionCall *c)
 {
 	KviKvsVariant * pXOrArray;
@@ -574,7 +596,9 @@ bool KviKvsObject_painter::functiondrawWinFocusRect(KviKvsObjectFunctionCall *c)
 	KVSO_PARAMETERS_END(c)
 	QString function="$drawWinFocusRect";
 	KVSO_PARAMETERS_PAINTER(pXOrArray,iY,iW,iH)
-	if(m_pPainter)	m_pPainter->drawWinFocusRect(iX,iY,iW,iH);
+#ifndef COMPILE_USE_QT4
+		if(m_pPainter)	m_pPainter->drawWinFocusRect(iX,iY,iW,iH);
+#endif
 	return true;
 }
 bool KviKvsObject_painter::functiondrawEllipse(KviKvsObjectFunctionCall *c)
@@ -765,14 +789,17 @@ bool KviKvsObject_painter::functionbegin(KviKvsObjectFunctionCall *c)
 		c->warning(__tr2qs("Pixmap or Widget parameter is not an object"));
 		return true;
 	}
+
 	QPaintDevice * pd = 0;
-	if(pObject->inherits("KviKvsObject_pixmap"))pd = ((KviKvsObject_pixmap *)pObject)->pixmap();
+	if(pObject->inherits("KviKvsObject_pixmap"))pd =((KviKvsObject_pixmap *)pObject)->getPixmap();
 	else if (pObject->inherits("KviKvsObject_widget")) pd=((KviKvsObject_widget *)pObject)->widget();
 	
 	if (!pd)
 		c->warning(__tr2qs("Widget or Pixmap required "));
 	else {
 		attachDevice(pObject,pd);
+	//	m_pPainter->setOpacity(0.4);	
+		if (pObject->inherits("KviKvsObject_pixmap")) ((KviKvsObject_pixmap *)pObject)->pixmapChanged();
 	}
 	return true;
 }
@@ -813,13 +840,28 @@ bool KviKvsObject_painter::functiondrawText(KviKvsObjectFunctionCall *c)
 		KVSO_PARAMETER("y",KVS_PT_INT,0,iY)
 		KVSO_PARAMETER("text",KVS_PT_STRING,0,szText)
 		KVSO_PARAMETER("length",KVS_PT_INT,0,iLen)
-		KVSO_PARAMETER("mode",KVS_PT_STRING,0,szMode)
+		KVSO_PARAMETER("mode",KVS_PT_STRING,KVS_PF_OPTIONAL,szMode)
 	KVSO_PARAMETERS_END(c)
 	if(!m_pPainter)return true;
+#ifdef COMPILE_USE_QT4
+	if (!szMode.isEmpty()){
+		if(KviQString::equalCI(szMode,"RTL"))m_pPainter->setLayoutDirection(Qt::RightToLeft);
+		else if(KviQString::equalCI(szMode,"LTR"))m_pPainter->setLayoutDirection(Qt::LeftToRight);
+		else
+		{
+				c->warning(__tr2qs("Invalid mode '%Q'"),&szMode);
+				return true;
+		}
+	}
+
+	 m_pPainter->drawText(iX,iY,szText);
+#else
 	if(KviQString::equalCI(szMode,"Auto")) m_pPainter->drawText(iX,iY,szText,iLen,QPainter::Auto);
 	else if(KviQString::equalCI(szMode,"RTL")) m_pPainter->drawText(iX,iY,szText,iLen,QPainter::RTL);
 	else if(KviQString::equalCI(szMode,"LTR"))m_pPainter->drawText(iX,iY,szText,iLen,QPainter::LTR);
 	else c->warning(__tr2qs("Invalid mode '%Q'"),&szMode);
+
+#endif
 	return true;
 }
 
@@ -844,19 +886,13 @@ bool KviKvsObject_painter::functiondrawPixmap(KviKvsObjectFunctionCall *c)
 		c->warning(__tr2qs("Pixmap parameter is not an object"));
 		return true;
 	}
-/*
-	if (!pObject->object())
-	{
-		c->warning(__tr2qs("Widget parameter is not a valid object"));
-		return true;
-	}
-*/
 	if (!obj->inherits("KviKvsObject_pixmap"))
 	{
 		c->warning(__tr2qs("Pixmap object required"));
 		return true;
 	}
-	m_pPainter->drawPixmap(iX,iY,*((KviKvsObject_pixmap *)obj)->pixmap(),iStartx,iStarty,iEndx,iEndy);
+	QPixmap * pm=((KviKvsObject_pixmap *)obj)->getPixmap();
+	m_pPainter->drawPixmap(iX,iY,*((KviKvsObject_pixmap *)obj)->getPixmap(),iStartx,iStarty,iEndx,iEndy);
 	return true;
 }
 
@@ -918,4 +954,54 @@ bool KviKvsObject_painter::functionresetMatrix(KviKvsObjectFunctionCall *c)
 	m_pPainter->setWorldMatrix( m_pMatrix );
     return true;
 }
+
+#ifdef COMPILE_USE_QT4
+bool KviKvsObject_painter::functionsetOpacity(KviKvsObjectFunctionCall *c)
+{
+	if(!m_pPainter)return true; 
+	kvs_real_t dOpacity;
+		
+	KVSO_PARAMETERS_BEGIN(c)
+			KVSO_PARAMETER("opacity_factor",KVS_PT_DOUBLE,0,dOpacity)	
+	KVSO_PARAMETERS_END(c)
+	m_pPainter->setOpacity(dOpacity);
+	return true;
+}
+bool KviKvsObject_painter::functionsetTextAntialiasing(KviKvsObjectFunctionCall *c)
+{
+	if(!m_pPainter)return true; 
+	
+	bool bEnabled;
+	KVSO_PARAMETERS_BEGIN(c)
+		KVSO_PARAMETER("bEnabled",KVS_PT_BOOL,0,bEnabled)
+	KVSO_PARAMETERS_END(c)
+	m_pPainter->setRenderHint(QPainter::TextAntialiasing,bEnabled);
+	return true;
+}
+bool KviKvsObject_painter::functionsetAntialiasing(KviKvsObjectFunctionCall *c)
+{
+	if(!m_pPainter)return true; 
+	
+	bool bEnabled;
+	KVSO_PARAMETERS_BEGIN(c)
+		KVSO_PARAMETER("bEnabled",KVS_PT_BOOL,0,bEnabled)
+	KVSO_PARAMETERS_END(c)
+	m_pPainter->setRenderHint(QPainter::Antialiasing,bEnabled);
+	return true;
+}
+bool KviKvsObject_painter::functionsetSmoothPixmapTransform(KviKvsObjectFunctionCall *c)
+{
+	if(!m_pPainter)return true; 
+	
+	bool bEnabled;
+	KVSO_PARAMETERS_BEGIN(c)
+		KVSO_PARAMETER("bEnabled",KVS_PT_BOOL,0,bEnabled)
+	KVSO_PARAMETERS_END(c)
+	m_pPainter->setRenderHint(QPainter::SmoothPixmapTransform,bEnabled);
+	return true;
+}
+#endif
+
+
+
 #include "m_class_painter.moc"
