@@ -26,7 +26,7 @@
 #include "kvi_error.h"
 
 #include "kvi_debug.h"
-#include "kvi_command.h"
+
 #include "kvi_locale.h"
 #include "kvi_iconmanager.h"
 
@@ -55,20 +55,20 @@
 		The widget is treats as a separator; this means that the item is not selectable and you can, for example, simply insert a label if you need a popup menu with a title.
 		!fn: $insertHandle(<text_label:string>,<popupmenu:object>,[icon])
 		Inserts a submenu with optional icon into the popup menu.
-		!fn: $exec([<widget:objects>,<x:integer>,<y:integer>])
+		!fn: $exec([<widget:objects>,<x:uinteger>,<y:integer>])
 		If called without paramaters show the popup menu at the current pointer position.[br]
 		With the optional parameters show the popup menu at the coordinate x,y widget parameter relative.
-		!fn: $removeItem(<popup_id:integer>)
+		!fn: $removeItem(<popup_id:Uinteger>)
 		Removes the menu item that has the identifier id.
-		!fn: $removeItemAt(<index:integer>)
+		!fn: $removeItemAt(<index:uinteger>)
 		Removes the menu item at position index.
-		!fn: $insertSeparator(<index:integer>)
+		!fn: $insertSeparator(<index:uinteger>)
 		Inserts a separator at position index.[br]
 		If the index is negative the separator becomes the last menu item.
-		!fn: $activatedEvent(<popup_id:integer>)
+		!fn: $activatedEvent(<popup_id:uinteger>)
 		This function is called when a menu item and return the the item id.[br]
 		The default implementation emits the [classfnc]$activated[/classfnc]() signal.
-		!fn: $highligthtedEvent(<popup_id:integer>)
+		!fn: $highligthtedEvent(<popup_id:uinteger>)
 		This function is called when a menu item is highlighted and return the item id.[br]
 		The default implementation emits the [classfnc]$highlighted[/classfnc]() signal.
 	@signals:
@@ -184,7 +184,7 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_popupmenu)
 
 bool KviKvsObject_popupmenu::init(KviKvsRunTimeContext * pContext,KviKvsVariantList *pParams)
 {
-	setObject(new QPopupMenu(parentScriptWidget(), name()), true);
+	setObject(new KviTalPopupMenu(parentScriptWidget(), name()), true);
 	connect(widget(),SIGNAL(activated(int)),this,SLOT(slotactivated(int)));
 	connect(widget(),SIGNAL(highlighted(int)),this,SLOT(slothighlighted(int)));
 	return true;
@@ -203,12 +203,12 @@ bool KviKvsObject_popupmenu::functioninsertItem(KviKvsObjectFunctionCall *c)
     if(!szIcon.isEmpty())
 	{
 		pix = g_pIconManager->getImage(szIcon);
-        if (pix) id=((QPopupMenu *)widget())->insertItem(*pix,szItem);
+        if (pix) id=((KviTalPopupMenu *)widget())->insertItem(*pix,szItem);
 		else c->warning(__tr2qs("pix '%Q' doesn't exists"),&szIcon);
 
 	}
 	else
-		id=((QPopupMenu *)widget())->insertItem(szItem);
+		id=((KviTalPopupMenu *)widget())->insertItem(szItem);
 	c->returnValue()->setInteger(id);
 	return true;
 }
@@ -235,7 +235,7 @@ bool KviKvsObject_popupmenu::functioninsertWidget(KviKvsObjectFunctionCall *c)
 		c->warning(__tr2qs("Can't add a non-widget object"));
         return TRUE;
     }
-	if (widget()) ((QPopupMenu *)widget())->insertItem(((QPopupMenu  *)(pObject->object())));
+	if (widget()) ((KviTalPopupMenu *)widget())->insertItem(((KviTalPopupMenu  *)(pObject->object())));
 	return true;
 }
 bool KviKvsObject_popupmenu::functioninsertHandle(KviKvsObjectFunctionCall *c)
@@ -260,12 +260,12 @@ bool KviKvsObject_popupmenu::functioninsertHandle(KviKvsObjectFunctionCall *c)
     if(!szIcon.isEmpty())
 	{
 		pix = g_pIconManager->getImage(szIcon);
-        if (pix) id=((QPopupMenu *)widget())->insertItem(*pix,szLabel,((QPopupMenu  *)(ob->object())));
+        if (pix) id=((KviTalPopupMenu *)widget())->insertItem(*pix,szLabel,((KviTalPopupMenu  *)(ob->object())));
 		else c->warning(__tr2qs("pix '%Q' doesn't exists"),&szIcon);
 
 	}
 	else
-		id=((QPopupMenu *)widget())->insertItem(szLabel,((QPopupMenu  *)(ob->object())));
+		id=((KviTalPopupMenu *)widget())->insertItem(szLabel,((KviTalPopupMenu  *)(ob->object())));
 	c->returnValue()->setInteger(id);
 	return true;
 }
@@ -273,12 +273,12 @@ bool KviKvsObject_popupmenu::functionexec(KviKvsObjectFunctionCall *c)
 {
 	if(!c->params()->count())
 	{
-	 ((QPopupMenu *)widget())->exec(QCursor::pos());
+	 ((KviTalPopupMenu *)widget())->exec(QCursor::pos());
 	 return true;
 	}
 
 	KviKvsObject *pObject;
-	kvs_int_t iX,iY;
+	kvs_uint_t iX,iY;
 	QString szLabel,szIcon;
 	kvs_hobject_t hObject;
 	KVSO_PARAMETERS_BEGIN(c)
@@ -303,36 +303,36 @@ bool KviKvsObject_popupmenu::functionexec(KviKvsObjectFunctionCall *c)
 		return true;
 	}
 
-	((QPopupMenu *)widget())->exec(((QWidget *)(pObject->object()))->mapToGlobal(QPoint(iX,iY)) );
+	((KviTalPopupMenu *)widget())->exec(((QWidget *)(pObject->object()))->mapToGlobal(QPoint(iX,iY)) );
 
 	return true;
 }
 bool KviKvsObject_popupmenu::functionremoveItem(KviKvsObjectFunctionCall *c)
 {
-	kvs_int_t uItem;
+	kvs_uint_t uItem;
 	KVSO_PARAMETERS_BEGIN(c)
 		KVSO_PARAMETER("item_id",KVS_PT_UNSIGNEDINTEGER,0,uItem)
 	KVSO_PARAMETERS_END(c)
-	if(widget()) ((QPopupMenu *)widget())->removeItem(uItem);
+	if(widget()) ((KviTalPopupMenu *)widget())->removeItem(uItem);
 	return true;
 }
 bool KviKvsObject_popupmenu::functionremoveItemAt(KviKvsObjectFunctionCall *c)
 {
-	kvs_int_t uIndex;
+	kvs_uint_t uIndex;
 	KVSO_PARAMETERS_BEGIN(c)
 		KVSO_PARAMETER("index",KVS_PT_UNSIGNEDINTEGER,0,uIndex)
 	KVSO_PARAMETERS_END(c)
-	if(widget())((QPopupMenu *)widget())->removeItemAt(uIndex);
+	if(widget())((KviTalPopupMenu *)widget())->removeItemAt(uIndex);
 	return true;
 }
 
 bool KviKvsObject_popupmenu::functioninsertSeparator(KviKvsObjectFunctionCall *c)
 {
-	kvs_int_t uIndex;
+	kvs_uint_t uIndex;
 	KVSO_PARAMETERS_BEGIN(c)
 		KVSO_PARAMETER("index",KVS_PT_UNSIGNEDINTEGER,0,uIndex)
 	KVSO_PARAMETERS_END(c)
-	if(widget())((QPopupMenu *)widget())->insertSeparator(uIndex);
+	if(widget())((KviTalPopupMenu *)widget())->insertSeparator(uIndex);
 	return true;
 }
 
