@@ -24,7 +24,7 @@
 //
 
 
-#include <qpopupmenu.h>
+#include "kvi_tal_popupmenu.h"
 #include <qcursor.h>
 #include "class_widget.h"
 #include "object_macros.h"
