@@ -24,7 +24,7 @@
 //   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 //
 
-#include <qprogressbar.h>
+//#include <qprogressbar.h>
 #include "class_widget.h"
 #include "object_macros.h"
 
