@@ -23,7 +23,7 @@
 #include "class_radiobutton.h"
 #include "kvi_error.h"
 #include "kvi_debug.h"
-#include "kvi_command.h"
+
 #include "kvi_locale.h"
 #include "kvi_iconmanager.h"
 
@@ -51,6 +51,11 @@
 		!fn: $setPixmap(<image_id>)
 		Sets the pixmap shown on the radiobutton..See the [doc:image_id]image identifier[/doc] documentation for the explaination
 		of the <image_id> parameter.
+		!fn: <bool>$toggleEvent()
+		Called by KVIrc when the radibutton state is toggled.
+		The default implementation emits the toggled(<bool>) signal.
+		!sg: $toggled()
+		This signal is emitted by the default implementation of [classfnc]$toggleEvent[/classfnc]().[br]
 		
 
 */
@@ -62,6 +67,7 @@ KVSO_BEGIN_REGISTERCLASS(KviKvsObject_radiobutton,"radiobutton","widget")
 	KVSO_REGISTER_HANDLER(KviKvsObject_radiobutton,"setChecked", functionSetChecked)
 	KVSO_REGISTER_HANDLER(KviKvsObject_radiobutton,"isChecked", functionIsChecked)
 	KVSO_REGISTER_HANDLER(KviKvsObject_radiobutton,"setImage", functionSetImage)
+	KVSO_REGISTER_HANDLER(KviKvsObject_radiobutton,"toggleEvent",function_toggleEvent)
 
 KVSO_END_REGISTERCLASS(KviKvsObject_radiobutton)
 
@@ -77,6 +83,7 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_radiobutton)
 bool KviKvsObject_radiobutton::init(KviKvsRunTimeContext * pContext,KviKvsVariantList *pParams)
 {
 	setObject(new QRadioButton(parentScriptWidget(),name()),true);
+	connect(widget(),SIGNAL(toggled(bool)),this,SLOT(toggled(bool)));
 	return true;
 }
 bool KviKvsObject_radiobutton::functionSetText(KviKvsObjectFunctionCall *c)
@@ -115,6 +122,17 @@ bool KviKvsObject_radiobutton::functionSetImage(KviKvsObjectFunctionCall *c)
 	if(pix)widget()->setIcon(*pix);
 	return true;
 }
+bool KviKvsObject_radiobutton::function_toggleEvent(KviKvsObjectFunctionCall *c)
+{
+	emitSignal("toggled",c,c->params());
+	return true;
+}
+
+void KviKvsObject_radiobutton::toggled(bool b)
+{
+	KviKvsVariantList params(new KviKvsVariant(b));
+	callFunction(this,"toggleEvent",&params);
+}
 
 
 #include "m_class_radiobutton.moc"
