@@ -42,6 +42,10 @@ protected:
 	bool functionIsChecked(KviKvsObjectFunctionCall *c);
 	bool functionSetChecked(KviKvsObjectFunctionCall *c);
 	bool functionSetImage(KviKvsObjectFunctionCall *c);
+	bool function_toggleEvent(KviKvsObjectFunctionCall *c);
+protected slots:
+	void toggled(bool b);
+
 };
 
 #endif	//!_CLASS_RADIOBUTTON_H_
