@@ -23,9 +23,9 @@
 //
 #include "kvi_socket.h"
 
-#include "kvi_scriptobject.h"
 
-#include "kvi_list.h"
+
+#include "kvi_pointerlist.h"
 #include <qsocketnotifier.h>
 #include <qtimer.h>
 
@@ -118,6 +118,7 @@ class KviKvsObject_socket : public KviKvsObject
 public:
 	KVSO_DECLARE_OBJECT(KviKvsObject_socket)
 protected:
+	bool               m_bUdp;  
 	kvi_socket_t       m_sock;
 	int                m_iStatus;
 	QString             m_szRemoteIp;
@@ -156,6 +157,8 @@ protected:
 	bool functionWrite(KviKvsObjectFunctionCall *c);
 	bool functionWriteHex(KviKvsObjectFunctionCall *c);
 
+	bool functionSetProtocol(KviKvsObjectFunctionCall *c);
+
 	bool functionListen(KviKvsObjectFunctionCall *c);
 	bool functionAccept(KviKvsObjectFunctionCall *c);
 
