@@ -25,7 +25,7 @@
 #include "class_spinbox.h"
 #include "kvi_error.h"
 #include "kvi_debug.h"
-#include "kvi_command.h"
+
 #include "kvi_locale.h"
 #include "kvi_iconmanager.h"
 
@@ -86,6 +86,16 @@
 		!fn: <string> $specialValueText()
 		Returns the special-value text.
 		See also [classfnc]$setSpecialValueText[/classfnc]()
+		!fn: $valueChangedEvent(<new value:integer>)
+		This function is called by the framework when the spinbox value is changed and return the new slider value as its argument.[br]
+		The default implementation emits the [classfnc]$valueChanged[/classfnc]() signal,
+		so it is easy to handle the values from many spinboxes without reimplementing
+		the [classfnc]$valueChangedEvent[/classfnc]() for every one.[br]
+		Note: If you reimplement this function to catch the spinbox value, you will have to emit the signal by yourself (if you still need it, obviously).
+		@signals:
+		!sg: $valueChanged()
+		This signal is emitted by the default implementation of [classfnc]valueChangedEvent[/classfnc]().[br]
+		If you reimplement that function you will have to emit the signal manually (if you still need it).
 */
 
 
@@ -108,7 +118,7 @@ KVSO_BEGIN_REGISTERCLASS(KviKvsObject_spinbox,"spinbox","widget")
 	KVSO_REGISTER_HANDLER(KviKvsObject_spinbox,"setSuffix", functionsetSuffix);
 
 	
-//	KVSO_REGISTER_HANDLER(KviKvsObject_spinbox,"valueChangedEvent", functionvalueChangedEvent);
+	KVSO_REGISTER_HANDLER(KviKvsObject_spinbox,"valueChangedEvent", functionvalueChangedEvent);
 KVSO_END_REGISTERCLASS(KviKvsObject_spinbox)
 
 KVSO_BEGIN_CONSTRUCTOR(KviKvsObject_spinbox,KviKvsObject_widget)
@@ -123,7 +133,7 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_spinbox)
 bool KviKvsObject_spinbox::init(KviKvsRunTimeContext * pContext,KviKvsVariantList *pParams)
 {
 	setObject(new QSpinBox(parentScriptWidget(), name()), true);
-//	connect(widget(),SIGNAL(valueChanged(int)),this,SLOT(valueChanged(int)));
+	connect(widget(),SIGNAL(valueChanged(int)),this,SLOT(valueChanged(int)));
 	return true;
 }
 
@@ -186,7 +196,15 @@ bool KviKvsObject_spinbox::functionmaxValue(KviKvsObjectFunctionCall *c)
 }
 bool KviKvsObject_spinbox::functionlineStep(KviKvsObjectFunctionCall *c)
 {
-	if (widget()) c->returnValue()->setInteger(((QSpinBox *)widget())->lineStep());
+	if (widget())
+	{
+		#ifdef COMPILE_USE_QT4
+			c->returnValue()->setInteger(((QSpinBox *)widget())->singleStep());
+		#else
+			c->returnValue()->setInteger(((QSpinBox *)widget())->lineStep());
+		#endif
+	}
+	
 	return true;
 }
 
@@ -232,4 +250,16 @@ bool KviKvsObject_spinbox::functionsetSuffix(KviKvsObjectFunctionCall *c)
 	return true;
 }
 
+bool KviKvsObject_spinbox::functionvalueChangedEvent(KviKvsObjectFunctionCall *c)
+{
+	emitSignal("valueChanged",c,c->params());
+	return true;
+}
+
+void KviKvsObject_spinbox::valueChanged(int value)
+{
+	KviKvsVariantList params(new KviKvsVariant((kvs_int_t)value));
+	callFunction(this,"valueChangedEvent",&params);
+}
+
 #include "m_class_spinbox.moc"
