@@ -54,9 +54,11 @@ protected:
 	bool functionlineStep(KviKvsObjectFunctionCall *c);
 	bool functionsetSpecialValueText(KviKvsObjectFunctionCall *c);
 	bool functionspecialValueText(KviKvsObjectFunctionCall *c);
-
-
-
+	
+	bool functionvalueChangedEvent(KviKvsObjectFunctionCall *c);
+	
+protected slots:
+	void valueChanged(int);
 };
 
 #endif	//!_CLASS_SPINBOX_H_
