@@ -27,11 +27,17 @@
 #include "kvi_debug.h"
 #include "kvi_locale.h"
 #include "kvi_error.h"
-#include "kvi_command.h"
+
 #include "kvi_app.h"
-//#include "kvi_uparser.h"
+
 #include "kvi_window.h"
 #include "kvi_kvs_script.h"
+#ifdef COMPILE_USE_QT4
+#include <QMouseEvent>
+#define QT_LEFT_BUTTON Qt::LeftButton
+#else
+#define QT_LEFT_BUTTON QEvent::LeftButton
+#endif
 //#warning "Functions to change colors for different states"
 //#warning "$setUnderline(), $underline()"
 
@@ -157,138 +163,8 @@ bool KviScriptUrlLabelObject::eventFilter(QObject * o, QEvent * e)
 		Returns true if the label reacts on single clicks, false if it
 		reacts only on double clicks.
 */
-/*
-#define urlLabelFuncReg(__nam, __func) \
-	g_pUrlLabelClass->registerFunctionHandler(__nam, \
-	(KviScriptObjectFunctionHandlerProc)(KVI_PTR2MEMBER(KviScriptUrlLabelObject::__func)),\
-	0, true);
 
-void KviScriptUrlLabelObject::registerSelf()
-{
-	KviScriptObjectClass * base = g_pScriptObjectController-> \
-		lookupClass("label");
-	__range_valid(base);
-
-	g_pUrlLabelClass = new KviScriptObjectClass(base, "urllabel",
-		urlLabelClassCreateInstance, true);
-
-	urlLabelFuncReg("setUrl", functionSetUrl);
-	urlLabelFuncReg("url", functionUrl);
-	urlLabelFuncReg("setAction", functionSetAction);
-	urlLabelFuncReg("action", functionAction);
-	urlLabelFuncReg("setText", functionSetText);
-	urlLabelFuncReg("setCursorChange", functionSetCursorChange);
-	urlLabelFuncReg("cursorChange", functionCursorChange);
-	urlLabelFuncReg("setUseSingleClick", functionSetUseSingleClick);
-	urlLabelFuncReg("useSingleClick", functionUseSingleClick);
-}
-
-void KviScriptUrlLabelObject::unregisterSelf()
-{
-	delete g_pUrlLabelClass;
-    g_pUrlLabelClass = 0;
-}
-
-bool KviScriptUrlLabelObject::functionSetUrl(KviCommand * c, KviParameterList * p, \
-	KviStr & b)
-{
-	if(!widget())
-		return true;
-
-	ENTER_STACK_FRAME(c, "urllabel::setUrl");
-
-	KviStr * url = p->first();
-	if(url->isEmpty())
-		return c->error(KviError_notEnoughParameters);
-
-	m_url = url->ptr();
-	return c->leaveStackFrame();
-}
-
-bool KviScriptUrlLabelObject::functionUrl(KviCommand * c, KviParameterList * p, \
-	KviStr & b)
-{
-	b.append(m_url);
-	return true;
-}
-
-bool KviScriptUrlLabelObject::functionSetAction(KviCommand * c, KviParameterList * p,\
-	KviStr & b)
-{
-	if(!widget())
-		return true;
-
-	ENTER_STACK_FRAME(c, "urllabel::setAction");
-
-	KviStr * act = p->first();
-	if(act->isEmpty())
-		return c->error(KviError_notEnoughParameters);
-
-	m_action = act->ptr();
-	return c->leaveStackFrame();
-}
-
-bool KviScriptUrlLabelObject::functionAction(KviCommand * c, KviParameterList * p,
-	KviStr & b)
-{
-	b.append(m_action);
-	return true;
-}
-
-
-bool KviScriptUrlLabelObject::functionSetText(KviCommand * c, KviParameterList * p, \
-	KviStr & b)
-{
-	if(widget())
-	{
-		if(p->first())
-			((QLabel *)widget())->setText(p->first()->ptr());
-		else
-			((QLabel *)widget())->setText("[!-NULL-!]");
-	}
-
-	((QLabel *)widget())->setFixedSize(((QLabel *)widget())->sizeHint());
-
-	return true;
-}
-
-bool KviScriptUrlLabelObject::functionSetCursorChange(KviCommand * c, \
-	KviParameterList *p, KviStr & b)
-{
-	if(!widget())
-		return true;
-
-	if(m_changeCursor = p->getBool())
-		widget()->setCursor(Qt::pointingHandCursor);
-	else
-		widget()->setCursor(Qt::arrowCursor);
-
-	return true;
-}
-
-bool KviScriptUrlLabelObject::functionCursorChange(KviCommand * c, \
-	KviParameterList * p, KviStr & b)
-{
-	b.append((m_changeCursor ? '1' : '0'));
-	return true;
-}
-
-bool KviScriptUrlLabelObject::functionSetUseSingleClick(KviCommand * c, \
-	KviParameterList * p, KviStr & b)
-{
-	m_useSingleClick = p->getBool();
-	return true;
-}
-
-bool KviScriptUrlLabelObject::functionUseSingleClick(KviCommand * c, \
-	KviParameterList * p, KviStr & b)
-{
-	b.append((m_useSingleClick ? '1' : '0'));
-	return true;
-}
-*/
-// ========================================================================
-KVSO_BEGIN_REGISTERCLASS(KviKvsObject_urlabel,"urlabel","label")
+KVSO_BEGIN_REGISTERCLASS(KviKvsObject_urlabel,"urllabel","label")
 
 	KVSO_REGISTER_HANDLER(KviKvsObject_urlabel,"setUrl",functionsetUrl)
 	KVSO_REGISTER_HANDLER(KviKvsObject_urlabel,"url",functionurl)
@@ -327,7 +203,7 @@ bool KviKvsObject_urlabel::eventFilter(QObject * o, QEvent * e)
 			break;
 		case QEvent::Leave:
 			// this doesn't work...
-			if(((QMouseEvent *)e)->state() & QEvent::LeftButton)
+			if(((QMouseEvent *)e)->state() & QT_LEFT_BUTTON)
 				pal.setColor(QColorGroup::Foreground, \
 					m_activeClr);
 			else
@@ -352,7 +228,7 @@ bool KviKvsObject_urlabel::eventFilter(QObject * o, QEvent * e)
 		case QEvent::MouseButtonPress:
 			m_lastClickWasDbl = false;
 			if(!((QMouseEvent * )e)->button() & \
-			  QEvent::LeftButton || !m_useSingleClick)
+			  QT_LEFT_BUTTON || !m_useSingleClick)
 				break;
 			pal.setColor(QColorGroup::Foreground, m_activeClr);
 			break;
