@@ -24,7 +24,7 @@
 
 #include "kvi_malloc.h"
 #include "kvi_debug.h"
-#include "kvi_command.h"
+
 #include "kvi_error.h"
 #include "kvi_locale.h"
 #include "kvi_iconmanager.h"
@@ -37,15 +37,24 @@
 #include <qiconset.h>
 #include <qcolor.h>
 #include <qlayout.h>
+#include <qbitmap.h>
 #include <qmetaobject.h>
 #include "class_widget.h"
 #include "class_pixmap.h"
+
+#ifdef COMPILE_USE_QT4
+	#include <QKeyEvent>
+	#include <QDesktopWidget>
+#else
+	#include <qwidgetlist.h>
+#endif
+
 #include <qwidget.h>
 #include <qtooltip.h>
 #include <qfont.h>
 #include <qvariant.h>
-#include <qwidgetlist.h>
 
+// FIX ME: WFLAGS
 const char * const widgettypes_tbl[] = {
 			"TopLevel",
 			"Dialog",
@@ -56,9 +65,30 @@ const char * const widgettypes_tbl[] = {
 			"StaysOnTop",
 			"SysMenu",
 			"Minimize",
-			"Maximize"
+			"Maximize",
+			"NoAutoErase"
 			   };
+#ifdef COMPILE_USE_QT4
+const Qt::WidgetAttribute widgetattributes_cod[]= {
+	Qt::WA_OpaquePaintEvent,
+	Qt::WA_NoSystemBackground,
+	Qt::WA_PaintOnScreen,
+	Qt::WA_NoMousePropagation,
+};
+
+const char * const widgetattributes_tbl[] = {
+	"opaquePaintEvent",
+	"noSystemBackground",
+	"paintOnScreen",
+	"noMousePropagation",
+};
+#define widgetattributes_num	(sizeof(widgetattributes_tbl) / sizeof(widgetattributes_tbl[0]))
+
+
+const Qt::WindowType widgettypes_cod[] = {
+#else 
 const int widgettypes_cod[] = {
+#endif
 		Qt::WType_TopLevel,
 		Qt::WType_Dialog,
 		Qt::WType_Popup,
@@ -68,11 +98,27 @@ const int widgettypes_cod[] = {
 		Qt::WStyle_StaysOnTop,
 		Qt::WStyle_SysMenu,
 		Qt::WStyle_Minimize,
-		Qt::WStyle_Maximize
+		Qt::WStyle_Maximize,
+		Qt::WNoAutoErase
 };
 
-#define widgettypes_num	(sizeof(widgettypes_tbl) / sizeof(widgettypes_tbl[0]))
 
+#ifdef COMPILE_USE_QT4
+
+	#define QT_WIDGET_TABFOCUS Qt::TabFocus
+	#define	QT_WIDGET_CLICKFOCUS Qt::ClickFocus
+	#define QT_WIDGET_STRONGFOCUS Qt::StrongFocus
+	#define QT_WIDGET_NOFOCUS Qt::NoFocus
+
+#else
+	#define QT_WIDGET_TABFOCUS QWidget::TabFocus
+	#define	QT_WIDGET_CLICKFOCUS QWidget::ClickFocus
+	#define QT_WIDGET_STRONGFOCUS QWidget::StrongFocus
+	#define QT_WIDGET_NOFOCUS QWidget::NoFocus
+#endif
+
+
+#define widgettypes_num	(sizeof(widgettypes_tbl) / sizeof(widgettypes_tbl[0]))
 
 /*
 	@doc: widget
@@ -251,48 +297,55 @@ const int widgettypes_cod[] = {
 		Normally you will receive this event only if a mouse button is being pressed
 		while moving. If you want to receive it also when the mouse buttons are not
 		pressed, call [classfnc]$setMouseTracking[/classfnc]().
-		If you call "[cmd]setreturn[/cmd] 1" you will stop the internal processing
+		If you call "[cmd]return[/cmd]$true" you will stop the internal processing
 		of this event. The default implementation does nothing.
 		!fn: $focusInEvent()
 		This function is called when this widget gains keyboard focus.
-		If you call "[cmd]setreturn[/cmd] 1" you will stop the internal processing
+		If you call "[cmd]return[/cmd] $true" you will stop the internal processing
 		of this event. The default implementation does nothing.
 		!fn: $focusOutEvent()
 		This function is called when this widget looses keyboard focus.
-		If you call "[cmd]setreturn[/cmd] 1" you will stop the internal processing
+		If you call "[cmd]return[/cmd] $true" you will stop the internal processing
 		of this event. The default implementation does nothing.
 		!fn: $mouseLeaveEvent()
 		This function is called when the mouse leaves this widget.
-		If you call "[cmd]setreturn[/cmd] 1" you will stop the internal processing
+		If you call "[cmd]return[/cmd] $true" you will stop the internal processing
 		of this event. The default implementation does nothing.
 		!fn: $mouseEnterEvent()
 		This function is called when the mouse enters this widget.
-		If you call "[cmd]setreturn[/cmd] 1" you will stop the internal processing
+		If you call "[cmd]return[/cmd] $true" you will stop the internal processing
 		of this event. The default implementation does nothing.
 		!fn: $showEvent()
 		This function is called when this widget is being shown.
-		If you call "[cmd]setreturn[/cmd] 1" you will stop the internal processing
+		If you call "[cmd]return[/cmd] $true" you will stop the internal processing
 		of this event. The default implementation does nothing.
 		!fn: $hideEvent()
 		This function is called when this widget is being hidden.
-		If you call "[cmd]setreturn[/cmd] 1" you will stop the internal processing
+		If you call "[cmd]return[/cmd] $true" you will stop the internal processing
 		of this event. The default implementation does nothing.
 		!fn: $closeEvent()
 		This function is called when this widget is going to be closed.
-		If you call "[cmd]setreturn[/cmd] 1" you will ignore the close event.
+		If you call "[cmd]return[/cmd] $true" you will ignore the close event.
 		The default implementation does nothing.
 		!fn: $resizeEvent()
 		This function is called immediately after this widget has been resized.
-		If you call "[cmd]setreturn[/cmd] 1" you will stop the internal processing
+		If you call "[cmd]return[/cmd] $true" you will stop the internal processing
 		of this event. The default implementation does nothing.
 		!fn: $moveEvent()
 		This function is called immediately after this widget has been moved.
-		If you call "[cmd]setreturn[/cmd] 1" you will stop the internal processing
+		If you call "[cmd]return[/cmd] $true" you will stop the internal processing
 		of this event. The default implementation does nothing.
+		!fn: <tip:string> $maybeTipEvent(<x_tip_pos:integer>,<y_tip_pos:integer>)[QT4 only]
+		This event handler is called when a eventualy tip is going to be show.
+		You can be reimplement this event and set a dynamic tool tip by using "[cmd]return[/cmd] <tooltip_string>".
+		If a tooltip has setted with [classfnc]$setTooltip[/classfnc] the dynamic tooltip will be ignored.
+		The default implementation does nothing.		
 		!fn: $paintEvent()
 		This event handler can be reimplemented to repaint all or part of the widget.
 		It's needed by the Painter class.
 		It's very useful for drawing flicker free animations or low level special graphic effects.
+		If you call "[cmd]return[/cmd] $true" you will stop the internal processing
+		of this event.
 		The default implementation does nothing.
 		!fn: $setIcon(<image_id>)
 		Sets the icon for this widget. This is meaningful only for toplevel widgets.
@@ -323,6 +376,7 @@ const int widgettypes_cod[] = {
 		Dialog		- indicates that this widget is a top-level window that should be decorated as a dialog[br]
 		Desktop		- indicates that this widget is the desktop[br]
 		Popup		- indicates that this widget is a popup top-level window[br]
+		NoAutoErase - indicates that this widget paints all its pixels. Updating, resizing, scrolling and focus changes should therefore not erase the widget.
 		Customize	- let's the user to customize the style of the widget.[br]
 		[br]
 		Valid parameter for a customized widget are:[br]
@@ -387,7 +441,11 @@ const int widgettypes_cod[] = {
 		Translates the global screen coordinate pos to widget coordinates.
 		!fn: $mapToGlobal(<x>,<y>)
 		Translates widget coordinates into the global screen coordinate pos.
-	@examples:
+		!fn: integer $globalCursorX()
+		Return the x coordinate of mouse pointer global position.
+		!fn: integer $globalCursorY()
+		Return the y coordinate of the mo>use pointer global position.
+		@examples:
 		[example]
 			%Widget = $new(widget)
 			# This is the main container for other elements.
@@ -482,6 +540,7 @@ const int widgettypes_cod[] = {
 //=============================================================================================================
 
 
+
 KVSO_BEGIN_REGISTERCLASS(KviKvsObject_widget,"widget","object")
 	KVSO_REGISTER_HANDLER(KviKvsObject_widget,"reparent",function_reparent)
 	// apparence
@@ -540,6 +599,12 @@ KVSO_BEGIN_REGISTERCLASS(KviKvsObject_widget,"widget","object")
 	KVSO_REGISTER_HANDLER(KviKvsObject_widget,"setBackgroundImage",function_setBackgroundImage)
 	KVSO_REGISTER_HANDLER(KviKvsObject_widget,"backgroundColor",function_backgroundColor)
 	KVSO_REGISTER_HANDLER(KviKvsObject_widget,"foregroundColor",function_foregroundColor)
+	KVSO_REGISTER_HANDLER(KviKvsObject_widget,"setMask",function_setMask)
+
+	// QT4 only
+#ifdef COMPILE_USE_QT4
+	KVSO_REGISTER_HANDLER(KviKvsObject_widget,"setAttribute",function_setAttribute)
+#endif
 
 	// events
 	KVSO_REGISTER_STANDARD_NOTHINGRETURN_HANDLER(KviKvsObject_widget,"mousePressEvent")
@@ -557,19 +622,19 @@ KVSO_BEGIN_REGISTERCLASS(KviKvsObject_widget,"widget","object")
 	KVSO_REGISTER_STANDARD_NOTHINGRETURN_HANDLER(KviKvsObject_widget,"moveEvent")
 	KVSO_REGISTER_STANDARD_NOTHINGRETURN_HANDLER(KviKvsObject_widget,"paintEvent")
 	KVSO_REGISTER_STANDARD_NOTHINGRETURN_HANDLER(KviKvsObject_widget,"keyPressEvent")
+#ifdef COMPILE_USE_QT4
+	KVSO_REGISTER_STANDARD_NOTHINGRETURN_HANDLER(KviKvsObject_widget,"maybeTipEvent")
+#endif
 
 
 KVSO_END_REGISTERCLASS(KviKvsObject_widget)
 
 
 KVSO_BEGIN_CONSTRUCTOR(KviKvsObject_widget,KviKvsObject)
-
 KVSO_END_CONSTRUCTOR(KviKvsObject_widget)
 
-
 KVSO_BEGIN_DESTRUCTOR(KviKvsObject_widget)
 	emit aboutToDie();
-
 KVSO_END_CONSTRUCTOR(KviKvsObject_widget)
 
 bool KviKvsObject_widget::init(KviKvsRunTimeContext * pContext,KviKvsVariantList * pParams)
@@ -580,16 +645,36 @@ bool KviKvsObject_widget::init(KviKvsRunTimeContext * pContext,KviKvsVariantList
 
 bool KviKvsObject_widget::eventFilter(QObject *o,QEvent *e)
 {
-
 	if(o == object())
 	{
-		QString ret;
+		bool ret=false;
 		int aparam;
+		bool brokenhandler=false;
+		KviKvsVariant *retv=new KviKvsVariant(ret);
+			
 		switch(e->type())
 		{
-		case QEvent::Paint:
-			callFunction(this,"paintEvent",0,0);
-			break;
+			#ifdef COMPILE_USE_QT4
+			case QEvent::ToolTip:
+			{
+				QHelpEvent *helpEvent = static_cast<QHelpEvent *>(e);
+				QPoint point=helpEvent->pos();
+				QString szTooltip;
+				KviKvsVariant *tipret=new KviKvsVariant(szTooltip);
+				KviKvsVariantList params(new KviKvsVariant((kvs_int_t)point.x()),new KviKvsVariant((kvs_int_t)point.y()));
+				callFunction(this,"maybeTipEvent",tipret,&params);
+				tipret->asString(szTooltip);
+				QToolTip::showText(helpEvent->globalPos(),szTooltip);
+				break;
+			}
+			#endif
+			case QEvent::Paint:
+			{
+				QRect rect=((QPaintEvent *)e)->rect();
+				KviKvsVariantList params(new KviKvsVariant((kvs_int_t)rect.x()),new KviKvsVariant((kvs_int_t)rect.y()),new KviKvsVariant((kvs_int_t)rect.width()),new KviKvsVariant((kvs_int_t)rect.height()));
+				callFunction(this,"paintEvent",retv,&params);
+				break;
+			}
 
 		case QEvent::KeyPress:
 			{
@@ -701,83 +786,88 @@ bool KviKvsObject_widget::eventFilter(QObject *o,QEvent *e)
 			}
 			break;
 			case QEvent::MouseButtonPress:
-					if(((QMouseEvent *)e)->button() & LeftButton)aparam = 0;
+					if(((QMouseEvent *)e)->button() & Qt::LeftButton)aparam = 0;
 				else {
-					if(((QMouseEvent *)e)->button() & RightButton)aparam = 1;
+					if(((QMouseEvent *)e)->button() & Qt::RightButton)aparam = 1;
 					else aparam = 2;
 				}
-				if(!callFunction(this,"mousePressEvent",new KviKvsVariant(ret),new KviKvsVariantList(new KviKvsVariant((kvs_int_t)aparam),new KviKvsVariant((kvs_int_t)((QMouseEvent *)e)->pos().x()),new KviKvsVariant((kvs_int_t)((QMouseEvent *)e)->pos().y())
-				))) ret = ""; // ignore results of a broken event handler
+				if(!callFunction(this,"mousePressEvent",retv,new KviKvsVariantList(new KviKvsVariant((kvs_int_t)aparam),new KviKvsVariant((kvs_int_t)((QMouseEvent *)e)->pos().x()),new KviKvsVariant((kvs_int_t)((QMouseEvent *)e)->pos().y())
+				))) brokenhandler = true; // ignore results of a broken event handler
 		break;
 			case QEvent::MouseButtonRelease:
-				if(((QMouseEvent *)e)->button() & LeftButton)aparam = 0;
+				if(((QMouseEvent *)e)->button() & Qt::LeftButton)aparam = 0;
 				else {
-					if(((QMouseEvent *)e)->button() & RightButton)aparam = 1;
+					if(((QMouseEvent *)e)->button() & Qt::RightButton)aparam = 1;
 					else aparam = 2;
 				}
-				if(!callFunction(this,"mouseReleaseEvent",new KviKvsVariant(ret),new KviKvsVariantList(new KviKvsVariant((kvs_int_t)aparam),new KviKvsVariant((kvs_int_t)((QMouseEvent *)e)->pos().x()),new KviKvsVariant((kvs_int_t)((QMouseEvent *)e)->pos().y())
-				))) ret = ""; // ignore results of a broken event handler
+				if(!callFunction(this,"mouseReleaseEvent",retv,new KviKvsVariantList(new KviKvsVariant((kvs_int_t)aparam),new KviKvsVariant((kvs_int_t)((QMouseEvent *)e)->pos().x()),new KviKvsVariant((kvs_int_t)((QMouseEvent *)e)->pos().y())
+				))) brokenhandler = true; // ignore results of a broken event handler
 			break;
 			case QEvent::MouseButtonDblClick:
-				if(( (QMouseEvent *)e)->button() & LeftButton)aparam = 0;
+				if(( (QMouseEvent *)e)->button() & Qt::LeftButton)aparam = 0;
 				else {
-					if(((QMouseEvent *)e)->button() & RightButton)aparam = 1;
+					if(((QMouseEvent *)e)->button() & Qt::RightButton)aparam = 1;
 					else aparam = 2;
 				}
-					if(!callFunction(this,"mouseDoubleClickEvent",new KviKvsVariant(ret),new KviKvsVariantList(new KviKvsVariant((kvs_int_t)aparam),new KviKvsVariant((kvs_int_t)((QMouseEvent *)e)->pos().x()),new KviKvsVariant((kvs_int_t)((QMouseEvent *)e)->pos().y())
-				))) ret = ""; // ignore results of a broken event handler
+					if(!callFunction(this,"mouseDoubleClickEvent",retv,new KviKvsVariantList(new KviKvsVariant((kvs_int_t)aparam),new KviKvsVariant((kvs_int_t)((QMouseEvent *)e)->pos().x()),new KviKvsVariant((kvs_int_t)((QMouseEvent *)e)->pos().y())
+				))) brokenhandler = true; // ignore results of a broken event handler
 
 			break;
 			case QEvent::MouseMove:
-				if( (((QMouseEvent *)e)->state()) & LeftButton) aparam = 0;
+				if( (((QMouseEvent *)e)->state()) & Qt::LeftButton) aparam = 0;
 				else
 				{
-					if(((QMouseEvent *)e)->state() & RightButton)aparam = 1;
+					if(((QMouseEvent *)e)->state() & Qt::RightButton)aparam = 1;
 					else
 						{
-							if(((QMouseEvent *)e)->state() & MidButton)aparam = 2;
+							if(((QMouseEvent *)e)->state() & Qt::MidButton)aparam = 2;
 							else aparam = -1;
 						}
 				}
-				if(!callFunction(this,"mouseMoveEvent",new KviKvsVariant(ret),new KviKvsVariantList(new KviKvsVariant((kvs_int_t)aparam),new KviKvsVariant((kvs_int_t)((QMouseEvent *)e)->pos().x()),new KviKvsVariant((kvs_int_t)((QMouseEvent *)e)->pos().y())
-				))) ret = ""; // ignore results of a broken event handler
+				if(!callFunction(this,"mouseMoveEvent",retv,new KviKvsVariantList(new KviKvsVariant((kvs_int_t)aparam),new KviKvsVariant((kvs_int_t)((QMouseEvent *)e)->pos().x()),new KviKvsVariant((kvs_int_t)((QMouseEvent *)e)->pos().y())
+				))) brokenhandler = true; // ignore results of a broken event handler
 			break;
 			case QEvent::FocusIn:
-				if(!callFunction(this,"focusInEvent",new KviKvsVariant(ret),0))ret = "";
+				if(!callFunction(this,"focusInEvent",retv,0))brokenhandler = true;
 			break;
 			case QEvent::FocusOut:
-				if(!callFunction(this,"focusOutEvent",new KviKvsVariant(ret),0))ret = "";
+				if(!callFunction(this,"focusOutEvent",retv,0))brokenhandler = true;
 			break;
 			case QEvent::Resize:
-				if(!callFunction(this,"resizeEvent",new KviKvsVariant(ret),0))ret = "";
+				if(!callFunction(this,"resizeEvent",retv,0))brokenhandler = true;
 			break;
 			case QEvent::Move:
-				if(!callFunction(this,"moveEvent",new KviKvsVariant(ret),0))ret = "";
+				if(!callFunction(this,"moveEvent",retv,0))brokenhandler = true;
 			break;
 			case QEvent::Close:
-				if(!callFunction(this,"closeEvent",new KviKvsVariant(ret),0))ret = "";
+				if(!callFunction(this,"closeEvent",retv,0))brokenhandler = true;
 			break;
 			case QEvent::Enter:
-				if(!callFunction(this,"mouseEnterEvent",new KviKvsVariant(ret),0))ret = "";
+				if(!callFunction(this,"mouseEnterEvent",retv,0))brokenhandler = true;
 			break;
 			case QEvent::Leave:
-				if(!callFunction(this,"mouseLeaveEvent",new KviKvsVariant(ret),0))ret = "";
+				if(!callFunction(this,"mouseLeaveEvent",retv,0))brokenhandler = true;
 			break;
 			case QEvent::Show:
-				if(!callFunction(this,"showEvent",new KviKvsVariant(ret),0))ret = "";
+				if(!callFunction(this,"showEvent",retv,0))brokenhandler = true;
 			break;
 			case QEvent::Hide:
-				if(!callFunction(this,"hideEvent",new KviKvsVariant(ret),0))ret = "";
+				if(!callFunction(this,"hideEvent",retv,0))ret =false;
 			break;
 			default:
 				return KviKvsObject::eventFilter(o,e);
 			break;
 
 		}
+		if (!brokenhandler)	ret=retv->asBoolean();
+		delete retv;
+		return ret;
+		/*
 		if(ret.length() == 1)
 		{
 			if(KviQString::equalCI("1",ret))return true;
 		}
+		*/
 	}
 
 	return KviKvsObject::eventFilter(o,e);
@@ -1425,16 +1515,16 @@ bool KviKvsObject_widget::function_setFocusPolicy(KviKvsObjectFunctionCall *c)
 	KVSO_PARAMETERS_END(c)
 	if(!widget())return true;
 	if(KviQString::equalCI(szMode, "TabFocus"))
-		widget()->setFocusPolicy(QWidget::TabFocus);
+		widget()->setFocusPolicy(QT_WIDGET_TABFOCUS);
 	else
 	if(KviQString::equalCI(szMode, "ClickFocus"))
-		widget()->setFocusPolicy(QWidget::ClickFocus);
+		widget()->setFocusPolicy(QT_WIDGET_CLICKFOCUS);
 	else
 	if(KviQString::equalCI(szMode, "StrongFocus"))
-		widget()->setFocusPolicy(QWidget::StrongFocus);
+		widget()->setFocusPolicy(QT_WIDGET_STRONGFOCUS);
 	else
 	if(KviQString::equalCI(szMode, "NoFocus"))
-		widget()->setFocusPolicy(QWidget::NoFocus);
+		widget()->setFocusPolicy(QT_WIDGET_NOFOCUS);
 	else c->warning(__tr2qs("Invalid parameters"));
 	return true;
 }
@@ -1442,14 +1532,20 @@ bool KviKvsObject_widget::function_setFocusPolicy(KviKvsObjectFunctionCall *c)
 bool KviKvsObject_widget::function_setWFlags(KviKvsObjectFunctionCall *c)
 {
 	QStringList wflags;
+	//Qt::WindowType sum;
 	KVSO_PARAMETERS_BEGIN(c)
 		KVSO_PARAMETER("widget_flags",KVS_PT_STRINGLIST,KVS_PF_OPTIONAL,wflags)
 	KVSO_PARAMETERS_END(c)
 	if (!widget()) return true;
-	int flag,sum=0;
+	#ifdef COMPILE_USE_QT4
+		Qt::WindowFlags flag,sum=0;
+	#else
+		int flag,sum=0;
+	#endif
 	for ( QStringList::Iterator it = wflags.begin(); it != wflags.end(); ++it )
 	{
-			flag = 0;
+			
+				flag=0;
 			for(unsigned int j = 0; j < widgettypes_num; j++)
 			{
 				if(KviQString::equalCI((*it), widgettypes_tbl[j]))
@@ -1464,8 +1560,13 @@ bool KviKvsObject_widget::function_setWFlags(KviKvsObjectFunctionCall *c)
 				c->warning(__tr2qs("Unknown widget flag '%Q'"),&(*it));
 
 		}
-	widget()->reparent(widget()->parentWidget(),sum,QPoint(widget()->x(),widget()->y()));
-	return true;
+	
+#ifdef COMPILE_USE_QT4
+	widget()->setWindowFlags(sum);
+#else
+	 widget()->reparent(widget()->parentWidget(),sum,QPoint(widget()->x(),widget()->y()));
+#endif
+	 return true;
 }
 
 bool KviKvsObject_widget::function_setFont(KviKvsObjectFunctionCall *c)
@@ -1586,4 +1687,59 @@ bool KviKvsObject_widget::function_globalCursorY(KviKvsObjectFunctionCall *c)
 	if(widget())c->returnValue()->setInteger(QCursor::pos().y());
 	return true;
 }
+bool KviKvsObject_widget::function_setMask(KviKvsObjectFunctionCall *c)
+{
+	KviKvsObject *obj;
+	kvs_hobject_t hObject;
+	KVSO_PARAMETERS_BEGIN(c)
+		KVSO_PARAMETER("pixmap",KVS_PT_HOBJECT,0,hObject)
+	KVSO_PARAMETERS_END(c)
+	obj=KviKvsKernel::instance()->objectController()->lookupObject(hObject);
+	if(!widget())return true;
+	if (!obj)
+	{
+		c->warning(__tr2qs("Pixmap parameter is not an object"));
+		return true;
+	}
+	if (!obj->inherits("KviKvsObject_pixmap"))
+	{
+		c->warning(__tr2qs("Pixmap object required"));
+		return true;
+	}
+	QPixmap * pm=((KviKvsObject_pixmap *)obj)->getPixmap();
+#ifdef COMPILE_USE_QT4
+	QBitmap mask(pm->mask());
+#else
+	QBitmap mask(*pm->mask());
+#endif
+	if (mask.isNull()) c->warning(__tr2qs("Null mask"));
+	widget()->setMask(mask);
+	return true;
+}
+#ifdef COMPILE_USE_QT4
+bool KviKvsObject_widget::function_setAttribute(KviKvsObjectFunctionCall *c)
+{
+	QString attribute;
+	bool bFlag;
+	KVSO_PARAMETERS_BEGIN(c)
+		KVSO_PARAMETER("widget_atribute",KVS_PT_STRING,0,attribute)
+		KVSO_PARAMETER("bool_flag",KVS_PT_BOOLEAN,0,bFlag)
+	KVSO_PARAMETERS_END(c)
+	if (!widget()) return true;
+	bool found=false;
+	unsigned int j = 0;
+	for(; j < widgetattributes_num; j++)
+	{
+		if(KviQString::equalCI(attribute, widgetattributes_tbl[j]))
+		{
+			found=true;
+			break;
+		}
+	}
+	if(found)widget()->setAttribute(widgetattributes_cod[j],bFlag);
+	else c->warning(__tr2qs("Unknown widget attribute '%Q'"),&attribute);	
+	return true;
+}
+#endif
+
 #include "m_class_widget.moc"
