@@ -21,15 +21,12 @@
 //   along with this program. If not, write to the Free Software Foundation,
 //   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 //
-
+#include <kvi_tal_tooltip.h>
 #include "kvi_string.h"
-#include "kvi_scriptobject.h"
-
-
-
-
+#include "qtooltip.h"
 #include "object_macros.h"
 
+
 class KviKvsObject_widget : public KviKvsObject
 {
 	Q_OBJECT
@@ -102,9 +99,15 @@ protected:
 	bool function_width(KviKvsObjectFunctionCall *);
 	bool function_x(KviKvsObjectFunctionCall *);
 	bool function_y(KviKvsObjectFunctionCall *);
+	bool function_setMask(KviKvsObjectFunctionCall *c);
+	
+
+#ifdef COMPILE_USE_QT4
+bool function_setAttribute(KviKvsObjectFunctionCall *c);
+#endif
+
 signals:
 	void aboutToDie();
 };
 
-
 #endif	// !_CLASS_WIDGET_H_
