@@ -26,43 +26,21 @@
 
 #include "kvi_error.h"
 #include "kvi_debug.h"
-#include "kvi_command.h"
+
 #include "kvi_locale.h"
 #include "kvi_frame.h"
 
-static KviScriptObjectClass * g_pWindowClass = 0;
 
 
-
-
-/*
-	@doc:	window
-	@title:
-		window class
-	@type:
-		class
-	@short:
-		A MDI window object
-	@inherits:
-		[class]object[/class]
-		[class]widget[/class]
-	@description:
-		This class rappresents a MDI window in a KVIrc frame.
-		Regardless of the parent object passed, the window will be always
-		a "physical" child of the frame window: you can't embed a window object
-		inside a widget or another window. The parent object will just "own" this
-		window object and eventually destroy it when it dies.
-		This class can manage only a single central child widget that must
-		be set with $setCentralWidget().
-		The central widget MUST be set before you initially call show()
-	@functions:
-*/
-
 KviKvsScriptWindowWindow::KviKvsScriptWindowWindow(KviFrame * pParent,const QString &szName)
 : KviWindow(KVI_WINDOW_TYPE_SCRIPTOBJECT,pParent,szName)
 {
 	m_pCentralWidget = 0;
-	setBackgroundMode(QWidget::NoBackground);
+	#ifdef COMPILE_USE_QT4
+		setBackgroundMode(Qt::NoBackground);
+	#else
+		setBackgroundMode(QWidget::NoBackground);
+	#endif
 }
 
 KviKvsScriptWindowWindow::~KviKvsScriptWindowWindow()
@@ -93,6 +71,33 @@ void KviKvsScriptWindowWindow::centralWidgetDestroyed()
 	m_pCentralWidgetObject = 0;
 }
 
+
+
+
+/*
+	@doc:	window
+	@title:
+		window class
+	@type:
+		class
+	@short:
+		A MDI window object
+	@inherits:
+		[class]object[/class]
+		[class]widget[/class]
+	@description:
+		This class rappresents a MDI window in a KVIrc frame.
+		Regardless of the parent object passed, the window will be always
+		a "physical" child of the frame window: you can't embed a window object
+		inside a widget or another window. The parent object will just "own" this
+		window object and eventually destroy it when it dies.
+		This class can manage only a single central child widget that must
+		be set with $setCentralWidget().
+		The central widget MUST be set before you initially call show()
+	@functions:
+*/
+
+
 KVSO_BEGIN_REGISTERCLASS(KviKvsObject_window,"window","widget")
 	
 	KVSO_REGISTER_HANDLER(KviKvsObject_window,"setCaption", functionsetCaption)
