@@ -1,9 +1,10 @@
+//=============================================================================
 //
 //   File : libkviobjects.cpp
 //   Creation date : Wed Sep 09 2000 20:59:01 by Szymon Stefanek
 //
 //   This file is part of the KVirc irc client distribution
-//   Copyright (C) 1999-2000 Szymon Stefanek (pragma at kvirc dot net)
+//   Copyright (C) 2000-2006 Szymon Stefanek (pragma at kvirc dot net)
 //
 //   This program is FREE software. You can redistribute it and/or
 //   modify it under the terms of the GNU General Public License
@@ -19,25 +20,32 @@
 //   along with this program. If not, write to the Free Software Foundation,
 //   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 //
+//=============================================================================
 
-#include <qwidgetlist.h>
-#include <qobjectlist.h>
-#include <qlistview.h>
+#include "kvi_tal_listview.h"
 #include <qimage.h>
 #include "kvi_iconmanager.h"
 #include "kvi_window.h"
 #include "kvi_out.h"
 #include "kvi_mirccntrl.h"
-#include "kvi_command.h"
+
 #include "kvi_app.h"
 
 #include "kvi_module.h"
-//#include "kvi_uparser.h"
+
 #include "kvi_locale.h"
 #include "kvi_error.h"
 #include "kvi_cmdformatter.h"
 #include "kvi_out.h"
 #include "kvi_app.h"
+#include "kvi_fileutils.h"
+#ifndef COMPILE_USE_QT4
+	#include <qwidgetlist.h>
+	#include <qobjectlist.h>
+#endif
+
+#include <qdir.h>
+
 #include "class_button.h"
 #include "class_checkbox.h"
 #include "class_urllabel.h"
@@ -59,6 +67,7 @@
 #include "class_radiobutton.h"
 #include "class_process.h"
 #include "class_groupbox.h"
+#include "class_buttongroup.h"
 #include "class_tabwidget.h"
 #include "class_workspace.h"
 #include "class_popupmenu.h"
@@ -74,18 +83,15 @@
 #include "class_wrapper.h"
 #include "class_dialog.h"
 #include "class_xmlreader.h"
-#include "class_image.h"
 #include "class_dockwindow.h"
 #include "class_vbox.h"
 #include "class_hbox.h"
-
 static void dumpChildObjects(KviWindow *pWnd, QObject *parent, const char *spacing, bool bWidgetsOnly, KviKvsArray *n, int &idx);
 
 static bool objects_module_cleanup(KviModule *m)
 {
 	KviKvsObject_process::unregisterSelf();
 	KviKvsObject_socket::unregisterSelf();
-	KviKvsObject_image::unregisterSelf();
 	KviKvsObject_xmlreader::unregisterSelf();
 	KviKvsObject_wrapper::unregisterSelf();
 	KviKvsObject_file::unregisterSelf();
@@ -116,6 +122,7 @@ static bool objects_module_cleanup(KviModule *m)
 	KviKvsObject_hbox::unregisterSelf();
 	KviKvsObject_vbox::unregisterSelf();
 	KviKvsObject_label::unregisterSelf();
+	KviKvsObject_buttongroup::unregisterSelf();
 	KviKvsObject_groupbox::unregisterSelf();	
 	KviKvsObject_dialog::unregisterSelf();
 	KviKvsObject_checkbox::unregisterSelf();
@@ -202,7 +209,7 @@ static bool objects_kvs_cmd_clearObjects(KviKvsModuleCommandCall * c)
 	*/
 
 	KviKvsKernel::instance()->objectController()->clearInstances();
-	if(!c->switches()->find('i',"ii")) KviKvsKernel::instance()->objectController()->clearUserClasses();	
+	if(!c->switches()->find('i',"ii")) KviKvsKernel::instance()->objectController()->clearUserClasses();
 	return true;
 }
 
@@ -219,7 +226,7 @@ static bool objects_kvs_cmd_connect(KviKvsModuleCommandCall * c)
 		@short:
 			Connects a signal to a slot
 		@syntax:
-			objects.connect <source_object> <signal_name> <target_object> <slot_name>
+			objects.connect <source_object:hobject> <signal_name:string> <target_object:hobject> <slot_name:string>
 		@description:
 			Connects the <source_object>'s signal <signal_name> to the
 			<target_object>'s slot <slot_name>.
@@ -232,28 +239,7 @@ static bool objects_kvs_cmd_connect(KviKvsModuleCommandCall * c)
 			[cmd]class[/cmd], [cmd]object.disconnect[/cmd], [doc:objects]objects documentation[/doc]
 	*/
 
-	/*
-		@doc: connect
-		@title:
-			connect
-		@type:
-			command
-		@short:
-			Connects a signal to a slot
-		@syntax:
-			[Deprecated]connect <source_object> <signal_name> <target_object> <slot_name>
-		@description:
-			Connects the <source_object>'s signal <signal_name> to the
-			<target_object>'s slot <slot_name>.
-			When one of the two objects is destroyed, the signal/slot
-			connection is automatically removed.[br]
-			WARNING: This command name collides with the [doc:rfc2812]RFC2812[/doc]
-			CONNECT IRC Op command: this IRC command is available to operators only
-			and is rather rarely used: you can use it by the means of [doc:raw]raw[/doc].
-		@seealso:
-			[cmd]class[/cmd], [cmd]objects.disconnect[/cmd], [doc:objects]objects documentation[/doc]
-	*/
-
+	
 	KviKvsObject *obSrc;
 	KviKvsObject *obTrg;
 	QString szSignal,szSlot;
@@ -292,7 +278,7 @@ static bool objects_kvs_fnc_exists(KviKvsModuleFunctionCall * c)
 		@short:
 			Check if an object exists.
 		@syntax:
-			object.connect <obejct id>
+			<boolean> $object.exists(<obejct id:hobject>)
 		@description:
 			Check if an objects exists and return a boolean value.
 		@seealso:
@@ -309,9 +295,229 @@ static bool objects_kvs_fnc_exists(KviKvsModuleFunctionCall * c)
 	return true;
 }
 
+static bool objects_kvs_fnc_instances(KviKvsModuleFunctionCall * c)
+{ 
+	/*
+		@doc: objects.instances
+		@title:
+			objects.instances
+		@type:
+			command
+		@short:
+			List object instances
+		@syntax:
+			<array> $object.instances(<class name:string>[,<flags:string>])
+		@description:
+			Returns an array with the instance handles of
+			of objects of the specified class. <flags> is a
+			string containing modifiers for the function behaviour.[br]
+			If <flags> contains the letter "s" then
+			only unsubclassed instances of the specified
+			class are returned. This means that if B is
+			a subclass of A then when asked for instances
+			of A without the flag "s" this function will return
+			both instances of A and B, and with the flag "s"
+			this function will return only instances of A (and not B).
+			If the class name does not define a valid class
+			then an empty array is returned and a warning is
+			printed unless the "q" flag is used.
+		@examples:
+			[example]
+			foreach(%x,$objects.instances(object))
+			{
+				echo "OBJECT WITH CLASS" %x->$className() "AND NAME \""%x->$name()"\""
+			}
+			[/example]
+		@seealso:
+			[doc:objects]objects documentation[/doc]
+	*/
+	
+	QString szClassName;
+	QString szFlags;
+	KVSM_PARAMETERS_BEGIN(c)
+		KVSO_PARAMETER("class name",KVS_PT_NONEMPTYSTRING,0,szClassName)
+		KVSO_PARAMETER("flags",KVS_PT_STRING,KVS_PF_OPTIONAL,szFlags)
+	KVSM_PARAMETERS_END(c)
+
+	KviKvsArray * pArry = new KviKvsArray();
+	c->returnValue()->setArray(pArry);
+
+	KviKvsObjectClass * pClass = KviKvsKernel::instance()->objectController()->lookupClass(szClassName);
+	if(!pClass)
+	{
+		if(!szFlags.contains(QChar('q')))
+			c->warning(__tr2qs("The class '%Q' does not exist"),&szClassName);
+		return true;
+	}
+	KviPointerHashTable<void *,KviKvsObject> * od = KviKvsKernel::instance()->objectController()->objectDict();
+
+	KviPointerHashTableIterator<void *,KviKvsObject> it(*od);
+	kvs_uint_t uIdx = 0;
+	if(szFlags.contains(QChar('s')))
+	{
+		while(KviKvsObject * ob = it.current())
+		{
+			if(ob->getExactClass() == pClass)
+			{
+				pArry->set(uIdx,new KviKvsVariant(ob->handle()));
+				uIdx++;
+			}
+			++it;
+		}
+	} else {
+		while(KviKvsObject * ob = it.current())
+		{
+			if(ob->inheritsClass(pClass))
+			{
+				pArry->set(uIdx,new KviKvsVariant(ob->handle()));
+				uIdx++;
+			}
+			++it;
+		}
+	}
+	return true;
+}
+/*
+		@doc: objects.variables
+		@title:
+			objects.variables
+		@type:
+			command
+		@short:
+			List object's variables.
+		@syntax:
+			<hash> objects.variables(<hobject>)
+		@description:
+			Returns an hash with the object's variables(useful only for debugging).			
+		@seealso:
+			[doc:objects]objects documentation[/doc]
+	*/
+static bool objects_kvs_fnc_variables(KviKvsModuleFunctionCall * c)
+{
+	kvs_hobject_t hObj;
+	KVSM_PARAMETERS_BEGIN(c)
+		KVSO_PARAMETER("object",KVS_PT_HOBJECT,0,hObj)
+	KVSM_PARAMETERS_END(c)
+	KviKvsObject *ob=KviKvsKernel::instance()->objectController()->lookupObject(hObj);
+	if (!ob)
+	{
+		c->warning(__tr2qs("Object does not exists"));
+		return true;
+	}
+	KviPointerHashTableIterator<QString,KviKvsVariant> it(* ob->dataContainer()->dict());
+	KviKvsHash* pHash = new KviKvsHash();
+	c->returnValue()->setHash(pHash);
+	while(KviKvsVariant * t = it.current())
+	{
+		pHash->set(it.currentKey(),new KviKvsVariant(*t));
+		++it;
+	}
+	return true;
+
+	
+
+}
+/*
+		@doc: objects.classAllHandlers
+		@title:
+			objects.classAllHandlers
+		@type:
+			function
+		@short:
+			List all the functions .
+		@syntax:
+			<hash> objects.classAllHandlers(<class name:string>)
+		@description:
+			Returns an hash with the class's functions(useful only for debugging).			
+		@seealso:
+			[doc:objects]objects documentation[/doc]
+	*/
+static bool objects_kvs_fnc_classAllHandlers(KviKvsModuleFunctionCall * c)
+{
+	QString szClassName;
+	KVSM_PARAMETERS_BEGIN(c)
+		KVSO_PARAMETER("class name",KVS_PT_NONEMPTYSTRING,0,szClassName)
+	KVSM_PARAMETERS_END(c)
+	KviKvsObjectClass * pClass = KviKvsKernel::instance()->objectController()->lookupClass(szClassName);
+	if(!pClass)
+	{
+		c->warning(__tr2qs("The class '%Q' does not exist"),&szClassName);
+		return true;
+	}
+
+	KviPointerHashTableIterator<QString,KviKvsObjectFunctionHandler>  it(* pClass->getHandlers());
+	KviKvsHash* pHash = new KviKvsHash();
+	c->returnValue()->setHash(pHash);
+	while(KviKvsObjectFunctionHandler * t = it.current())
+	{
+		QString szCode;
+		KviKvsObjectFunctionHandler *handler=pClass->lookupFunctionHandler(it.currentKey());
+		pClass->getFunctionCode(szCode,*handler);
+		pHash->set(it.currentKey(),new KviKvsVariant(szCode));
+		++it;
+	}
+
+	return true;
+}
+static bool objects_kvs_fnc_classes(KviKvsModuleFunctionCall * c)
+{ 
+	
+	/*
+		@doc: objects.classes
+		@title:
+			objects.classes
+		@type:
+			command
+		@short:
+			List user defined classes
+		@syntax:
+			<array> $object.classes()
+		@description:
+			Returns an array with the user defined classes.			
+		@seealso:
+			[doc:objects]objects documentation[/doc]
+	*/
+	
+	KviKvsArray * pArry = new KviKvsArray();
+	c->returnValue()->setArray(pArry);
+	int uIdx=0;
+	KviPointerHashTableIterator<QString,KviKvsObjectClass> it(*KviKvsKernel::instance()->objectController()->classDict());
+	KviPointerHashTable<QString,bool> *classdict=new KviPointerHashTable<QString,bool>;
+	classdict->setAutoDelete(false);
+	bool bFake=true;
+	while(KviKvsObjectClass * pClass=it.current())
+	{
+		if (!pClass->isBuiltin())classdict->insert(it.currentKey(),&bFake);
+		++it;
+	}
+	QString szPath;
+	g_pApp->getLocalKvircDirectory(szPath,KviApp::Classes);
+	QDir d(szPath);
+	QStringList sl;
+	sl = d.entryList(QDir::Files);
+	for(QStringList::Iterator it2 = sl.begin();it2 != sl.end();++it2)
+	{
+		QString szName=*it2;
+		szName.replace("--","::");		
+		if (szName!=".." && szName!=".") classdict->insert(szName.left(szName.length()-4),&bFake);	
+	}
+	KviKvsArray* pArray = new KviKvsArray();
+	c->returnValue()->setArray(pArray);
+	int idx=0;
+	KviPointerHashTableIterator<QString,bool>  strIt(*classdict);
+	while(strIt.current())
+	{
+		pArray->set(idx,new KviKvsVariant(strIt.currentKey()));
+		idx++;
+		++strIt;
+	}
+	delete classdict;
+	return true;
+
+}
 
 static bool objects_kvs_cmd_disconnect(KviKvsModuleCommandCall * c)
-{ 
+{
 	/*
 		@doc: objects.disconnect
 		@title:
@@ -321,7 +527,7 @@ static bool objects_kvs_cmd_disconnect(KviKvsModuleCommandCall * c)
 		@short:
 			Disconnects a signal from a slot
 		@syntax:
-			disconnect <source_object> <signal_name> <target_object> <slot_name>
+			disconnect <source_object:hobject> <signal_name:string> <target_object:hobject> <slot_name:string>
 		@description:
 			Disconnects the <source_object>'s signal <signal_name> from the
 			<target_object>'s slot <slot_name>.
@@ -331,24 +537,7 @@ static bool objects_kvs_cmd_disconnect(KviKvsModuleCommandCall * c)
 			[cmd]class[/cmd], [cmd]objects.connect[/cmd], [doc:objects]objects documentation[/doc]
 	*/
 
-	/*
-		@doc: disconnect
-		@title:
-			disconnect
-		@type:
-			command
-		@short:
-			[Deprecated]Disconnects a signal from a slot
-		@syntax:
-			disconnect <source_object> <signal_name> <target_object> <slot_name>
-		@description:
-			Disconnects the <source_object>'s signal <signal_name> from the
-			<target_object>'s slot <slot_name>.
-			When one of the two objects is destroyed, the signal/slot
-			connection is automatically removed.
-		@seealso:
-			[cmd]class[/cmd], [cmd]connect[/cmd], [doc:objects]objects documentation[/doc]
-	*/
+	
 
 
 	KviKvsObject *obSrc;
@@ -363,6 +552,16 @@ static bool objects_kvs_cmd_disconnect(KviKvsModuleCommandCall * c)
 	KVSM_PARAMETERS_END(c)
 	obTrg=KviKvsKernel::instance()->objectController()->lookupObject(hTrg);
 	obSrc=KviKvsKernel::instance()->objectController()->lookupObject(hSrc);
+	if(!obTrg)
+	{
+		c->warning(__tr2qs("Inexisting target object for objects.disconnect"));
+		return true;
+	}
+	if(!obSrc)
+	{
+		c->warning(__tr2qs("Inexisting source object for objects.disconnect"));
+		return true;
+	}
 	obSrc->disconnectSignal(szSignal,obTrg,szSlot);
 	return true;
 }
@@ -370,7 +569,7 @@ static bool objects_kvs_cmd_disconnect(KviKvsModuleCommandCall * c)
 
 
 static bool objects_kvs_cmd_bitBlt(KviKvsModuleCommandCall * c)
-{ 
+{
 	/*
 		@doc: objects.bitblt
 		@type:
@@ -404,33 +603,51 @@ static bool objects_kvs_cmd_bitBlt(KviKvsModuleCommandCall * c)
 		KVSO_PARAMETER("height",KVS_PT_UNSIGNEDINTEGER,0,uH)
 	KVSO_PARAMETERS_END(c)
 	obSrc=KviKvsKernel::instance()->objectController()->lookupObject(hSrc);
+	if (!obSrc)
+	{
+			c->warning(__tr2qs("Source is not an object"));
+		return true;
+	}
 	obDst=KviKvsKernel::instance()->objectController()->lookupObject(hDst);
-	QImage * imgSource=0;
-	QPaintDevice * pdSource = 0;
-	if (obSrc->inherits("KviKvsObject_image")) 
-		imgSource=((KviKvsObject_image *)obSrc)->image();
-	else{
+	if (!obDst)
+	{
+			c->warning(__tr2qs("Destination is not an object"));
+		return true;
+	}
 
-	if(obSrc->inherits("KviKvsObject_pixmap")) pdSource = ((KviKvsObject_pixmap *)obSrc)->pixmap();
+	QImage  * imgSource=0;
+	QPaintDevice  * pdSource = 0;
+	
+	if(obSrc->inherits("KviKvsObject_pixmap")) pdSource =((KviKvsObject_pixmap *)obSrc)->getPixmap();
 	else if (obSrc->inherits("KviKvsObject_widget")) pdSource=((KviKvsObject_widget *)obSrc)->widget();
 	if (!pdSource)
 	{
 		c->warning(__tr2qs("Widget, Image or Pixmap required "));
 		return true;
 	}
+	QPaintDevice  * pdDest = 0;
+	if(obDst->inherits("KviKvsObject_pixmap")){
+		pdDest= ((KviKvsObject_pixmap *)obDst)->getPixmap();
 	}
-	QPaintDevice * pdDest = 0;
-	if(obDst->inherits("KviKvsObject_pixmap")) pdDest= ((KviKvsObject_pixmap *)obDst)->pixmap();
 	else if (obDst->inherits("KviKvsObject_widget")) pdDest=((KviKvsObject_widget *)obDst)->widget();
 	if (!pdDest)
 	{
 		c->warning(__tr2qs("Widget or Pixmap required"));
 		return true;
 	}
-	if (obSrc->inherits("KviKvsObject_image")) 
-	bitBlt(pdDest,iXdst,iYdst,imgSource,iXsrc,iYsrc,uW,uH);
-	else
-		bitBlt(pdDest,iXdst,iYdst,pdSource,iXsrc,iYsrc,uW,uH);
+	if(obDst->inherits("KviKvsObject_pixmap")){
+		((KviKvsObject_pixmap *)obDst)->pixmapChanged();
+	}
+#ifdef COMPILE_USE_QT4
+	/*QPainter p(pdDest);
+	QRect rectdest(iXdst,iYdst,uW,uH);
+	QRect rectsrc(iXsrc,iYsrc,uW,uH);
+
+	p.drawPixmap(rectdest,pdSource,rectsrc);
+*/
+	#else
+	bitBlt(pdDest,iXdst,iYdst,pdSource,iXsrc,iYsrc,uW,uH);
+#endif
 	return true;
 }
 	/*
@@ -445,8 +662,8 @@ static bool objects_kvs_cmd_bitBlt(KviKvsModuleCommandCall * c)
 			Blends two images  to a destination.
 		@syntax:
 			objects.blend <background: image hobject> <x_offset_bkg:unsigned integer> <y_offset_bkg:unsigned integer> 
-			<foreground: image hobject> <x_offset_fgr:unsigned integer> <y_offset_fgr:unsigned integer> <width:unsigned integer> <height:unsigned integer>
-			<destination: image, pixmap. widget hobject> <x_offset_dest:unsigned integer> <y_offset_dest:unsigned integer> <blend_factor>
+			<foreground: image hobject> <x_offset_fgr:unsigned integer> <y_offset_fgr:unsigned integer> 
+			<destination: image, pixmap. widget hobject> <x_offset_dest:unsigned integer> <y_offset_dest:unsigned integer> <width:unsigned integer> <height:unsigned integer> <blend_factor>
 		@description:
 			Blends two images <background> and <foreground> and copy the result to <destination> at the coordinates <x_offset>,<y_offset> with a <blend_factor> value .[br]
 			Destination must be a widget or pixmap.[br]
@@ -463,25 +680,25 @@ static bool objects_kvs_cmd_blend(KviKvsModuleCommandCall * c)
 	kvs_int_t iBkX,iBkY;
 	kvs_int_t iFoX,iFoY;
 	kvs_int_t iDesX,iDesY,uW,uH;
-    kvs_real_t iBlend;
+	kvs_real_t dBlend;
 
 	kvs_hobject_t hBk,hFo,hDest;
 
 	KVSO_PARAMETERS_BEGIN(c)
-	
+		KVSO_PARAMETER("destination",KVS_PT_HOBJECT,0,hDest)
+		KVSO_PARAMETER("x_offset_dest",KVS_PT_INT,0,iDesX)
+		KVSO_PARAMETER("y_offset_dest",KVS_PT_INT,0,iDesY)
+
 		KVSO_PARAMETER("image_background",KVS_PT_HOBJECT,0,hBk)
 		KVSO_PARAMETER("x_offset_background",KVS_PT_UNSIGNEDINTEGER,0,iBkX)
 		KVSO_PARAMETER("y_offset_background",KVS_PT_UNSIGNEDINTEGER,0,iBkY)
 		KVSO_PARAMETER("image_foreground",KVS_PT_HOBJECT,0,hFo)
 		KVSO_PARAMETER("x_offset_foreground",KVS_PT_UNSIGNEDINTEGER,0,iFoX)
 		KVSO_PARAMETER("y_offset_foreground",KVS_PT_UNSIGNEDINTEGER,0,iFoY)
-		KVSO_PARAMETER("destination",KVS_PT_HOBJECT,0,hDest)
-		KVSO_PARAMETER("x_offset_dest",KVS_PT_INT,0,iDesX)
-		KVSO_PARAMETER("y_offset_dest",KVS_PT_INT,0,iDesY)
 		KVSO_PARAMETER("width",KVS_PT_UNSIGNEDINTEGER,0,uW)
 		KVSO_PARAMETER("height",KVS_PT_UNSIGNEDINTEGER,0,uH)
 
-		KVSO_PARAMETER("blend_value",KVS_PT_REAL,0,iBlend)
+		KVSO_PARAMETER("blend_value",KVS_PT_REAL,0,dBlend)
 
 	
 
@@ -497,21 +714,15 @@ static bool objects_kvs_cmd_blend(KviKvsModuleCommandCall * c)
 		c->warning(__tr2qs("One o more of background, foreground or destination aren't objects"));
 		return true;
 	}
-/*	if (!obFor->object() || !obBck->object() || !obDest->object())
-	{
-		c->warning(__tr2qs("One o more of background, foreground or destination aren't valid objects"));
-		return true;
-	}
-*/
 
-	if (!obBck->inherits("KviKvsObject_image") || !obFor->inherits("KviKvsObject_image"))
+	if (!obBck->inherits("KviKvsObject_pixmap") || !obFor->inherits("KviKvsObject_pixmap"))
 	{
-		c->warning(__tr2qs("Image objects required"));
+		c->warning(__tr2qs("Pixmap objects required"));
 		return true;
 	}
 
-	QPaintDevice * pdDest = 0;
-	if(obDest->inherits("KviKvsObject_pixmap")) pdDest = ((KviKvsObject_pixmap *)obDest)->pixmap();
+	QPaintDevice  * pdDest = 0;
+	if(obDest->inherits("KviKvsObject_pixmap")) pdDest = ((KviKvsObject_pixmap *)obDest)->getPixmap();
 	else if (obDest->inherits("KviKvsObject_widget")) pdDest=((KviKvsObject_widget *)obDest)->widget();
 	
 	if (!pdDest)
@@ -520,10 +731,11 @@ static bool objects_kvs_cmd_blend(KviKvsModuleCommandCall * c)
 		return true;
 	}
 
+	if(obDest->inherits("KviKvsObject_pixmap")) ((KviKvsObject_pixmap *)obDest)->pixmapChanged();
 
 
-	QImage *img_back=((KviKvsObject_image *)obBck)->image();
-	QImage *img_fore=((KviKvsObject_image *)obFor)->image();
+	QImage  *img_back=((KviKvsObject_pixmap *)obBck)->getImage();
+	QImage *img_fore=((KviKvsObject_pixmap *)obFor)->getImage();
 
 	// check size
 	if ((iBkX+uW>img_back->width())||(iBkY+uH>img_back->height()))
@@ -538,6 +750,7 @@ static bool objects_kvs_cmd_blend(KviKvsModuleCommandCall * c)
 	}
 	QImage buffer;
 	buffer.create(uW,uH,32);
+	buffer.setAlphaBuffer(true);
 	for(int y = 0;y < buffer.height();y++)
 	{
 		QRgb * dst = (QRgb *)buffer.scanLine(y);
@@ -546,23 +759,33 @@ static bool objects_kvs_cmd_blend(KviKvsModuleCommandCall * c)
 		bkg += iBkX;
 		QRgb * fgn = (QRgb *)img_fore->scanLine(y+iFoY);
 		fgn += iFoX;
-		double dRemaining = 1.0 - iBlend;
+		double dRemaining = 1.0 - dBlend;
 		int a=0;
 		while(dst < end)
 		{
-			*dst = qRgb(
-						(int)((qRed(*bkg) * dRemaining) + (qRed(*fgn) * iBlend)),
-						(int)((qGreen(*bkg) * dRemaining) + (qGreen(*fgn) * iBlend)),
-						(int)((qBlue(*bkg) * dRemaining) + (qBlue(*fgn) * iBlend))
-					);
+			
+	
+			*dst = qRgba(
+				(int)((qRed(*bkg) * dRemaining) + (qRed(*fgn) * dBlend)),
+				(int)((qGreen(*bkg) * dRemaining) + (qGreen(*fgn) * dBlend)),
+				(int)((qBlue(*bkg) * dRemaining) + (qBlue(*fgn) * dBlend)),
+				(int)((qAlpha(*bkg) * dRemaining) + (qAlpha(*fgn) * dBlend))
+				);
+
 			dst++;
 			bkg++;
 			fgn++;
 		}
+		
 
 	}
-
+#ifdef COMPILE_USE_QT4
+	QPainter p(pdDest);
+	QRect rect(iDesX,iDesY,buffer.width(),buffer.height());
+	p.drawImage(rect,buffer);
+#else
 	bitBlt(pdDest,iDesX,iDesY,&buffer,0,0,buffer.width(),buffer.height());
+#endif
 	return true;
 
 }
@@ -588,7 +811,7 @@ static bool objects_kvs_fnc_listObjects(KviKvsModuleFunctionCall * cmd)
                 This function returns the tree of the widgets of the kvirc, if the flag <b> is planned to 1,[br]
                 will return it on the currente window, if it' is planned to 0 instead it will return it as a string.[br] 
                 ES:
-                %A[]=$split("\|",$objects.dump(0))
+                %A[]=$str.split("\|",$objects.dump(0))
                 %i=0
                 while (%i != %A[]#)
                 {
@@ -603,25 +826,64 @@ static bool objects_kvs_fnc_listObjects(KviKvsModuleFunctionCall * cmd)
 		KVSO_PARAMETER("flag on video",KVS_PT_BOOL,0,bFlag)
 	KVSO_PARAMETERS_END(cmd)
 	if (bFlag) cmd->window()->output(80, "Objects dump:");
-    QWidgetList *l = g_pApp->topLevelWidgets();
-	l->setAutoDelete(false);
-    QWidgetListIt it(*l);
-    KviStr spacing = ">";
+	#ifdef COMPILE_USE_QT4
+	QWidgetList list = g_pApp->topLevelWidgets();
+	
+	KviStr spacing = ">";
 	QString  szTemp;
 	KviKvsArray * n = new KviKvsArray();
 	int idx=0;
-    while( it.current() )
-    {
-		if( it.current()->isWidgetType())
-        {
+	for(int i=0;i<list.count();i++)
+	{
+		if( list.at(i)->isWidgetType())
+		{
 			if (bFlag)
 			{
 				cmd->window()->output(80, "Ptr %u: top level object: %c%s%c, class %s, %s, rect = %d, %d, %d, %d",
-                it.current(),
-                KVI_TEXT_BOLD, it.current()->name(), KVI_TEXT_BOLD,
-                it.current()->className(),
-                it.current()->isVisible() ? "visible" : "hidden",
-                it.current()->x(), it.current()->y(), it.current()->width(), it.current()->height());
+				list.at(i),
+				KVI_TEXT_BOLD, list.at(i)->name(), KVI_TEXT_BOLD,
+				list.at(i)->className(),
+				list.at(i)->isVisible() ? "visible" : "hidden",
+				list.at(i)->x(), list.at(i)->y(), list.at(i)->width(), list.at(i)->height());
+			}
+			QString  szClass=list.at(i)->className();
+			QString szObj=list.at(i)->name();
+			QString szTemp;
+			szTemp = szClass + "::" + szObj;
+			KviKvsVariant v;
+			v.setString(szTemp);
+			n->set(idx,new KviKvsVariant(v));
+			debug ("string %s",szTemp.latin1());
+			debug ("class %s",szClass.latin1());
+			debug ("Obj %s",szObj.latin1());
+	
+			idx++;
+	
+			dumpChildObjects(cmd->window(), list.at(i), spacing.ptr(), bFlag,n,idx);
+		}
+	//++it;
+	}
+
+#else
+	QWidgetList *l = g_pApp->topLevelWidgets();
+	l->setAutoDelete(false);
+	QWidgetListIt it(*l);
+	KviStr spacing = ">";
+	QString  szTemp;
+	KviKvsArray * n = new KviKvsArray();
+	int idx=0;
+	while( it.current() )
+	{
+		if( it.current()->isWidgetType())
+		{
+			if (bFlag)
+			{
+				cmd->window()->output(80, "Ptr %u: top level object: %c%s%c, class %s, %s, rect = %d, %d, %d, %d",
+				it.current(),
+				KVI_TEXT_BOLD, it.current()->name(), KVI_TEXT_BOLD,
+				it.current()->className(),
+				it.current()->isVisible() ? "visible" : "hidden",
+				it.current()->x(), it.current()->y(), it.current()->width(), it.current()->height());
 			}
 			QString  szClass=it.current()->className();
 			QString szObj=it.current()->name();
@@ -639,49 +901,78 @@ static bool objects_kvs_fnc_listObjects(KviKvsModuleFunctionCall * cmd)
 			dumpChildObjects(cmd->window(), it.current(), spacing.ptr(), bFlag,n,idx);
 		
 	
-        }
-        ++it;
+		}
+	++it;
 	}
-    cmd->returnValue()->setArray(n);
-    delete l;
-    return true;
-                
+
+#endif
+	cmd->returnValue()->setArray(n);
+	return true;
 }
 
 static void dumpChildObjects(KviWindow *pWnd, QObject *parent, const char *spacing, bool bFlag, KviKvsArray *n, int &idx)
 {
+#ifdef COMPILE_USE_QT4
+	const QObjectList list = parent->children();
+	if( !list.count() ) return;
+	QString sp(spacing);
+	sp.append(">");
+	for(int i=0;i<list.count();i++)
+	{
+		if( list.at(i)->isWidgetType() )
+		{
+			if (bFlag)
+			{
+				pWnd->output(80, "%sPtr %u: object: %c%s%c, class %s",
+					spacing, list.at(i), KVI_TEXT_BOLD,
+					list.at(i)->name(), KVI_TEXT_BOLD, list.at(i)->className()
+				);
+			}
+			QString szClass=list.at(i)->className();
+			QString szObj=list.at(i)->name();
+			QString szTemp;
+			szTemp=spacing+szClass+"::"+szObj;
+			KviKvsVariant v;
+			v.setString(szTemp);
+			n->set(idx,new KviKvsVariant(v));
+			debug ("string %s",szTemp.latin1());
+			idx++;
+			dumpChildObjects(pWnd, list.at(i), sp, bFlag, n, idx );
+		}
+	}
 
-        const QObjectList *l = parent->children();
-    	if( !l ) return;
-        if( l->isEmpty() ) return;
-        QObjectListIt it(*l);
-        QString sp(spacing);
-        sp.append(">");
-        while( it.current() ) 
-                {
-                
-                if( it.current()->isWidgetType() ) 
-				{
-					if (bFlag)
-					{
-                        pWnd->output(80, "%sPtr %u: object: %c%s%c, class %s",
-                        spacing, it.current(), KVI_TEXT_BOLD,
-                        it.current()->name(), KVI_TEXT_BOLD, it.current()->className()
-                        );
-					}
-				QString szClass=it.current()->className();
-                QString szObj=it.current()->name();
-				QString szTemp;
-				szTemp=spacing+szClass+"::"+szObj;
-				KviKvsVariant v;
-				v.setString(szTemp);
-				n->set(idx,new KviKvsVariant(v));
-				debug ("string %s",szTemp.latin1());
-				idx++;
-                dumpChildObjects(pWnd, it.current(), sp, bFlag, n, idx );
+#else
+	const QObjectList *l = parent->children();
+	if( !l ) return;
+	if( l->isEmpty() ) return;
+	QObjectListIt it(*l);
+	QString sp(spacing);
+	sp.append(">");
+	while( it.current() )
+	{
+                if( it.current()->isWidgetType() )
+		{
+			if (bFlag)
+			{
+				pWnd->output(80, "%sPtr %u: object: %c%s%c, class %s",
+					spacing, it.current(), KVI_TEXT_BOLD,
+					it.current()->name(), KVI_TEXT_BOLD, it.current()->className()
+				);
+			}
+			QString szClass=it.current()->className();
+			QString szObj=it.current()->name();
+			QString szTemp;
+			szTemp=spacing+szClass+"::"+szObj;
+			KviKvsVariant v;
+			v.setString(szTemp);
+			n->set(idx,new KviKvsVariant(v));
+			debug ("string %s",szTemp.latin1());
+			idx++;
+			dumpChildObjects(pWnd, it.current(), sp, bFlag, n, idx );
                 }
-          ++it;
-        }
+		++it;
+	}
+#endif
 }
 
 static bool objects_module_can_unload(KviModule *m)
@@ -690,11 +981,16 @@ static bool objects_module_can_unload(KviModule *m)
 	// FIXME: unlock when no more instances & derived classes!
 	return false;
 }
-    static bool objects_module_init(KviModule * m)
+static bool objects_module_init(KviModule * m)
 {
 	// functions
 	KVSM_REGISTER_FUNCTION(m,"exists",objects_kvs_fnc_exists);
+	KVSM_REGISTER_FUNCTION(m,"instances",objects_kvs_fnc_instances);
+	KVSM_REGISTER_FUNCTION(m,"classes",objects_kvs_fnc_classes);
 	KVSM_REGISTER_FUNCTION(m,"dump",objects_kvs_fnc_listObjects);
+	KVSM_REGISTER_FUNCTION(m,"variables",objects_kvs_fnc_variables);
+	KVSM_REGISTER_FUNCTION(m,"classAllHandlers",objects_kvs_fnc_classAllHandlers);
+	
 	// commands
 	KVSM_REGISTER_SIMPLE_COMMAND(m,"connect",objects_kvs_cmd_connect);
 	KVSM_REGISTER_SIMPLE_COMMAND(m,"disconnect",objects_kvs_cmd_disconnect);
@@ -703,52 +999,6 @@ static bool objects_module_can_unload(KviModule *m)
 	KVSM_REGISTER_SIMPLE_COMMAND(m,"blend",objects_kvs_cmd_blend);
 	KVSM_REGISTER_SIMPLE_COMMAND(m,"clearObjects",objects_kvs_cmd_clearObjects);
 
-/*
-	KviScriptSocketObject::registerSelf();
-	KviScriptStringObject::registerSelf();
-	KviScriptListObject::registerSelf();
-	KviScriptFileObject::registerSelf();
-	KviScriptWidgetObject::registerSelf();
-	// add new widget-inherited objects here. NOT before the previous line ;)
-
-	KviScriptWorkSpaceObject::registerSelf();
-	KviScriptMainWindowObject::registerSelf();
-	KviScriptToolButtonObject::registerSelf();
-	KviScriptToolBarObject::registerSelf();
-	KviScriptListViewItemObject::registerSelf();
-	KviScriptListViewObject::registerSelf();
-	KviScriptWrapperObject::registerSelf();
-	KviScriptWizardObject::registerSelf();
-	KviScriptButtonObject::registerSelf();
-	KviScriptCheckBoxObject::registerSelf(); // must be after button !
-
-	KviScriptListBoxObject::registerSelf();
-	KviScriptComboBoxObject::registerSelf();
-	KviScriptMLEditObject::registerSelf();
-	KviScriptLineEditObject::registerSelf();
-	KviScriptLabelObject::registerSelf();
-	KviScriptUrlLabelObject::registerSelf();
-	
-	KviScriptMenuBarObject::registerSelf();
-
-	KviScriptWindowObject::registerSelf();
-	KviScriptDialogObject::registerSelf();
-
-	KviScriptLayoutObject::registerSelf();
-
-	KviScriptLcdObject::registerSelf();
-	KviScriptProgressbarObject::registerSelf();
-	KviScriptSpinboxObject::registerSelf();
-	KviScriptSliderObject::registerSelf();
-	KviScriptRadioButtonObject::registerSelf();
-	KviScriptProcessObject::registerSelf();
-	KviScriptTabWidgetObject::registerSelf();
-	KviScriptGroupBoxObject::registerSelf();
-	KviScriptPopupMenuObject::registerSelf();
-
-	KviScriptPixmapObject::registerSelf();
-	KviScriptPainterObject::registerSelf();
-*/
 	KviKvsObject_list::registerSelf();
 
 	KviKvsObject_widget::registerSelf();
@@ -759,6 +1009,7 @@ static bool objects_module_can_unload(KviModule *m)
 	KviKvsObject_checkbox::registerSelf();
 	KviKvsObject_dialog::registerSelf();
 	KviKvsObject_groupbox::registerSelf();
+	KviKvsObject_buttongroup::registerSelf();
 	KviKvsObject_label::registerSelf();
 	KviKvsObject_vbox::registerSelf();
 	KviKvsObject_hbox::registerSelf();
@@ -792,7 +1043,6 @@ static bool objects_module_can_unload(KviModule *m)
 	KviKvsObject_file::registerSelf();
 	KviKvsObject_wrapper::registerSelf();
 	KviKvsObject_xmlreader::registerSelf();
-	KviKvsObject_image::registerSelf();
 	KviKvsObject_socket::registerSelf();
 	KviKvsObject_process::registerSelf();
 
@@ -802,8 +1052,8 @@ static bool objects_module_can_unload(KviModule *m)
 
 KVIRC_MODULE(
 	"Objects",
-	"1.0.0",
-	"Copyright (C) 2000-2004:\n" \
+	"2.0.0",
+	"Copyright (C) 2000-2006:\n" \
 		"  Szymon Stefanek (pragma at kvirc dot net)\n" \
 		"  Krzysztof Godlewski (kristoff at poczta dot wprost dot pl)\n" \
 		"  Tonino Imbesi (grifisx at barmes dot org)\n" \
