@@ -31,61 +31,45 @@
 #include "kvi_iconmanager.h"
 #include "kvi_module.h"
 #include "kvi_styled_controls.h"
-
+#include "kvi_pointerhashtable.h"
 #include <qlayout.h>
-#include <qaccel.h>
+#include "kvi_accel.h"
 #include <qlabel.h>
-#include <qvbox.h>
+#include "kvi_tal_vbox.h"
 #include <qsplitter.h>
-#include <qwidgetstack.h>
+#include "kvi_tal_widgetstack.h"
 #include <qpushbutton.h>
-#include <qtooltip.h>
-#include <qheader.h>
-#include <qpopupmenu.h>
+#include "kvi_tal_tooltip.h"
+
+#ifdef COMPILE_USE_QT4
+	#include <q3header.h>
+#else
+	#include <qheader.h>
+	#include <qobjectlist.h>
+#endif
+#include "kvi_tal_popupmenu.h"
 #include <qtoolbutton.h>
 #include <qcheckbox.h>
-#include <qgroupbox.h>
-#include <qtooltip.h>
-#include <qobjectlist.h>
+#include <kvi_tal_groupbox.h>
 #include <qpainter.h>
 #include <qfont.h>
+#include <qevent.h>
 
 //extern KviModule * g_pOptionsModule;
-extern QDict<KviOptionsDialog> * g_pOptionsDialogDict;
+extern KviPointerHashTable<QString,KviOptionsDialog> * g_pOptionsDialogDict;
 
 extern KVIRC_API KviApp * g_pApp;
 extern KviOptionsInstanceManager * g_pOptionsInstanceManager;
 
-KviGeneralOptionsFrontWidget::KviGeneralOptionsFrontWidget(QWidget *parent)
+KviGeneralOptionsFrontWidget::KviGeneralOptionsFrontWidget(QWidget *parent,const QString &szText)
 :KviOptionsWidget(parent,"general_options_front_widget")
 {
 	createLayout(1,1);
-#ifdef COMPILE_INFO_TIPS
-	QLabel * l = new QLabel(__tr2qs_ctx(
-					"<table width=\"100%\"><tr><td bgcolor=\"#303030\">" \
-					"<center><h1><font color=\"#FFFFFF\">General Preferences</font></h1></center>" \
-					"</td></tr><tr><td><br><br>" \
-					"<center><b>These sections contain various settings for KVIrc</b></center><br><br>" \
-					"<p>When you have finished, click \"<b>OK</b>\" to accept your changes " \
-					"or \"<b>Cancel</b>\" to discard them. Clicking \"<b>Apply</b>\" will commit your " \
-					"changes without closing the window." \
-					"</td></tr><tr><td>" \
-					"Many settings have tooltips that can be shown " \
-					"by holding the cursor over their label for a few seconds." \
-					"</p></td></tr></table>","options"),this);
-#else
-	QLabel * l = new QLabel(__tr2qs_ctx(
-					"<table width=\"100%\"><tr><td bgcolor=\"#303030\">" \
-					"<center><h1><font color=\"#FFFFFF\">General Preferences</font></h1></center>" \
-					"</td></tr><tr><td><br><br>" \
-					"Select a category in the list view on the left " \
-					"to view the related settings. " \
-					"When you have finished, click \"<b>OK</b>\" to accept your changes " \
-					"or \"<b>Cancel</b>\" to discard them. Clicking \"<b>Apply</b>\" will commit your " \
-					"changes without closing this window.<br><br>" \
-					"</td></tr></table>","options"),this);
+	QLabel * l = new QLabel(szText,this);
+#ifdef COMPILE_USE_QT4
+	l->setWordWrap(true);
 #endif
-//	l->setAlignment(AlignCenter);
+	l->setAlignment(Qt::AlignTop);
 	layout()->addWidget(l,0,0);
 }
 
@@ -96,8 +80,8 @@ KviGeneralOptionsFrontWidget::~KviGeneralOptionsFrontWidget()
 
 
 
-KviOptionsListViewItem::KviOptionsListViewItem(QListView *parent,KviOptionsWidgetInstanceEntry * e)
-:QListViewItem(parent,e->szName)
+KviOptionsListViewItem::KviOptionsListViewItem(KviTalListView *parent,KviOptionsWidgetInstanceEntry * e)
+:KviTalListViewItem(parent,e->szName)
 {
 	m_pInstanceEntry = e;
 	m_pOptionsWidget = 0;
@@ -105,8 +89,8 @@ KviOptionsListViewItem::KviOptionsListViewItem(QListView *parent,KviOptionsWidge
 	setPixmap(0,*(g_pIconManager->getSmallIcon(e->iIcon)));
 }
 
-KviOptionsListViewItem::KviOptionsListViewItem(QListViewItem *parent,KviOptionsWidgetInstanceEntry * e)
-:QListViewItem(parent,e->szName)
+KviOptionsListViewItem::KviOptionsListViewItem(KviTalListViewItem *parent,KviOptionsWidgetInstanceEntry * e)
+:KviTalListViewItem(parent,e->szName)
 {
 	m_pInstanceEntry = e;
 	m_pOptionsWidget = 0;
@@ -126,9 +110,9 @@ void KviOptionsListViewItem::paintCell(QPainter * p,const QColorGroup & cg,int c
 		tmp.setColor(QColorGroup::Base,Qt::red);
 		tmp.setColor(QColorGroup::Background,Qt::red);
 		tmp.setColor(QColorGroup::Text,Qt::yellow);
-		QListViewItem::paintCell(p,tmp,column,width,align);
+		KviTalListViewItem::paintCell(p,tmp,column,width,align);
 	} else {
-		QListViewItem::paintCell(p,cg,column,width,align);
+		KviTalListViewItem::paintCell(p,cg,column,width,align);
 	}
 }
 
@@ -136,29 +120,88 @@ void KviOptionsListViewItem::paintCell(QPainter * p,const QColorGroup & cg,int c
 KviOptionsDialog::KviOptionsDialog(QWidget * par,const QString &szGroup)
 : QDialog(par,"general_options_dialog")
 {
-	setCaption(__tr2qs_ctx("Preferences - KVIrc","options"));
 	setIcon(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_KVIRC)));
 
 	m_szGroup = szGroup;
 
+	QString szDialogTitle;
+
+	if(szGroup.isEmpty() || KviQString::equalCI(szGroup,"general"))
+	{
+		szDialogTitle = __tr2qs_ctx("General Preferences","options");
+	} else if(KviQString::equalCI(szGroup,"theme"))
+	{
+		szDialogTitle = __tr2qs_ctx("Theme Preferences","options");
+	} else {
+		szDialogTitle = __tr2qs_ctx("KVIrc Preferences","options");
+	}
+
+	QString szDialog = __tr2qs_ctx("This dialog contains a set of KVIrc settings.<br> Use the icons " \
+							"on the left to navigate through the option pages. The text box in the " \
+							"bottom left corner is a small search engine. It will highlight the " \
+							"pages that contain options related to the search term you have entered.","options");
+
+
+	QString szInfoTips;
+#ifdef COMPILE_INFO_TIPS
+	szInfoTips = __tr2qs_ctx("Many settings have tooltips that can be shown by holding " \
+							"the cursor over their label for a few seconds.","options"); 
+#else
+	szInfoTips = "";
+#endif
+	QString szOkCancelButtons = __tr2qs_ctx("When you have finished, click \"<b>OK</b>\" to accept your changes " \
+						"or \"<b>Cancel</b>\" to discard them. Clicking \"<b>Apply</b>\" will commit your " \
+						"changes without closing the window.","options");
+
+
+	QString szFrontText = QString(
+			"<table width=\"100%\" height=\"100%\" valign=\"top\" align=\"center\" cellpadding=\"4\">" \
+				"<tr>" \
+					"<td bgcolor=\"#303030\" valign=\"top\">" \
+						"<center><h1><font color=\"#FFFFFF\">%1</font></h1></center>" \
+					"</td>" \
+				"</tr>" \
+				"<tr>" \
+					"<td valign=\"bottom\">" \
+						"<br>" \
+						"<br>" \
+						"<p>" \
+							"%2" \
+						"</p>" \
+						"<br>" \
+						"<p>" \
+							"%3" \
+						"</p>" \
+						"<br>" \
+						"<p>" \
+							"%4" \
+						"</p>" \
+					"</td>" \
+				"</tr>" \
+			"</table>"
+		).arg(szDialogTitle).arg(szDialog).arg(szInfoTips).arg(szOkCancelButtons);
+
+	QString szCaption = szDialogTitle + " - KVIrc";
+	setCaption(szCaption);
+
 	QGridLayout * g1 = new QGridLayout(this,2,5,8,8);
-	QSplitter * spl = new QSplitter(QSplitter::Horizontal,this);
+	QSplitter * spl = new QSplitter(Qt::Horizontal,this);
 
 	g1->addMultiCellWidget(spl,0,0,0,4);
 
-	QVBox * vbox = new QVBox(spl);
+	KviTalVBox * vbox = new KviTalVBox(spl);
 	vbox->setSpacing(2);
 	vbox->setMargin(0);
 
 	// Controlling list view
-	m_pListView = new QListView(vbox);
+	m_pListView = new KviTalListView(vbox);
 	m_pListView->addColumn("");
 	m_pListView->header()->hide();
 	m_pListView->setRootIsDecorated(true);
 	m_pListView->setSorting(-1);
-	connect(m_pListView,SIGNAL(selectionChanged(QListViewItem *)),this,SLOT(listViewItemSelectionChanged(QListViewItem *)));
+	connect(m_pListView,SIGNAL(selectionChanged(KviTalListViewItem *)),this,SLOT(listViewItemSelectionChanged(KviTalListViewItem *)));
 
-	QHBox * hbox = new QHBox(vbox);
+	KviTalHBox * hbox = new KviTalHBox(vbox);
 	vbox->setSpacing(2);
 	vbox->setMargin(0);
 
@@ -170,42 +213,53 @@ KviOptionsDialog::KviOptionsDialog(QWidget * par,const QString &szGroup)
 	connect(m_pSearchButton,SIGNAL(clicked()),this,SLOT(searchClicked()));
 	connect(m_pSearchLineEdit,SIGNAL(textChanged(const QString &)),this,SLOT(searchLineEditTextChanged(const QString &)));
 
-	vbox = new QVBox(spl);
+#ifdef COMPILE_INFO_TIPS
+	QString szTip = __tr2qs_ctx("<p>This is the search tool for this options dialog.</p>" \
+								"<p>You can enter a search term either in your native " \
+								"language or in english and press the button on the right. " \
+								"The pages that contain some options related to the " \
+								"search term will be highlighted and you will be able " \
+								"to quickly find them.</p><p>Try \"nickname\" for example.</p>","options");
+	KviTalToolTip::add(m_pSearchLineEdit,szTip);
+	KviTalToolTip::add(m_pSearchButton,szTip);
+#endif
+
+	vbox = new KviTalVBox(spl);
 	vbox->setSpacing(2);
 	vbox->setMargin(0);
 
-	m_pCategoryLabel = new QLabel("<b>" + __tr2qs_ctx("General Preferences","options") + "</b>",vbox,"labgeneraloptions");
+	m_pCategoryLabel = new QLabel("<b>&nbsp;</b>",vbox,"labgeneraloptions");
 	//m_pCategoryLabel->setMargin(3);
 
 	QFrame * f = new QFrame(vbox);
 	f->setFrameStyle(QFrame::HLine | QFrame::Sunken);
 
 	// Widget stack
-	m_pWidgetStack = new QWidgetStack(vbox);
+	m_pWidgetStack = new KviTalWidgetStack(vbox);
 	vbox->setStretchFactor(m_pWidgetStack,1);
 
 	// First widget visible
-	m_pFrontWidget = new KviGeneralOptionsFrontWidget(m_pWidgetStack);
+	m_pFrontWidget = new KviGeneralOptionsFrontWidget(m_pWidgetStack,szFrontText);
 	m_pWidgetStack->addWidget(m_pFrontWidget,0);
 	m_pWidgetStack->raiseWidget(m_pFrontWidget);
 
 //  Ok,Cancel,Help
 
 	QPushButton * b = new QPushButton(__tr2qs_ctx("&OK","options"),this,"btnok");
-	QToolTip::add(b,__tr2qs_ctx("Close this dialog, accepting all changes.","options"));
+	KviTalToolTip::add(b,__tr2qs_ctx("Close this dialog, accepting all changes.","options"));
 	connect(b,SIGNAL(clicked()),this,SLOT(okClicked()));
 	//b->setMinimumWidth(whatIsThisWidth);
 	b->setIconSet(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_ACCEPT)));
 	g1->addWidget(b,1,2);	
 
 	b = new QPushButton(__tr2qs_ctx("&Apply","options"),this,"btnapply");
-	QToolTip::add(b,__tr2qs_ctx("Commit all changes immediately.","options"));
+	KviTalToolTip::add(b,__tr2qs_ctx("Commit all changes immediately.","options"));
 	connect(b,SIGNAL(clicked()),this,SLOT(applyClicked()));
 	b->setIconSet(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_ACCEPT)));
 	g1->addWidget(b,1,3);
 
 	b = new QPushButton(__tr2qs_ctx("Cancel","options"),this,"btncancel");
-	QToolTip::add(b,__tr2qs_ctx("Close this dialog, discarding all changes.","options"));
+	KviTalToolTip::add(b,__tr2qs_ctx("Close this dialog, discarding all changes.","options"));
 	b->setDefault(true);
 	//b->setMinimumWidth(whatIsThisWidth);
 	connect(b,SIGNAL(clicked()),this,SLOT(cancelClicked()));
@@ -217,8 +271,7 @@ KviOptionsDialog::KviOptionsDialog(QWidget * par,const QString &szGroup)
 
 
 	fillListView(0,g_pOptionsInstanceManager->instanceEntryTree(),szGroup);
-
-
+	
 	if(!parent())
 	{
 
@@ -232,8 +285,9 @@ KviOptionsDialog::KviOptionsDialog(QWidget * par,const QString &szGroup)
 		move(KVI_OPTION_RECT(KviOption_rectGeneralOptionsDialogGeometry).x(),
 			KVI_OPTION_RECT(KviOption_rectGeneralOptionsDialogGeometry).y());
 	}
-	QAccel *a = new QAccel( this );
-        a->connectItem( a->insertItem(Key_Escape), this,SLOT(close()) );
+
+	KviAccel *a = new KviAccel( this );
+        a->connectItem( a->insertItem(Qt::Key_Escape), this,SLOT(close()) );
 	
 }
 
@@ -243,30 +297,9 @@ KviOptionsDialog::~KviOptionsDialog()
 			size().width(),size().height());
 	if(g_pOptionsDialogDict)
 		g_pOptionsDialogDict->remove(m_szGroup);
-//	g_pOptionsModule->unlock();
 }
 
 
-/*
-void KviOptionsDialog::refreshListView(void)
-{
-	bool bChangeWidget=0;
-	KviOptionsListViewItem *i = (KviOptionsListViewItem *)m_pListView->currentItem();
-	if(i->m_pInstanceEntry)
-	{
-		if(i->m_pInstanceEntry->iMinimalUserExperienceLevel > KVI_OPTION_UINT(KviOption_uintUserExperienceLevel))
-			bChangeWidget=1;
-	}
-	m_pListView->clear();
-	fillListView(0,g_pOptionsInstanceManager->instanceEntryTree());
-	if(bChangeWidget)
-	{
-		m_pListView->setCurrentItem(m_pListView->firstChild());
-		listViewItemSelectionChanged(m_pListView->firstChild());
-	}
-}
-*/
-
 void KviOptionsDialog::searchLineEditTextChanged(const QString &)
 {
 	QString txt = m_pSearchLineEdit->text().stripWhiteSpace();
@@ -275,6 +308,7 @@ void KviOptionsDialog::searchLineEditTextChanged(const QString &)
 
 bool KviOptionsDialog::recursiveSearch(KviOptionsListViewItem * pItem,const QStringList &lKeywords)
 {
+	//debug("recursive search:");
 	if(!pItem)return false;
 
 	if(!pItem->m_pOptionsWidget)
@@ -284,28 +318,48 @@ bool KviOptionsDialog::recursiveSearch(KviOptionsListViewItem * pItem,const QStr
 	}
 
 	bool bFoundSomethingHere = false;
+	KviPointerHashTable<void *,bool> lOptionWidgetsToMark;
+	lOptionWidgetsToMark.setAutoDelete(true);
+	QTabWidget * pTabWidgetToMark = 0;
 	
+	QObject * o;
+#ifdef COMPILE_USE_QT4
+	QObjectList ol = pItem->m_pOptionsWidget->queryList();
+	if(ol.count() > 0)
+	{
+		for(QObjectList::Iterator it = ol.begin();it != ol.end();++it)
+		{
+			o = *it;
+#else
 	QObjectList * ol = pItem->m_pOptionsWidget->queryList();
 	if(ol)
 	{
 		QObjectListIt it(*ol);
-		QObject * o;
 		while((o = it.current())/* && (!bFoundSomethingHere)*/)
 		{
+#endif
 			QString szText;
 			if(o->inherits("QLabel"))szText = ((QLabel *)o)->text();
 			else if(o->inherits("QCheckBox"))szText = ((QCheckBox *)o)->text();
-			else if(o->inherits("QGroupBox"))szText = ((QGroupBox *)o)->title();
+			else if(o->inherits("KviTalGroupBox"))szText = ((KviTalGroupBox *)o)->title();
 #ifdef COMPILE_INFO_TIPS
 			if(o->inherits("QWidget"))
+#ifdef COMPILE_USE_QT4
+				szText.append(((QWidget *)o)->toolTip());
+#else
 				szText.append(QToolTip::textFor((QWidget*)o));
+#endif
 #endif
 			if(!szText.isEmpty())
 			{
 				bool bOk = true;
-				for(QStringList::ConstIterator it = lKeywords.begin();it != lKeywords.end();++it)
+				for(int j=0;j<lKeywords.count();j++)
 				{
-					if(szText.find(*it,0,false) == -1)
+#ifdef COMPILE_USE_QT4
+					if(szText.find(lKeywords.at(j),0,false) == -1)
+#else
+					if(szText.find(*(lKeywords.at(j)),0,false) == -1)
+#endif
 					{
 						bOk = false;
 						break;
@@ -323,12 +377,72 @@ bool KviOptionsDialog::recursiveSearch(KviOptionsListViewItem * pItem,const QStr
 					font.setBold(bOk);
 					font.setUnderline(bOk);
 					pWidget->setFont(font);
+
+					// if there is a QTabWidget in the parent chain, signal it in the tab text
+					QObject * pParent = pWidget->parent();
+					while(pParent)
+					{
+						if(pParent->inherits("QTabWidget"))
+						{
+							pTabWidgetToMark = (QTabWidget *)pParent;
+							break;
+						}
+						pParent = pParent->parent();
+					}
+
+					if(pTabWidgetToMark)
+					{
+						// lookup the KviOptionsWidget parent
+						pParent = pWidget->parent();
+						while(pParent)
+						{
+							if(pParent->inherits("KviOptionsWidget"))
+							{
+								bool * pExistingBool = lOptionWidgetsToMark.find(pParent);
+								if(pExistingBool)
+								{
+									if(bOk)
+										*pExistingBool = true;
+								} else {
+									lOptionWidgetsToMark.insert(pParent,new bool(bOk));
+								}
+								break;
+							}
+							pParent = pParent->parent();
+						}
+					}
 				}
 			}
-			
+
+#ifndef COMPILE_USE_QT4
+			++it;
+#endif
+		}
+#ifndef COMPILE_USE_QT4
+		delete ol;
+#endif
+	}
+
+	if(pTabWidgetToMark)
+	{
+		KviPointerHashTableIterator<void *,bool> it(lOptionWidgetsToMark);
+		while(bool * pBool = it.current())
+		{
+			KviOptionsWidget * pOptionsWidget = (KviOptionsWidget *)it.currentKey();
+			QString szTxt = pTabWidgetToMark->tabLabel(pOptionsWidget);
+			if(KviQString::equalCIN(szTxt,">>> ",4))
+			{
+				szTxt.replace(">>> ","");
+				szTxt.replace(" <<<","");
+			}
+			if(*pBool)
+			{
+				szTxt.insert(0,">>> ");
+				szTxt += QString(" <<<");
+			}
+			pTabWidgetToMark->setTabLabel(pOptionsWidget,szTxt);
 			++it;
 		}
-		delete ol;
 	}
 
 	pItem->setHighlighted(bFoundSomethingHere);
@@ -374,20 +488,22 @@ void KviOptionsDialog::searchClicked()
 		search(szTxt);
 }
 
-void KviOptionsDialog::fillListView(QListViewItem * p,KviPtrList<KviOptionsWidgetInstanceEntry> * l,const QString &szGroup)
+void KviOptionsDialog::fillListView(KviTalListViewItem * p,KviPointerList<KviOptionsWidgetInstanceEntry> * l,const QString &szGroup,bool bNotContainedOnly)
 {
 	if(!l)return;
 
 	KviOptionsListViewItem * it;
 	KviOptionsWidgetInstanceEntry * e;
 
-	KviPtrList<KviOptionsWidgetInstanceEntry> tmp;
+	KviPointerList<KviOptionsWidgetInstanceEntry> tmp;
 	tmp.setAutoDelete(false);
 
 
 	for(e = l->first();e;e = l->next())
 	{
-		e->bDoInsert = KviQString::equalCI(szGroup,e->szGroup);
+		// must be in the correct group
+		// if we want only containers then well.. must be one
+		e->bDoInsert = KviQString::equalCI(szGroup,e->szGroup) && ((!bNotContainedOnly) || e->bIsContainer || e->bIsNotContained);
 		KviOptionsWidgetInstanceEntry * ee = tmp.first();
 		int idx = 0;
 		while(ee)
@@ -405,20 +521,35 @@ void KviOptionsDialog::fillListView(QListViewItem * p,KviPtrList<KviOptionsWidge
 		{
 			if(p)it = new KviOptionsListViewItem(p,e);
 			else it = new KviOptionsListViewItem(m_pListView,e);
+			if(!it->m_pOptionsWidget)
+			{
+				it->m_pOptionsWidget = g_pOptionsInstanceManager->getInstance(it->m_pInstanceEntry,m_pWidgetStack);
+				m_pWidgetStack->addWidget(it->m_pOptionsWidget,0);
+			}
 		} else {
 			it = (KviOptionsListViewItem *)p;
 		}
-		if(e->pChildList && (!e->bIsContainer))
-			fillListView(it,e->pChildList,szGroup);
+		
+		if(e->pChildList)
+		{
+			if(e->bIsContainer)
+			{
+				// it's a container: add only eventual not contained children (containers or explicitly marked as not contained)
+				fillListView(it,e->pChildList,szGroup,true);
+			} else {
+				// it's not a container, add any children
+				fillListView(it,e->pChildList,szGroup,false);
+			}
+		}
 	}
 }
 
-void KviOptionsDialog::listViewItemSelectionChanged(QListViewItem *it)
+void KviOptionsDialog::listViewItemSelectionChanged(KviTalListViewItem *it)
 {
 	if(it)
 	{
 		QString str = it->text(0);
-		QListViewItem * par = it->parent();
+		KviTalListViewItem * par = it->parent();
 
 		while(par)
 		{
@@ -465,86 +596,10 @@ KviOptionsListViewItem * KviOptionsDialog::findItemByPage(KviOptionsListViewItem
 	return 0;
 }
 
-/*
-KviOptionsListViewItem * KviOptionsDialog::showHiddenChildren(QListViewItem * p,KviPtrList<KviOptionsWidgetInstanceEntry> * l)
-{
-	if(!l)return 0;
-	if(!p)return 0;
-
-
-	KviOptionsListViewItem * pFirstHiddenChild = 0;
-
-	KviOptionsListViewItem * it;
-	KviOptionsWidgetInstanceEntry * e;
-
-	KviPtrList<KviOptionsWidgetInstanceEntry> tmp;
-	tmp.setAutoDelete(false);	
-
-	for(e = l->first();e;e = l->next())
-	{
-		bool bFound = false;
-		it = (KviOptionsListViewItem *)(p->firstChild());
-		while(it && (!bFound))
-		{
-			if(it->m_pInstanceEntry == e)
-			{
-				// already there
-				if((!pFirstHiddenChild) && e->bHidden )pFirstHiddenChild = it;
-					bFound = true;
-			}
-			it = (KviOptionsListViewItem *)(it->nextSibling());
-		}
-		KviOptionsWidgetInstanceEntry * ee = tmp.first();
-		if(!bFound)
-		{
-			int idx = 0;
-			while(ee)
-			{
-				if(ee->iPriority >= e->iPriority)break;
-				idx++;
-				ee = tmp.next();
-			}
-			tmp.insert(idx,e);
-		}
-	}
-
-	//KviOptionsListViewItem * prev = 0;
-	for(e = tmp.first();e;e = tmp.next())
-	{
-		it = new KviOptionsListViewItem(p,e);
-		pFirstHiddenChild = it;
-		KviOptionsDialog::showHiddenChildren(it,e->pChildList);
-	}
-	return pFirstHiddenChild;
-}
-*/
 
 void KviOptionsDialog::pageWantsToSwitchToAdvancedPage(KviOptionsWidget * pPage)
 {
-	/*
-	// find the item that has this page
-	KviOptionsListViewItem *i = findItemByPage((KviOptionsListViewItem *)(m_pListView->firstChild()),pPage);
-	if(!i)return; // oops...
-	
-	// got the item that has requested to switch
-	
-	
-	KviOptionsListViewItem *pFirstHiddenChild = 0;
-	// show its hidden children
-	if(i->m_pInstanceEntry->pChildList)
-		pFirstHiddenChild = showHiddenChildren(i,i->m_pInstanceEntry->pChildList);
-	
-	if(!pFirstHiddenChild)
-	{
-		debug("A page wanted to switch to the Advanced child but there was none...");
-		return; // ooops
-	}
-
-	i->setOpen(true);
-
-	// jump to the first child
-	m_pListView->setSelected(pFirstHiddenChild,true);
-	*/
+	// unused
 }
 
 void KviOptionsDialog::applyClicked()
@@ -554,6 +609,7 @@ void KviOptionsDialog::applyClicked()
 
 void KviOptionsDialog::apply(bool bDialogAboutToClose)
 {
+
 	KviOptionsListViewItem *it = (KviOptionsListViewItem *)m_pListView->firstChild();
 	while(it)
 	{
@@ -569,6 +625,7 @@ void KviOptionsDialog::apply(bool bDialogAboutToClose)
 	}
 
 	g_pApp->saveConfiguration();
+
 }
 
 void KviOptionsDialog::okClicked()
