@@ -38,10 +38,10 @@
 #include "dialog.h"
 
 #include <qsplitter.h>
-#include <qdict.h>
+#include "kvi_pointerhashtable.h"
 
 
-QDict<KviOptionsDialog> * g_pOptionsDialogDict = 0;
+KviPointerHashTable<QString,KviOptionsDialog> * g_pOptionsDialogDict = 0;
 
 KviOptionsInstanceManager * g_pOptionsInstanceManager = 0;
 
@@ -87,7 +87,7 @@ static bool options_kvs_cmd_save(KviKvsModuleCommandCall * c)
 		If [options_group] is omitted, the option group "general" is assumed.
 		This command is exported by the "options" module.
 	@seealso:
-		[fnc]$options.isdialog[/fnc]
+		[fnc]$options.isDialog[/fnc]
 */
 
 
@@ -122,9 +122,8 @@ static bool options_kvs_cmd_dialog(KviKvsModuleCommandCall * c)
 		}
 		g_pOptionsDialogDict->insert(szGroup,d);
 	}
-
-	d->show();
 	d->raise();
+	d->show();
 	d->setFocus();
 	return true;
 }
@@ -160,7 +159,7 @@ static void options_kvs_module_print_pages(KviKvsModuleCommandCall * c,KviOption
 }
 static bool options_kvs_cmd_pages(KviKvsModuleCommandCall * c)
 {
-	KviPtrList<KviOptionsWidgetInstanceEntry> * l = g_pOptionsInstanceManager->instanceEntryTree();
+	KviPointerList<KviOptionsWidgetInstanceEntry> * l = g_pOptionsInstanceManager->instanceEntryTree();
 
 	for(KviOptionsWidgetInstanceEntry * e = l->first();e;e = l->next())
 	{
@@ -280,7 +279,7 @@ static bool options_module_init(KviModule * m)
 	KVSM_REGISTER_SIMPLE_COMMAND(m,"edit",options_kvs_cmd_edit);
 	KVSM_REGISTER_FUNCTION(m,"isDialog",options_kvs_fnc_isdialog);
 
-	g_pOptionsDialogDict = new QDict<KviOptionsDialog>;
+	g_pOptionsDialogDict = new KviPointerHashTable<QString,KviOptionsDialog>;
 	g_pOptionsDialogDict->setAutoDelete(false);
 
 	return true;
@@ -288,8 +287,8 @@ static bool options_module_init(KviModule * m)
 
 static bool options_module_cleanup(KviModule *m)
 {
-	QDictIterator<KviOptionsDialog> it(*g_pOptionsDialogDict);
-	KviPtrList<KviOptionsDialog> l;
+	KviPointerHashTableIterator<QString,KviOptionsDialog> it(*g_pOptionsDialogDict);
+	KviPointerList<KviOptionsDialog> l;
 	l.setAutoDelete(false);
 	KviOptionsDialog * d;
 	while(d = it.current())
