@@ -28,6 +28,7 @@
 #include "kvi_locale.h"
 #include "kvi_options.h"
 #include "kvi_iconmanager.h"
+#include <qradiobutton.h>
 
 
 KviConnectionOptionsWidget::KviConnectionOptionsWidget(QWidget * parent)
@@ -35,7 +36,7 @@ KviConnectionOptionsWidget::KviConnectionOptionsWidget(QWidget * parent)
 {
 
 	createLayout(2,1);
-	QGroupBox *gbox = addGroupBox(0,0,0,0,1,QGroupBox::Horizontal,__tr2qs_ctx("On Disconnect","options"));
+	KviTalGroupBox *gbox = addGroupBox(0,0,0,0,1,Qt::Horizontal,__tr2qs_ctx("On Disconnect","options"));
 
 
 	KviBoolSelector *b1 = addBoolSelector(gbox,__tr2qs_ctx("Keep channels open","options"),KviOption_boolKeepChannelsOpenOnDisconnect,true);
@@ -48,7 +49,7 @@ KviConnectionOptionsWidget::KviConnectionOptionsWidget(QWidget * parent)
 	mergeTip(b1,__tr2qs_ctx("<center>This option will cause KVIrc to keep queries open after disconnect.</center>","options"));
 #endif
 
-	 gbox = addGroupBox(0,1,0,1,1,QGroupBox::Horizontal,__tr2qs_ctx("On Unexpected Disconnect","options"));
+	 gbox = addGroupBox(0,1,0,1,1,Qt::Horizontal,__tr2qs_ctx("On Unexpected Disconnect","options"));
 
 
 	b1 = addBoolSelector(gbox,__tr2qs_ctx("Keep channels open","options"),KviOption_boolKeepChannelsOpenOnUnexpectedDisconnect,true);
@@ -70,7 +71,7 @@ KviConnectionOptionsWidget::KviConnectionOptionsWidget(QWidget * parent)
 	mergeTip(b1,__tr2qs_ctx("<center>This option will cause KVIrc to reopen query windows after a successful reconnect attempt.</center>","options"));
 #endif
 
-//	gbox = addGroupBox(0,1,0,1,1,QGroupBox::Horizontal,__tr2qs_ctx("On Unexpected Disconnect","options"));
+//	gbox = addGroupBox(0,1,0,1,1,Qt::Horizontal,__tr2qs_ctx("On Unexpected Disconnect","options"));
 	KviBoolSelector * b = addBoolSelector(gbox,__tr2qs_ctx("Automatically reconnect","options"),KviOption_boolAutoReconnectOnUnexpectedDisconnect);
 #ifdef COMPILE_INFO_TIPS
 	mergeTip(b,__tr2qs_ctx("<center>This option will enable auto-reconnecting after an unexpected disconnect. " \
@@ -119,7 +120,7 @@ KviSSLOptionsWidget::KviSSLOptionsWidget(QWidget * parent)
 #ifdef COMPILE_SSL_SUPPORT
 	createLayout(3,1);
 
-	QGroupBox * gbox = addGroupBox(0,0,0,0,1,QGroupBox::Horizontal,__tr2qs_ctx("Certificate","options"));
+	KviTalGroupBox * gbox = addGroupBox(0,0,0,0,1,Qt::Horizontal,__tr2qs_ctx("Certificate","options"));
 
 	KviBoolSelector * b = addBoolSelector(gbox,__tr2qs_ctx("Use SSL certificate (PEM format only)","options"),
 		&(KVI_OPTION_BOOL(KviOption_boolUseSSLCertificate)),true);
@@ -130,7 +131,7 @@ KviSSLOptionsWidget::KviSSLOptionsWidget(QWidget * parent)
 		&(KVI_OPTION_STRING(KviOption_stringSSLCertificatePass)),KVI_OPTION_BOOL(KviOption_boolUseSSLCertificate));
 	connect(b,SIGNAL(toggled(bool)),p,SLOT(setEnabled(bool)));
 
-	gbox = addGroupBox(0,1,0,1,1,QGroupBox::Horizontal,__tr2qs_ctx("Private Key","options"));
+	gbox = addGroupBox(0,1,0,1,1,Qt::Horizontal,__tr2qs_ctx("Private Key","options"));
 	b = addBoolSelector(gbox,__tr2qs_ctx("Use SSL private key","options"),
 		&(KVI_OPTION_BOOL(KviOption_boolUseSSLPrivateKey)),true);
 	f = addFileSelector(gbox,__tr2qs_ctx("Private key location:","options"),
@@ -161,7 +162,7 @@ KviTransportOptionsWidget::KviTransportOptionsWidget(QWidget * parent)
 	createLayout(5,1);
 	KviUIntSelector * u;
 	
-	QGroupBox * g = addGroupBox(0,0,0,0,1,QGroupBox::Horizontal,__tr2qs_ctx("Timeout Values","options"),this);
+	KviTalGroupBox * g = addGroupBox(0,0,0,0,1,Qt::Horizontal,__tr2qs_ctx("Timeout Values","options"),this);
 	u = addUIntSelector(g,__tr2qs_ctx("Connect timeout:","options"),KviOption_uintIrcSocketTimeout,5,6000,60);
 	u->setSuffix(__tr2qs_ctx(" sec","options"));
 	u = addUIntSelector(g,__tr2qs_ctx("Outgoing data queue flush timeout:","options"),KviOption_uintSocketQueueFlushTimeout,100,2000,500);
@@ -175,7 +176,7 @@ KviTransportOptionsWidget::KviTransportOptionsWidget(QWidget * parent)
 #endif
 	connect(b,SIGNAL(toggled(bool)),u,SLOT(setEnabled(bool)));
 
-	g = addGroupBox(0,3,0,3,2,QGroupBox::Horizontal,__tr2qs_ctx("Network Interfaces","options"));
+	g = addGroupBox(0,3,0,3,2,Qt::Horizontal,__tr2qs_ctx("Network Interfaces","options"));
 	
 	b = addBoolSelector(g,__tr2qs_ctx("Bind IPv4 connections to:","options"),KviOption_boolBindIrcIpV4ConnectionsToSpecifiedAddress);
 	KviStringSelector * s = addStringSelector(g,"",KviOption_stringIpV4ConnectionBindAddress,KVI_OPTION_BOOL(KviOption_boolBindIrcIpV4ConnectionsToSpecifiedAddress));
@@ -204,23 +205,47 @@ KviTransportOptionsWidget::~KviTransportOptionsWidget()
 KviIdentOptionsWidget::KviIdentOptionsWidget(QWidget * parent)
 : KviOptionsWidget(parent,"ident_options_widget")
 {
-	createLayout(5,1);
+	createLayout(6,1);
 
 	m_pEnableIdent = addBoolSelector(0,0,0,0,__tr2qs_ctx("Enable ident service (bad practice on UNIX!)","options"),KviOption_boolUseIdentService);
 	connect(m_pEnableIdent,SIGNAL(toggled(bool)),this,SLOT(enableIpv4InIpv6(bool)));
 
-	QGroupBox * gbox = addGroupBox(0,1,0,1,1,QGroupBox::Horizontal,__tr2qs_ctx("Configuration","options"),KVI_OPTION_BOOL(KviOption_boolUseIdentService));
+	KviTalGroupBox * gbox = addGroupBox(0,1,0,1,1,Qt::Horizontal,__tr2qs_ctx("Output verbosity","options"),KVI_OPTION_BOOL(KviOption_boolUseIdentService));
+	connect(m_pEnableIdent,SIGNAL(toggled(bool)),gbox,SLOT(setEnabled(bool)));
+
+	addLabel(gbox,__tr2qs_ctx("Output identd messages to:","options"));
+
+	m_pActiveRadio = new QRadioButton(__tr2qs_ctx("Active window","options"),gbox);
+	m_pConsoleRadio = new QRadioButton(__tr2qs_ctx("Console","options"),gbox);
+	m_pQuietRadio = new QRadioButton(__tr2qs_ctx("Do not show any identd messages","options"),gbox);
+
+	switch(KVI_OPTION_UINT(KviOption_uintIdentdOutputMode))
+	{
+		case KviIdentdOutputMode::Quiet :
+			m_pQuietRadio->setChecked(true);
+			break;
+		case KviIdentdOutputMode::ToConsole :
+			m_pConsoleRadio->setChecked(true);
+			break;
+		case KviIdentdOutputMode::ToActiveWindow :
+			m_pActiveRadio->setChecked(true);
+			break;
+	}
+
+	gbox = addGroupBox(0,2,0,2,1,Qt::Horizontal,__tr2qs_ctx("Configuration","options"),KVI_OPTION_BOOL(KviOption_boolUseIdentService));
 	
+	KviBoolSelector *b = addBoolSelector(gbox,__tr2qs_ctx("Enable ident service only while connecting to server","options"),KviOption_boolUseIdentServiceOnlyOnConnect);
+	connect(m_pEnableIdent,SIGNAL(toggled(bool)),b,SLOT(setEnabled(bool)));
+
 	KviStringSelector * s = addStringSelector(gbox,__tr2qs_ctx("Ident username:","options"),
 		KviOption_stringIdentdUser,KVI_OPTION_BOOL(KviOption_boolUseIdentService));
-	connect(m_pEnableIdent,SIGNAL(toggled(bool)),s,SLOT(setEnabled(bool)));
 	
 	KviUIntSelector * u = addUIntSelector(gbox,__tr2qs_ctx("Service port:","options"),
 		KviOption_uintIdentdPort,0,65535,113,KVI_OPTION_BOOL(KviOption_boolUseIdentService));
 	connect(m_pEnableIdent,SIGNAL(toggled(bool)),u,SLOT(setEnabled(bool)));
 	connect(m_pEnableIdent,SIGNAL(toggled(bool)),gbox,SLOT(setEnabled(bool)));
 
-	gbox = addGroupBox(0,2,0,2,1,QGroupBox::Horizontal,__tr2qs_ctx("IPv6 Settings","options"),KVI_OPTION_BOOL(KviOption_boolUseIdentService));
+	gbox = addGroupBox(0,3,0,3,1,Qt::Horizontal,__tr2qs_ctx("IPv6 Settings","options"),KVI_OPTION_BOOL(KviOption_boolUseIdentService));
 	m_pEnableIpv6 = addBoolSelector(gbox,__tr2qs_ctx("Enable service for IPv6","options"),
 		KviOption_boolIdentdEnableIpV6,
 		KVI_OPTION_BOOL(KviOption_boolUseIdentService));
@@ -235,7 +260,7 @@ KviIdentOptionsWidget::KviIdentOptionsWidget(QWidget * parent)
 		KVI_OPTION_BOOL(KviOption_boolUseIdentService) && KVI_OPTION_BOOL(KviOption_boolIdentdEnableIpV6));
 	connect(m_pEnableIdent,SIGNAL(toggled(bool)),gbox,SLOT(setEnabled(bool)));
 
-	addLabel(0,3,0,3,
+	addLabel(0,4,0,4,
 #ifdef COMPILE_ON_WINDOWS
 			__tr2qs_ctx("<p><b>Warning:</b><br>" \
 			"This is a <b>non RFC 1413 compliant</b> ident daemon that implements " \
@@ -251,13 +276,24 @@ KviIdentOptionsWidget::KviIdentOptionsWidget(QWidget * parent)
 #endif
 	);
 
-	addRowSpacer(0,4,0,4);
+	addRowSpacer(0,5,0,5);
 }
 
 KviIdentOptionsWidget::~KviIdentOptionsWidget()
 {
 }
 
+void KviIdentOptionsWidget::commit()
+{
+	KviOptionsWidget::commit();
+	if(m_pConsoleRadio->isOn())
+		KVI_OPTION_UINT(KviOption_uintIdentdOutputMode)=KviIdentdOutputMode::ToConsole;
+	if(m_pActiveRadio->isOn())
+		KVI_OPTION_UINT(KviOption_uintIdentdOutputMode)=KviIdentdOutputMode::ToActiveWindow;
+	if(m_pQuietRadio->isOn())
+		KVI_OPTION_UINT(KviOption_uintIdentdOutputMode)=KviIdentdOutputMode::Quiet;
+}
+
 void KviIdentOptionsWidget::enableIpv4InIpv6(bool)
 {
 #ifdef COMPILE_IPV6_SUPPORT
