@@ -27,7 +27,7 @@
 #include "kvi_options.h"
 
 //#ifdef COMPILE_INFO_TIPS
-//	#include <qtooltip.h>
+//	#include "kvi_tal_tooltip.h"
 //#endif
 
 KviCtcpOptionsWidget::KviCtcpOptionsWidget(QWidget * parent)
@@ -44,7 +44,7 @@ KviCtcpOptionsWidget::KviCtcpOptionsWidget(QWidget * parent)
 					"<br><br></p>","options"));
 
 
-	QGroupBox *gs = addGroupBox(0,1,0,1,1,QGroupBox::Horizontal,__tr2qs_ctx("CTCP Replies","options"));
+	KviTalGroupBox *gs = addGroupBox(0,1,0,1,1,Qt::Horizontal,__tr2qs_ctx("CTCP Replies","options"));
 	KviStringSelector * s = addStringSelector(gs, __tr2qs_ctx("Append to VERSION reply:","options"),KviOption_stringCtcpVersionPostfix);
 
 #ifdef COMPILE_INFO_TIPS
