@@ -31,11 +31,22 @@
 
 //#warning "Info tips"
 
+KviDccOptionsWidget::KviDccOptionsWidget(QWidget * pParent)
+: KviOptionsWidget(pParent)
+{
+}
 
-KviDccOptionsWidget::KviDccOptionsWidget(QWidget * parent)
+KviDccOptionsWidget::~KviDccOptionsWidget()
+{
+}
+
+///////////////////////////////////////////////////////////////////////////////////////////////////////////////
+
+
+KviDccGeneralOptionsWidget::KviDccGeneralOptionsWidget(QWidget * parent)
 : KviOptionsWidget(parent,"dccgeneral_options_widget")
 {
-	createLayout(5,1);
+	createLayout(2,1);
 
 	KviBoolSelector * b = addBoolSelector(0,0,0,0,__tr2qs_ctx("Use workaround for firewall","options"),KviOption_boolCantAcceptIncomingDccConnections);
 
@@ -45,18 +56,23 @@ KviDccOptionsWidget::KviDccOptionsWidget(QWidget * parent)
 			"Please note that these methods may NOT work when communicating with a non-KVIrc client.</center>","options"));
 #endif
 
-	QGroupBox * g = addGroupBox(0,1,0,1,1,QGroupBox::Horizontal,__tr2qs_ctx("Network Properties","options"));
+	addRowSpacer(0,1,0,1);
+}
 
-	KviUIntSelector * u = addUIntSelector(g,__tr2qs_ctx("DCC socket timeout:","options"),KviOption_uintDccSocketTimeout,10,65536,180);
-	u->setSuffix(__tr2qs_ctx(" sec","options"));
+KviDccGeneralOptionsWidget::~KviDccGeneralOptionsWidget()
+{
+}
 
+///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-#ifdef COMPILE_INFO_TIPS
-	mergeTip(u,__tr2qs_ctx("<center>This is the amount of time that KVIrc will wait for a response before assuming that a DCC has failed " \
-		"because the remote client was unable to connect to our listening socket.</center>","options"));
-#endif
+KviDccAdvancedOptionsWidget::KviDccAdvancedOptionsWidget(QWidget * parent)
+: KviOptionsWidget(parent,"dccgeneral_options_widget")
+{
+	createLayout(5,1);
+
+	KviTalGroupBox * g = addGroupBox(0,0,0,0,1,Qt::Horizontal,__tr2qs_ctx("Network Properties","options"));
 	
-	b = addBoolSelector(g,__tr2qs_ctx("Use user-defined address or network interface","options"),KviOption_boolDccListenOnSpecifiedInterfaceByDefault);
+	KviBoolSelector * b = addBoolSelector(g,__tr2qs_ctx("Use user-defined address or network interface","options"),KviOption_boolDccListenOnSpecifiedInterfaceByDefault);
 
 
 #ifdef COMPILE_INFO_TIPS
@@ -81,9 +97,9 @@ KviDccOptionsWidget::KviDccOptionsWidget(QWidget * parent)
 	mergeTip(b,__tr2qs_ctx("<center>Enable this option if you want specify a local port range for DCC.</center>","options"));
 #endif
 
-	QHBox * hb = new QHBox(g);
+	KviTalHBox * hb = new KviTalHBox(g);
 	hb->setSpacing(4);
-	u = addUIntSelector(hb,__tr2qs_ctx("Lowest port:","options"),KviOption_uintDccMinPort,1,65535,5000,KVI_OPTION_BOOL(KviOption_boolUserDefinedPortRange));
+	KviUIntSelector * u = addUIntSelector(hb,__tr2qs_ctx("Lowest port:","options"),KviOption_uintDccMinPort,1,65535,5000,KVI_OPTION_BOOL(KviOption_boolUserDefinedPortRange));
 	connect(b,SIGNAL(toggled(bool)),u,SLOT(setEnabled(bool)));
 
 	u = addUIntSelector(hb,__tr2qs_ctx("Highest port:","options"),KviOption_uintDccMaxPort,1,65535,30000,KVI_OPTION_BOOL(KviOption_boolUserDefinedPortRange));
@@ -125,7 +141,7 @@ KviDccOptionsWidget::KviDccOptionsWidget(QWidget * parent)
 									
 	connect(b2,SIGNAL(toggled(bool)),b,SLOT(setEnabled(bool)));
 
-	b = addBoolSelector(0,2,1,2,__tr2qs_ctx("Notify failed DCC handshakes to the remote end","options"),
+	b = addBoolSelector(0,1,1,1,__tr2qs_ctx("Notify failed DCC handshakes to the remote end","options"),
 									KviOption_boolNotifyFailedDccHandshakes);
 #ifdef COMPILE_INFO_TIPS
 	mergeTip(b,__tr2qs_ctx("<center>If you enable this option, when a DCC request from a remote " \
@@ -135,21 +151,32 @@ KviDccOptionsWidget::KviDccOptionsWidget(QWidget * parent)
 					"might help if you often get attacked by CTCP floods.</center>","options"));
 #endif
 
-	u = addUIntSelector(0,3,1,3,__tr2qs_ctx("Maximum number of DCC sessions","options"),KviOption_uintMaxDccSlots,0,1000,64);
+	u = addUIntSelector(0,2,1,2,__tr2qs_ctx("Maximum number of DCC sessions","options"),KviOption_uintMaxDccSlots,0,1000,64);
 #ifdef COMPILE_INFO_TIPS
 	mergeTip(u,__tr2qs_ctx("<center>This is the maximum number of concurrent DCC sessions " \
 					"and it includes all the DCC types (send,chat,recv...). " \
 					"KVIrc will refuse the requests when this limit is reached.</center>","options"));
 #endif
 
+	addUIntSelector(0,3,1,3,__tr2qs_ctx("DCC socket timeout:","options"),KviOption_uintDccSocketTimeout,10,65536,180);
+	u->setSuffix(__tr2qs_ctx(" sec","options"));
+#ifdef COMPILE_INFO_TIPS
+	mergeTip(u,__tr2qs_ctx("<center>This is the amount of time that KVIrc will wait for a response before assuming that a DCC has failed " \
+		"because the remote client was unable to connect to our listening socket.</center>","options"));
+#endif
+
 	addRowSpacer(0,4,1,4);
 }
 
-KviDccOptionsWidget::~KviDccOptionsWidget()
+KviDccAdvancedOptionsWidget::~KviDccAdvancedOptionsWidget()
 {
 }
 
 
+
+///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+
+
 KviDccSendOptionsWidget::KviDccSendOptionsWidget(QWidget * parent)
 : KviOptionsWidget(parent,"dccsend_options_widget")
 {
@@ -164,44 +191,38 @@ KviDccSendOptionsWidget::~KviDccSendOptionsWidget()
 KviDccSendGeneralOptionsWidget::KviDccSendGeneralOptionsWidget(QWidget * parent)
 : KviOptionsWidget(parent,"dccsend_options_widget")
 {
-	createLayout(10,4);
+	createLayout(5,1);
 
-	KviBoolSelector * b1 = addBoolSelector(0,3,4,3,__tr2qs_ctx("Open all minimized","options"),KviOption_boolCreateMinimizedDccSend);
-	QGroupBox * g = addGroupBox(0,0,4,0,1,QGroupBox::Horizontal,__tr2qs_ctx("On Incoming File","options"));
+	KviBoolSelector * b;
+
+	KviTalGroupBox * g = addGroupBox(0,0,0,0,1,Qt::Horizontal,__tr2qs_ctx("On Incoming File","options"));
 	KviBoolSelector * b2 = addBoolSelector(g,__tr2qs_ctx("Automatically accept","options"),KviOption_boolAutoAcceptDccSend);
+	KviBoolSelector * b3 = addBoolSelector(g,__tr2qs_ctx("Open transfer window as minimized when auto-accepted","options"),KviOption_boolCreateMinimizedDccSendWhenAutoAccepted,!KVI_OPTION_BOOL(KviOption_boolCreateMinimizedDccSend));
+	KviBoolSelector * b4 = addBoolSelector(g,__tr2qs_ctx("Automatically resume when auto-accepted","options"),KviOption_boolAutoResumeDccSendWhenAutoAccepted,KVI_OPTION_BOOL(KviOption_boolAutoAcceptDccSend));
 
-	KviBoolSelector * b = addBoolSelector(g,__tr2qs_ctx("Open minimized when auto-accepted","options"),KviOption_boolCreateMinimizedDccSendWhenAutoAccepted,!KVI_OPTION_BOOL(KviOption_boolCreateMinimizedDccSend));
-	connect(b1,SIGNAL(toggled(bool)),b,SLOT(setNotEnabled(bool)));
-	
-	b = addBoolSelector(g,__tr2qs_ctx("Automatically resume when auto-accepted","options"),KviOption_boolAutoResumeDccSendWhenAutoAccepted,KVI_OPTION_BOOL(KviOption_boolAutoAcceptDccSend));
-	connect(b2,SIGNAL(toggled(bool)),b,SLOT(setEnabled(bool)));
-
-	addDirectorySelector(0,1,4,1,__tr2qs_ctx("Download folder:","options"),KviOption_stringIncomingPath);
-
-	addBoolSelector(0,2,4,2,__tr2qs_ctx("Sort saved files by nicknames (create subfolders)","options"),KviOption_boolSortReceivedByDccFilesByNicks);
-	addBoolSelector(0,4,4,4,__tr2qs_ctx("Automatically close on completion","options"),KviOption_boolAutoCloseDccSendOnSuccess);
-	addBoolSelector(0,5,4,5,__tr2qs_ctx("Notify completion in console","options"),KviOption_boolNotifyDccSendSuccessInConsole);
-	addBoolSelector(0,6,4,6,__tr2qs_ctx("Notify completion in notifier","options"),KviOption_boolNotifyDccSendSuccessInNotifier);
+	g = addGroupBox(0,1,0,1,1,Qt::Horizontal,__tr2qs_ctx("Save Location","options"));
+	addDirectorySelector(g,__tr2qs_ctx("Download folder:","options"),KviOption_stringIncomingPath);
+	addBoolSelector(g,__tr2qs_ctx("Sort saved files by nicknames (create subfolders)","options"),KviOption_boolSortReceivedByDccFilesByNicks);
+	addBoolSelector(g,__tr2qs_ctx("Guess save path from media type","options"),KviOption_boolUseIncomingDccMediaTypeSavePath);
 
 
+	g = addGroupBox(0,2,0,2,1,Qt::Horizontal,__tr2qs_ctx("On Download Completion","options"));
+	addBoolSelector(g,__tr2qs_ctx("Notify completion in console","options"),KviOption_boolNotifyDccSendSuccessInConsole);
+	addBoolSelector(g,__tr2qs_ctx("Notify completion in notifier","options"),KviOption_boolNotifyDccSendSuccessInNotifier);
+	b = addBoolSelector(g,__tr2qs_ctx("Automatically clear transfer","options"),KviOption_boolAutoCloseDccSendOnSuccess);
 #ifdef COMPILE_INFO_TIPS
 	mergeTip(b,
-		__tr2qs_ctx("<center>The \"send ahead\" DCC method allows data to be sent faster by breaking " \
-				"some of the rules of the original DCC SEND protocol specification.<br>" \
-				"Most clients can handle this kind of optimisation so disable it only if you have problems.</center>","options"));
+		__tr2qs_ctx("<center>This option will cause succesfully terminated transfers " \
+				"to be automatically removed from the transfer window.</center>","options"));
 #endif //COMPILE_INFO_TIPS
 
-	addBoolSelector(0,7,4,7,__tr2qs_ctx("Guess save path from media type","options"),KviOption_boolUseIncomingDccMediaTypeSavePath);
 
-	KviUIntSelector * u = addUIntSelector(0,8,4,8,__tr2qs_ctx("Maximum number of DCC transfers","options"),KviOption_uintMaxDccSendTransfers,0,1000,10);
-	
-#ifdef COMPILE_INFO_TIPS
-	mergeTip(u,__tr2qs_ctx("<center>This is the maximum number of concurrent DCC transfers. " \
-					"KVIrc will refuse the requests when this limit is reached.</center>","options"));
-#endif
+	KviBoolSelector * b1 = addBoolSelector(0,3,0,3,__tr2qs_ctx("Always open transfer window as minimized","options"),KviOption_boolCreateMinimizedDccSend);
 
-	addAdvancedButton(4,8,4,8);
-	addRowSpacer(0,9,4,9);
+	connect(b1,SIGNAL(toggled(bool)),b3,SLOT(setNotEnabled(bool)));
+	connect(b2,SIGNAL(toggled(bool)),b4,SLOT(setEnabled(bool)));
+
+	addRowSpacer(0,4,0,4);
 }
 
 KviDccSendGeneralOptionsWidget::~KviDccSendGeneralOptionsWidget()
@@ -212,9 +233,9 @@ KviDccSendGeneralOptionsWidget::~KviDccSendGeneralOptionsWidget()
 KviDccSendAdvancedOptionsWidget::KviDccSendAdvancedOptionsWidget(QWidget * parent)
 : KviOptionsWidget(parent,"dccsend_advanced_options_widget")
 {
-	createLayout(6,1);
+	createLayout(4,1);
 
-	QGroupBox * g = addGroupBox(0,0,0,0,1,QGroupBox::Horizontal,__tr2qs_ctx("Bug Compatibility","options"));
+	KviTalGroupBox * g = addGroupBox(0,0,0,0,1,Qt::Horizontal,__tr2qs_ctx("Bug Compatibility","options"));
 	KviBoolSelector * b = addBoolSelector(g,__tr2qs_ctx("Send ACK for byte 0","options"),KviOption_boolSendZeroAckInDccRecv);
 #ifdef COMPILE_INFO_TIPS
 	mergeTip(b,
@@ -238,31 +259,40 @@ KviDccSendAdvancedOptionsWidget::KviDccSendAdvancedOptionsWidget(QWidget * paren
 #endif //COMPILE_INFO_TIPS
 
 
-	g = addGroupBox(0,1,0,1,2,QGroupBox::Horizontal,__tr2qs_ctx("Speed limits","options"));
+	g = addGroupBox(0,1,0,1,1,Qt::Horizontal,__tr2qs_ctx("Limits","options"));
 
-	b = addBoolSelector(g,__tr2qs_ctx("Limit upload bandwidth to","options"),KviOption_boolLimitDccSendSpeed);
-	KviUIntSelector * u = addUIntSelector(g,"",KviOption_uintMaxDccSendSpeed,0,0xffffff1,1024,KVI_OPTION_BOOL(KviOption_boolLimitDccSendSpeed));
+	KviTalHBox * hb = new KviTalHBox(g);
+	b = addBoolSelector(hb,__tr2qs_ctx("Limit upload bandwidth to","options"),KviOption_boolLimitDccSendSpeed);
+	KviUIntSelector * u = addUIntSelector(hb,"",KviOption_uintMaxDccSendSpeed,0,0xffffff1,1024,KVI_OPTION_BOOL(KviOption_boolLimitDccSendSpeed));
 	u->setSuffix(" " + __tr2qs_ctx("bytes/sec","options"));
 	connect(b,SIGNAL(toggled(bool)),u,SLOT(setEnabled(bool)));
 	
-	b = addBoolSelector(g,__tr2qs_ctx("Limit download bandwidth to","options"),KviOption_boolLimitDccRecvSpeed);
-	u = addUIntSelector(g,"",KviOption_uintMaxDccRecvSpeed,0,0xffffff1,1024,KVI_OPTION_BOOL(KviOption_boolLimitDccRecvSpeed));
+	hb = new KviTalHBox(g);
+	b = addBoolSelector(hb,__tr2qs_ctx("Limit download bandwidth to","options"),KviOption_boolLimitDccRecvSpeed);
+	u = addUIntSelector(hb,"",KviOption_uintMaxDccRecvSpeed,0,0xffffff1,1024,KVI_OPTION_BOOL(KviOption_boolLimitDccRecvSpeed));
 	u->setSuffix(" " + __tr2qs_ctx("bytes/sec","options"));
 	connect(b,SIGNAL(toggled(bool)),u,SLOT(setEnabled(bool)));
 
 
-	u = addUIntSelector(0,2,0,2,__tr2qs_ctx("Packet size:","options"),KviOption_uintDccSendPacketSize,16,65536,1024);
-	u->setSuffix(__tr2qs_ctx(" bytes","options"));
+	u = addUIntSelector(g,__tr2qs_ctx("Maximum number of DCC transfers","options"),KviOption_uintMaxDccSendTransfers,0,1000,10);
 #ifdef COMPILE_INFO_TIPS
-	mergeTip(u,
-		__tr2qs_ctx("<center>This parameter controls the packet size used for DCC SEND.<br>" \
-				"With bigger packets you will be probably send data faster, but " \
-				"you will also saturate your bandwidth and in some cases " \
-				"cause more disk activity.<br>" \
-				"Reasonable values are from 512 to 4096 bytes.</center>","options"));
+	mergeTip(u,__tr2qs_ctx("<center>This is the maximum number of concurrent DCC transfers. " \
+					"KVIrc will refuse the requests when this limit is reached.</center>","options"));
+#endif
+
+	g = addGroupBox(0,2,0,2,1,Qt::Horizontal,__tr2qs_ctx("Tweaks","options"));
+
+	b = addBoolSelector(g,__tr2qs_ctx("Use fast send (send ahead)","options"),KviOption_boolUseFastDccSend);
+#ifdef COMPILE_INFO_TIPS
+	mergeTip(b,
+		__tr2qs_ctx("<center>The \"send ahead\" DCC method allows data to be sent faster by breaking " \
+				"some of the rules of the original DCC SEND protocol specification.<br>" \
+				"Most clients can handle this kind of optimisation so disable it only if you have problems.</center>","options"));
 #endif //COMPILE_INFO_TIPS
 
-	b = addBoolSelector(0,3,0,3,__tr2qs_ctx("Force idle step","options"),KviOption_boolDccSendForceIdleStep);
+	hb = new KviTalHBox(g);
+
+	b = addBoolSelector(hb,__tr2qs_ctx("Force idle step","options"),KviOption_boolDccSendForceIdleStep);
 #ifdef COMPILE_INFO_TIPS
 	mergeTip(b,
 		__tr2qs_ctx("<center>Enable this option when the dcc file transfers " \
@@ -271,7 +301,7 @@ KviDccSendAdvancedOptionsWidget::KviDccSendAdvancedOptionsWidget(QWidget * paren
 				"forcibly inserted between each sent/received data packet.</center>","options"));
 #endif // COMPILE_INFO_TIPS
 
-	u = addUIntSelector(0,4,0,4,__tr2qs_ctx("Idle interval:","options"),KviOption_uintDccSendIdleStepInMSec,1,65536,30,KVI_OPTION_BOOL(KviOption_boolDccSendForceIdleStep));
+	u = addUIntSelector(hb,__tr2qs_ctx("","options"),KviOption_uintDccSendIdleStepInMSec,1,65536,30,KVI_OPTION_BOOL(KviOption_boolDccSendForceIdleStep));
 	connect(b,SIGNAL(toggled(bool)),u,SLOT(setEnabled(bool)));
 	u->setSuffix(__tr2qs_ctx(" msec","options"));
 	
@@ -283,9 +313,19 @@ KviDccSendAdvancedOptionsWidget::KviDccSendAdvancedOptionsWidget(QWidget * paren
 				"Reasonable values are from 5 to 50 milliseconds.</center>","options"));
 #endif //COMPILE_INFO_TIPS
 
-	b = addBoolSelector(0,5,0,5,__tr2qs_ctx("Use fast send (send ahead)","options"),KviOption_boolUseFastDccSend);
+	u = addUIntSelector(g,__tr2qs_ctx("Packet size:","options"),KviOption_uintDccSendPacketSize,16,65536,1024);
+	u->setSuffix(__tr2qs_ctx(" bytes","options"));
+#ifdef COMPILE_INFO_TIPS
+	mergeTip(u,
+		__tr2qs_ctx("<center>This parameter controls the packet size used for DCC SEND.<br>" \
+				"With bigger packets you will be probably send data faster, but " \
+				"you will also saturate your bandwidth and in some cases " \
+				"cause more disk activity.<br>" \
+				"Reasonable values are from 512 to 4096 bytes.</center>","options"));
+#endif //COMPILE_INFO_TIPS
 
-	addRowSpacer(0,6,0,6);
+
+	addRowSpacer(0,3,0,3);
 
 }
 
@@ -306,11 +346,12 @@ KviDccChatOptionsWidget::KviDccChatOptionsWidget(QWidget * parent)
 {
 	createLayout(3,1);
 
-	KviBoolSelector * b1 = addBoolSelector(0,0,0,0,__tr2qs_ctx("Open all minimized","options"),KviOption_boolCreateMinimizedDccChat);
-	QGroupBox * g = addGroupBox(0,1,0,1,1,QGroupBox::Horizontal,__tr2qs_ctx("On Chat Request","options"));
+	KviTalGroupBox * g = addGroupBox(0,0,0,0,1,Qt::Horizontal,__tr2qs_ctx("On Chat Request","options"));
 	KviBoolSelector * b = addBoolSelector(g,__tr2qs_ctx("Automatically accept","options"),KviOption_boolAutoAcceptDccChat);
-
 	b = addBoolSelector(g,__tr2qs_ctx("Open minimized when auto-accepted","options"),KviOption_boolCreateMinimizedDccChatWhenAutoAccepted,!KVI_OPTION_BOOL(KviOption_boolCreateMinimizedDccChat));
+
+	KviBoolSelector * b1 = addBoolSelector(0,1,0,1,__tr2qs_ctx("Always open as minimized","options"),KviOption_boolCreateMinimizedDccChat);
+
 	connect(b1,SIGNAL(toggled(bool)),b,SLOT(setNotEnabled(bool)));
 
 	addRowSpacer(0,2,0,2);
@@ -326,7 +367,7 @@ KviDccVoiceOptionsWidget::KviDccVoiceOptionsWidget(QWidget *p):KviOptionsWidget(
 	createLayout(8, 1);
 
 	KviBoolSelector * b1 = addBoolSelector(0,0,0,0,__tr2qs_ctx("Open all minimized","options"),KviOption_boolCreateMinimizedDccVoice);
-	QGroupBox * g = addGroupBox(0,1,0,1,1,QGroupBox::Horizontal,__tr2qs_ctx("On Voice Request","options"));
+	KviTalGroupBox * g = addGroupBox(0,1,0,1,1,Qt::Horizontal,__tr2qs_ctx("On Voice Request","options"));
 	KviBoolSelector * b = addBoolSelector(g,__tr2qs_ctx("Automatically accept","options"),KviOption_boolAutoAcceptDccVoice);
 
 	b = addBoolSelector(g,__tr2qs_ctx("Open minimized when auto-accepted","options"),KviOption_boolCreateMinimizedDccVoiceWhenAutoAccepted,!KVI_OPTION_BOOL(KviOption_boolCreateMinimizedDccVoice));
