@@ -31,6 +31,16 @@
 
 #include <qlabel.h>
 
+KviAlertHighlightingOptionsWidget::KviAlertHighlightingOptionsWidget(QWidget * parent)
+: KviOptionsWidget(parent,"highlighting_options_widget")
+{
+}
+
+KviAlertHighlightingOptionsWidget::~KviAlertHighlightingOptionsWidget()
+{
+}
+
+
 
 KviHighlightingOptionsWidget::KviHighlightingOptionsWidget(QWidget * parent)
 : KviOptionsWidget(parent,"highlighting_options_widget")
@@ -59,7 +69,26 @@ KviHighlightingOptionsWidget::KviHighlightingOptionsWidget(QWidget * parent)
 	mergeTip(b,__tr2qs_ctx("<center>If this option is enabled, KVIrc will popup a little notifier window in the low right corner of your desktop when a highlighted message is printed and KVIrc is not the active window</center>","options"));
 #endif
 
-	QGroupBox * g = addGroupBox(0,6,0,6,1,QGroupBox::Horizontal,__tr2qs_ctx("Taskbar Alert","options"));
+	addRowSpacer(0,6,0,6);
+}
+
+KviHighlightingOptionsWidget::~KviHighlightingOptionsWidget()
+{
+}
+
+
+
+
+
+
+KviAlertOptionsWidget::KviAlertOptionsWidget(QWidget * parent)
+: KviOptionsWidget(parent,"highlighting_options_widget")
+{
+	createLayout(2,1);
+
+	KviBoolSelector * b;
+
+	KviTalGroupBox * g = addGroupBox(0,0,0,0,1,Qt::Horizontal,__tr2qs_ctx("Alert Restrictions","options"));
 	KviBoolSelector * b3 = addBoolSelector(g,__tr2qs_ctx("Restrict alert","options"),KviOption_boolHighlightOnlyNormalMsg);
 #ifdef COMPILE_INFO_TIPS
 	mergeTip(b3, __tr2qs_ctx("<center>If this option is enabled, KVIrc will alert in the taskbar only if a normal message is received in a channel.<br>Actions like joins, parts and mode changes will be ignored.<br> This is useful if you are in channels with a high rate of traffic and only want to be alerted for messages that are interesting to you.</center>","options"));
@@ -74,6 +103,7 @@ KviHighlightingOptionsWidget::KviHighlightingOptionsWidget(QWidget * parent)
 #endif
 	connect(b3,SIGNAL(toggled(bool)),b4,SLOT(setEnabled(bool)));
 	connect(b3,SIGNAL(toggled(bool)),b5,SLOT(setEnabled(bool)));
+
 	KviBoolSelector * b6 = addBoolSelector(g,__tr2qs_ctx("Use custom alert level","options"),KviOption_boolHighlightOnlyAtCostumHighlightLevel);
 #ifdef COMPILE_INFO_TIPS
 	mergeTip(b6, __tr2qs_ctx("<center>If this option is enabled, KVIrc will alert in the taskbar only if the specified alert level is reached.</center>","options"));
@@ -85,10 +115,10 @@ KviHighlightingOptionsWidget::KviHighlightingOptionsWidget(QWidget * parent)
 #endif
 	connect(b6,SIGNAL(toggled(bool)),b7,SLOT(setEnabled(bool)));
 
-	layout()->setRowStretch(1,1);
+	addRowSpacer(0,1,0,1);
 }
 
-KviHighlightingOptionsWidget::~KviHighlightingOptionsWidget()
+KviAlertOptionsWidget::~KviAlertOptionsWidget()
 {
 }
 
