@@ -24,9 +24,23 @@
 
 #include "kvi_optionswidget.h"
 
+#define KVI_OPTIONS_WIDGET_ICON_KviAlertHighlightingOptionsWidget KVI_SMALLICON_RAW
+#define KVI_OPTIONS_WIDGET_NAME_KviAlertHighlightingOptionsWidget __tr2qs_no_lookup("Alert/Highlight")
+#define KVI_OPTIONS_WIDGET_PARENT_KviAlertHighlightingOptionsWidget KviToolsOptionsWidget
+#define KVI_OPTIONS_WIDGET_CONTAINER_KviAlertHighlightingOptionsWidget true
+
+class KviAlertHighlightingOptionsWidget : public KviOptionsWidget
+{
+	Q_OBJECT
+public:
+	KviAlertHighlightingOptionsWidget(QWidget * parent);
+	~KviAlertHighlightingOptionsWidget();
+};
+
+
 #define KVI_OPTIONS_WIDGET_ICON_KviHighlightingOptionsWidget KVI_SMALLICON_RAW
-#define KVI_OPTIONS_WIDGET_NAME_KviHighlightingOptionsWidget __tr2qs_no_lookup("Alert/Highlight")
-#define KVI_OPTIONS_WIDGET_PARENT_KviHighlightingOptionsWidget KviToolsOptionsWidget
+#define KVI_OPTIONS_WIDGET_NAME_KviHighlightingOptionsWidget __tr2qs_no_lookup("Highlight")
+#define KVI_OPTIONS_WIDGET_PARENT_KviHighlightingOptionsWidget KviAlertHighlightingOptionsWidget
 
 class KviHighlightingOptionsWidget : public KviOptionsWidget
 {
@@ -36,4 +50,18 @@ public:
 	~KviHighlightingOptionsWidget();
 };
 
+
+#define KVI_OPTIONS_WIDGET_ICON_KviAlertOptionsWidget KVI_SMALLICON_RAW
+#define KVI_OPTIONS_WIDGET_NAME_KviAlertOptionsWidget __tr2qs_no_lookup("Taskbar Alert")
+#define KVI_OPTIONS_WIDGET_PARENT_KviAlertOptionsWidget KviAlertHighlightingOptionsWidget
+
+class KviAlertOptionsWidget : public KviOptionsWidget
+{
+	Q_OBJECT
+public:
+	KviAlertOptionsWidget(QWidget * parent);
+	~KviAlertOptionsWidget();
+};
+
+
 #endif //_OPTW_HIGHLIGHTING_H_
