@@ -24,7 +24,7 @@
 
 #include "optw_ident.h"
 
-#include <qgroupbox.h>
+#include <kvi_tal_groupbox.h>
 
 #include "kvi_options.h"
 #include "kvi_locale.h"
