@@ -24,22 +24,5 @@
 
 #include "kvi_optionswidget.h"
 
-#define KVI_OPTIONS_WIDGET_ICON_KviIdentOptionsWidget KVI_SMALLICON_IDENT
-#define KVI_OPTIONS_WIDGET_NAME_KviIdentOptionsWidget __tr_no_lookup("Ident Service")
-#define KVI_OPTIONS_WIDGET_PARENT_KviIdentOptionsWidget KviConnectionOptionsWidget
-
-class KviIdentOptionsWidget : public KviOptionsWidget
-{
-	Q_OBJECT
-public:
-	KviIdentOptionsWidget(QWidget * parent);
-	~KviIdentOptionsWidget();
-protected:
-	KviBoolSelector * m_pEnableIdent;
-	KviBoolSelector * m_pEnableIpv6;
-	KviBoolSelector * m_pIpv4InIpv6;
-public slots:
-	void enableIpv4InIpv6(bool);
-};
 
 #endif //_OPTW_IDENT_H_
