@@ -28,12 +28,11 @@
 #include <qcheckbox.h>
 #include <qpushbutton.h>
 #include <qlayout.h>
-#include <qtooltip.h>
+#include "kvi_tal_tooltip.h"
 #include <qtabwidget.h>
 #include <qcombobox.h>
 #include <qmessagebox.h>
 #include <qtimer.h>
-#include <qtooltip.h>
 #include <qvalidator.h>
 
 #include "kvi_defaults.h"
@@ -49,14 +48,13 @@
 #include "kvi_http.h"
 
 
-
 //#warning "Info tips"
 
 
 KviNickAlternativesDialog::KviNickAlternativesDialog(QWidget * par,const QString &n1,const QString &n2,const QString &n3)
 : QDialog(par)
 {
-	QGridLayout * g = new QGridLayout(this,5,3,4,8);
+	QGridLayout * g = new QGridLayout(this,5,3,4,12);
 
 	setCaption(__tr2qs_ctx("Nickname alternatives","options"));
 
@@ -87,7 +85,10 @@ KviNickAlternativesDialog::KviNickAlternativesDialog(QWidget * par,const QString
 	m_pNickEdit3 = new QLineEdit(this);
 	g->addMultiCellWidget(m_pNickEdit3,3,3,1,2);
 	m_pNickEdit3->setText(n3);
-	QHBox * h = new QHBox(this);h->setSpacing(8);g->addWidget(h,4,2);	
+	KviTalHBox * h = new KviTalHBox(this);
+	h->setSpacing(8);
+	g->addWidget(h,4,2);
+
 	QPushButton * pb = new QPushButton(__tr2qs_ctx("Cancel","options"),h);
 	//g->addWidget(pb,4,2);
 	connect(pb,SIGNAL(clicked()),this,SLOT(reject()));
@@ -236,7 +237,7 @@ KviAvatarSelectionDialog::KviAvatarSelectionDialog(QWidget * par,const QString &
 	QPushButton * b = new QPushButton(__tr2qs_ctx("&Browse...","options"),this);
 	connect(b,SIGNAL(clicked()),this,SLOT(chooseFileClicked()));
 	g->addWidget(b,1,2);
-	QHBox * h = new QHBox(this);h->setSpacing(8);g->addMultiCellWidget(h,2,2,1,2);
+	KviTalHBox * h = new KviTalHBox(this);h->setSpacing(8);g->addMultiCellWidget(h,2,2,1,2);
 	b = new QPushButton(__tr2qs_ctx("&OK","options"),h);
 	b->setMinimumWidth(80);
 	b->setDefault(true);
@@ -271,7 +272,8 @@ void KviAvatarSelectionDialog::cancelClicked()
 void KviAvatarSelectionDialog::chooseFileClicked()
 {
 	QString tmp;
- 	if(KviFileDialog::askForOpenFileName(tmp,__tr2qs_ctx("Choose an Image File - KVIrc","options")))
+ 	if(KviFileDialog::askForOpenFileName(tmp,__tr2qs_ctx("Choose an Image File - KVIrc","options"),
+		QString::null,QString::null,false,true,this))
 	{
 		m_pLineEdit->setText(tmp);
 	}
@@ -311,8 +313,8 @@ KviIdentityGeneralOptionsWidget::KviIdentityGeneralOptionsWidget(QWidget * paren
 	createLayout(3,1);
 	layout()->setMargin(10);
 
-	QGroupBox * gbox = addGroupBox(0,0,0,0,1,QGroupBox::Horizontal,__tr2qs_ctx("Basic Properties","options"));
-	QHBox * hb = new QHBox(gbox);
+	KviTalGroupBox * gbox = addGroupBox(0,0,0,0,1,Qt::Horizontal,__tr2qs_ctx("Basic Properties","options"));
+	KviTalHBox * hb = new KviTalHBox(gbox);
 	hb->setSpacing(3);
 
 	KviStringSelector * sel = addStringSelector(hb,__tr2qs_ctx("Nickname:","options"),KviOption_stringNickname1);
@@ -351,9 +353,9 @@ KviIdentityGeneralOptionsWidget::KviIdentityGeneralOptionsWidget(QWidget * paren
 	QString szCenterEnd("</center>");
 	QString szTrailing = "<br><br>" + szOptionalCtcpUserInfo + szCenterEnd;
 
-	gbox = addGroupBox(0,1,0,1,1,QGroupBox::Horizontal,__tr2qs_ctx("Profile","options"));
+	gbox = addGroupBox(0,1,0,1,1,Qt::Horizontal,__tr2qs_ctx("Profile","options"));
 
-	hb = new QHBox(gbox);
+	hb = new KviTalHBox(gbox);
 	hb->setSpacing(4);
 	
 	QLabel * l = new QLabel(__tr2qs_ctx("Age:","options"),hb);
@@ -362,8 +364,8 @@ KviIdentityGeneralOptionsWidget::KviIdentityGeneralOptionsWidget(QWidget * paren
 	m_pAgeCombo = new QComboBox(hb);
 #ifdef COMPILE_INFO_TIPS
 	QString szTip1 = szCenterBegin + __tr2qs_ctx("Here you can specify your age.","options") + szTrailing;
-	QToolTip::add(l,szTip1);
-	QToolTip::add(m_pAgeCombo,szTip1);
+	KviTalToolTip::add(l,szTip1);
+	KviTalToolTip::add(m_pAgeCombo,szTip1);
 #endif
 	m_pAgeCombo->insertItem(__tr2qs_ctx("Unspecified","options"));
 	unsigned int i;
@@ -383,7 +385,7 @@ KviIdentityGeneralOptionsWidget::KviIdentityGeneralOptionsWidget(QWidget * paren
 	hb->setStretchFactor(m_pAgeCombo,1);
 
 
-	hb = new QHBox(gbox);
+	hb = new KviTalHBox(gbox);
 	hb->setSpacing(4);
 	
 	l = new QLabel(__tr2qs_ctx("Gender:","options"),hb);
@@ -392,8 +394,8 @@ KviIdentityGeneralOptionsWidget::KviIdentityGeneralOptionsWidget(QWidget * paren
 	m_pGenderCombo = new QComboBox(hb);
 #ifdef COMPILE_INFO_TIPS
 	QString szTip2 =  szCenterBegin + __tr2qs_ctx("Here you can specify your gender.","options") + szTrailing;
-	QToolTip::add(l,szTip2);
-	QToolTip::add(m_pGenderCombo,szTip2);
+	KviTalToolTip::add(l,szTip2);
+	KviTalToolTip::add(m_pGenderCombo,szTip2);
 #endif
 
 	m_pGenderCombo->insertItem(__tr2qs_ctx("Unspecified","options"));
@@ -495,18 +497,34 @@ KviIdentityAvatarOptionsWidget::KviIdentityAvatarOptionsWidget(QWidget * parent)
 	m_pLocalAvatar = new KviPixmap(KVI_OPTION_PIXMAP(KviOption_pixmapMyAvatar));
 
 	bool bHaveAvatar = (!KVI_OPTION_STRING(KviOption_stringMyAvatar).isEmpty()) && m_pLocalAvatar->pixmap();
-	
+
+#ifdef COMPILE_INFO_TIPS
+	QString szTip = __tr2qs_ctx("Here you can choose your avatar image. It will be visible<br>" \
+							"by other people that request it. Choose a nice image of yourself,<br>" \
+							"possibly avoiding obscenity and offending images. It is a good idea<br>" \
+							"to choose a relatively small file (say 150 Kb max) because<br>" \
+							"most clients have a limit on the size of avatars being downloaded.<br>" \
+							"The image also should be smaller than 800x600 pixels since<br>" \
+							"it will have to be viewable in everyone's monitor.","options");
+#endif
+
 	m_pUseAvatarCheck = new KviStyledCheckBox(__tr2qs_ctx("Use avatar","options"),this);
 	addWidgetToLayout(m_pUseAvatarCheck,0,0,0,0);
 	m_pUseAvatarCheck->setChecked(bHaveAvatar);
+#ifdef COMPILE_INFO_TIPS
+	mergeTip(m_pUseAvatarCheck,szTip);
+#endif
 
 	m_pAvatarPreview = new KviPixmapPreview(this);
 	addWidgetToLayout(m_pAvatarPreview,0,1,0,1);
 	m_pAvatarPreview->setPixmap(m_pLocalAvatar);
 	m_pAvatarPreview->setEnabled(bHaveAvatar);
 	connect(m_pUseAvatarCheck,SIGNAL(toggled(bool)),m_pAvatarPreview,SLOT(setEnabled(bool)));
+#ifdef COMPILE_INFO_TIPS
+	mergeTip(m_pAvatarPreview,szTip);
+#endif
 
-	QHBox * hb = new QHBox(this);
+	KviTalHBox * hb = new KviTalHBox(this);
 	hb->setSpacing(4);
 	addWidgetToLayout(hb,0,2,0,2);
 
@@ -573,7 +591,7 @@ void KviIdentityAvatarOptionsWidget::chooseAvatar()
 			{
 				// downloaded!
 				// try to load it
-				if(!m_pLocalAvatar->load(dlg.localFileName().utf8().data()))
+				if(!m_pLocalAvatar->load(dlg.localFileName()))
 				{
 					// unloadable
 					szCurrent = "";
@@ -598,7 +616,7 @@ void KviIdentityAvatarOptionsWidget::chooseAvatar()
 		}
 	} else {
 		// this is a local path
-		if(m_pLocalAvatar->load(szCurrent.utf8().data()))
+		if(m_pLocalAvatar->load(szCurrent))
 		{
 			// local path, loaded
 			QString tmp = szCurrent;
@@ -624,6 +642,19 @@ void KviIdentityAvatarOptionsWidget::chooseAvatar()
 		}
 	}
 
+	if(m_pLocalAvatar->pixmap())
+	{
+		if((m_pLocalAvatar->pixmap()->width() > 1024) || (m_pLocalAvatar->pixmap()->height() > 768))
+		{
+			QMessageBox::warning(this,__tr2qs_ctx("Avatar Might Be Too Big - KVIrc","options"),
+						__tr2qs_ctx("The avatar you have choosen is bigger than 1024x768 pixels.<br>" \
+							"Such a big image will not be seen on all the user monitors<br>" \
+							"and will probably be scaled by the remote clients with poor quality<br>" \
+							"algorithms to improve performance. You *should* scale it manually<br>" \
+							"to a sane size (like 800x600) or choose a different image.","options"));
+		}
+	}
+
 	m_pAvatarNameEdit->setText(szCurrent);
 	m_pAvatarPreview->setPixmap(m_pLocalAvatar);
 }
@@ -649,12 +680,12 @@ KviIdentityAdvancedOptionsWidget::KviIdentityAdvancedOptionsWidget(QWidget * par
 	createLayout(2,1);
 	layout()->setMargin(10);
 
-	QGroupBox * gbox = addGroupBox(0,0,0,0,1,QGroupBox::Horizontal,__tr2qs_ctx("User Mode","options"));
+	KviTalGroupBox * gbox = addGroupBox(0,0,0,0,1,Qt::Horizontal,__tr2qs_ctx("User Mode","options"));
 	m_pISelector = addBoolSelector(gbox,__tr2qs_ctx("Invisible (+i)","options"),&m_bI);
 	m_pSSelector = addBoolSelector(gbox,__tr2qs_ctx("Server notices (+s)","options"),&m_bS);
 	m_pWSelector = addBoolSelector(gbox,__tr2qs_ctx("Wallops (+w)","options"),&m_bW);
 
-   	gbox = addGroupBox(0,1,0,1,1,QGroupBox::Horizontal,__tr2qs_ctx("Default Messages","options"));
+   	gbox = addGroupBox(0,1,0,1,1,Qt::Horizontal,__tr2qs_ctx("Default Messages","options"));
 
 
 	KviStringSelector * sel = addStringSelector(gbox, __tr2qs_ctx("Part message:","options"),KviOption_stringPartMessage);
