@@ -41,18 +41,20 @@ KviInputLookOptionsWidget::KviInputLookOptionsWidget(QWidget * parent)
 	addColorSelector(0,5,1,5,__tr2qs_ctx("Control char color","options"),KviOption_colorInputControl);
 	addColorSelector(0,6,1,6,__tr2qs_ctx("Cursor color","options"),KviOption_colorInputCursor);
 
-	addLabel(0,7,0,7,__tr2qs_ctx("Horisontal align:","options"));
-	m_pHorisontalAlign=new QComboBox(this);
-	addWidgetToLayout(m_pHorisontalAlign,1,7,1,7);
+	addPixmapSelector(0,7,1,7,__tr2qs_ctx("Background image","options"),KviOption_pixmapInputBackground);
+
+	addLabel(0,8,0,8,__tr2qs_ctx("Horizontal align:","options"));
+	m_pHorizontalAlign=new QComboBox(this);
+	addWidgetToLayout(m_pHorizontalAlign,1,8,1,8);
 	
-	addLabel(0,8,0,8,__tr2qs_ctx("Vertical align:","options"));
+	addLabel(0,9,0,9,__tr2qs_ctx("Vertical align:","options"));
 	m_pVerticalAlign=new QComboBox(this);
-	addWidgetToLayout(m_pVerticalAlign,1,8,1,8);
+	addWidgetToLayout(m_pVerticalAlign,1,9,1,9);
 	
-	m_pHorisontalAlign->insertItem(__tr2qs_ctx("Tile","options"));
-	m_pHorisontalAlign->insertItem(__tr2qs_ctx("Left","options"));
-	m_pHorisontalAlign->insertItem(__tr2qs_ctx("Right","options"));
-	m_pHorisontalAlign->insertItem(__tr2qs_ctx("Center","options"));
+	m_pHorizontalAlign->insertItem(__tr2qs_ctx("Tile","options"));
+	m_pHorizontalAlign->insertItem(__tr2qs_ctx("Left","options"));
+	m_pHorizontalAlign->insertItem(__tr2qs_ctx("Right","options"));
+	m_pHorizontalAlign->insertItem(__tr2qs_ctx("Center","options"));
 	
 	m_pVerticalAlign->insertItem(__tr2qs_ctx("Tile","options"));
 	m_pVerticalAlign->insertItem(__tr2qs_ctx("Top","options"));
@@ -62,16 +64,16 @@ KviInputLookOptionsWidget::KviInputLookOptionsWidget(QWidget * parent)
 	switch( KVI_OPTION_UINT(KviOption_uintInputPixmapAlign) & Qt::AlignHorizontal_Mask)
 	{
 		case Qt::AlignLeft:
-			m_pHorisontalAlign->setCurrentItem(1);
+			m_pHorizontalAlign->setCurrentItem(1);
 			break;
 		case Qt::AlignRight:
-			m_pHorisontalAlign->setCurrentItem(2);
+			m_pHorizontalAlign->setCurrentItem(2);
 			break;
 		case Qt::AlignHCenter:
-			m_pHorisontalAlign->setCurrentItem(3);
+			m_pHorizontalAlign->setCurrentItem(3);
 			break;
 		default:
-			m_pHorisontalAlign->setCurrentItem(0);
+			m_pHorizontalAlign->setCurrentItem(0);
 	}
 	
 	switch( KVI_OPTION_UINT(KviOption_uintInputPixmapAlign) & Qt::AlignVertical_Mask)
@@ -89,9 +91,8 @@ KviInputLookOptionsWidget::KviInputLookOptionsWidget(QWidget * parent)
 			m_pVerticalAlign->setCurrentItem(0);
 	}
 
-	addPixmapSelector(0,9,1,9,__tr2qs_ctx("Background image","options"),KviOption_pixmapInputBackground);
 
-	layout()->setRowStretch(9,1);
+	layout()->setRowStretch(7,1);
 }
 
 KviInputLookOptionsWidget::~KviInputLookOptionsWidget()
@@ -101,7 +102,7 @@ KviInputLookOptionsWidget::~KviInputLookOptionsWidget()
 void KviInputLookOptionsWidget::commit()
 {
 	int iFlags=0;
-	switch(m_pHorisontalAlign->currentItem())
+	switch(m_pHorizontalAlign->currentItem())
 	{
 		case 1:
 			iFlags|=Qt::AlignLeft;
@@ -140,7 +141,7 @@ KviInputFeaturesOptionsWidget::KviInputFeaturesOptionsWidget(QWidget * parent)
 	addBoolSelector(0,0,0,0,__tr2qs_ctx("Warp cursor at the end of line when browsing history","options"),KviOption_boolInputHistoryCursorAtEnd);
 	addBoolSelector(0,1,0,1,__tr2qs_ctx("Disable the input history window and it's log memory.","options"),KviOption_boolDisableInputHistory); //G&N 2005
 	addBoolSelector(0,2,0,2,__tr2qs_ctx("Hide input toolbuttons by default","options"),KviOption_boolHideInputToolButtons);
-	QGroupBox * g = addGroupBox(0,3,0,3,1,QGroupBox::Horizontal,__tr2qs_ctx("Nick completion","options"));
+	KviTalGroupBox * g = addGroupBox(0,3,0,3,1,Qt::Horizontal,__tr2qs_ctx("Nick completion","options"));
 	addBoolSelector(g,__tr2qs_ctx("Use bash-like nick completion","options"),KviOption_boolBashLikeNickCompletion);
 	addStringSelector(g,__tr2qs_ctx("Nick completion postfix string","options"),KviOption_stringNickCompletionPostfix);
 	addBoolSelector(g,__tr2qs_ctx("Use the completion postfix string for the first word only","options"),KviOption_boolUseNickCompletionPostfixForFirstWordOnly);
