@@ -1,12 +1,13 @@
 #ifndef _OPTW_INPUT_H_
 #define _OPTW_INPUT_H_
 
+//==================================================================================
 //
 //   File : optw_input.h
 //   Creation date : Sat Aug 11 2001 04:25:01 CEST by Szymon Stefanek
 //
 //   This file is part of the KVirc irc client distribution
-//   Copyright (C) 2001 Szymon Stefanek (pragma at kvirc dot net)
+//   Copyright (C) 2001-2006 Szymon Stefanek (pragma at kvirc dot net)
 //
 //   This program is FREE software. You can redistribute it and/or
 //   modify it under the terms of the GNU General Public License
@@ -22,6 +23,7 @@
 //   along with this program. If not, write to the Free Software Foundation,
 //   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 //
+//==================================================================================
 
 #include "kvi_optionswidget.h"
 #include <qcombobox.h>
@@ -35,7 +37,7 @@ class KviInputLookOptionsWidget : public KviOptionsWidget
 {
 	Q_OBJECT
 private:
-	QComboBox* m_pHorisontalAlign;
+	QComboBox* m_pHorizontalAlign;
 	QComboBox* m_pVerticalAlign;
 public:
 	KviInputLookOptionsWidget(QWidget * parent);
