@@ -36,32 +36,31 @@
 KviInterfaceFeaturesOptionsWidget::KviInterfaceFeaturesOptionsWidget(QWidget * parent)
 : KviOptionsWidget(parent,"interfacefeatures_options_widget")
 {
-	createLayout(10,1);
+	createLayout(8,1);
 
 
-	addBoolSelector(0,0,0,0,__tr2qs_ctx("Close in tray","options"),KviOption_boolCloseInTray);
-	addBoolSelector(0,1,0,1,__tr2qs_ctx("Minimize in tray","options"),KviOption_boolMinimizeInTray);
-	addBoolSelector(0,1,0,1,__tr2qs_ctx("Minimize on startup","options"),KviOption_boolStartupMinimized);
-	addBoolSelector(0,3,0,3,__tr2qs_ctx("Confirm quit with active connections","options"),KviOption_boolConfirmCloseWhenThereAreConnections);
-	addBoolSelector(0,4,0,4,__tr2qs_ctx("Remember window properties","options"),KviOption_boolWindowsRememberProperties);
+
+	addBoolSelector(0,0,0,0,__tr2qs_ctx("Minimize on startup","options"),KviOption_boolStartupMinimized);
+	addBoolSelector(0,1,0,1,__tr2qs_ctx("Confirm quit with active connections","options"),KviOption_boolConfirmCloseWhenThereAreConnections);
+	addBoolSelector(0,2,0,2,__tr2qs_ctx("Remember window properties","options"),KviOption_boolWindowsRememberProperties);
 
 	QString szSplashDisableFile;
 	g_pApp->getLocalKvircDirectory(szSplashDisableFile,KviApp::Pics,"disable-splash." KVI_VERSION);
 	bool bDisableSplash = KviFileUtils::fileExists(szSplashDisableFile);
 	m_pDisableSplash = new KviStyledCheckBox(__tr2qs_ctx("Disable splash screen","options"),this);
-	addWidgetToLayout(m_pDisableSplash,0,5,0,5);
+	addWidgetToLayout(m_pDisableSplash,0,3,0,3);
 	m_pDisableSplash->setChecked(bDisableSplash);
 	
-	addBoolSelector(0,6,0,6,__tr2qs_ctx("Enable visual effects","options"),KviOption_boolEnableVisualEffects);
-	addBoolSelector(0,7,0,7,__tr2qs_ctx("Hide Channel window tool buttons by default","options"),KviOption_boolHideWindowToolButtons);
+	addBoolSelector(0,4,0,4,__tr2qs_ctx("Enable visual effects","options"),KviOption_boolEnableVisualEffects);
+	addBoolSelector(0,5,0,5,__tr2qs_ctx("Hide Channel window tool buttons by default","options"),KviOption_boolHideWindowToolButtons);
 	
-	QGroupBox * g = addGroupBox(0,8,0,8,1,QGroupBox::Horizontal,__tr2qs_ctx("Open Dialog Window For","options"));
+	KviTalGroupBox * g = addGroupBox(0,6,0,6,1,Qt::Horizontal,__tr2qs_ctx("Open Dialog Window For","options"));
 	addBoolSelector(g,__tr2qs_ctx("Preferences","options"),KviOption_boolShowGeneralOptionsDialogAsToplevel);
 	addBoolSelector(g,__tr2qs_ctx("Registered Users","options"),KviOption_boolShowRegisteredUsersDialogAsToplevel);
 	addBoolSelector(g,__tr2qs_ctx("Identity","options"),KviOption_boolShowIdentityDialogAsToplevel);
 	addBoolSelector(g,__tr2qs_ctx("Servers","options"),KviOption_boolShowServersConnectDialogAsToplevel);
 	addBoolSelector(g,__tr2qs_ctx("Join Channels","options"),KviOption_boolShowChannelsJoinDialogAsToplevel);
-	addRowSpacer(0,9,0,9);
+	addRowSpacer(0,7,0,7);
 }
 
 KviInterfaceFeaturesOptionsWidget::~KviInterfaceFeaturesOptionsWidget()
