@@ -172,12 +172,12 @@ KviThemeMdiCaptionsOptionsWidget::~KviThemeMdiCaptionsOptionsWidget()
 KviThemeMdiAreaOptionsWidget::KviThemeMdiAreaOptionsWidget(QWidget * parent)
 : KviOptionsWidget(parent)
 {
-	createLayout(3,1);
+	createLayout(2,1);
 
 	addColorSelector(0,0,0,0,__tr2qs_ctx("Background","options"),KviOption_colorMdiBackground);
 	addPixmapSelector(0,1,0,1,__tr2qs_ctx("Background Image","options"),KviOption_pixmapMdiBackground);
 
-	addRowSpacer(0,2,0,2);
+	layout()->setRowStretch(1,1);
 }
 
 KviThemeMdiAreaOptionsWidget::~KviThemeMdiAreaOptionsWidget()
@@ -190,7 +190,7 @@ KviThemeMdiAreaOptionsWidget::~KviThemeMdiAreaOptionsWidget()
 KviThemeToolBarAppletsOptionsWidget::KviThemeToolBarAppletsOptionsWidget(QWidget * parent)
 : KviOptionsWidget(parent)
 {
-	createLayout(10,1);
+	createLayout(9,1);
 	
 	addFontSelector(0,0,0,0,__tr2qs_ctx("Font","options"),KviOption_fontIrcToolBarApplet);
 	
@@ -204,7 +204,7 @@ KviThemeToolBarAppletsOptionsWidget::KviThemeToolBarAppletsOptionsWidget(QWidget
 
 	addPixmapSelector(0,8,0,8,__tr2qs_ctx("Background Image","options"),KviOption_pixmapIrcToolBarAppletBackground);
 
-	addRowSpacer(0,9,0,9);
+	layout()->setRowStretch(8,1);
 }
 
 KviThemeToolBarAppletsOptionsWidget::~KviThemeToolBarAppletsOptionsWidget()
