@@ -34,24 +34,97 @@
 KviIrcOptionsWidget::KviIrcOptionsWidget(QWidget * parent)
 : KviOptionsWidget(parent,"irc_options_widget")
 {
-	createLayout(4,6);
-	KviBoolSelector *b = addBoolSelector(0,0,4,0,__tr2qs_ctx("Minimize console after successful login","options"),KviOption_boolMinimizeConsoleAfterConnect,KVI_OPTION_BOOL(KviOption_boolMinimizeConsoleAfterConnect));
-	b->setEnabled(true);
+}
+
+
+KviIrcOptionsWidget::~KviIrcOptionsWidget()
+{
+}
+
+
+KviIrcGeneralOptionsWidget::KviIrcGeneralOptionsWidget(QWidget * parent)
+: KviOptionsWidget(parent,"irc_options_widget")
+{
+	createLayout(3,1);
+	KviBoolSelector *b = addBoolSelector(0,0,0,0,__tr2qs_ctx("Minimize console after successful login","options"),KviOption_boolMinimizeConsoleAfterConnect);
 
 #ifdef COMPILE_INFO_TIPS
 	mergeTip(b,__tr2qs_ctx("<center>This option will cause KVIrc to minimize the console window after successfully logging into a server.</center>","options"));
 #endif
-	QGroupBox *g = addGroupBox(0,1,4,1,1,QGroupBox::Horizontal,__tr2qs_ctx("On Channel Kick","options"));
 
-	b = addBoolSelector(g,__tr2qs_ctx("Keep channel open","options"),KviOption_boolKeepChannelOpenOnKick);
- 	b = addBoolSelector(g,__tr2qs_ctx("Rejoin channel","options"),KviOption_boolRejoinChannelOnKick);
+	b = addBoolSelector(0,1,0,1,__tr2qs_ctx("Show network name in console taskbar entry","options"),KviOption_boolShowNetworkNameForConsoleTaskBarEntry);
+#ifdef COMPILE_INFO_TIPS
+	mergeTip(b,__tr2qs_ctx("<center>This option will cause KVIrc to show the network name as the console taskbar entry instead of the server name. This is nice to keep on unless your servers are not organized in networks or you often connect to two servers of the same network.</center>","options"));
+#endif
+
+
+	addRowSpacer(0,2,0,2);
+}
+
+
+KviIrcGeneralOptionsWidget::~KviIrcGeneralOptionsWidget()
+{
+}
+
+
+
+KviIrcAdvancedOptionsWidget::KviIrcAdvancedOptionsWidget(QWidget * parent)
+: KviOptionsWidget(parent,"irc_advanced_options_widget")
+{
+	createLayout(3,1);
+	KviBoolSelector *b = addBoolSelector(0,0,0,0,__tr2qs_ctx("Force immediate quit","options"),KviOption_boolForceBrutalQuit);    
+#ifdef COMPILE_INFO_TIPS
+	mergeTip(b,
+		__tr2qs_ctx("<center>This option causes KVIrc to close " \
+		"the connection immediately after sending the QUIT message.<br>" \
+		"When this option is disabled, KVIrc will wait for the server " \
+		"to close the connection.<br>" \
+		"Note that if you use this, your QUIT message may be not displayed.</center>","options"));
+#endif
+	addBoolSelector(0,1,0,1,__tr2qs_ctx("Prepend gender info to realname","options"),KviOption_boolPrependGenderInfoToRealname);    
+}
+
+KviIrcAdvancedOptionsWidget::~KviIrcAdvancedOptionsWidget()
+{
+}
+
+
+
+
+
+KviChannelOptionsWidget::KviChannelOptionsWidget(QWidget * pParent)
+: KviOptionsWidget(pParent)
+{
+}
+
+KviChannelOptionsWidget::~KviChannelOptionsWidget()
+{
+}
+
+
+KviChannelGeneralOptionsWidget::KviChannelGeneralOptionsWidget(QWidget * pParent)
+: KviOptionsWidget(pParent)
+{
+	createLayout(5,1);
+
+	KviTalGroupBox * g = addGroupBox(0,0,0,0,1,Qt::Horizontal,__tr2qs_ctx("On Channel Kick","options"));
+
+ 	KviBoolSelector *b = addBoolSelector(g,__tr2qs_ctx("Rejoin channel","options"),KviOption_boolRejoinChannelOnKick);
 #ifdef COMPILE_INFO_TIPS
 	mergeTip(b,
 		__tr2qs_ctx("<center>This option will cause KVIrc to attempt " \
 		"to rejoin a channel after being kicked.</center>","options"));
 #endif
+	b = addBoolSelector(g,__tr2qs_ctx("Keep channel open","options"),KviOption_boolKeepChannelOpenOnKick);
+#ifdef COMPILE_INFO_TIPS
+	mergeTip(b,
+		__tr2qs_ctx("<center>This option will cause KVIrc to keep " \
+			"the channel window open after being kicked.<br>" \
+			"It might be a good idea to also enable the " \
+			"\"Rejoin channel\" option.</center>","options"));
+#endif 
 
-	g = addGroupBox(0,2,4,2,1,QGroupBox::Horizontal,__tr2qs_ctx("On Channel Part","options"));
+	g = addGroupBox(0,1,0,1,1,Qt::Horizontal,__tr2qs_ctx("On Channel Part","options"));
 
 	b = addBoolSelector(g,__tr2qs_ctx("Keep channel open","options"),KviOption_boolKeepChannelOpenOnPart);
 #ifdef COMPILE_INFO_TIPS
@@ -60,19 +133,44 @@ KviIrcOptionsWidget::KviIrcOptionsWidget(QWidget * parent)
 			"the channel window open after leaving it.</center>","options"));
 #endif 
 
-	b = addBoolSelector(0,3,4,3,__tr2qs_ctx("Automatically join channel on invite","options"),KviOption_boolAutoJoinOnInvite);
+	b = addBoolSelector(0,2,0,2,__tr2qs_ctx("Automatically join channel on invite","options"),KviOption_boolAutoJoinOnInvite);
 #ifdef COMPILE_INFO_TIPS
 	mergeTip(b,
 		__tr2qs_ctx("<center>This option will cause KVIrc to automatically " \
 			"join a channel when an INVITE message for that channel is received.<br>" \
 			"<b>Warning:</b> This may help spammers harass you. :)</center>","options"));
 #endif
-	addBoolSelector(0,4,4,4,__tr2qs_ctx("Log joined channels history","options"),KviOption_boolLogChannelHistory);
+
+	b = addBoolSelector(0,3,0,3, __tr2qs_ctx("Always open channels as minimized","options"),KviOption_boolCreateMinimizedChannels);
+    
+#ifdef COMPILE_INFO_TIPS
+	mergeTip(b,
+		__tr2qs_ctx("<center>This option causes newly created " \
+			"channel windows to be immediately minimized.<br>" \
+			"Enable this if you don't like channels " \
+			"popping up while you're typing something in a channel. :D</center>","options"));
+#endif
+
+
+	addRowSpacer(0,4,0,4);
+}
+
+KviChannelGeneralOptionsWidget::~KviChannelGeneralOptionsWidget()
+{
+}
+
+
+KviChannelAdvancedOptionsWidget::KviChannelAdvancedOptionsWidget(QWidget * pParent)
+: KviOptionsWidget(pParent)
+{
+	createLayout(6,4);
+
+	KviBoolSelector * b = addBoolSelector(0,0,4,0,__tr2qs_ctx("Log joined channels history","options"),KviOption_boolLogChannelHistory);
 	
-	addLabel(0,5,0,5,__tr2qs_ctx("Default ban mask:","options"));
+	addLabel(0,1,0,1,__tr2qs_ctx("Default ban mask:","options"));
 	
 	m_pBanTypeCombo=new QComboBox(this);
-	addWidgetToLayout(m_pBanTypeCombo,1,5,4,5);
+	addWidgetToLayout(m_pBanTypeCombo,1,1,4,1);
 	
 	KviIrcMask hostmask("nick!user@machine.host.top");
 	KviIrcMask ipmask("nick!user@192.168.1.2");
@@ -86,48 +184,14 @@ KviIrcOptionsWidget::KviIrcOptionsWidget(QWidget * parent)
 		m_pBanTypeCombo->insertItem(QString("%1 (%2)").arg(tmp1).arg(tmp2));
 	}
 	m_pBanTypeCombo->setCurrentItem(KVI_OPTION_UINT(KviOption_uintDefaultBanType));
-	addRowSpacer(0,6,4,6);
-}
 
-
-KviIrcOptionsWidget::~KviIrcOptionsWidget()
-{
-}
-
-void KviIrcOptionsWidget::commit()
-{
-	KVI_OPTION_UINT(KviOption_uintDefaultBanType)=m_pBanTypeCombo->currentItem();
-	if((KVI_OPTION_UINT(KviOption_uintDefaultBanType)<0 )|| (KVI_OPTION_UINT(KviOption_uintDefaultBanType)>26)) KVI_OPTION_UINT(KviOption_uintDefaultBanType)=7;
-	KviOptionsWidget::commit();
-}
-
-KviIrcAdvancedOptionsWidget::KviIrcAdvancedOptionsWidget(QWidget * parent)
-: KviOptionsWidget(parent,"irc_advanced_options_widget")
-{
-	createLayout(2,1);
-	KviBoolSelector *b = addBoolSelector(0,0,0,0,__tr2qs_ctx("Force immediate quit","options"),KviOption_boolForceBrutalQuit);    
-#ifdef COMPILE_INFO_TIPS
-	mergeTip(b,
-		__tr2qs_ctx("<center>This option causes KVIrc to close " \
-		"the connection immediately after sending the QUIT message.<br>" \
-		"When this option is disabled, KVIrc will wait for the server " \
-		"to close the connection.<br>" \
-		"Note that if you use this, your QUIT message may be not displayed.</center>","options"));
-#endif
-#ifdef COMPILE_INFO_TIPS
-	mergeTip(b,
-		__tr2qs_ctx("<center>This option will cause KVIrc to keep " \
-			"the channel window open after being kicked.<br>" \
-			"It might be a good idea to also enable the " \
-			"\"Rejoin channel\" option.</center>","options"));
-#endif 
-
-	QGroupBox * g = addGroupBox(0,1,0,1,1,QGroupBox::Horizontal,__tr2qs_ctx("On Channel Join","options"));
+	KviTalGroupBox * g = addGroupBox(0,2,4,2,1,Qt::Horizontal,__tr2qs_ctx("On Channel Join","options"));
 	addBoolSelector(g,__tr2qs_ctx("Do not send /WHO request","options"),KviOption_boolDisableWhoRequestOnJoin);
   	addBoolSelector(g,__tr2qs_ctx("Do not request ban list","options"),KviOption_boolDisableBanListRequestOnJoin);
   	addBoolSelector(g,__tr2qs_ctx("Do not request ban exception list","options"),KviOption_boolDisableBanExceptionListRequestOnJoin);
  	addBoolSelector(g,__tr2qs_ctx("Do not request invite list","options"),KviOption_boolDisableInviteListRequestOnJoin);
- 	b = addBoolSelector(g,__tr2qs_ctx("Do not update the away list","options"),KviOption_boolDisableAwayListUpdates);
+
+ 	b = addBoolSelector(0,3,4,3,__tr2qs_ctx("Do not update the away list","options"),KviOption_boolDisableAwayListUpdates);
 #ifdef COMPILE_INFO_TIPS
 	mergeTip(b,
 		__tr2qs_ctx("<center>KVIrc sends out a channel /WHO message every now and then to keep " \
@@ -135,10 +199,22 @@ KviIrcAdvancedOptionsWidget::KviIrcAdvancedOptionsWidget(QWidget * parent)
 			"your IRC bandwidth.</center>","options"));
 #endif
 
+	g = addGroupBox(0,4,4,4,1,Qt::Horizontal,__tr2qs_ctx("On Channel Join","options"));
+	addBoolSelector(g,__tr2qs_ctx("Echo channel topic","options"),KviOption_boolEchoNumericTopic);
+	addBoolSelector(g,__tr2qs_ctx("Show channel sync time","options"),KviOption_boolShowChannelSyncTime);
+
+	addRowSpacer(0,5,4,5);
 }
 
-KviIrcAdvancedOptionsWidget::~KviIrcAdvancedOptionsWidget()
+KviChannelAdvancedOptionsWidget::~KviChannelAdvancedOptionsWidget()
 {
 }
 
+void KviChannelAdvancedOptionsWidget::commit()
+{
+	KVI_OPTION_UINT(KviOption_uintDefaultBanType)=m_pBanTypeCombo->currentItem();
+	if((KVI_OPTION_UINT(KviOption_uintDefaultBanType)<0 )|| (KVI_OPTION_UINT(KviOption_uintDefaultBanType)>26)) KVI_OPTION_UINT(KviOption_uintDefaultBanType)=7;
+	KviOptionsWidget::commit();
+}
+
 #include "m_optw_irc.moc"
