@@ -32,13 +32,13 @@
 #include <qlabel.h>
 
 #ifdef COMPILE_INFO_TIPS
-	#include <qtooltip.h>
+	#include "kvi_tal_tooltip.h"
 #endif
 
 KviIrcOutputOptionsWidget::KviIrcOutputOptionsWidget(QWidget * parent)
 : KviOptionsWidget(parent,"ircoutput_options_widget")
 {
-	createLayout(8,2);
+	createLayout(7,2);
 
 	QLabel * l =new QLabel(__tr2qs_ctx("Output verbosity","options"),this);
 	addWidgetToLayout(l,0,0,0,0);
@@ -56,7 +56,7 @@ KviIrcOutputOptionsWidget::KviIrcOutputOptionsWidget(QWidget * parent)
 		KVI_OPTION_UINT(KviOption_uintOutputVerbosityLevel) = KVI_VERBOSITY_LEVEL_NORMAL;
 	m_pVerbosityCombo->setCurrentItem(KVI_OPTION_UINT(KviOption_uintOutputVerbosityLevel));
 
-	QGroupBox * g = addGroupBox(0,1,1,1,1,QGroupBox::Horizontal,__tr2qs_ctx("Show in active window","options"));
+	KviTalGroupBox * g = addGroupBox(0,1,1,1,1,Qt::Horizontal,__tr2qs_ctx("Show in active window","options"));
 	addBoolSelector(g,__tr2qs_ctx("External messages","options"),KviOption_boolExternalMessagesToActiveWindow);
 	addBoolSelector(g,__tr2qs_ctx("External CTCP replies","options"),KviOption_boolCtcpRepliesToActiveWindow);
 	addBoolSelector(g,__tr2qs_ctx("Whois replies","options"),KviOption_boolWhoisRepliesToActiveWindow);
@@ -71,10 +71,8 @@ KviIrcOutputOptionsWidget::KviIrcOutputOptionsWidget(QWidget * parent)
 		addBoolSelector(0,3,1,3,__tr2qs_ctx("Show server pings","options"),KviOption_boolShowPingPong);
 		addBoolSelector(0,4,1,4,__tr2qs_ctx("Show own parts in the console","options"),KviOption_boolShowOwnParts);
 		addBoolSelector(0,5,1,5,__tr2qs_ctx("Show compact mode changes","options"),KviOption_boolShowCompactModeChanges);
-		g = addGroupBox(0,6,1,6,1,QGroupBox::Horizontal,__tr2qs_ctx("On Channel Join","options"));
-		addBoolSelector(g,__tr2qs_ctx("Echo channel topic","options"),KviOption_boolEchoNumericTopic);
-		addBoolSelector(g,__tr2qs_ctx("Show channel sync time","options"),KviOption_boolShowChannelSyncTime);
-		addRowSpacer(0,7,1,7);
+
+		addRowSpacer(0,6,1,6);
 //	} else {
 //		addRowSpacer(0,2,1,2);
 //	}
