@@ -24,15 +24,15 @@
 //
 
 #include "kvi_optionswidget.h"
-#include <qlistview.h>
+#include "kvi_tal_listview.h"
 
 class QComboBox;
 
 #define KVI_OPTIONS_WIDGET_ICON_KviIrcOutputOptionsWidget KVI_SMALLICON_RAW
-#define KVI_OPTIONS_WIDGET_NAME_KviIrcOutputOptionsWidget __tr2qs_no_lookup("Verbosity&Output")
+#define KVI_OPTIONS_WIDGET_NAME_KviIrcOutputOptionsWidget __tr2qs_no_lookup("Verbosity And Output")
 #define KVI_OPTIONS_WIDGET_PARENT_KviIrcOutputOptionsWidget KviIrcOptionsWidget
 #define KVI_OPTIONS_WIDGET_KEYWORDS_KviIrcOutputOptionsWidget __tr2qs_no_lookup("debug")
-#define KVI_OPTIONS_WIDGET_PRIORITY_KviIrcOutputOptionsWidget 90000
+#define KVI_OPTIONS_WIDGET_PRIORITY_KviIrcOutputOptionsWidget 75000
 
 class KviIrcOutputOptionsWidget : public KviOptionsWidget
 {
