@@ -27,6 +27,17 @@
 
 //#warning "Info tips"
 
+KviIrcViewThemeOptionsWidget::KviIrcViewThemeOptionsWidget(QWidget * pParent)
+: KviOptionsWidget(pParent)
+{
+}
+
+KviIrcViewThemeOptionsWidget::~KviIrcViewThemeOptionsWidget()
+{
+}
+
+////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+
 KviIrcViewLookOptionsWidget::KviIrcViewLookOptionsWidget(QWidget * parent)
 : KviOptionsWidget(parent,"ircviewlook_options_widget")
 {
@@ -35,21 +46,22 @@ KviIrcViewLookOptionsWidget::KviIrcViewLookOptionsWidget(QWidget * parent)
 	addFontSelector(0,0,1,0,__tr2qs_ctx("Font:","options"),KviOption_fontIrcView);
 	addColorSelector(0,1,1,1,__tr2qs_ctx("Background color:","options"),KviOption_colorIrcViewBackground);
 	
-	addLabel(0,2,0,2,__tr2qs_ctx("Horisontal align:","options"));
-	m_pHorisontalAlign=new QComboBox(this);
-	addWidgetToLayout(m_pHorisontalAlign,1,2,1,2);
+	addPixmapSelector(0,2,1,2,__tr2qs_ctx("Background image:","options"),KviOption_pixmapIrcViewBackground);
+
+	addLabel(0,3,0,3,__tr2qs_ctx("Horizontal align:","options"));
+	m_pHorizontalAlign=new QComboBox(this);
+	addWidgetToLayout(m_pHorizontalAlign,1,3,1,3);
 	
-	addLabel(0,3,0,3,__tr2qs_ctx("Vertical align:","options"));
+	addLabel(0,4,0,4,__tr2qs_ctx("Vertical align:","options"));
 	m_pVerticalAlign=new QComboBox(this);
-	addWidgetToLayout(m_pVerticalAlign,1,3,1,3);
+	addWidgetToLayout(m_pVerticalAlign,1,4,1,4);
 		
-	addPixmapSelector(0,4,1,4,__tr2qs_ctx("Background image:","options"),KviOption_pixmapIrcViewBackground);
 	addColorSelector(0,5,1,5,__tr2qs_ctx("Mark Line:","options"),KviOption_colorIrcViewMarkLine);
 	
-	m_pHorisontalAlign->insertItem(__tr2qs_ctx("Tile","options"));
-	m_pHorisontalAlign->insertItem(__tr2qs_ctx("Left","options"));
-	m_pHorisontalAlign->insertItem(__tr2qs_ctx("Right","options"));
-	m_pHorisontalAlign->insertItem(__tr2qs_ctx("Center","options"));
+	m_pHorizontalAlign->insertItem(__tr2qs_ctx("Tile","options"));
+	m_pHorizontalAlign->insertItem(__tr2qs_ctx("Left","options"));
+	m_pHorizontalAlign->insertItem(__tr2qs_ctx("Right","options"));
+	m_pHorizontalAlign->insertItem(__tr2qs_ctx("Center","options"));
 	
 	m_pVerticalAlign->insertItem(__tr2qs_ctx("Tile","options"));
 	m_pVerticalAlign->insertItem(__tr2qs_ctx("Top","options"));
@@ -59,16 +71,16 @@ KviIrcViewLookOptionsWidget::KviIrcViewLookOptionsWidget(QWidget * parent)
 	switch( KVI_OPTION_UINT(KviOption_uintIrcViewPixmapAlign) & Qt::AlignHorizontal_Mask)
 	{
 		case Qt::AlignLeft:
-			m_pHorisontalAlign->setCurrentItem(1);
+			m_pHorizontalAlign->setCurrentItem(1);
 			break;
 		case Qt::AlignRight:
-			m_pHorisontalAlign->setCurrentItem(2);
+			m_pHorizontalAlign->setCurrentItem(2);
 			break;
 		case Qt::AlignHCenter:
-			m_pHorisontalAlign->setCurrentItem(3);
+			m_pHorizontalAlign->setCurrentItem(3);
 			break;
 		default:
-			m_pHorisontalAlign->setCurrentItem(0);
+			m_pHorizontalAlign->setCurrentItem(0);
 	}
 	
 	switch( KVI_OPTION_UINT(KviOption_uintIrcViewPixmapAlign) & Qt::AlignVertical_Mask)
@@ -96,7 +108,7 @@ KviIrcViewLookOptionsWidget::~KviIrcViewLookOptionsWidget()
 void KviIrcViewLookOptionsWidget::commit()
 {
 	int iFlags=0;
-	switch(m_pHorisontalAlign->currentItem())
+	switch(m_pHorizontalAlign->currentItem())
 	{
 		case 1:
 			iFlags|=Qt::AlignLeft;
@@ -125,27 +137,13 @@ void KviIrcViewLookOptionsWidget::commit()
 	KviOptionsWidget::commit();
 }
 
+////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+
 KviIrcViewFeaturesOptionsWidget::KviIrcViewFeaturesOptionsWidget(QWidget * parent)
 : KviOptionsWidget(parent,"ircviewfeatures_options_widget")
 {
 	createLayout(14,1);
 
-	addBoolSelector(0,0,0,0,__tr2qs_ctx("Show message icons","options"),KviOption_boolIrcViewShowImages);
-	addBoolSelector(0,1,0,1,__tr2qs_ctx("Draw some emoticons (smileys) as pictures","options"),KviOption_boolDrawEmoticons);
-	m_pUseTimestampSelector = addBoolSelector(0,2,0,2,__tr2qs_ctx("Show timestamp","options"),KviOption_boolIrcViewTimestamp);
-	
-	connect(m_pUseTimestampSelector,SIGNAL(toggled(bool)),this,SLOT(enableDisableTimestampSelector(bool)));
-	KviBoolSelector * b = addBoolSelector(0,3,0,3,__tr2qs_ctx("Use UTC time for timestamp","options"),KviOption_boolIrcViewTimestampUTC,KVI_OPTION_BOOL(KviOption_boolIrcViewTimestamp));
-	
-	connect(m_pUseTimestampSelector,SIGNAL(toggled(bool)),b,SLOT(setEnabled(bool)));
-	m_pSpecialTimestampColorSelector = addBoolSelector(0,4,0,4,__tr2qs_ctx("Use special color for timestamps","options"),KviOption_boolUseSpecialColorForTimestamp,KVI_OPTION_BOOL(KviOption_boolIrcViewTimestamp));
-	connect(m_pSpecialTimestampColorSelector,SIGNAL(toggled(bool)),this,SLOT(enableDisableTimestampSelector(bool)));
-	connect(m_pUseTimestampSelector,SIGNAL(toggled(bool)),m_pSpecialTimestampColorSelector,SLOT(setEnabled(bool)));
-	
-	m_pTimestampColorSelector = addMircTextColorSelector(0,5,0,5,__tr2qs_ctx("Timestamp color","options"),KviOption_uintTimeStampForeground,KviOption_uintTimeStampBackground,KVI_OPTION_BOOL(KviOption_boolIrcViewTimestamp) && KVI_OPTION_BOOL(KviOption_boolUseSpecialColorForTimestamp));
-
-	KviStringSelector * st=addStringSelector(0,6,0,6,__tr2qs_ctx("Timestamp format:","options"),KviOption_stringIrcViewTimestampFormat);
-	connect(m_pUseTimestampSelector,SIGNAL(toggled(bool)),st,SLOT(setEnabled(bool)));
 	
 
 	addBoolSelector(0,7,0,7,__tr2qs_ctx("Enable URL highlighting","options"),KviOption_boolIrcViewUrlHighlighting);
@@ -159,16 +157,12 @@ KviIrcViewFeaturesOptionsWidget::KviIrcViewFeaturesOptionsWidget(QWidget * paren
 	addBoolSelector(0,12,0,12,__tr2qs_ctx("Track last read text line","options"),KviOption_boolTrackLastReadTextViewLine);
 	addRowSpacer(0,13,0,13);
 
-	connect(m_pUseTimestampSelector,SIGNAL(toggled(bool)),m_pSpecialTimestampColorSelector,SLOT(setEnabled(bool)));
 }
 
 KviIrcViewFeaturesOptionsWidget::~KviIrcViewFeaturesOptionsWidget()
 {
 }
 
-void KviIrcViewFeaturesOptionsWidget::enableDisableTimestampSelector(bool)
-{
-	m_pTimestampColorSelector->setEnabled(m_pUseTimestampSelector->isChecked() && m_pSpecialTimestampColorSelector->isChecked());
-}
+
 
 #include "m_optw_ircview.moc"
