@@ -28,7 +28,7 @@
 
 #include <qlayout.h>
 #include <qpushbutton.h>
-#include <qvbox.h>
+#include "kvi_tal_vbox.h"
 #include <qcursor.h>
 #include <qpainter.h>
 #include "kvi_styled_controls.h"
@@ -54,6 +54,113 @@
 #endif
 
 
+KviMessageOptionsWidget::KviMessageOptionsWidget(QWidget * pParent)
+: KviOptionsWidget(pParent)
+{
+}
+
+KviMessageOptionsWidget::~KviMessageOptionsWidget()
+{
+}
+
+////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+
+
+////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+
+KviPrivmsgOptionsWidget::KviPrivmsgOptionsWidget(QWidget * parent)
+: KviOptionsWidget(parent,"privmsg_options_widget")
+{
+	createLayout(4,1);
+
+	KviBoolSelector * b1;
+	KviBoolSelector * b2;
+
+	KviTalGroupBox * g = addGroupBox(0,0,0,0,1,Qt::Horizontal,__tr2qs_ctx("General","options"));
+	
+	addBoolSelector(g,__tr2qs_ctx("Show message icons","options"),KviOption_boolIrcViewShowImages);
+	addBoolSelector(g,__tr2qs_ctx("Draw some emoticons (smileys) as pictures","options"),KviOption_boolDrawEmoticons);
+	addBoolSelector(g,__tr2qs_ctx("Don't show colors in user messages","options"),KviOption_boolStripMircColorsInUserMessages);
+
+
+
+
+	g = addGroupBox(0,1,0,1,1,Qt::Horizontal,__tr2qs_ctx("Nicknames","options"));
+
+	b1 = addBoolSelector(g,__tr2qs_ctx("\"Smart\" nickname colors","options"),KviOption_boolColorNicks);
+	b2 = addBoolSelector(g,__tr2qs_ctx("Use same colors as in the userlist","options"),KviOption_boolUseUserListColorsAsNickColors,!KVI_OPTION_BOOL(KviOption_boolColorNicks));
+	connect(b1,SIGNAL(toggled(bool)),b2,SLOT(setNotEnabled(bool)));
+	addBoolSelector(g,__tr2qs_ctx("Show nicknames in bold","options"),KviOption_boolBoldedNicks);
+	addBoolSelector(g,__tr2qs_ctx("Show user and host","options"),KviOption_boolShowUserAndHostInPrivmsgView);
+	addBoolSelector(g,__tr2qs_ctx("Show channel mode prefix","options"),KviOption_boolShowChannelUserFlagInPrivmsgView);
+	KviBoolSelector * b = addBoolSelector(g,__tr2qs_ctx("User-defined prefix and postfix","options"),KviOption_boolUseExtendedPrivmsgView);
+
+	QLabel * l = addLabel(g,__tr2qs_ctx("[PREFIX]nickname[!user@host][POSTFIX] message","options"));
+
+	l->setEnabled(KVI_OPTION_BOOL(KviOption_boolUseExtendedPrivmsgView));
+	connect(b,
+		SIGNAL(toggled(bool)),
+		l,
+		SLOT(setEnabled(bool)));
+
+	KviTalVBox * vb = new KviTalVBox(g);
+	vb->setSpacing(5);
+
+	connect(
+		b,
+		SIGNAL(toggled(bool)),
+		addStringSelector(vb,__tr2qs_ctx("Prefix:","options"),KviOption_stringExtendedPrivmsgPrefix,KVI_OPTION_BOOL(KviOption_boolUseExtendedPrivmsgView)),
+		SLOT(setEnabled(bool)));
+	connect(
+		b,
+		SIGNAL(toggled(bool)),
+		addStringSelector(vb,__tr2qs_ctx("Postfix:","options"),KviOption_stringExtendedPrivmsgPostfix,KVI_OPTION_BOOL(KviOption_boolUseExtendedPrivmsgView)),
+		SLOT(setEnabled(bool)));
+	addRowSpacer(0,3,0,3);
+}
+
+KviPrivmsgOptionsWidget::~KviPrivmsgOptionsWidget()
+{
+
+}
+
+KviTimestampOptionsWidget::KviTimestampOptionsWidget(QWidget * pParent)
+: KviOptionsWidget(pParent)
+{
+	createLayout(5,1);
+	m_pUseTimestampSelector = addBoolSelector(0,0,0,0,__tr2qs_ctx("Show timestamp","options"),KviOption_boolIrcViewTimestamp);
+	
+	connect(m_pUseTimestampSelector,SIGNAL(toggled(bool)),this,SLOT(enableDisableTimestampSelector(bool)));
+	KviBoolSelector* b = addBoolSelector(0,1,0,1,__tr2qs_ctx("Use UTC time for timestamp","options"),KviOption_boolIrcViewTimestampUTC,KVI_OPTION_BOOL(KviOption_boolIrcViewTimestamp));
+	
+	connect(m_pUseTimestampSelector,SIGNAL(toggled(bool)),b,SLOT(setEnabled(bool)));
+	
+	KviTalHBox *hb = new KviTalHBox(this);
+	addWidgetToLayout(hb,0,2,0,2);
+	
+	m_pSpecialTimestampColorSelector = addBoolSelector(hb,__tr2qs_ctx("Use special color for timestamps","options"),KviOption_boolUseSpecialColorForTimestamp,KVI_OPTION_BOOL(KviOption_boolIrcViewTimestamp));
+	connect(m_pSpecialTimestampColorSelector,SIGNAL(toggled(bool)),this,SLOT(enableDisableTimestampSelector(bool)));
+	connect(m_pUseTimestampSelector,SIGNAL(toggled(bool)),m_pSpecialTimestampColorSelector,SLOT(setEnabled(bool)));
+	
+	m_pTimestampColorSelector = addMircTextColorSelector(hb,"",KviOption_uintTimeStampForeground,KviOption_uintTimeStampBackground,KVI_OPTION_BOOL(KviOption_boolIrcViewTimestamp) && KVI_OPTION_BOOL(KviOption_boolUseSpecialColorForTimestamp));
+
+	KviStringSelector * st=addStringSelector(0,3,0,3,__tr2qs_ctx("Timestamp format:","options"),KviOption_stringIrcViewTimestampFormat);
+	connect(m_pUseTimestampSelector,SIGNAL(toggled(bool)),st,SLOT(setEnabled(bool)));
+
+	connect(m_pUseTimestampSelector,SIGNAL(toggled(bool)),m_pSpecialTimestampColorSelector,SLOT(setEnabled(bool)));
+	addRowSpacer(0,4,0,4);
+}
+
+KviTimestampOptionsWidget::~KviTimestampOptionsWidget()
+{
+}
+
+void KviTimestampOptionsWidget::enableDisableTimestampSelector(bool)
+{
+	m_pTimestampColorSelector->setEnabled(m_pUseTimestampSelector->isChecked() && m_pSpecialTimestampColorSelector->isChecked());
+}
+
+/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
 KviStandardColorsOptionsWidget::KviStandardColorsOptionsWidget(QWidget * parent)
 : KviOptionsWidget(parent,"stdcolors")
@@ -87,11 +194,11 @@ KviStandardColorsOptionsWidget::~KviStandardColorsOptionsWidget()
 }
 
 
-
+/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
 
 KviMessageListView::KviMessageListView(QWidget * par)
-: QListView(par)
+: KviTalListView(par)
 {
 	setItemMargin(2);
 }
@@ -114,6 +221,7 @@ void KviMessageListView::paintEmptyAreaInternal(QPainter * p,const QRect &viewpo
 		if(pix)
 		{
 			QPoint pnt = viewportToContents(viewportRect.topLeft());
+			p->fillRect(painterRect.x(),painterRect.y(),painterRect.width(),painterRect.height(),KVI_OPTION_COLOR(KviOption_colorIrcViewBackground));
 			p->drawTiledPixmap(painterRect.x(),painterRect.y(),painterRect.width(),painterRect.height(),*pix,pnt.x(),pnt.y());
 		} else {
 			p->fillRect(painterRect.x(),painterRect.y(),painterRect.width(),painterRect.height(),KVI_OPTION_COLOR(KviOption_colorIrcViewBackground));
@@ -126,6 +234,7 @@ void KviMessageListView::paintEmptyAreaInternal(QPainter * p,const QRect &viewpo
 void KviMessageListView::paintEmptyArea(QPainter * p,const QRect &rct)
 {
 	paintEmptyAreaInternal(p,rct,rct);
+	KviTalListView::paintEmptyArea(p,rct);
 }
 
 
@@ -133,8 +242,8 @@ void KviMessageListView::paintEmptyArea(QPainter * p,const QRect &rct)
 
 
 
-KviMessageListViewItem::KviMessageListViewItem(QListView * l,int optId)
-: QListViewItem(l)
+KviMessageListViewItem::KviMessageListViewItem(KviTalListView * l,int optId)
+: KviTalListViewItem(l)
 {
 	m_iOptId = optId;
 	setText(0,"WWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWW");
@@ -160,6 +269,7 @@ void KviMessageListViewItem::paintCell(QPainter * p,const QColorGroup &,int,int
 		if(pix)
 		{
 			QPoint pnt = listView()->viewportToContents(QPoint(int(p->worldMatrix().dx()),int(p->worldMatrix().dy())));
+			p->fillRect(0,0,w,height(),KVI_OPTION_COLOR(KviOption_colorIrcViewBackground));
 			p->drawTiledPixmap(0,0,w,height(),*pix,pnt.x(),pnt.y());
 		} else {
 			p->fillRect(0,0,w,height(),KVI_OPTION_COLOR(KviOption_colorIrcViewBackground));
@@ -187,14 +297,23 @@ void KviMessageListViewItem::paintCell(QPainter * p,const QColorGroup &,int,int
 	p->drawText(24,listView()->itemMargin(),w - 24,height() - (listView()->itemMargin() * 2),Qt::AlignLeft | Qt::AlignVCenter,txt);
 	if(isSelected())
 	{
+#ifdef COMPILE_USE_QT4
+		QPen pen(KVI_OPTION_COLOR(KviOption_colorIrcViewBackground));
+		pen.setStyle(Qt::DashLine);
+		p->setPen( pen);
+		p->drawRect(0,0,w,height());
+		p->drawRect(1,1,w - 2,height() - 2);
+#else
+	
 		p->drawWinFocusRect(0,0,w,height(),KVI_OPTION_COLOR(KviOption_colorIrcViewBackground));
 		p->drawWinFocusRect(1,1,w - 2,height() - 2,KVI_OPTION_COLOR(KviOption_colorIrcViewBackground));
+#endif
 	}
 }
 
 
-KviMessageColorListBoxItem::KviMessageColorListBoxItem(QListBox * b,const QColor &clr,int idx)
-: QListBoxText(b,QString::null)
+KviMessageColorListBoxItem::KviMessageColorListBoxItem(KviTalListBox * b,const QColor &clr,int idx)
+: KviTalListBoxText(b,QString::null)
 {
 	m_clr = clr;
 	m_iClrIdx = idx;
@@ -209,13 +328,15 @@ void KviMessageColorListBoxItem::paint(QPainter * p)
 {
 	QColor clr;
 
+	const KviTalListBox * lb = (const KviTalListBox *)listBox();
+
 	if((m_iClrIdx >= 0) && (m_iClrIdx <= 15))
 	{
-		clr = listBox()->isEnabled() ? KVI_OPTION_MIRCCOLOR(m_iClrIdx) : Qt::gray;
-		p->fillRect(0,0,width(listBox()),height(listBox()),clr);
+		clr = lb->isEnabled() ? KVI_OPTION_MIRCCOLOR(m_iClrIdx) : Qt::gray;
+		p->fillRect(0,0,width(lb),height(lb),clr);
 	} else {
 		clr = listBox()->colorGroup().background();
-		QListBoxText::paint(p);
+		KviTalListBoxText::paint(p);
 	}
 #if QT_VERSION >= 300
 	if(isSelected())
@@ -223,13 +344,22 @@ void KviMessageColorListBoxItem::paint(QPainter * p)
 	if(selected())
 #endif
 	{
-		p->drawWinFocusRect(0,0,width(listBox()),height(listBox()),clr);
-		p->drawWinFocusRect(1,1,width(listBox()) - 2,height(listBox()) - 2,clr);
-		p->drawWinFocusRect(2,2,width(listBox()) - 4,height(listBox()) - 4,clr);
+#ifdef COMPILE_USE_QT4
+	QPen pen(clr);
+	pen.setStyle(Qt::DashLine);
+	p->setPen( pen);
+	p->drawRect(0,0,width(lb),height(lb));
+	p->drawRect(1,1,width(lb) - 2,height(lb) - 2);
+	p->drawRect(2,2,width(lb) - 4,height(lb) - 4);
+#else
+	p->drawWinFocusRect(0,0,width(lb),height(lb),clr);
+	p->drawWinFocusRect(1,1,width(lb) - 2,height(lb) - 2,clr);
+	p->drawWinFocusRect(2,2,width(lb) - 4,height(lb) - 4,clr);
+#endif
 	}
 }
 /*
-int KviMessageColorListBoxItem::width(const QListBox * lb) const
+int KviMessageColorListBoxItem::width(const KviTalListBox * lb) const
 {
 	int w = lb->width();
 	if(w < 30)w = 30;
@@ -237,7 +367,7 @@ int KviMessageColorListBoxItem::width(const QListBox * lb) const
 	return w;
 }
 
-int KviMessageColorListBoxItem::height(const QListBox *) const 
+int KviMessageColorListBoxItem::height(const KviTalListBox *) const 
 {
 	return 30;
 }
@@ -257,7 +387,7 @@ KviIrcColorsOptionsWidget::~KviIrcColorsOptionsWidget()
 }
 */
 
-KviMessageOptionsWidget::KviMessageOptionsWidget(QWidget * parent)
+KviMessageColorsOptionsWidget::KviMessageColorsOptionsWidget(QWidget * parent)
 : KviOptionsWidget(parent,"messages")
 {
 	int i;
@@ -270,19 +400,23 @@ KviMessageOptionsWidget::KviMessageOptionsWidget(QWidget * parent)
 	m_pListView = new KviMessageListView(this);
 	m_pListView->addColumn(__tr2qs_ctx("Message Type","options"));
 	m_pListView->setAllColumnsShowFocus(true);
-	m_pListView->setSelectionMode(QListView::Single);
+	m_pListView->setSelectionMode(KviTalListView::Single);
 	m_pListView->setFont(KVI_OPTION_FONT(KviOption_fontIrcView));
 	m_pListView->setStaticBackground(true);
+#ifdef COMPILE_USE_QT4
+	m_pListView->viewport()->setBackgroundMode(Qt::NoBackground);
+#else
 	m_pListView->viewport()->setBackgroundMode(QWidget::NoBackground);
+#endif
 
 	addWidgetToLayout(m_pListView,0,0,2,0);
 
-	QVBox * box = new QVBox(this);
+	KviTalVBox * box = new KviTalVBox(this);
 	addWidgetToLayout(box,3,0,3,0);
 
 	QLabel * l = new QLabel(__tr2qs_ctx("Background:","options"),box);
 
-	m_pBackListBox = new QListBox(box);
+	m_pBackListBox = new KviTalListBox(box);
 	m_pBackItems[16] = new KviMessageColorListBoxItem(m_pBackListBox,Qt::gray,KVI_TRANSPARENT);
 	for(i=0;i<16;i++)
 	{
@@ -291,7 +425,7 @@ KviMessageOptionsWidget::KviMessageOptionsWidget(QWidget * parent)
 
 	l = new QLabel(__tr2qs_ctx("Foreground:","options"),box);
 
-	m_pForeListBox = new QListBox(box);
+	m_pForeListBox = new KviTalListBox(box);
 	for(i=0;i<16;i++)
 	{
 		m_pForeItems[i] = new KviMessageColorListBoxItem(m_pForeListBox,KVI_OPTION_MIRCCOLOR(i),i);
@@ -299,19 +433,19 @@ KviMessageOptionsWidget::KviMessageOptionsWidget(QWidget * parent)
 
 	l = new QLabel(__tr2qs_ctx("Alert level:","options"),box);
 
-	m_pLevelListBox = new QListBox(box);
-	QListBoxText * lbt;
+	m_pLevelListBox = new KviTalListBox(box);
+	KviTalListBoxText * lbt;
 	for(i=0;i<6;i++)
 	{
 		QString tmpn;
 		tmpn.setNum(i);
-		lbt = new QListBoxText(m_pLevelListBox,tmpn);
+		lbt = new KviTalListBoxText(m_pLevelListBox,tmpn);
 	}
 
 	m_pIconButton = new KviStyledToolButton(box);
 	connect(m_pIconButton,SIGNAL(clicked()),this,SLOT(iconButtonClicked()));
 
-	m_pIconPopup = new QPopupMenu(this);
+	m_pIconPopup = new KviTalPopupMenu(this);
 	KviIconWidget * iw = new KviIconWidget(m_pIconPopup);
 	connect(iw,SIGNAL(selected(int)),this,SLOT(newIconSelected(int)));
 	m_pIconPopup->insertItem(iw);
@@ -319,7 +453,7 @@ KviMessageOptionsWidget::KviMessageOptionsWidget(QWidget * parent)
 
 	m_pEnableLogging = new KviStyledCheckBox(__tr2qs_ctx("Log this","options"),box);
 
-	QHBox * h = new QHBox(this);
+	KviTalHBox * h = new KviTalHBox(this);
 	addWidgetToLayout(h,0,1,3,1);
 	QPushButton * b = new QPushButton(__tr2qs_ctx("Load From...","options"),h);
 	connect(b,SIGNAL(clicked()),this,SLOT(load()));
@@ -337,18 +471,18 @@ KviMessageOptionsWidget::KviMessageOptionsWidget(QWidget * parent)
 	layout()->setRowStretch(0,1);
 	layout()->setColStretch(0,1);
 
-	connect(m_pListView,SIGNAL(selectionChanged(QListViewItem *)),this,SLOT(itemChanged(QListViewItem *)));
-	connect(m_pForeListBox,SIGNAL(selectionChanged(QListBoxItem *)),this,SLOT(colorChanged(QListBoxItem *)));
-	connect(m_pBackListBox,SIGNAL(selectionChanged(QListBoxItem *)),this,SLOT(colorChanged(QListBoxItem *)));
+	connect(m_pListView,SIGNAL(selectionChanged(KviTalListViewItem *)),this,SLOT(itemChanged(KviTalListViewItem *)));
+	connect(m_pForeListBox,SIGNAL(selectionChanged(KviTalListBoxItem *)),this,SLOT(colorChanged(KviTalListBoxItem *)));
+	connect(m_pBackListBox,SIGNAL(selectionChanged(KviTalListBoxItem *)),this,SLOT(colorChanged(KviTalListBoxItem *)));
 
 	itemChanged(0);
 }
 
-KviMessageOptionsWidget::~KviMessageOptionsWidget()
+KviMessageColorsOptionsWidget::~KviMessageColorsOptionsWidget()
 {
 }
 
-void KviMessageOptionsWidget::newIconSelected(int iconId)
+void KviMessageColorsOptionsWidget::newIconSelected(int iconId)
 {
 	if(!m_pLastItem)return;
 	if(iconId >= KVI_NUM_SMALL_ICONS)return;
@@ -357,7 +491,7 @@ void KviMessageOptionsWidget::newIconSelected(int iconId)
 	m_pListView->repaintItem(m_pLastItem);
 }
 
-void KviMessageOptionsWidget::saveLastItem()
+void KviMessageColorsOptionsWidget::saveLastItem()
 {
 	if(!m_pLastItem)return;
 
@@ -383,7 +517,7 @@ void KviMessageOptionsWidget::saveLastItem()
 	m_pListView->repaintItem(m_pLastItem);
 }
 
-void KviMessageOptionsWidget::itemChanged(QListViewItem * it)
+void KviMessageColorsOptionsWidget::itemChanged(KviTalListViewItem * it)
 {
 	//debug("Item changed","options");
 	if(m_pLastItem)saveLastItem();
@@ -420,17 +554,17 @@ void KviMessageOptionsWidget::itemChanged(QListViewItem * it)
 
 }
 
-void KviMessageOptionsWidget::colorChanged(QListBoxItem *)
+void KviMessageColorsOptionsWidget::colorChanged(KviTalListBoxItem *)
 {
 	if(m_pLastItem)saveLastItem();
 }
 
-void KviMessageOptionsWidget::iconButtonClicked()
+void KviMessageColorsOptionsWidget::iconButtonClicked()
 {
 	m_pIconPopup->popup(QCursor::pos());
 }
 
-void KviMessageOptionsWidget::commit()
+void KviMessageColorsOptionsWidget::commit()
 {
 	saveLastItem();
 
@@ -446,17 +580,17 @@ void KviMessageOptionsWidget::commit()
 	KviOptionsWidget::commit();
 }
 
-void KviMessageOptionsWidget::save()
+void KviMessageColorsOptionsWidget::save()
 {
-	KviStr szName;
-	KviStr szInit;
+	QString szName;
+	QString szInit;
 	g_pApp->getLocalKvircDirectory(szInit,KviApp::MsgColors);
 
 	if(KviFileDialog::askForSaveFileName(szName,__tr2qs_ctx("Choose a Filename - KVIrc","options"),szInit))
 	{
 		if(m_pLastItem)saveLastItem();
 
-		KviConfig cfg(szName.ptr(),KviConfig::Write);
+		KviConfig cfg(szName,KviConfig::Write);
 
 		cfg.setGroup("Messages");
 
@@ -485,7 +619,7 @@ void KviMessageOptionsWidget::save()
 
 //#include <errno.h>
 
-void KviMessageOptionsWidget::load()
+void KviMessageColorsOptionsWidget::load()
 {
 
 	//KviStr szName;
