@@ -33,15 +33,15 @@
 
 #define KVI_OPTIONS_WIDGET_ICON_KviNickServOptionsWidget KVI_SMALLICON_NICKSERV
 #define KVI_OPTIONS_WIDGET_NAME_KviNickServOptionsWidget __tr2qs_no_lookup("NickServ")
-#define KVI_OPTIONS_WIDGET_PARENT_KviNickServOptionsWidget KviIrcAdvancedOptionsWidget
+#define KVI_OPTIONS_WIDGET_PARENT_KviNickServOptionsWidget KviToolsOptionsWidget
 #define KVI_OPTIONS_WIDGET_KEYWORDS_KviNickServOptionsWidget __tr2qs_no_lookup("authentication,identify")
-//#define KVI_OPTIONS_WIDGET_PRIORITY_KviNickServOptionsWidget 10000
+#define KVI_OPTIONS_WIDGET_PRIORITY_KviNickServOptionsWidget 10000
 //#define KVI_OPTIONS_WIDGET_HIDDEN_KviNickServOptionsWidget true
 
 class QLineEdit;
 class QPushButton;
 class KviNickServRule;
-class QListView;
+class KviTalListView;
 class QCheckBox;
 
 class KviNickServRuleEditor : public QDialog
@@ -72,7 +72,7 @@ public:
 	KviNickServOptionsWidget(QWidget * parent);
 	~KviNickServOptionsWidget();
 protected:
-	QListView             * m_pNickServListView;
+	KviTalListView             * m_pNickServListView;
 	QCheckBox             * m_pNickServCheck;
 	QPushButton           * m_pAddRuleButton;
 	QPushButton           * m_pDelRuleButton;
