@@ -37,9 +37,9 @@
 KviQueryOptionsWidget::KviQueryOptionsWidget(QWidget * parent)
 : KviOptionsWidget(parent,"query_options_widget")
 {
-	createLayout(7,1);
+	createLayout(8,1);
 
-	QGroupBox *g = addGroupBox(0,0,0,0,1,QGroupBox::Horizontal,__tr2qs_ctx("Open Query For","options"));
+	KviTalGroupBox *g = addGroupBox(0,0,0,0,1,Qt::Horizontal,__tr2qs_ctx("Open Query For","options"));
 	KviBoolSelector *b  = addBoolSelector(g, __tr2qs_ctx("Private messages","options"),KviOption_boolCreateQueryOnPrivmsg);
 #ifdef COMPILE_INFO_TIPS
 	mergeTip(b,
@@ -59,8 +59,8 @@ KviQueryOptionsWidget::KviQueryOptionsWidget(QWidget * parent)
 #endif
 
 
-	b = addBoolSelector(0,1,0,1, __tr2qs_ctx("Minimize new queries","options"),KviOption_boolCreateMinimizedQuery);
-    
+	b = addBoolSelector(0,1,0,1,__tr2qs_ctx("Always open queries as minimized","options"),KviOption_boolCreateMinimizedQuery);
+   
 #ifdef COMPILE_INFO_TIPS
 	mergeTip(b,
 		__tr2qs_ctx("<center>This option causes newly created " \
@@ -70,6 +70,7 @@ KviQueryOptionsWidget::KviQueryOptionsWidget(QWidget * parent)
 #endif
 
 
+
 	b = addBoolSelector(0,2,0,2, __tr2qs_ctx("Enable target user tracking","options"),KviOption_boolEnableQueryTracing);
 #ifdef COMPILE_INFO_TIPS
 	mergeTip(b,
