@@ -1,11 +1,12 @@
 #ifndef _OPTW_SOUND_H_
 #define _OPTW_SOUND_H_
+//=============================================================================
 //
 //   File : optw_sound.h
 //   Creation date : Fri Sep  6 02:18:21 2002 GMT by Szymon Stefanek
 //
 //   This file is part of the KVirc irc client distribution
-//   Copyright (C) 2002 Szymon Stefanek (pragma at kvirc dot net)
+//   Copyright (C) 2002-2006 Szymon Stefanek (pragma at kvirc dot net)
 //
 //   This program is FREE software. You can redistribute it and/or
 //   modify it under the terms of the GNU General Public License
@@ -21,17 +22,17 @@
 //   along with this program. If not, write to the Free Software Foundation,
 //   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 //
-
+//=============================================================================
 
 #include "kvi_optionswidget.h"
 #include <qcombobox.h>
 #include <qpushbutton.h>
 
 #define KVI_OPTIONS_WIDGET_ICON_KviSoundOptionsWidget KVI_SMALLICON_SOUND
-#define KVI_OPTIONS_WIDGET_NAME_KviSoundOptionsWidget __tr2qs_no_lookup("Sound System")
+#define KVI_OPTIONS_WIDGET_NAME_KviSoundOptionsWidget __tr2qs_no_lookup("Sound")
 #define KVI_OPTIONS_WIDGET_PARENT_KviSoundOptionsWidget KviGeneralOptOptionsWidget
-#define KVI_OPTIONS_WIDGET_KEYWORDS_KviSoundOptionsWidget __tr2qs_no_lookup("sound,xmms,audio,play")
-#define KVI_OPTIONS_WIDGET_PRIORITY_KviSoundOptionsWidget 80000
+#define KVI_OPTIONS_WIDGET_CONTAINER_KviSoundOptionsWidget true
+
 
 class KviSoundOptionsWidget : public KviOptionsWidget
 {
@@ -39,6 +40,20 @@ class KviSoundOptionsWidget : public KviOptionsWidget
 public:
 	KviSoundOptionsWidget(QWidget * parent);
 	~KviSoundOptionsWidget();
+};
+
+#define KVI_OPTIONS_WIDGET_ICON_KviSoundGeneralOptionsWidget KVI_SMALLICON_SOUND
+#define KVI_OPTIONS_WIDGET_NAME_KviSoundGeneralOptionsWidget __tr2qs_no_lookup("Sound System")
+#define KVI_OPTIONS_WIDGET_PARENT_KviSoundGeneralOptionsWidget KviSoundOptionsWidget
+#define KVI_OPTIONS_WIDGET_KEYWORDS_KviSoundGeneralOptionsWidget __tr2qs_no_lookup("sound,xmms,audio,play,amarok")
+#define KVI_OPTIONS_WIDGET_PRIORITY_KviSoundGeneralOptionsWidget 70000
+
+class KviSoundGeneralOptionsWidget : public KviOptionsWidget
+{
+	Q_OBJECT
+public:
+	KviSoundGeneralOptionsWidget(QWidget * parent);
+	~KviSoundGeneralOptionsWidget();
 protected:
 	QComboBox * m_pSoundSystemBox;
 	QPushButton * m_pSoundTestButton;
@@ -62,12 +77,11 @@ protected slots:
 	void mediaAutoDetect();
 };
 
-
 #define KVI_OPTIONS_WIDGET_ICON_KviSoundsOptionsWidget KVI_SMALLICON_SOUND
 #define KVI_OPTIONS_WIDGET_NAME_KviSoundsOptionsWidget __tr2qs_no_lookup("Sounds")
-#define KVI_OPTIONS_WIDGET_PARENT_KviSoundsOptionsWidget KviGeneralOptOptionsWidget
+#define KVI_OPTIONS_WIDGET_PARENT_KviSoundsOptionsWidget KviSoundOptionsWidget
 #define KVI_OPTIONS_WIDGET_KEYWORDS_KviSoundsOptionsWidget __tr2qs_no_lookup("sound,events")
-#define KVI_OPTIONS_WIDGET_PRIORITY_KviSoundsOptionsWidget 70000
+#define KVI_OPTIONS_WIDGET_PRIORITY_KviSoundsOptionsWidget 80000
 
 class KviSoundsOptionsWidget : public KviOptionsWidget
 {
@@ -76,4 +90,5 @@ public:
 	KviSoundsOptionsWidget(QWidget * parent);
 	~KviSoundsOptionsWidget();
 };
+
 #endif //_OPTW_SOUND_H_
