@@ -24,16 +24,6 @@
 
 #include "kvi_optionswidget.h"
 
-#define KVI_OPTIONS_WIDGET_ICON_KviSSLOptionsWidget KVI_SMALLICON_SSL
-#define KVI_OPTIONS_WIDGET_NAME_KviSSLOptionsWidget __tr_no_lookup("Crypto")
-#define KVI_OPTIONS_WIDGET_PARENT_KviSSLOptionsWidget KviConnectionOptionsWidget
 
-class KviSSLOptionsWidget : public KviOptionsWidget
-{
-	Q_OBJECT
-public:
-	KviSSLOptionsWidget(QWidget * parent);
-	~KviSSLOptionsWidget();
-};
 
 #endif //_OPTW_SSL_H_
