@@ -29,11 +29,11 @@
 
 #include <qlayout.h>
 #include <qcursor.h>
-#include <qhbox.h>
+#include "kvi_tal_hbox.h"
 
 
 KviTextIconEditor::KviTextIconEditor(QWidget * par,KviTextIcon * icon,KviTextIconTableItem* item)
-: QHBox(par),m_pTableItem(item)
+: KviTalHBox(par),m_pTableItem(item)
 {
 	m_pIconButton=new QToolButton(this);
 	m_pBrowseButton=new QToolButton(this);
@@ -56,7 +56,7 @@ void KviTextIconEditor::doPopup()
 {
 	if(!m_pPopup)
 	{
-		m_pPopup = new QPopupMenu(this);
+		m_pPopup = new KviTalPopupMenu(this);
 		KviIconWidget * iw = new KviIconWidget(m_pPopup);
 		connect(iw,SIGNAL(selected(int)),this,SLOT(iconSelected(int)));
 		m_pPopup->insertItem(iw);
@@ -95,8 +95,8 @@ void KviTextIconEditor::updateIcon()
 	}
 }
 
-KviTextIconTableItem::KviTextIconTableItem(QTable * t,KviTextIcon * icon)
-: QTableItem(t,QTableItem::WhenCurrent,QString::null)
+KviTextIconTableItem::KviTextIconTableItem(KviTalTable * t,KviTextIcon * icon)
+: KviTalTableItem(t,KviTalTableItem::WhenCurrent,QString::null)
 {
 	if(icon)
 		m_pIcon=icon;
@@ -141,9 +141,9 @@ KviTextIconsOptionsWidget::KviTextIconsOptionsWidget(QWidget * parent)
 {
 	createLayout(2,2);
 
-	QDictIterator<KviTextIcon> it(*(g_pTextIconManager->textIconDict()));
+	KviPointerHashTableIterator<QString,KviTextIcon> it(*(g_pTextIconManager->textIconDict()));
 
-	m_pTable = new QTable(g_pTextIconManager->textIconDict()->count(),2,this);
+	m_pTable = new KviTalTable(g_pTextIconManager->textIconDict()->count(),2,this);
 
 #ifdef COMPILE_INFO_TIPS
 	mergeTip(m_pTable->viewport(),__tr2qs_ctx("This table contains the text icon associations.<br>" \
@@ -216,6 +216,7 @@ void KviTextIconsOptionsWidget::delClicked()
 
 void KviTextIconsOptionsWidget::commit()
 {
+
 	KviOptionsWidget::commit();
 	g_pTextIconManager->clear();
 	int n = m_pTable->numRows();
@@ -233,12 +234,11 @@ void KviTextIconsOptionsWidget::commit()
 	}
 	g_pTextIconManager->checkDefaultAssociations();
 	
-	for(int i=0;i < n;i++)
-	{
-		m_pTable->clearCell(i,0);
-		m_pTable->clearCell(i,1);
-		m_pTable->clearCell(i,2);
-	}
+	for(int i=0; i<n; i++)
+		for (int j=0; j<m_pTable->numCols(); j++)
+			if (m_pTable->item(i,j))
+				m_pTable->clearCell(i,j);
+	
 }
 
 #include "m_optw_texticons.moc"
