@@ -22,7 +22,7 @@
 
 #include "optw_transport.h"
 
-#include <qgroupbox.h>
+#include <kvi_tal_groupbox.h>
 
 #include "kvi_options.h"
 #include "kvi_locale.h"
