@@ -32,11 +32,25 @@
 KviUserListLookOptionsWidget::KviUserListLookOptionsWidget(QWidget * parent)
 : KviOptionsWidget(parent,"userlistlook_options_widget")
 {
-	createLayout(7,2);
+}
+
+KviUserListLookOptionsWidget::~KviUserListLookOptionsWidget()
+{
+}
+
+
+
+//////////////////////////////////////////////////////////////////////////////////////////////////////
+
+
+KviUserListLookForegroundOptionsWidget::KviUserListLookForegroundOptionsWidget(QWidget * parent)
+: KviOptionsWidget(parent,"userlistlook_foreground_options_widget")
+{
+	createLayout(2,2);
 
 	addFontSelector(0,0,1,0,__tr2qs_ctx("Font:","options"),KviOption_fontUserListView);
 	
-	QGroupBox * g = addGroupBox(0,1,1,1,2,QGroupBox::Horizontal,__tr2qs_ctx("Nickname Colors","options"));
+	KviTalGroupBox * g = addGroupBox(0,1,1,1,1,Qt::Horizontal,__tr2qs_ctx("Nickname Colors","options"));
 	addColorSelector(g,__tr2qs_ctx("Normal:","options"),KviOption_colorUserListViewNormalForeground);
 	addColorSelector(g,__tr2qs_ctx("Selected:","options"),KviOption_colorUserListViewSelectionForeground);
 	addColorSelector(g,__tr2qs_ctx("Channel owner:","options"),KviOption_colorUserListViewChanOwnerForeground);
@@ -47,24 +61,32 @@ KviUserListLookOptionsWidget::KviUserListLookOptionsWidget(QWidget * parent)
 	addColorSelector(g,__tr2qs_ctx("User-op:","options"),KviOption_colorUserListViewUserOpForeground);
 	addColorSelector(g,__tr2qs_ctx("Away:","options"),KviOption_colorUserListViewAwayForeground);
 	
-	QHBox * hb = new QHBox(g);
+	KviTalHBox * hb = new KviTalHBox(g);
 	hb->setSpacing(4);
-	addBoolSelector(hb,__tr2qs_ctx("Use different color for own nick:","options"),KviOption_boolUseDifferentColorForOwnNick);
-	addColorSelector(hb,"",KviOption_colorUserListViewOwnForeground);
-	
-	g = addGroupBox(0,2,1,2,2,QGroupBox::Horizontal,__tr2qs_ctx("Background Colors","options"));
-	addColorSelector(g,__tr2qs_ctx("Normal:","options"),KviOption_colorUserListViewBackground);
-	addColorSelector(g,__tr2qs_ctx("Selected:","options"),KviOption_colorUserListViewSelectionBackground);
-
-
-	g = addGroupBox(0,3,1,3,1,QGroupBox::Horizontal,__tr2qs_ctx("Nickname Grid","options"));
-	KviBoolSelector * b = addBoolSelector(g,__tr2qs_ctx("Draw nickname grid","options"),KviOption_boolUserListViewDrawGrid);
-	hb = new QHBox(g);
-	hb->setSpacing(4);
-
-	KviColorSelector * s = addColorSelector(hb,__tr2qs_ctx("Grid color:","options"),KviOption_colorUserListViewGrid,KVI_OPTION_BOOL(KviOption_boolUserListViewDrawGrid));
+	KviBoolSelector * b = addBoolSelector(hb,__tr2qs_ctx("Use different color for own nick:","options"),KviOption_boolUseDifferentColorForOwnNick);
+	KviColorSelector * s = addColorSelector(hb,"",KviOption_colorUserListViewOwnForeground,KVI_OPTION_BOOL(KviOption_boolUseDifferentColorForOwnNick));
 	connect(b,SIGNAL(toggled(bool)),s,SLOT(setEnabled(bool)));
 
+	addRowSpacer(0,3,0,3);
+}
+
+KviUserListLookForegroundOptionsWidget::~KviUserListLookForegroundOptionsWidget()
+{
+}
+
+KviUserListGridOptionsWidget::KviUserListGridOptionsWidget(QWidget * parent)
+: KviOptionsWidget(parent)
+{
+	createLayout(5,1);
+	KviBoolSelector* b = addBoolSelector(0,0,0,0,__tr2qs_ctx("Draw nickname grid","options"),KviOption_boolUserListViewDrawGrid);
+
+	KviColorSelector* s = addColorSelector(0,1,0,1,__tr2qs_ctx("Grid color:","options"),KviOption_colorUserListViewGrid,KVI_OPTION_BOOL(KviOption_boolUserListViewDrawGrid));
+	connect(b,SIGNAL(toggled(bool)),s,SLOT(setEnabled(bool)));
+
+	KviTalHBox* hb = new KviTalHBox(this);
+	addWidgetToLayout(hb,0,2,0,2);
+	hb->setSpacing(4);
+
 	QLabel * l = new QLabel(__tr2qs_ctx("Grid type:","options"),hb);
 	l->setEnabled(KVI_OPTION_BOOL(KviOption_boolUserListViewDrawGrid));
 	connect(b,SIGNAL(toggled(bool)),l,SLOT(setEnabled(bool)));
@@ -76,20 +98,48 @@ KviUserListLookOptionsWidget::KviUserListLookOptionsWidget(QWidget * parent)
 	m_pGridTypeCombo->setCurrentItem(KVI_OPTION_UINT(KviOption_uintUserListViewGridType));
 	m_pGridTypeCombo->setEnabled(KVI_OPTION_BOOL(KviOption_boolUserListViewDrawGrid));
 	connect(b,SIGNAL(toggled(bool)),m_pGridTypeCombo,SLOT(setEnabled(bool)));
+	addRowSpacer(0,3,0,3);
+}
+
+KviUserListGridOptionsWidget::~KviUserListGridOptionsWidget()
+{
+}
+
+void KviUserListGridOptionsWidget::commit()
+{
+	KviOptionsWidget::commit();
+	KVI_OPTION_UINT(KviOption_uintUserListViewGridType) = m_pGridTypeCombo->currentItem();
+	if(KVI_OPTION_UINT(KviOption_uintUserListViewGridType) > KVI_USERLISTVIEW_GRIDTYPE_MAXIMUM)
+		KVI_OPTION_UINT(KviOption_uintUserListViewGridType) = KVI_USERLISTVIEW_GRIDTYPE_DEFAULT;
 	
+}
+
+//////////////////////////////////////////////////////////////////////////////////////////////////////
+
+KviUserListLookBackgroundOptionsWidget::KviUserListLookBackgroundOptionsWidget(QWidget * parent)
+: KviOptionsWidget(parent,"userlistlook_background_options_widget")
+{
+	createLayout(3,2);
+
+	KviTalGroupBox * g = addGroupBox(0,0,1,0,1,Qt::Horizontal,__tr2qs_ctx("Background Colors","options"));
+	addColorSelector(g,__tr2qs_ctx("Normal:","options"),KviOption_colorUserListViewBackground);
+	addColorSelector(g,__tr2qs_ctx("Selected:","options"),KviOption_colorUserListViewSelectionBackground);
+
+
+	addPixmapSelector(0,1,1,1,__tr2qs_ctx("Background image:","options"),KviOption_pixmapUserListViewBackground);
+
+	addLabel(0,2,0,2,__tr2qs_ctx("Horizontal Alignment:","options"));
+	m_pHorizontalAlign=new QComboBox(this);
+	addWidgetToLayout(m_pHorizontalAlign,1,2,1,2);
 	
-	addLabel(0,4,1,4,__tr2qs_ctx("Horisontal align:","options"));
-	m_pHorisontalAlign=new QComboBox(this);
-	addWidgetToLayout(m_pHorisontalAlign,1,4,1,4);
-	
-	addLabel(0,5,1,5,__tr2qs_ctx("Vertical align:","options"));
+	addLabel(0,3,0,3,__tr2qs_ctx("Vertical Alignment:","options"));
 	m_pVerticalAlign=new QComboBox(this);
-	addWidgetToLayout(m_pVerticalAlign,1,5,1,5);
+	addWidgetToLayout(m_pVerticalAlign,1,3,1,3);
 	
-	m_pHorisontalAlign->insertItem(__tr2qs_ctx("Tile","options"));
-	m_pHorisontalAlign->insertItem(__tr2qs_ctx("Left","options"));
-	m_pHorisontalAlign->insertItem(__tr2qs_ctx("Right","options"));
-	m_pHorisontalAlign->insertItem(__tr2qs_ctx("Center","options"));
+	m_pHorizontalAlign->insertItem(__tr2qs_ctx("Tile","options"));
+	m_pHorizontalAlign->insertItem(__tr2qs_ctx("Left","options"));
+	m_pHorizontalAlign->insertItem(__tr2qs_ctx("Right","options"));
+	m_pHorizontalAlign->insertItem(__tr2qs_ctx("Center","options"));
 	
 	m_pVerticalAlign->insertItem(__tr2qs_ctx("Tile","options"));
 	m_pVerticalAlign->insertItem(__tr2qs_ctx("Top","options"));
@@ -99,16 +149,16 @@ KviUserListLookOptionsWidget::KviUserListLookOptionsWidget(QWidget * parent)
 	switch( KVI_OPTION_UINT(KviOption_uintUserListPixmapAlign) & Qt::AlignHorizontal_Mask)
 	{
 		case Qt::AlignLeft:
-			m_pHorisontalAlign->setCurrentItem(1);
+			m_pHorizontalAlign->setCurrentItem(1);
 			break;
 		case Qt::AlignRight:
-			m_pHorisontalAlign->setCurrentItem(2);
+			m_pHorizontalAlign->setCurrentItem(2);
 			break;
 		case Qt::AlignHCenter:
-			m_pHorisontalAlign->setCurrentItem(3);
+			m_pHorizontalAlign->setCurrentItem(3);
 			break;
 		default:
-			m_pHorisontalAlign->setCurrentItem(0);
+			m_pHorizontalAlign->setCurrentItem(0);
 	}
 	
 	switch( KVI_OPTION_UINT(KviOption_uintUserListPixmapAlign) & Qt::AlignVertical_Mask)
@@ -125,22 +175,24 @@ KviUserListLookOptionsWidget::KviUserListLookOptionsWidget(QWidget * parent)
 		default:
 			m_pVerticalAlign->setCurrentItem(0);
 	}
-	
-	addPixmapSelector(0,6,1,6,__tr2qs_ctx("Background image:","options"),KviOption_pixmapUserListViewBackground);
+
+
 
 	//layout()->setColStretch(0,1);
-	layout()->setRowStretch(4,1);
+	layout()->setRowStretch(1,1);
 }
 
-KviUserListLookOptionsWidget::~KviUserListLookOptionsWidget()
+KviUserListLookBackgroundOptionsWidget::~KviUserListLookBackgroundOptionsWidget()
 {
 }
 
 
-void KviUserListLookOptionsWidget::commit()
+void KviUserListLookBackgroundOptionsWidget::commit()
 {
+	KviOptionsWidget::commit();
+
 	int iFlags=0;
-	switch(m_pHorisontalAlign->currentItem())
+	switch(m_pHorizontalAlign->currentItem())
 	{
 		case 1:
 			iFlags|=Qt::AlignLeft;
@@ -166,27 +218,24 @@ void KviUserListLookOptionsWidget::commit()
 	}
 	
 	KVI_OPTION_UINT(KviOption_uintUserListPixmapAlign)=iFlags;
-	
-	KviOptionsWidget::commit();
-	KVI_OPTION_UINT(KviOption_uintUserListViewGridType) = m_pGridTypeCombo->currentItem();
-	if(KVI_OPTION_UINT(KviOption_uintUserListViewGridType) > KVI_USERLISTVIEW_GRIDTYPE_MAXIMUM)
-		KVI_OPTION_UINT(KviOption_uintUserListViewGridType) = KVI_USERLISTVIEW_GRIDTYPE_DEFAULT;
-	
 }
 
+//////////////////////////////////////////////////////////////////////////////////////////////////////
+
 
 KviUserListFeaturesOptionsWidget::KviUserListFeaturesOptionsWidget(QWidget * parent)
 : KviOptionsWidget(parent,"userlistfeatures_options_widget")
 {
-	createLayout(6,1);
+	createLayout(7,1);
 
-	KviBoolSelector *b = addBoolSelector(0,0,0,0,__tr2qs_ctx("Show user channel icons","options"),KviOption_boolShowUserChannelIcons);
-	b = addBoolSelector(0,1,0,1,__tr2qs_ctx("Show user channel activity indicator","options"),KviOption_boolShowUserChannelState);
-	b = addBoolSelector(0,2,0,2,__tr2qs_ctx("Hide users label","options"),KviOption_boolDisableUserListLabel);
-	b = addBoolSelector(0,3,0,3,__tr2qs_ctx("Enable user tooltips","options"),KviOption_boolShowUserListViewToolTips);
-	b = addBoolSelector(0,4,0,4,__tr2qs_ctx("Hide avatars","options"),KviOption_boolDisableAvatars);
+	KviBoolSelector *b = addBoolSelector(0,0,0,0,__tr2qs_ctx("Show gender icons","options"),KviOption_boolDrawGenderIcons);
+	b = addBoolSelector(0,1,0,1,__tr2qs_ctx("Show user channel icons","options"),KviOption_boolShowUserChannelIcons);
+	b = addBoolSelector(0,2,0,2,__tr2qs_ctx("Show user channel activity indicator","options"),KviOption_boolShowUserChannelState);
+	b = addBoolSelector(0,3,0,3,__tr2qs_ctx("Hide users label","options"),KviOption_boolDisableUserListLabel);
+	b = addBoolSelector(0,4,0,4,__tr2qs_ctx("Enable user tooltips","options"),KviOption_boolShowUserListViewToolTips);
+	b = addBoolSelector(0,5,0,5,__tr2qs_ctx("Hide avatars","options"),KviOption_boolDisableAvatars);
 
-	addRowSpacer(0,5,0,5);
+	addRowSpacer(0,6,0,6);
 }
 
 KviUserListFeaturesOptionsWidget::~KviUserListFeaturesOptionsWidget()
