@@ -32,8 +32,8 @@
 #include "kvi_kvs_script.h"
 #include "kvi_kvs_variant.h"
 #include "kvi_userinput.h"
-
-#include <qdict.h>
+#include "kvi_qcstring.h"
+#include "kvi_pointerhashtable.h"
 
 #ifdef DEBUG
 	#undef DEBUG
@@ -227,7 +227,7 @@ bool KviPerlInterpreter::execute(
 	
 	g_lWarningList.clear();
 
-	QCString szUtf8 = szCode.utf8();
+	KviQCString szUtf8 = szCode.utf8();
 	PERL_SET_CONTEXT(m_pInterpreter);
 	
 	// clear the _ array
@@ -295,7 +295,7 @@ bool KviPerlInterpreter::execute(
 	return true;
 }
 
-static QDict<KviPerlInterpreter> * g_pInterpreters = 0;
+static KviPointerHashTable<QString,KviPerlInterpreter> * g_pInterpreters = 0;
 
 static KviPerlInterpreter * perlcore_get_interpreter(const QString &szContextName)
 {
@@ -322,7 +322,7 @@ static void perlcore_destroy_interpreter(const QString &szContextName)
 
 static void perlcore_destroy_all_interpreters()
 {
-	QDictIterator<KviPerlInterpreter> it(*g_pInterpreters);
+	KviPointerHashTableIterator<QString,KviPerlInterpreter> it(*g_pInterpreters);
 	
 	while(it.current())
 	{
@@ -376,7 +376,7 @@ static bool perlcore_module_ctrl(KviModule * m,const char * cmd,void * param)
 static bool perlcore_module_init(KviModule * m)
 {
 #ifdef COMPILE_PERL_SUPPORT
-	g_pInterpreters = new QDict<KviPerlInterpreter>(17,false);
+	g_pInterpreters = new KviPointerHashTable<QString,KviPerlInterpreter>(17,false);
 	g_pInterpreters->setAutoDelete(false);
 	return true;
 #else // !COMPILE_PERL_SUPPORT
