@@ -46,24 +46,24 @@
 #include <qlayout.h>
 #include <qlabel.h>
 #include <qtooltip.h>
-#include <qasciidict.h>
+#include "kvi_pointerhashtable.h"
 #include <qpushbutton.h>
-#include <qvbox.h>
+#include "kvi_tal_vbox.h"
 
 extern KviPopupEditorWindow * g_pPopupEditorWindow;
 
 
 
 //KviPopupEntryItem
-KviPopupListViewItem::KviPopupListViewItem(QListView * pListView,KviPopupListViewItem * after,Type t)
-: QListViewItem(pListView,after)
+KviPopupListViewItem::KviPopupListViewItem(KviTalListView * pListView,KviPopupListViewItem * after,Type t)
+: KviTalListViewItem(pListView,after)
 {
 	m_type = t;
 	init();
 }
 
 KviPopupListViewItem::KviPopupListViewItem(KviPopupListViewItem * parent,KviPopupListViewItem * after,Type t)
-: QListViewItem(parent,after)
+: KviTalListViewItem(parent,after)
 {
 	m_type = t;
 	init();
@@ -188,7 +188,7 @@ KviSinglePopupEditor::KviSinglePopupEditor(QWidget * par)
 : QWidget(par)
 {
 	m_pLastSelectedItem = 0;
-	m_pContextPopup = new QPopupMenu(this);
+	m_pContextPopup = new KviTalPopupMenu(this);
 	m_pClipboard = 0;
 	m_pTestPopup = 0;
 
@@ -202,10 +202,14 @@ KviSinglePopupEditor::KviSinglePopupEditor(QWidget * par)
 	m_pMenuButton = new QPushButton(__tr2qs("Test"),this);
 	g->addWidget(m_pMenuButton,0,2);
 	connect(m_pMenuButton,SIGNAL(clicked()),this,SLOT(testPopup()));
-
+#ifdef COMPILE_USE_QT4
+	QSplitter * spl = new QSplitter(Qt::Vertical,this,"popupeditor");
+	spl->setOpaqueResize(false);
+#else
 	QSplitter * spl = new QSplitter(QSplitter::Vertical,this);
+#endif
 
-	m_pListView = new QListView(spl);
+	m_pListView = new KviTalListView(spl);
 	m_pListView->addColumn(__tr2qs("Item"));
 	m_pListView->addColumn(__tr2qs("Type"));
 	m_pListView->setMultiSelection(false);
@@ -215,9 +219,9 @@ KviSinglePopupEditor::KviSinglePopupEditor(QWidget * par)
 	m_pListView->setSorting(-1);
 
 
-	connect(m_pListView,SIGNAL(selectionChanged(QListViewItem *)),this,SLOT(selectionChanged(QListViewItem *)));
-	connect(m_pListView,SIGNAL(rightButtonPressed(QListViewItem *,const QPoint &,int)),
-		this,SLOT(itemPressed(QListViewItem *,const QPoint &,int)));
+	connect(m_pListView,SIGNAL(selectionChanged(KviTalListViewItem *)),this,SLOT(selectionChanged(KviTalListViewItem *)));
+	connect(m_pListView,SIGNAL(rightButtonPressed(KviTalListViewItem *,const QPoint &,int)),
+		this,SLOT(itemPressed(KviTalListViewItem *,const QPoint &,int)));
 
 	m_pEditor = KviScriptEditor::createInstance(spl);
 
@@ -366,7 +370,7 @@ void KviSinglePopupEditor::testModeMenuItemClicked(KviKvsPopupMenuItem * it)
 }
 
 
-void KviSinglePopupEditor::itemPressed(QListViewItem *it,const QPoint &pnt,int col)
+void KviSinglePopupEditor::itemPressed(KviTalListViewItem *it,const QPoint &pnt,int col)
 {
 	m_pContextPopup->clear();
 
@@ -799,7 +803,7 @@ KviKvsPopupMenu * KviSinglePopupEditor::getMenu()
 	return p;
 }
 
-void KviSinglePopupEditor::selectionChanged(QListViewItem * it)
+void KviSinglePopupEditor::selectionChanged(KviTalListViewItem * it)
 {
 	saveLastSelectedItem();
 
@@ -1000,8 +1004,8 @@ void KviSinglePopupEditor::edit(KviMenuListViewItem * it)
 
 
 
-KviMenuListViewItem::KviMenuListViewItem(QListView * par,KviKvsPopupMenu * popup)
-: QListViewItem(par)
+KviMenuListViewItem::KviMenuListViewItem(KviTalListView * par,KviKvsPopupMenu * popup)
+: KviTalListViewItem(par)
 {
 	setPixmap(0,*(g_pIconManager->getSmallIcon(KVI_SMALLICON_POPUP)));
 	setText(0,popup->name());
@@ -1024,15 +1028,19 @@ KviPopupEditor::KviPopupEditor(QWidget * par)
 : QWidget(par)
 {
 	QGridLayout * l = new QGridLayout(this,1,1,0,2);
-
+#ifdef COMPILE_USE_QT4
+	QSplitter * spl = new QSplitter(Qt::Horizontal,this,"popupeditor");
+	spl->setOpaqueResize(false);
+#else
 	QSplitter * spl = new QSplitter(QSplitter::Horizontal,this);
+#endif
 	l->addWidget(spl,0,0);
 	
-	QVBox * box = new QVBox(spl);
+	KviTalVBox * box = new KviTalVBox(spl);
 
-	m_pListView = new QListView(box);
+	m_pListView = new KviTalListView(box);
 	m_pListView->addColumn(__tr2qs("Popup"));
-	m_pListView->setSelectionMode(QListView::Extended);
+	m_pListView->setSelectionMode(KviTalListView::Extended);
 	m_pListView->setShowSortIndicator(true);
 
 	QPushButton * pb = new QPushButton(__tr2qs("&Export All To..."),box);
@@ -1045,7 +1053,7 @@ KviPopupEditor::KviPopupEditor(QWidget * par)
 	m_bOneTimeSetupDone = false;
 	m_pLastEditedItem = 0;
 
-	m_pContextPopup = new QPopupMenu(this);
+	m_pContextPopup = new KviTalPopupMenu(this);
 
 	currentItemChanged(0);
 }
@@ -1059,10 +1067,10 @@ void KviPopupEditor::oneTimeSetup()
 	if(m_bOneTimeSetupDone)return;
 	m_bOneTimeSetupDone = true;
 
-	const QDict<KviKvsPopupMenu> * a = KviKvsPopupManager::instance()->popupDict();
+	const KviPointerHashTable<QString,KviKvsPopupMenu> * a = KviKvsPopupManager::instance()->popupDict();
 	if(!a)return;
 
-	QDictIterator<KviKvsPopupMenu> it(*a);
+	KviPointerHashTableIterator<QString,KviKvsPopupMenu> it(*a);
 
 	KviMenuListViewItem * item;
 
@@ -1075,13 +1083,13 @@ void KviPopupEditor::oneTimeSetup()
 		++it;
 	}
 
-	connect(m_pListView,SIGNAL(currentChanged(QListViewItem *)),this,SLOT(currentItemChanged(QListViewItem *)));
-	connect(m_pListView,SIGNAL(rightButtonPressed(QListViewItem *,const QPoint &,int)),
-		this,SLOT(itemPressed(QListViewItem *,const QPoint &,int)));
+	connect(m_pListView,SIGNAL(currentChanged(KviTalListViewItem *)),this,SLOT(currentItemChanged(KviTalListViewItem *)));
+	connect(m_pListView,SIGNAL(rightButtonPressed(KviTalListViewItem *,const QPoint &,int)),
+		this,SLOT(itemPressed(KviTalListViewItem *,const QPoint &,int)));
 
 }
 
-void KviPopupEditor::itemPressed(QListViewItem *it,const QPoint &pnt,int col)
+void KviPopupEditor::itemPressed(KviTalListViewItem *it,const QPoint &pnt,int col)
 {
 	__range_valid(m_bOneTimeSetupDone);
 	m_pContextPopup->clear();
@@ -1154,7 +1162,7 @@ void KviPopupEditor::exportPopups(bool bSelectedOnly)
 	QString out;
 
 	int count=0;
-	QListViewItemIterator itv( m_pListView );
+	KviTalListViewItemIterator itv( m_pListView );
 	while( itv.current() )
 	{
 		if ( (itv.current()->isSelected()) || (bSelectedOnly == true) )
@@ -1221,7 +1229,7 @@ void KviPopupEditor::saveLastEditedItem()
 	m_pLastEditedItem->setText(0,m->popupName());
 }
 
-void KviPopupEditor::currentItemChanged(QListViewItem *it)
+void KviPopupEditor::currentItemChanged(KviTalListViewItem *it)
 {
 	saveLastEditedItem();
 
@@ -1247,7 +1255,7 @@ void KviPopupEditor::commit()
 	KviMenuListViewItem * it = (KviMenuListViewItem *)m_pListView->firstChild();
 
 	// Copy the original popup dict
-	QDict<KviKvsPopupMenu> copy(*(KviKvsPopupManager::instance()->popupDict()));
+	KviPointerHashTable<QString,KviKvsPopupMenu> copy(*(KviKvsPopupManager::instance()->popupDict()));
 	copy.setAutoDelete(false);
 
 	while(it)
@@ -1262,7 +1270,7 @@ void KviPopupEditor::commit()
 
 	// the remaining elements in the copy need to be removed from
 	// the "new" dictionary (they are no longer used)
-	QDictIterator<KviKvsPopupMenu> iter(copy);
+	KviPointerHashTableIterator<QString,KviKvsPopupMenu> iter(copy);
 
 	while(iter.current())
 	{
