@@ -21,9 +21,7 @@
 //
 
 #include "kvi_module.h"
-//#include "kvi_uparser.h"
 #include "kvi_locale.h"
-#include "kvi_command.h"
 #include "kvi_frame.h"
 
 #include "raweditor.h"
