@@ -39,8 +39,8 @@
 #include <qmessagebox.h>
 #include <qsplitter.h>
 #include <qlayout.h>
-#include <qvbox.h>
-#include <qpopupmenu.h>
+#include "kvi_tal_vbox.h"
+#include "kvi_tal_popupmenu.h"
 #include <qtooltip.h>
 #include <qinputdialog.h>
 #include <qpushbutton.h>
@@ -49,8 +49,8 @@ extern KviRawEditorWindow * g_pRawEditorWindow;
 
 
 
-KviRawListViewItem::KviRawListViewItem(QListView *par,int idx)
-: QListViewItem(par)
+KviRawListViewItem::KviRawListViewItem(KviTalListView *par,int idx)
+: KviTalListViewItem(par)
 {
 	m_iIdx = idx;
  	m_szName.setNum(idx);
@@ -74,13 +74,16 @@ KviRawEditor::KviRawEditor(QWidget * par)
 : QWidget(par,"raw_event_editor")
 {
 	QGridLayout * l = new QGridLayout(this,1,1,2,2);
-
+#ifdef COMPILE_USE_QT4
+	QSplitter * spl = new QSplitter(Qt::Horizontal,this,"raweditorv");
+	spl->setOpaqueResize(false);
+#else
 	QSplitter * spl = new QSplitter(QSplitter::Horizontal,this);
-
+#endif
 	l->addWidget(spl,0,0);
 
-	QVBox * boxi = new QVBox(spl);
-	m_pListView = new QListView(boxi);
+	KviTalVBox * boxi = new KviTalVBox(spl);
+	m_pListView = new KviTalListView(boxi);
 	m_pListView->addColumn(__tr2qs("Raw Event"));
 	m_pListView->setMultiSelection(false);
 	m_pListView->setShowSortIndicator(true);
@@ -89,7 +92,7 @@ KviRawEditor::KviRawEditor(QWidget * par)
 	QPushButton * pb = new QPushButton(__tr2qs("&Export All To..."),boxi);
 	connect(pb,SIGNAL(clicked()),this,SLOT(exportAllEvents()));
 	
-	QVBox * box = new QVBox(spl);
+	KviTalVBox * box = new KviTalVBox(spl);
 	m_pNameEditor = new QLineEdit(box);
 	QToolTip::add(m_pNameEditor,__tr2qs("Edit the raw event handler name."));
 	m_pEditor = KviScriptEditor::createInstance(box);
@@ -113,7 +116,7 @@ void KviRawEditor::oneTimeSetup()
 
 	for(unsigned int i = 0;i < 999;i++)
 	{
-		KviPtrList<KviKvsEventHandler> * l = KviKvsEventManager::instance()->rawHandlers(i);
+		KviPointerList<KviKvsEventHandler> * l = KviKvsEventManager::instance()->rawHandlers(i);
 		if(l)
 		{
 			it = new KviRawListViewItem(m_pListView,i);
@@ -130,14 +133,14 @@ void KviRawEditor::oneTimeSetup()
 	}
 
 
-	m_pContextPopup = new QPopupMenu(this);
+	m_pContextPopup = new KviTalPopupMenu(this);
 
-	connect(m_pListView,SIGNAL(selectionChanged(QListViewItem *)),this,SLOT(selectionChanged(QListViewItem *)));
-	connect(m_pListView,SIGNAL(rightButtonPressed(QListViewItem *,const QPoint &,int)),
-		this,SLOT(itemPressed(QListViewItem *,const QPoint &,int)));
+	connect(m_pListView,SIGNAL(selectionChanged(KviTalListViewItem *)),this,SLOT(selectionChanged(KviTalListViewItem *)));
+	connect(m_pListView,SIGNAL(rightButtonPressed(KviTalListViewItem *,const QPoint &,int)),
+		this,SLOT(itemPressed(KviTalListViewItem *,const QPoint &,int)));
 }
 
-void KviRawEditor::itemPressed(QListViewItem *it,const QPoint &pnt,int col)
+void KviRawEditor::itemPressed(KviTalListViewItem *it,const QPoint &pnt,int col)
 {
 	__range_valid(m_bOneTimeSetupDone);
 	m_pContextPopup->clear();
@@ -239,14 +242,14 @@ void KviRawEditor::addHandlerForCurrentRaw()
 {
 	__range_valid(m_pOneTimeSetupDone);
 
-	QListViewItem * it = m_pListView->selectedItem();
+	KviTalListViewItem * it = m_pListView->selectedItem();
 	if(it)
 	{
 		if(it->parent() == 0)
 		{
 			QString buffer = __tr2qs("default");
 			getUniqueHandlerName((KviRawListViewItem *)it,buffer);
-			QListViewItem * ch = new KviRawHandlerListViewItem(it,buffer,"",true);
+			KviTalListViewItem * ch = new KviRawHandlerListViewItem(it,buffer,"",true);
 			it->setOpen(true);
 			m_pListView->setSelected(ch,true);
 		}
@@ -258,7 +261,7 @@ void KviRawEditor::removeCurrentHandler()
 	__range_valid(m_pOneTimeSetupDone);
 	if(m_pLastEditedItem)
 	{
-		QListViewItem * it = m_pLastEditedItem;
+		KviTalListViewItem * it = m_pLastEditedItem;
 		m_pLastEditedItem = 0;
 		delete it;
 		m_pEditor->setEnabled(false);
@@ -283,12 +286,12 @@ void KviRawEditor::commit()
 
 	saveLastEditedItem();
 	KviKvsEventManager::instance()->removeAllScriptRawHandlers();
-	for(QListViewItem * it = m_pListView->firstChild();it;it = it->nextSibling())
+	for(KviTalListViewItem * it = m_pListView->firstChild();it;it = it->nextSibling())
 	{
 		if(it->firstChild())
 		{
 			QString szContext;
-			for(QListViewItem * ch = it->firstChild();ch;ch = ch->nextSibling())
+			for(KviTalListViewItem * ch = it->firstChild();ch;ch = ch->nextSibling())
 			{
 
 				KviQString::sprintf(szContext,"RawEvent%d::%Q",&(((KviRawListViewItem *)it)->m_iIdx),&(((KviRawHandlerListViewItem *)ch)->m_szName));
@@ -325,7 +328,7 @@ void KviRawEditor::saveLastEditedItem()
 	m_pLastEditedItem->m_szBuffer = tmp;
 }
 
-void KviRawEditor::selectionChanged(QListViewItem * it)
+void KviRawEditor::selectionChanged(KviTalListViewItem * it)
 {
 	__range_valid(m_bOneTimeSetupDone);
 	saveLastEditedItem();
