@@ -23,8 +23,8 @@
 //======================================================================================
 // incomplete
 #include "kvi_module.h"
-//#include "kvi_uparser.h"
-#include "kvi_command.h"
+
+
 #include "kvi_regchan.h"
 #include "kvi_locale.h"
 #include "kvi_out.h"
@@ -102,7 +102,7 @@ static bool regchan_kvs_cmd_add(KviKvsModuleCommandCall * c)
 			regchan.remove #kvirc openprojects
 		[/example]
 	@seealso:
-		regchan.add
+		[cmd]regchan.add[/cmd]
 */
 static bool regchan_kvs_cmd_remove(KviKvsModuleCommandCall * c)
 { 
@@ -151,7 +151,7 @@ static bool regchan_kvs_cmd_remove(KviKvsModuleCommandCall * c)
 			regchan.setproperty #kvirc openprojects autojoin true
 		[/example]
 	@seealso:
-		regchan.add
+		[cmd]regchan.add[/cmd]
 */
 
 static bool regchan_kvs_cmd_setProperty(KviKvsModuleCommandCall * c)
@@ -199,7 +199,7 @@ static bool regchan_kvs_cmd_showlist(KviKvsModuleCommandCall * c)
 
 	int tot = 0;
 
-	QAsciiDictIterator<KviRegisteredChannelList> it(*(g_pRegisteredChannelDataBase->channelDict()));
+	KviPointerHashTableIterator<const char *,KviRegisteredChannelList> it(*(g_pRegisteredChannelDataBase->channelDict()));
 	while(KviRegisteredChannelList * l = it.current())
 	{
 		for(KviRegisteredChannel * ch = l->first();ch;ch = l->next())
@@ -207,7 +207,7 @@ static bool regchan_kvs_cmd_showlist(KviKvsModuleCommandCall * c)
 			tot++;
 			c->window()->output(KVI_OUT_SYSTEMMESSAGE,__tr2qs("Channel: %c%s@%s"),
 				KVI_TEXT_BOLD,ch->name().ptr(),ch->netMask().ptr());
-			QAsciiDictIterator<KviStr> pit(*(ch->propertyDict()));
+			KviPointerHashTableIterator<const char *,KviStr> pit(*(ch->propertyDict()));
 			while(KviStr * s = pit.current())
 			{
 				c->window()->output(KVI_OUT_SYSTEMMESSAGE,__tr2qs("   Property: %s=%s"),pit.currentKey(),s->ptr());
@@ -259,8 +259,8 @@ static bool regchan_kvs_fnc_list(KviKvsModuleFunctionCall * c)
 	if(szChan.isEmpty())szChan="*";
 	if(szNetmask.isEmpty())szNetmask="*";
 
-	QAsciiDict<KviRegisteredChannelList> * d = g_pRegisteredChannelDataBase->channelDict();
-	QAsciiDictIterator<KviRegisteredChannelList> it(*d);
+	KviPointerHashTable<const char *,KviRegisteredChannelList> * d = g_pRegisteredChannelDataBase->channelDict();
+	KviPointerHashTableIterator<const char *,KviRegisteredChannelList> it(*d);
 
 	while(KviRegisteredChannelList * l = it.current())
 	{
@@ -338,12 +338,12 @@ static bool regchan_kvs_fnc_property(KviKvsModuleFunctionCall * c)
 			echo $regchan.match(#kvirc,$my.network)
 		[/example]
 	@seealso:
-		$regchan.find
+		[fnc]$regchan.find[/fnc]
 */
 
 
 static bool regchan_kvs_fnc_match(KviKvsModuleFunctionCall * c)
-{ 
+{
 	QString szChan,szNetwork;
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("channel name",KVS_PT_STRING,0,szChan)
@@ -375,7 +375,7 @@ static bool regchan_kvs_fnc_match(KviKvsModuleFunctionCall * c)
 			echo $regchan.find(#kvirc,*)
 		[/example]
 	@seealso:
-		$regchan.match
+		[fnc]$regchan.match[/fnc]
 */
 
 static bool regchan_kvs_fnc_find(KviKvsModuleFunctionCall * c)
