@@ -31,12 +31,26 @@
 #include <qwidget.h>
 #include <qlineedit.h>
 #include <qpushbutton.h>
-#include <qlistview.h>
-#include <qlistbox.h>
-#include <qdict.h>
-#include <qtabdialog.h>
+#include "kvi_tal_listview.h"
+#include "kvi_tal_listbox.h"
+#include "kvi_pointerhashtable.h"
+#include <kvi_tal_tabdialog.h>
+#ifdef COMPILE_USE_QT4
+#include <q3table.h>
+#define Kvi_Tal_Table Q3Table
+#define Kvi_Tal_TableItem Q3TableItem
+
+#else
 #include <qtable.h>
-#include <qpopupmenu.h>
+#define Kvi_Tal_Table QTable
+#define Kvi_Tal_TableItem QTableItem
+
+#endif
+#include "kvi_tal_popupmenu.h"
+
+#ifndef _EDITUSER_CPP_
+	extern KviRegisteredUserDataBase * g_pLocalRegisteredUserDataBase;
+#endif
 
 class KviRegisteredUser;
 
@@ -44,11 +58,15 @@ class KviReguserPropertiesDialog : public QDialog
 {
 	Q_OBJECT
 public:
-	KviReguserPropertiesDialog(QWidget *p,QDict<QString> * dict);
+	KviReguserPropertiesDialog(QWidget *p,KviPointerHashTable<QString,QString> * dict);
 	~KviReguserPropertiesDialog();
 protected:
+#ifdef COMPILE_USE_QT4
+	Q3Table *m_pTable;
+#else
 	QTable             * m_pTable;
-	QDict<QString>     * m_pPropertyDict;
+#endif
+	KviPointerHashTable<QString,QString>     * m_pPropertyDict;
 	QPushButton        * m_pDelButton;
 	QPushButton        * m_pAddButton;
 protected:
@@ -79,61 +97,8 @@ protected slots:
 	void okClicked();
 };
 
-class KviRegisteredUsersDialogItemBase : public QListViewItem
-{
-public:
-	enum Types { User,Group };
-protected:
-	KviRegisteredUsersDialogItemBase(Types type,QListView * par)
-	:QListViewItem(par),m_iType(type)
-	{
-	};
-	KviRegisteredUsersDialogItemBase(Types type,QListViewItem * par)
-	:QListViewItem(par),m_iType(type)
-	{
-	};
-	~KviRegisteredUsersDialogItemBase()
-	{
-	};
-	
-private:
-	KviRegisteredUsersDialogItemBase::Types m_iType;
-public:
-	KviRegisteredUsersDialogItemBase::Types type() { return m_iType; };
-};
 
-class KviRegisteredUsersGroupItem : public KviRegisteredUsersDialogItemBase
-{
-protected:
-	KviRegisteredUserGroup * m_pGroup;
-public:
-	KviRegisteredUsersGroupItem(QListView * par,KviRegisteredUserGroup * g)
-	:KviRegisteredUsersDialogItemBase(Group,par), m_pGroup(g)
-	{
-		setText(0,m_pGroup->name());
-	}
-	~KviRegisteredUsersGroupItem()
-	{
-	}
-	KviRegisteredUserGroup * group() { return m_pGroup; };
-};
-
-class KviRegisteredUsersDialogItem : public KviRegisteredUsersDialogItemBase
-{
-protected:
-	KviRegisteredUser * m_pUser;
-public:
-	KviRegisteredUsersDialogItem(QListViewItem * par,KviRegisteredUser * u);
-
-public:
-	KviRegisteredUser * user(){ return m_pUser; };
-	void setUser(KviRegisteredUser * u){ m_pUser = u; };
-	virtual void paintCell(QPainter * p,const QColorGroup &cg,int column,int width,int align);
-
-};
-
-
-class KviRegisteredUserEntryDialog : public QTabDialog
+class KviRegisteredUserEntryDialog : public KviTalTabDialog
 {
 	Q_OBJECT
 public:
@@ -145,7 +110,7 @@ protected:
 	QLineEdit          * m_pNameEdit;
 	QLineEdit          * m_pCommentEdit;
 
-	QListBox           * m_pMaskListBox;
+	KviTalListBox           * m_pMaskListBox;
 
 	QPushButton        * m_pDelMaskButton;
 	QPushButton        * m_pEditMaskButton;
@@ -157,12 +122,21 @@ protected:
 	KviPixmap          * m_pAvatar;
 	KviPixmapSelector  * m_pAvatarSelector;
 
-	QDict<QString>     * m_pPropertyDict;
+	KviPointerHashTable<QString,QString>     * m_pPropertyDict;
 	
 	QCheckBox          * m_pCustomColorCheck;
 	QColor		   * m_pCustomColor;
 	KviColorSelector   * m_pCustomColorSelector;
 
+	//Ignore TAB
+	QCheckBox          * m_pIgnoreEnabled;
+	QCheckBox          * m_pIgnoreQuery;
+	QCheckBox          * m_pIgnoreChannel;
+	QCheckBox          * m_pIgnoreNotice;
+	QCheckBox          * m_pIgnoreCtcp;
+	QCheckBox          * m_pIgnoreInvite;
+	QCheckBox          * m_pIgnoreDcc;
+
 	virtual void closeEvent(QCloseEvent *);
 protected slots:
 	void okClicked();
@@ -170,49 +144,9 @@ protected slots:
 	void delMaskClicked();
 	void editMaskClicked();
 	void editAllPropertiesClicked();
-	void maskCurrentChanged(QListBoxItem *it);
+	void maskCurrentChanged(KviTalListBoxItem *it);
 };
 
 
-class KviRegisteredUsersDialog : public QWidget
-{
-	Q_OBJECT
-public:
-	KviRegisteredUsersDialog(QWidget * par = 0);
-	~KviRegisteredUsersDialog();
-public:
-	QListView   * m_pListView;
-	QPushButton * m_pAddButton;
-	QPushButton * m_pWizardAddButton;
-	QPushButton * m_pRemoveButton;
-	QPushButton * m_pEditButton;
-	QPushButton * m_pImportButton;
-	QPushButton * m_pExportButton;
-	QPushButton * m_pAddGroupButton;
-	
-	QIntDict<KviRegisteredUserGroup> m_TmpDict;
-protected slots:
-	void itemPressed(QListViewItem *it,const QPoint &pnt,int c);
-	void itemDoubleClicked(QListViewItem *it);
-protected:
-	void fillList();
-protected:
-	virtual void closeEvent(QCloseEvent *);
-	void editItem(KviRegisteredUsersDialogItem * i);
-	void editGroup(KviRegisteredUserGroup* group);
-protected slots:
-	void cancelClicked();
-	void okClicked();
-	void addClicked();
-	void removeClicked();
-	void editClicked();
-	void selectionChanged();
-	void importClicked();
-	void exportClicked();
-	void addWizardClicked();
-	void addGroupClicked();
-	void listViewRightButtonClicked ( QListViewItem *, const QPoint &, int );
-	void moveToGroupMenuClicked(int);
-};
 
 #endif //_EDITUSER_H_
