@@ -23,9 +23,9 @@
 //=============================================================================
 
 #include "kvi_module.h"
-//#include "kvi_uparser.h"
+
 #include "kvi_regusersdb.h"
-#include "kvi_command.h"
+#include "kvi_ircuserdb.h"
 #include "kvi_out.h"
 #include "kvi_mirccntrl.h"
 #include "kvi_window.h"
@@ -36,8 +36,10 @@
 
 #include "edituser.h"
 #include "wizard.h"
+#include "kvi_ircconnection.h"
+#include "dialog.h"
 
-#include "kvi_list.h"
+#include "kvi_pointerlist.h"
 #include <qsplitter.h> // FIXME: REmove this!
 
 //#warning "$reguser.matches..."
@@ -46,9 +48,11 @@
 //#warning "THIS MODULE HAS TO BE REVISED (notify list consistency!!!)"
 
 // kvi_app.cpp
+
+
 extern KVIRC_API KviRegisteredUserDataBase * g_pRegisteredUserDataBase;
 
-KviPtrList<KviRegistrationWizard> * g_pRegistrationWizardList = 0;
+KviPointerList<KviRegistrationWizard> * g_pRegistrationWizardList = 0;
 
 KviRegisteredUsersDialog * g_pRegisteredUsersDialog = 0;
 
@@ -129,7 +133,6 @@ static bool reguser_kvs_cmd_edit(KviKvsModuleCommandCall * c)
 			g_pRegisteredUsersDialog = new KviRegisteredUsersDialog(c->window()->frame()->splitter());
 		}
 	}
-
 	g_pRegisteredUsersDialog->show();
 	g_pRegisteredUsersDialog->raise();
 	g_pRegisteredUsersDialog->setFocus();
@@ -147,7 +150,7 @@ static bool reguser_kvs_cmd_edit(KviKvsModuleCommandCall * c)
 	@short:
 		Registers an user
 	@syntax:
-		reguser.add [-r] [-f] [-q] <name> [mask]
+		reguser.add [-r] [-f] [-q] [-g=group] <name> [mask]
 	@description:
 		Adds a new entry with the specified <name> to the database.[br]
 		If the database contains an entry with the same <name>, this command just prints
@@ -191,7 +194,12 @@ static bool reguser_kvs_cmd_add(KviKvsModuleCommandCall * c)
 
 
 	KviRegisteredUser * u = g_pRegisteredUserDataBase->addUser(szName);
-
+	QString group;
+	if(c->hasSwitch('g',"group"))
+	{
+		c->switches()->getAsStringIfExisting('g',"group",group);
+		u->setGroup(group);
+	}
 	if(u == 0)
 	{
 		if(c->hasSwitch('f',"force"))
@@ -244,7 +252,7 @@ static bool reguser_kvs_cmd_add(KviKvsModuleCommandCall * c)
 	@seealso:
 		[module:reguser]Registered users database interface[/module],
 		[doc:registered_users]Registered users database[/doc],
-		[cmd]reguser.add[cmd],
+		[cmd]reguser.add[/cmd],
 		[cmd]reguser.addmask[/cmd],
 		[fnc]$reguser.list[/fnc]
 */
@@ -306,8 +314,8 @@ static bool reguser_kvs_cmd_remove(KviKvsModuleCommandCall * c)
 		[cmd]reguser.remove[/cmd],
 		[cmd]reguser.delmask[/cmd],
 		[fnc]$reguser.list[/fnc],
-		[fnc]reguser.match[/fnc],
-		[fnc]reguser.exactMatch[/fnc]
+		[fnc]$reguser.match[/fnc],
+		[fnc]$reguser.exactMatch[/fnc]
 */
 
 static bool reguser_kvs_cmd_addmask(KviKvsModuleCommandCall * c)
@@ -375,12 +383,12 @@ static bool reguser_kvs_cmd_addmask(KviKvsModuleCommandCall * c)
 	@seealso:
 		[module:reguser]Registered users database interface[/module],
 		[doc:registered_users]Registered users database[/doc],
-		[cmd]reguser.add[cmd],
+		[cmd]reguser.add[/cmd],
 		[cmd]reguser.remove[/cmd],
 		[cmd]reguser.addmask[/cmd],
 		[fnc]$reguser.list[/fnc],
-		[fnc]reguser.match[/fnc],
-		[fnc]reguser.exactMatch[/fnc]
+		[fnc]$reguser.match[/fnc],
+		[fnc]$reguser.exactMatch[/fnc]
 */
 
 static bool reguser_kvs_cmd_delmask(KviKvsModuleCommandCall * c)
@@ -405,6 +413,237 @@ static bool reguser_kvs_cmd_delmask(KviKvsModuleCommandCall * c)
 	return true;
 }
 
+/*
+	@doc: reguser.setIgnoreEnabled
+	@type:
+		command
+	@title:
+		reguser.setIgnoreEnabled
+	@keyterms:
+		enable/disable ignoring of this user
+	@short:
+		Enable/disable ignoring of this user
+	@syntax:
+		reguser.setIgnoreEnabled [-q] <name:string> <isEnabled:bool>
+	@description:
+		
+	@examples:
+		[example]
+			reguser.setproperty "Alexey" $true
+		[/example]
+	@seealso:
+		[module:reguser]Registered users database interface[/module],
+		[doc:registered_users]Registered users database[/doc],
+		[fnc]$reguser.matchProperty[/fnc],
+		[fnc]$reguser.property[/fnc]
+*/
+
+static bool reguser_kvs_cmd_setIgnoreEnabled(KviKvsModuleCommandCall * c)
+{
+	QString szName;
+	bool bEnabled;
+	KVSM_PARAMETERS_BEGIN(c) 
+		KVSM_PARAMETER("name",KVS_PT_STRING,0,szName) 
+		KVSM_PARAMETER("isEnabled",KVS_PT_BOOL,0,bEnabled) 
+	KVSM_PARAMETERS_END(c) 
+	
+	if(szName.isEmpty())
+	{
+		if(!c->hasSwitch('q',"quiet"))c->warning(__tr2qs("No name specified"));
+		return true;
+	}
+
+	KviRegisteredUser * u = g_pRegisteredUserDataBase->findUserByName(szName);
+	if(!u)
+	{
+		if(!c->hasSwitch('q',"quiet"))c->warning(__tr2qs("User %Q not found"),&szName);
+	} else {
+		u->setIgnoreEnabled(bEnabled);
+	}
+	return true;
+}
+
+
+/*
+	@doc: reguser.setIgnoreFlags
+	@type:
+		command
+	@title:
+		reguser.setIgnoreFlags
+	@keyterms:
+		Sets ignore flags for registered user
+	@short:
+		Sets ignore flags for registered user
+	@syntax:
+		reguser.setIgnoreFlags [-p|--query] [-c|--channel] [-n|--notice] [-t|--ctcp] [-i|--invite] [-d|--dcc] [-q] <name:string>
+	@switches:
+		!sw: -q | --quiet
+		Don't warn if the specified user doesn't exist. Just continue silently.
+		!sw: -p | --query
+		Sets ignore for query messages and actions
+		!sw: -c | --channel
+		Sets ignore for channel messages and actions
+		!sw: -n | --notice
+		Sets ignore for notices
+		!sw: -t | --ctcp
+		Sets ignore for CTCP's
+		!sw: -i | --invite
+		Sets ignore for invites
+		!sw: -d | --dcc
+		Sets ignore for DCC's
+
+	@description:
+		Sets ignore flags for registered user
+	@examples:
+		[example]
+			reguser.setproperty "Alexey" $true
+		[/example]
+	@seealso:
+		[module:reguser]Registered users database interface[/module],
+		[doc:registered_users]Registered users database[/doc],
+		[fnc]$reguser.matchProperty[/fnc],
+		[fnc]$reguser.property[/fnc]
+*/
+
+static bool reguser_kvs_cmd_setIgnoreFlags(KviKvsModuleCommandCall * c)
+{
+	QString szName;
+	KVSM_PARAMETERS_BEGIN(c) 
+		KVSM_PARAMETER("name",KVS_PT_STRING,0,szName) 
+	KVSM_PARAMETERS_END(c) 
+	
+	if(szName.isEmpty())
+	{
+		if(!c->hasSwitch('q',"quiet"))c->warning(__tr2qs("No name specified"));
+		return true;
+	}
+
+	KviRegisteredUser * u = g_pRegisteredUserDataBase->findUserByName(szName);
+	if(!u)
+	{
+		if(!c->hasSwitch('q',"quiet"))c->warning(__tr2qs("User %Q not found"),&szName);
+	} else {
+		int iIgnoreFlags=0;
+		if(c->hasSwitch('p',"query"))
+			iIgnoreFlags |= KviRegisteredUser::Query;
+		if(c->hasSwitch('c',"channel"))
+			iIgnoreFlags |= KviRegisteredUser::Channel;
+		if(c->hasSwitch('n',"notice"))
+			iIgnoreFlags |= KviRegisteredUser::Notice;
+		if(c->hasSwitch('t',"ctcp"))
+			iIgnoreFlags |= KviRegisteredUser::Ctcp;
+		if(c->hasSwitch('i',"invite"))
+			iIgnoreFlags |= KviRegisteredUser::Invite;
+		if(c->hasSwitch('d',"dcc"))
+			iIgnoreFlags |= KviRegisteredUser::Dcc;
+		u->setIgnoreFlags(iIgnoreFlags);
+	}
+	return true;
+}
+
+/*
+	@doc: reguser.getIgnoreFlags
+	@type:
+		function
+	@title:
+		$reguser.getIgnoreFlags
+	@short:
+		Returns ignore flags for registered user
+	@syntax:
+		$reguser.getIgnoreFlags(<name:string>)
+	@description:
+		Returns the ignore flags for registered user. Flags are string of letters:[br]
+		p - query ignore[br]
+		c - channel ignore[br]
+		t - ctcp ignore[br]
+		n - notice ignore[br]
+		d - dcc ignore[br]
+		i - invite ignore[br]
+	@seealso:
+		[module:reguser]Registered users database interface[/module],
+		[doc:registered_users]Registered users database[/doc],
+		[cmd]reguser.add[/cmd],
+		[cmd]reguser.remove[/cmd],
+		[cmd]reguser.addmask[/cmd],
+		[cmd]reguser.delmask[/cmd],
+		[fnc]$reguser.list[/fnc],
+		[fnc]$reguser.match[/fnc],
+		[fnc]$reguser.matchProperty[/fnc]
+*/
+
+static bool reguser_kvs_fnc_getIgnoreFlags(KviKvsModuleFunctionCall * c)
+{ 
+	QString szName;
+	QString szFlags;
+	KVSM_PARAMETERS_BEGIN(c)
+		KVSM_PARAMETER("name",KVS_PT_STRING,0,szName)
+	KVSM_PARAMETERS_END(c)
+	
+	KviKvsArray* pArray = new KviKvsArray();
+	int aid=0;
+	KviRegisteredUser * u = g_pRegisteredUserDataBase->findUserByName(szName);
+	if(u)
+	{
+		if(u->ignoreFlags() & KviRegisteredUser::Query)
+			szFlags+='q';
+		if(u->ignoreFlags() & KviRegisteredUser::Channel)
+			szFlags+='c';
+		if(u->ignoreFlags() & KviRegisteredUser::Notice)
+			szFlags+='n';
+		if(u->ignoreFlags() & KviRegisteredUser::Ctcp)
+			szFlags+='t';
+		if(u->ignoreFlags() & KviRegisteredUser::Invite)
+			szFlags+='i';
+		if(u->ignoreFlags() & KviRegisteredUser::Dcc)
+			szFlags+='d';
+		c->returnValue()->setString(szFlags);
+		
+	}
+	return true;
+}
+
+/*
+	@doc: reguser.isIgnoreEnabled
+	@type:
+		function
+	@title:
+		$reguser.isIgnoreEnabled
+	@short:
+		Returns if ignore enabled registered user
+	@syntax:
+		$reguser.isIgnoreEnabled(<name:string>)
+	@description:
+		Returns if ignore enabled registered user
+	@seealso:
+		[module:reguser]Registered users database interface[/module],
+		[doc:registered_users]Registered users database[/doc],
+		[cmd]reguser.add[/cmd],
+		[cmd]reguser.remove[/cmd],
+		[cmd]reguser.addmask[/cmd],
+		[cmd]reguser.delmask[/cmd],
+		[fnc]$reguser.list[/fnc],
+		[fnc]$reguser.match[/fnc],
+		[fnc]$reguser.matchProperty[/fnc]
+*/
+
+static bool reguser_kvs_fnc_isIgnoreEnabled(KviKvsModuleFunctionCall * c)
+{ 
+	QString szName;
+	KVSM_PARAMETERS_BEGIN(c)
+		KVSM_PARAMETER("name",KVS_PT_STRING,0,szName)
+	KVSM_PARAMETERS_END(c)
+	
+	KviKvsArray* pArray = new KviKvsArray();
+	int aid=0;
+	KviRegisteredUser * u = g_pRegisteredUserDataBase->findUserByName(szName);
+	if(u)
+	{
+		c->returnValue()->setBoolean(u->ignoreEnagled());
+		
+	}
+	return true;
+}
+
 /*
 	@doc: reguser.setproperty
 	@type:
@@ -493,7 +732,7 @@ static bool reguser_kvs_cmd_setproperty(KviKvsModuleCommandCall * c)
 	@seealso:
 		[module:reguser]Registered users database interface[/module],
 		[doc:registered_users]Registered users database[/doc],
-		[cmd]reguser.add[cmd],
+		[cmd]reguser.add[/cmd],
 		[cmd]reguser.remove[/cmd],
 		[cmd]reguser.addmask[/cmd],
 		[fnc]$reguser.list[/fnc],
@@ -514,12 +753,12 @@ static bool reguser_kvs_fnc_list(KviKvsModuleFunctionCall * c)
 	
 	int cnt = 0;
 
-	QDict<KviRegisteredUser> * d = g_pRegisteredUserDataBase->userDict();
-	QDictIterator<KviRegisteredUser> it(*d);
+	KviPointerHashTable<QString,KviRegisteredUser> * d = g_pRegisteredUserDataBase->userDict();
+	KviPointerHashTableIterator<QString,KviRegisteredUser> it(*d);
 
 	while(KviRegisteredUser * u = it.current())
 	{
-		KviPtrList<KviIrcMask> * ml = u->maskList();
+		KviPointerList<KviIrcMask> * ml = u->maskList();
 		if(u->matches(mask) || (ml->count() == 0))
 		{
 			pArray->set(aid,new KviKvsVariant(u->name()));
@@ -552,10 +791,10 @@ static bool reguser_kvs_fnc_list(KviKvsModuleFunctionCall * c)
 	@seealso:
 		[module:reguser]Registered users database interface[/module],
 		[doc:registered_users]Registered users database[/doc],
-		[cmd]reguser.add[cmd],
+		[cmd]reguser.add[/cmd],
 		[cmd]reguser.remove[/cmd],
-		[fnc]reguser.match[/fnc],
-		[fnc]reguser.exactMatch[/fnc]
+		[fnc]$reguser.match[/fnc],
+		[fnc]$reguser.exactMatch[/fnc]
 */
 
 static bool reguser_kvs_cmd_showlist(KviKvsModuleCommandCall * c)
@@ -570,11 +809,11 @@ static bool reguser_kvs_cmd_showlist(KviKvsModuleCommandCall * c)
 
 	int count = 0;
 
-	QDict<KviRegisteredUser> * d = g_pRegisteredUserDataBase->userDict();
-	QDictIterator<KviRegisteredUser> it(*d);
+	KviPointerHashTable<QString,KviRegisteredUser> * d = g_pRegisteredUserDataBase->userDict();
+	KviPointerHashTableIterator<QString,KviRegisteredUser> it(*d);
 	while(KviRegisteredUser * u = it.current())
 	{
-		KviPtrList<KviIrcMask> * ml = u->maskList();
+		KviPointerList<KviIrcMask> * ml = u->maskList();
 		if(u->matches(mask) || (ml->count() == 0))
 		{
 			c->window()->output(KVI_OUT_SYSTEMMESSAGE,__tr2qs(" User: %c%Q"),KVI_TEXT_BOLD,&(u->name()));
@@ -589,10 +828,10 @@ static bool reguser_kvs_cmd_showlist(KviKvsModuleCommandCall * c)
 				}
 			}
 
-			QDict<QString> * pd = u->propertyDict();
+			KviPointerHashTable<QString,QString> * pd = u->propertyDict();
 			if(pd)
 			{
-				QDictIterator<QString> pdit(*pd);
+				KviPointerHashTableIterator<QString,QString> pdit(*pd);
 				while(pdit.current())
 				{
 					QString key = pdit.currentKey();
@@ -627,11 +866,11 @@ static bool reguser_kvs_cmd_showlist(KviKvsModuleCommandCall * c)
 	@seealso:
 		[module:reguser]Registered users database interface[/module],
 		[doc:registered_users]Registered users database[/doc],
-		[cmd]reguser.add[cmd],
+		[cmd]reguser.add[/cmd],
 		[cmd]reguser.remove[/cmd],
 		[cmd]reguser.addmask[/cmd],
 		[fnc]$reguser.list[/fnc],
-		[fnc]reguser.exactMatch[/fnc]
+		[fnc]$reguser.exactMatch[/fnc]
 */
 
 static bool reguser_kvs_fnc_match(KviKvsModuleFunctionCall * c)
@@ -642,6 +881,7 @@ static bool reguser_kvs_fnc_match(KviKvsModuleFunctionCall * c)
 		KVSM_PARAMETER("user_mask",KVS_PT_STRING,0,szMask)
 	KVSM_PARAMETERS_END(c)
 	KviIrcMask mask(szMask);
+//FIXME: it crashes kvirc	KviRegisteredUser * u = c->context()->connection()->userDataBase()->registeredUser(mask.nick(),mask.user(),mask.host());
 	KviRegisteredUser * u = g_pRegisteredUserDataBase->findMatchingUser(mask.nick(),mask.user(),mask.host());
 	if(u) c->returnValue()->setString(u->name());
 	return true;
@@ -663,11 +903,11 @@ static bool reguser_kvs_fnc_match(KviKvsModuleFunctionCall * c)
 	@seealso:
 		[module:reguser]Registered users database interface[/module],
 		[doc:registered_users]Registered users database[/doc],
-		[cmd]reguser.add[cmd],
+		[cmd]reguser.add[/cmd],
 		[cmd]reguser.remove[/cmd],
 		[cmd]reguser.addmask[/cmd],
 		[fnc]$reguser.list[/fnc],
-		[fnc]reguser.match[/fnc]
+		[fnc]$reguser.match[/fnc]
 */
 
 static bool reguser_kvs_fnc_exactMatch(KviKvsModuleFunctionCall * c)
@@ -720,8 +960,8 @@ static bool reguser_kvs_fnc_exactMatch(KviKvsModuleFunctionCall * c)
 //
 //	KviStr list;
 //
-//	const QAsciiDict<KviRegisteredUserList> * d = g_pRegisteredUserDataBase->nickDict();
-//	QAsciiDictIterator<KviRegisteredUserList> it(*d);
+//	const KviPointerHashTable<const char *,KviRegisteredUserList> * d = g_pRegisteredUserDataBase->nickDict();
+//	KviPointerHashTableIterator<const char *,KviRegisteredUserList> it(*d);
 //	while(KviRegisteredUserList * l = it.current())
 //	{
 //		search_reguser_list(l,c->window(),parms->safeFirstParam(),list);
@@ -761,12 +1001,12 @@ static bool reguser_kvs_fnc_exactMatch(KviKvsModuleFunctionCall * c)
 	@seealso:
 		[module:reguser]Registered users database interface[/module],
 		[doc:registered_users]Registered users database[/doc],
-		[cmd]reguser.add[cmd],
+		[cmd]reguser.add[/cmd],
 		[cmd]reguser.remove[/cmd],
 		[cmd]reguser.addmask[/cmd],
 		[cmd]reguser.delmask[/cmd],
 		[fnc]$reguser.list[/fnc],
-		[fnc]reguser.match[/fnc],
+		[fnc]$reguser.match[/fnc],
 		[fnc]$reguser.matchProperty[/fnc]
 */
 
@@ -825,11 +1065,11 @@ static bool reguser_kvs_fnc_mask(KviKvsModuleFunctionCall * c)
 	@seealso:
 		[module:reguser]Registered users database interface[/module],
 		[doc:registered_users]Registered users database[/doc],
-		[cmd]reguser.add[cmd],
+		[cmd]reguser.add[/cmd],
 		[cmd]reguser.remove[/cmd],
 		[cmd]reguser.addmask[/cmd],
 		[fnc]$reguser.list[/fnc],
-		[fnc]reguser.match[/fnc],
+		[fnc]$reguser.match[/fnc],
 		[fnc]$reguser.matchProperty[/fnc]
 */
 
@@ -878,24 +1118,25 @@ static bool reguser_kvs_fnc_property(KviKvsModuleFunctionCall * c)
 	@seealso:
 		[module:reguser]Registered users database interface[/module],
 		[doc:registered_users]Registered users database[/doc],
-		[cmd]reguser.add[cmd],
+		[cmd]reguser.add[/cmd],
 		[cmd]reguser.remove[/cmd],
 		[cmd]reguser.addmask[/cmd],
 		[fnc]$reguser.list[/fnc],
-		[fnc]reguser.match[/fnc],
-		[fnc]reguser.property[/fnc]
+		[fnc]$reguser.match[/fnc],
+		[fnc]$reguser.property[/fnc]
 */
 
 static bool reguser_kvs_fnc_matchProperty(KviKvsModuleFunctionCall * c)
 { 
-	QString szName; 
+	QString szMask; 
 	QString szProperty;
 	KVSM_PARAMETERS_BEGIN(c)
-		KVSM_PARAMETER("user_name",KVS_PT_STRING,0,szName)
+		KVSM_PARAMETER("user_mask",KVS_PT_STRING,0,szMask)
 		KVSM_PARAMETER("property_name",KVS_PT_STRING,KVS_PF_OPTIONAL,szProperty)
 	KVSM_PARAMETERS_END(c)
 	
-	KviIrcMask mask(szName);
+	KviIrcMask mask(szMask);
+//FIXME: it crashes kvirc	KviRegisteredUser * u = c->context()->connection()->userDataBase()->registeredUser(mask.nick(),mask.user(),mask.host());
 	KviRegisteredUser * u = g_pRegisteredUserDataBase->findMatchingUser(mask.nick(),mask.user(),mask.host());
 	if(u)
 	{
@@ -924,7 +1165,7 @@ static bool reguser_kvs_fnc_matchProperty(KviKvsModuleFunctionCall * c)
 	@seealso:
 		[module:reguser]Registered users database interface[/module],
 		[doc:registered_users]Registered users database[/doc],
-		[cmd]reguser.add[cmd],
+		[cmd]reguser.add[/cmd],
 */
 
 static bool reguser_kvs_cmd_wizard(KviKvsModuleCommandCall * c)
@@ -941,7 +1182,8 @@ static bool reguser_kvs_cmd_wizard(KviKvsModuleCommandCall * c)
 
 static bool reguser_module_init(KviModule * m)
 {
-	g_pRegistrationWizardList = new KviPtrList<KviRegistrationWizard>;
+	g_pLocalRegisteredUserDataBase = 0;
+	g_pRegistrationWizardList = new KviPointerList<KviRegistrationWizard>;
 	g_pRegistrationWizardList->setAutoDelete(true);
 
 	KVSM_REGISTER_SIMPLE_COMMAND(m,"add",reguser_kvs_cmd_add);
@@ -952,6 +1194,8 @@ static bool reguser_module_init(KviModule * m)
 	KVSM_REGISTER_SIMPLE_COMMAND(m,"showlist",reguser_kvs_cmd_showlist);
 	KVSM_REGISTER_SIMPLE_COMMAND(m,"setproperty",reguser_kvs_cmd_setproperty);
 	KVSM_REGISTER_SIMPLE_COMMAND(m,"wizard",reguser_kvs_cmd_wizard);
+	KVSM_REGISTER_SIMPLE_COMMAND(m,"setIgnoreEnabled",reguser_kvs_cmd_setIgnoreEnabled);
+	KVSM_REGISTER_SIMPLE_COMMAND(m,"setIgnoreFlags",reguser_kvs_cmd_setIgnoreFlags);
 	
 	KVSM_REGISTER_FUNCTION(m,"match",reguser_kvs_fnc_match);
 	KVSM_REGISTER_FUNCTION(m,"list",reguser_kvs_fnc_list);
@@ -959,6 +1203,8 @@ static bool reguser_module_init(KviModule * m)
 	KVSM_REGISTER_FUNCTION(m,"mask",reguser_kvs_fnc_mask);
 	KVSM_REGISTER_FUNCTION(m,"property",reguser_kvs_fnc_property);
 	KVSM_REGISTER_FUNCTION(m,"matchProperty",reguser_kvs_fnc_matchProperty);
+	KVSM_REGISTER_FUNCTION(m,"getIgnoreFlags",reguser_kvs_fnc_getIgnoreFlags);
+	KVSM_REGISTER_FUNCTION(m,"isIgnoreEnabled",reguser_kvs_fnc_isIgnoreEnabled);
 
 	return true;
 }
@@ -966,11 +1212,11 @@ static bool reguser_module_init(KviModule * m)
 static bool reguser_module_cleanup(KviModule *m)
 {
 	if(g_pRegisteredUsersDialog)delete g_pRegisteredUsersDialog;
-    g_pRegisteredUsersDialog = 0;
+	g_pRegisteredUsersDialog = 0;
 
 	while(KviRegistrationWizard * w = g_pRegistrationWizardList->first())delete w;
 	delete g_pRegistrationWizardList;
-    g_pRegistrationWizardList = 0;
+	g_pRegistrationWizardList = 0;
 
 	// FIXME: UNREGISTER THE METAOBJECTS
 	return true;
