@@ -24,13 +24,16 @@
 #include "wizard.h"
 
 #include "kvi_locale.h"
-#include "kvi_list.h"
+#include "kvi_pointerlist.h"
 #include "kvi_app.h"
 #include "kvi_ircmask.h"
 #include "kvi_selectors.h"
 #include "kvi_pixmap.h"
 #include "kvi_regusersdb.h"
 #include "kvi_iconmanager.h"
+#ifdef COMPILE_USE_QT4
+#include <QDesktopWidget>
+#endif
 
 #include <qcheckbox.h>
 #include <qlabel.h>
@@ -43,13 +46,15 @@
 
 
 extern KVIRC_API KviRegisteredUserDataBase * g_pRegisteredUserDataBase;
-extern KviPtrList<KviRegistrationWizard> * g_pRegistrationWizardList;
+extern KviPointerList<KviRegistrationWizard> * g_pRegistrationWizardList;
 
 KviRegistrationWizard::KviRegistrationWizard(const char * startMask,KviRegisteredUserDataBase * db,QWidget * par,bool bModal)
-: QWizard(par,"regusers_wizard",bModal)
+: KviTalWizard(par)
 {
 	m_pDb = db;
 	
+	setModal(bModal);
+	
 	m_bModal = bModal;
 
 	KviIrcMask mask(startMask ? startMask : "*!*@*");
@@ -115,13 +120,13 @@ KviRegistrationWizard::KviRegistrationWizard(const char * startMask,KviRegistere
 	//KviIrcMask masktempl(szMask.ptr());
 
     m_pNicknameEdit1 = new QLineEdit(m_pPage2);
-    m_pNicknameEdit1->setAlignment(int(QLineEdit::AlignRight));
+    m_pNicknameEdit1->setAlignment(Qt::AlignRight);
 	if(mask.nick() != "*")m_pNicknameEdit1->setText(mask.nick());
 	connect(m_pNicknameEdit1,SIGNAL(textChanged(const QString &)),this,SLOT(maskChanged(const QString &)));
     m_pPage2Layout->addWidget( m_pNicknameEdit1, 1, 0 );
 
     m_pUsernameEdit1 = new QLineEdit(m_pPage2);
-    m_pUsernameEdit1->setAlignment(int(QLineEdit::AlignHCenter));
+    m_pUsernameEdit1->setAlignment(Qt::AlignHCenter);
 	if(mask.hasUser())m_pUsernameEdit1->setText(mask.user());
 	connect(m_pUsernameEdit1,SIGNAL(textChanged(const QString &)),this,SLOT(maskChanged(const QString &)));
     m_pPage2Layout->addWidget(m_pUsernameEdit1,1,2);
@@ -132,11 +137,11 @@ KviRegistrationWizard::KviRegistrationWizard(const char * startMask,KviRegistere
 	m_pPage2Layout->addWidget(m_pHostEdit1,1,4);
 
     m_pNicknameEdit2 = new QLineEdit(m_pPage2);
-    m_pNicknameEdit2->setAlignment(int(QLineEdit::AlignRight));
+    m_pNicknameEdit2->setAlignment(Qt::AlignRight);
     m_pPage2Layout->addWidget(m_pNicknameEdit2,2,0);
 
     m_pUsernameEdit2 = new QLineEdit(m_pPage2);
-    m_pUsernameEdit2->setAlignment(int(QLineEdit::AlignHCenter));
+    m_pUsernameEdit2->setAlignment(Qt::AlignHCenter);
     m_pPage2Layout->addWidget(m_pUsernameEdit2,2,2);
 
     m_pHostEdit2 = new QLineEdit(m_pPage2);
@@ -144,22 +149,22 @@ KviRegistrationWizard::KviRegistrationWizard(const char * startMask,KviRegistere
 
     TextLabel10_2 = new QLabel(m_pPage2);
     TextLabel10_2->setText("<center><b>!</b></center>");
-    TextLabel10_2->setAlignment(int(QLabel::AlignCenter));
+    TextLabel10_2->setAlignment(int(Qt::AlignCenter));
     m_pPage2Layout->addWidget(TextLabel10_2,2,1);
 
     TextLabel10 = new QLabel(m_pPage2);
     TextLabel10->setText("<center><b>!</b></center>");
-    TextLabel10->setAlignment(int(QLabel::AlignCenter));
+    TextLabel10->setAlignment(int(Qt::AlignCenter));
     m_pPage2Layout->addWidget(TextLabel10,1,1);
 
     TextLabel10_3 = new QLabel(m_pPage2);
     TextLabel10_3->setText("<center><b>@</b></center>");
-    TextLabel10_3->setAlignment(int(QLabel::AlignCenter));
+    TextLabel10_3->setAlignment(int(Qt::AlignCenter));
     m_pPage2Layout->addWidget(TextLabel10_3,1,3);
 
     TextLabel10_3_2 = new QLabel(m_pPage2);
     TextLabel10_3_2->setText("<center><b>@</b></center>");
-    TextLabel10_3_2->setAlignment(int(QLabel::AlignCenter));
+    TextLabel10_3_2->setAlignment(int(Qt::AlignCenter));
     m_pPage2Layout->addWidget(TextLabel10_3_2,2,3);
 
     addPage(m_pPage2,__tr2qs("Step 2: Mask Selection"));
@@ -269,7 +274,7 @@ KviRegistrationWizard::~KviRegistrationWizard()
 
 void KviRegistrationWizard::reject()
 {
-	QWizard::reject();
+	KviTalWizard::reject();
 	if(!m_bModal)delete this;
 //	hide();
 //	g_pApp->collectGarbage(this);
@@ -277,7 +282,6 @@ void KviRegistrationWizard::reject()
 
 void KviRegistrationWizard::accept()
 {
-	QWizard::accept();
 	bool bLocalDb = true;
 	if(!m_pDb)
 	{
@@ -285,32 +289,32 @@ void KviRegistrationWizard::accept()
 		m_pDb = g_pRegisteredUserDataBase;
 	}
 
-	KviStr name = m_pEditRealName->text();
+	QString szName = m_pEditRealName->text();
 	KviRegisteredUser * u;
 
 
 	if(bLocalDb)
 	{
-		if(name.isEmpty())name = "user";
+		if(szName.isEmpty()) szName = "user";
 
-		KviStr szNameOk = name;
+		QString szNameOk = szName;
 
 		int idx = 1;
 
 		do {
-			u = m_pDb->findUserByName(szNameOk.ptr());
+			u = m_pDb->findUserByName(szNameOk);
 			if(u)
 			{
-				szNameOk.sprintf("%s%d",name.ptr(),idx);
+				KviQString::sprintf(szNameOk,"%Q%d",&szNameOk,idx);
 				idx++;
 			}
 		} while(u);
 
-		u = m_pDb->addUser(szNameOk.ptr());
+		u = m_pDb->addUser(szNameOk);
 
 	} else {
-		u = m_pDb->findUserByName(name.ptr());
-		if(!u)u = m_pDb->addUser(name.ptr());
+		u = m_pDb->findUserByName(szName);
+		if(!u)u = m_pDb->addUser(szName);
 	}
 
 	if(!u)
@@ -318,15 +322,14 @@ void KviRegistrationWizard::accept()
 		// ops... no way
 		// FIXME: spit an error message ?
 		debug("Ops.. something wrong with the regusers db");
-		delete this;
+		//delete this;
 		return;
 	}
 
-	KviStr m1 = m_pNicknameEdit1->text();
-	KviStr m2 = m_pUsernameEdit1->text();
-	KviStr m3 = m_pHostEdit1->text();
-	KviStr mask(KviStr::Format,"%s!%s@%s",m1.ptr(),m2.ptr(),m3.ptr());
-	KviIrcMask * mk = new KviIrcMask(mask.ptr());
+	QString m1 = m_pNicknameEdit1->text();
+	QString m2 = m_pUsernameEdit1->text();
+	QString m3 = m_pHostEdit1->text();
+	KviIrcMask * mk = new KviIrcMask(m1,m2,m3);
 	m_pDb->removeMask(*mk);
 	m_pDb->addMask(u,mk);
 
@@ -336,24 +339,19 @@ void KviRegistrationWizard::accept()
 	if(m2.isEmpty())m2 = "*";
 	if(m3.isEmpty())m3 = "*";
 	m3 = m_pHostEdit2->text();
-	KviStr mask2(KviStr::Format,"%s!%s@%s",m1.ptr(),m2.ptr(),m3.ptr());
-	mk = new KviIrcMask(mask2.ptr());
-	if(mk->nick() != "*")
-	{
-		m_pDb->removeMask(*mk);
-		m_pDb->addMask(u,mk);
-	} else {
-		delete mk;
-	}
-
+	mk = new KviIrcMask(m1,m2,m3);
+	
+	m_pDb->removeMask(*mk);
+	m_pDb->addMask(u,mk);
+	
 	m_pAvatarSelector->commit();
 
 	bool bSetAvatar = false;
 
 	if(!m_pAvatar->isNull())
 	{
-		KviStr szPath = m_pAvatar->path();
-		u->setProperty("avatar",szPath.ptr());
+		QString szPath = m_pAvatar->path();
+		u->setProperty("avatar",szPath);
 		bSetAvatar = true;
 	}
 
@@ -361,23 +359,26 @@ void KviRegistrationWizard::accept()
 	{
 		m1 = m_pNotifyNickEdit1->text();
 		m2 = m_pNotifyNickEdit2->text();
-		if(m2.hasData())
+		if(!m2.isEmpty())
 		{
-			if(m1.hasData())m1.append(' ');
+			if(!m1.isEmpty())
+				m1.append(' ');
 			m1.append(m2);
 		}
 	
-		if(m1.hasData())
+		if(!m1.isEmpty())
 		{
-			u->setProperty("notify",m1.ptr());
+			u->setProperty("notify",m1);
 			if(!bLocalDb)g_pApp->restartNotifyLists();
 		}
 	}
 
-	if(bSetAvatar && !bLocalDb)g_pApp->resetAvatarForMatchingUsers(u);
+	if(bSetAvatar && !bLocalDb)
+		g_pApp->resetAvatarForMatchingUsers(u);
 
+	KviTalWizard::accept();
 
-	if(!m_bModal)delete this;
+//	if(!m_bModal)delete this;
 //	hide();
 //	g_pApp->collectGarbage(this);
 }
@@ -387,7 +388,7 @@ void KviRegistrationWizard::showEvent(QShowEvent *e)
 {
 	if(height() < 420)resize(width(),420);
 	move((g_pApp->desktop()->width() - width())/2,(g_pApp->desktop()->height() - height())/2);
-	QWizard::showEvent(e);
+	KviTalWizard::showEvent(e);
 }
 
 void KviRegistrationWizard::maskChanged(const QString &)
