@@ -23,12 +23,12 @@
 //=============================================================================
 
 #include "kvi_module.h"
-//#include "kvi_uparser.h"
+
 #include "kvi_sharedfiles.h"
 #include "kvi_ircmask.h"
 #include "kvi_fileutils.h"
 #include "kvi_locale.h"
-#include "kvi_command.h"
+
 #include "kvi_out.h"
 #include "kvi_mirccntrl.h"
 #include "kvi_window.h"
@@ -36,7 +36,7 @@
 
 
 #include <time.h>
-#include <qasciidict.h>
+#include "kvi_pointerhashtable.h"
 
 extern KVIRC_API KviSharedFilesManager * g_pSharedFilesManager;
 
@@ -210,7 +210,7 @@ static bool sharedfile_kvs_cmd_clear(KviKvsModuleCommandCall * c)
 
 static bool sharedfile_kvs_cmd_list(KviKvsModuleCommandCall * c)
 {
-	QDictIterator<KviSharedFileList> it(*(g_pSharedFilesManager->sharedFileListDict()));
+	KviPointerHashTableIterator<QString,KviSharedFileList> it(*(g_pSharedFilesManager->sharedFileListDict()));
 
 	int idx = 0;
 
