@@ -22,7 +22,7 @@
 //==================================================================================
 
 #include "kvi_module.h"
-//#include "kvi_uparser.h"
+
 
 #include "sharedfileswindow.h"
 
@@ -106,7 +106,7 @@ static bool sharedfileswindow_kvs_cmd_open(KviKvsModuleCommandCall * c)
 	KviModuleExtensionDescriptor * d = c->module()->findExtensionDescriptor("tool",KVI_SHARED_FILES_WINDOW_EXTENSION_NAME);
 	if(d)
 	{
-		QDict<QVariant> dict(17,true);
+		KviPointerHashTable<QString,QVariant> dict(17,true);
 		dict.setAutoDelete(true);
 		dict.replace("bCreateMinimized",new QVariant(c->hasSwitch('m',"minimized")));
 		dict.replace("bNoRaise",new QVariant(c->hasSwitch('n',"noraise")));
@@ -121,9 +121,9 @@ static bool sharedfileswindow_kvs_cmd_open(KviKvsModuleCommandCall * c)
 static bool sharedfileswindow_module_init(KviModule * m)
 {
 	KviModuleExtensionDescriptor * d = m->registerExtension("tool",
-							KVI_SHARED_FILES_WINDOW_EXTENSION_NAME,
-							__tr2qs_ctx("Manage S&hared Files","sharedfileswindow"),
-							sharedfileswindow_extension_alloc);
+		KVI_SHARED_FILES_WINDOW_EXTENSION_NAME,
+		__tr2qs_ctx("Manage S&hared Files","sharedfileswindow"),
+		sharedfileswindow_extension_alloc);
 
 	if(d)d->setIcon(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_SHAREDFILES)));
 
