@@ -42,8 +42,8 @@
 #include <qlineedit.h>
 #include <qpushbutton.h>
 #include <qsplitter.h>
-#include <qhbox.h>
-#include <qvbox.h>
+#include "kvi_tal_hbox.h"
+#include "kvi_tal_vbox.h"
 #include <qlayout.h>
 #include <qcheckbox.h>
 #include <qmessagebox.h>
@@ -181,8 +181,8 @@ void KviSharedFileEditDialog::okClicked()
 }
 
 
-KviSharedFilesListViewItem::KviSharedFilesListViewItem(QListView * lv,KviSharedFile * f)
-: QListViewItem(lv,f->name())
+KviSharedFilesListViewItem::KviSharedFilesListViewItem(KviTalListView * lv,KviSharedFile * f)
+: KviTalListViewItem(lv,f->name())
 {
 	setText(1,f->absFilePath());
 	setText(2,f->userMask());
@@ -206,26 +206,29 @@ KviSharedFilesWindow::KviSharedFilesWindow(KviModuleExtensionDescriptor * d,KviF
 : KviWindow(KVI_WINDOW_TYPE_TOOL,lpFrm,"shared files window",0) , KviModuleExtension(d)
 {
 	g_pSharedFilesWindow = this;
-
+#ifdef COMPILE_USE_QT4
+	m_pSplitter = new QSplitter(Qt::Horizontal,this,"splitter");
+#else
 	m_pSplitter = new QSplitter(QSplitter::Horizontal,this,"splitter");
+#endif
 
-	QVBox * vbox = new QVBox(m_pSplitter);
+	KviTalVBox * vbox = new KviTalVBox(m_pSplitter);
 
-	m_pListView  = new QListView(vbox);
+	m_pListView  = new KviTalListView(vbox);
 	//m_pListView->header()->hide();
 	m_pListView->setAllColumnsShowFocus(true);
 	m_pListView->addColumn(__tr2qs_ctx("Name","sharedfileswindow"),200);
 	m_pListView->addColumn(__tr2qs_ctx("Filename","sharedfileswindow"),300);
 	m_pListView->addColumn(__tr2qs_ctx("Mask","sharedfileswindow"),200);
 	m_pListView->addColumn(__tr2qs_ctx("Expires","sharedfileswindow"),200);
-	m_pListView->setSelectionMode(QListView::Single);
+	m_pListView->setSelectionMode(KviTalListView::Single);
 	connect(m_pListView,SIGNAL(selectionChanged()),this,SLOT(enableButtons()));
 
 	connect(g_pSharedFilesManager,SIGNAL(sharedFilesChanged()),this,SLOT(fillFileView()));
 	connect(g_pSharedFilesManager,SIGNAL(sharedFileAdded(KviSharedFile *)),this,SLOT(sharedFileAdded(KviSharedFile *)));
 	connect(g_pSharedFilesManager,SIGNAL(sharedFileRemoved(KviSharedFile *)),this,SLOT(sharedFileRemoved(KviSharedFile *)));
 
-	QHBox * b = new QHBox(vbox);
+	KviTalHBox * b = new KviTalHBox(vbox);
 
 	m_pAddButton = new QPushButton(__tr2qs_ctx("&Add...","sharedfileswindow"),b);
 	connect(m_pAddButton,SIGNAL(clicked()),this,SLOT(addClicked()));
@@ -244,7 +247,7 @@ KviSharedFilesWindow::~KviSharedFilesWindow()
 
 void KviSharedFilesWindow::enableButtons()
 {
-	QListViewItem * it = m_pListView->currentItem();
+	KviTalListViewItem * it = m_pListView->currentItem();
 	m_pEditButton->setEnabled(it);
 	m_pRemoveButton->setEnabled(it);
 }
@@ -287,7 +290,7 @@ void KviSharedFilesWindow::editClicked()
 void KviSharedFilesWindow::fillFileView()
 {
 	m_pListView->clear();
-	QDictIterator<KviSharedFileList> it(*(g_pSharedFilesManager->sharedFileListDict()));
+	KviPointerHashTableIterator<QString,KviSharedFileList> it(*(g_pSharedFilesManager->sharedFileListDict()));
 
 	KviSharedFilesListViewItem * itm;
 
@@ -311,7 +314,7 @@ void KviSharedFilesWindow::sharedFileAdded(KviSharedFile * f)
 
 void KviSharedFilesWindow::sharedFileRemoved(KviSharedFile * f)
 {
-	QListViewItem * it = m_pListView->firstChild();
+	KviTalListViewItem * it = m_pListView->firstChild();
 	while(it)
 	{
 		if(((KviSharedFilesListViewItem *)it)->readOnlySharedFilePointer() == f)
@@ -340,7 +343,7 @@ void KviSharedFilesWindow::tipRequest(KviDynamicToolTip * tip,const QPoint &pnt)
 /*
 void KviSharedFilesWindow::fillTransferView()
 {
-	KviPtrList<KviSharedFiles> * l = KviSharedFilesManager::instance()->transferList();
+	KviPointerList<KviSharedFiles> * l = KviSharedFilesManager::instance()->transferList();
 	if(!l)return;
 	KviSharedFilesItem * it;
 	for(KviSharedFiles * t = l->first();t;t = l->next())
@@ -374,13 +377,13 @@ void KviSharedFilesWindow::transferUnregistering(KviSharedFiles * t)
 	if(it)delete it;
 }
 
-void KviSharedFilesWindow::rightButtonPressed(QListViewItem *it,const QPoint &pnt,int col)
+void KviSharedFilesWindow::rightButtonPressed(KviTalListViewItem *it,const QPoint &pnt,int col)
 {
-	if(!m_pContextPopup)m_pContextPopup = new QPopupMenu(this);
-	if(!m_pLocalFilePopup)m_pLocalFilePopup = new QPopupMenu(this);
+	if(!m_pContextPopup)m_pContextPopup = new KviTalPopupMenu(this);
+	if(!m_pLocalFilePopup)m_pLocalFilePopup = new KviTalPopupMenu(this);
 	if(!m_pOpenFilePopup)
 	{
-		m_pOpenFilePopup= new QPopupMenu(this);
+		m_pOpenFilePopup= new KviTalPopupMenu(this);
 		connect(m_pOpenFilePopup,SIGNAL(activated(int)),this,SLOT(openFilePopupActivated(int)));
 	}
 
@@ -487,7 +490,7 @@ void KviSharedFilesWindow::rightButtonPressed(QListViewItem *it,const QPoint &pn
 
 KviSharedFiles * KviSharedFilesWindow::selectedTransfer()
 {
-	QListViewItem * it = m_pListView->selectedItem();
+	KviTalListViewItem * it = m_pListView->selectedItem();
 	if(!it)return 0;
 	KviSharedFilesItem * i = (KviSharedFilesItem *)it;
 	return i->transfer();
@@ -623,8 +626,8 @@ void KviSharedFilesWindow::heartbeat()
 {
 	if(m_pListView->childCount() < 1)return;
 
-	QListViewItem * i1;
-	QListViewItem * i2;
+	KviTalListViewItem * i1;
+	KviTalListViewItem * i2;
 
 	i1 = m_pListView->itemAt(QPoint(1,1));
 	if(!i1)
