@@ -30,8 +30,9 @@
 #include "kvi_console.h"
 #include "kvi_moduleextension.h"
 #include "kvi_sharedfiles.h"
+#include "kvi_styled_controls.h"
 
-#include <qlistview.h>
+#include "kvi_tal_listview.h"
 #include <qdialog.h>
 
 class QGridLayout; 
@@ -39,12 +40,11 @@ class QDateTimeEdit;
 class QLabel;
 class QLineEdit;
 class QPushButton;
-class KviStyledCheckBox;
 
-class KviSharedFilesListViewItem : public QListViewItem
+class KviSharedFilesListViewItem : public KviTalListViewItem
 {
 public:
-	KviSharedFilesListViewItem(QListView * lv,KviSharedFile * f);
+	KviSharedFilesListViewItem(KviTalListView * lv,KviSharedFile * f);
 	~KviSharedFilesListViewItem();
 protected:
 	KviSharedFile * m_pSharedFilePointer; // THIS IS READ ONLY!
@@ -87,7 +87,7 @@ public:
 protected:
 	QSplitter           * m_pVertSplitter;
 
-	QListView           * m_pListView;
+	KviTalListView           * m_pListView;
 
 	QPushButton         * m_pRemoveButton;
 	QPushButton         * m_pEditButton;
