@@ -21,7 +21,7 @@
 
 
 #include "kvi_module.h"
-//#include "kvi_uparser.h"
+
 
 #include "socketspywindow.h"
 
@@ -31,7 +31,7 @@
 
 #include <qsplitter.h>
 
-KviPtrList<KviSocketSpyWindow> * g_pSocketSpyWindowList = 0;
+KviPointerList<KviSocketSpyWindow> * g_pSocketSpyWindowList = 0;
 
 
 /*
@@ -60,7 +60,7 @@ static bool socketspy_kvs_cmd_open(KviKvsModuleCommandCall * c)
 
 static bool socketspy_module_init(KviModule * m)
 {
-	g_pSocketSpyWindowList = new KviPtrList<KviSocketSpyWindow>;
+	g_pSocketSpyWindowList = new KviPointerList<KviSocketSpyWindow>;
 	g_pSocketSpyWindowList->setAutoDelete(false);
 
 	KVSM_REGISTER_SIMPLE_COMMAND(m,"open",socketspy_kvs_cmd_open);
@@ -71,7 +71,7 @@ static bool socketspy_module_cleanup(KviModule *m)
 {
 	while(g_pSocketSpyWindowList->first())g_pSocketSpyWindowList->first()->die();
 	delete g_pSocketSpyWindowList;
-    g_pSocketSpyWindowList = 0;
+	g_pSocketSpyWindowList = 0;
 	return true;
 }
 
