@@ -31,13 +31,17 @@
 #include <qsplitter.h>
 //#include "kvi_module.h"
 
-extern KviPtrList<KviSocketSpyWindow> * g_pSocketSpyWindowList;
+extern KviPointerList<KviSocketSpyWindow> * g_pSocketSpyWindowList;
 
 KviSocketSpyWindow::KviSocketSpyWindow(KviFrame * lpFrm,KviConsole * lpConsole)
 : KviWindow(KVI_WINDOW_TYPE_SOCKETSPY,lpFrm,"socket_spy",lpConsole) , KviIrcDataStreamMonitor(lpConsole->context())
 {
 	g_pSocketSpyWindowList->append(this);
+	#ifdef COMPILE_USE_QT4
+	m_pSplitter = new QSplitter(Qt::Horizontal,this,"splitter");
+	#else
 	m_pSplitter = new QSplitter(QSplitter::Horizontal,this,"splitter");
+#endif
 	m_pIrcView = new KviIrcView(m_pSplitter,lpFrm,this);
 	// Ensure proper focusing
 	//setFocusHandler(m_pIrcView,this);
