@@ -25,7 +25,7 @@
 //#warning: FIXME: Incomplete documentation ('seealso', 'example', etc)
 
 #include "kvi_module.h"
-//#include "kvi_uparser.h"
+
 #include "kvi_locale.h"
 #include "kvi_mirccntrl.h"
 #include "kvi_qstring.h"
@@ -178,16 +178,16 @@ static bool str_kvs_fnc_len(KviKvsModuleFunctionCall * c)
 }
 
 /*
-    @doc: str.lowcase
-    @type:
-        function
-    @title:
-        $str.lowcase
-    @short:
-        Returns the given string with all characters turned to lower case
-    @syntax:
-        <string> $str.lowcase(<string_to_convert:string>)
-    @description:
+	@doc: str.lowcase
+	@type:
+		function
+	@title:
+		$str.lowcase
+	@short:
+		Returns the given string with all characters turned to lower case
+	@syntax:
+		<string> $str.lowcase(<string_to_convert:string>)
+	@description:
 		Returns the <string_to_convert> with all characters turned to lower case.
 		Warning: this function uses ISO-8859-1 locale to make the case translation.
 		If you want to use a locale aware translation mapping then please
@@ -284,16 +284,16 @@ static bool str_kvs_fnc_localeupcase(KviKvsModuleFunctionCall * c)
 }
 
 /*
-    @doc: str.isnumber
-    @type:
-        function
-    @title:
-        $str.isnumber
-    @short:
-        Returns 1 if the given string represents a number
-    @syntax:
-        <bool> $str.isnumber(<givenstring:string>)
-    @description:
+	@doc: str.isnumber
+	@type:
+		function
+	@title:
+		$str.isnumber
+	@short:
+		Returns 1 if the given string represents a number
+	@syntax:
+		<bool> $str.isnumber(<givenstring:string>)
+	@description:
 		Returns 1 if the given string represents a number, 0 if not.
 */
 
@@ -310,16 +310,16 @@ static bool str_kvs_fnc_isnumber(KviKvsModuleFunctionCall * c)
 
 
 /*
-    @doc: str.isunsignednumber
-    @type:
-        function
-    @title:
-        $str.isunsignednumber
-    @short:
-        Returns 1 if the given string represents an unsigned number
-    @syntax:
-        <bool> $str.isunsignednumber(<givenstring:string>)
-    @description:
+	@doc: str.isunsignednumber
+	@type:
+		function
+	@title:
+		$str.isunsignednumber
+	@short:
+		Returns 1 if the given string represents an unsigned number
+	@syntax:
+		<bool> $str.isunsignednumber(<givenstring:string>)
+	@description:
 		Returns 1 if the given string represents an unsigned number, 0 if not.
 */
 
@@ -438,16 +438,16 @@ static bool str_kvs_fnc_containsnocase(KviKvsModuleFunctionCall * c)
 }
 
 /*
-    @doc: str.equal
-    @type:
-        function
-    @title:
-        $str.equal
-    @short:
-        Returns 1 if the two string parameters are equal
-    @syntax:
-        <bool> $str.equal(<fromcompare:string>,<tocompare:string>)
-    @description:
+	@doc: str.equal
+	@type:
+		function
+	@title:
+		$str.equal
+	@short:
+		Returns 1 if the two string parameters are equal
+	@syntax:
+		<bool> $str.equal(<fromcompare:string>,<tocompare:string>)
+	@description:
 		Returns 1 if the two string parameters are equal. This function is case sensitive.
 	@seealso:
 		[fnc]$str.equalnocase[/fnc]()
@@ -466,16 +466,16 @@ static bool str_kvs_fnc_equal(KviKvsModuleFunctionCall * c)
 	return true;
 }
 /*
-    @doc: str.equalnocase
-    @type:
-        function
-    @title:
-        $str.equalnocase
-    @short:
-        Returns 1 if the two string parameters are equal, case insensitive
-    @syntax:
-        <bool> $str.equalnocase(<fromcompare:string>,<tocompare:string>)
-    @description:
+	@doc: str.equalnocase
+	@type:
+		function
+	@title:
+		$str.equalnocase
+	@short:
+		Returns 1 if the two string parameters are equal, case insensitive
+	@syntax:
+		<bool> $str.equalnocase(<fromcompare:string>,<tocompare:string>)
+	@description:
 		Returns 1 if the two strngs parameters are equal, without taking the case of the
 		characters in consideration.
 	@seealso:
@@ -527,19 +527,19 @@ static bool str_kvs_fnc_cmp(KviKvsModuleFunctionCall * c)
 }
 
 /*
-    @doc: str.cmpnocase
-    @type:
-        function
-    @title:
-        $str.cmpnocase
-    @short:
-        Compare two strings alphabetically, case insensitive.
-    @syntax:
-        <bool> $str.cmpnocase(<fromcompare:string>,<tocompare:string>)
-    @description:
-        This function compares two strings alphabetically. If the first string is 'greater'
-        than the second, it will return a positive number, a negative number is the second is
-        greater and 0 if the two strings are equal. This function is case insensitive.
+	@doc: str.cmpnocase
+	@type:
+		function
+	@title:
+		$str.cmpnocase
+	@short:
+		Compare two strings alphabetically, case insensitive.
+	@syntax:
+		<bool> $str.cmpnocase(<fromcompare:string>,<tocompare:string>)
+	@description:
+		This function compares two strings alphabetically. If the first string is 'greater'
+		than the second, it will return a positive number, a negative number is the second is
+		greater and 0 if the two strings are equal. This function is case insensitive.
 	@seealso:
 		[fnc]$str.cmp[/fnc]()
 */
@@ -588,7 +588,17 @@ static bool str_kvs_fnc_find(KviKvsModuleFunctionCall * c)
 	int pos = 1;
 	if(iOcurence!=0)
 		pos = iOcurence;
-	if (pos<1)
+	if(pos<1)
+	{
+		c->returnValue()->setInteger(-1);
+		return true;
+	}
+	if(szFindIn.isEmpty())
+	{
+		c->returnValue()->setInteger(-1);
+		return true;
+	}
+	if(szToFind.isEmpty())
 	{
 		c->returnValue()->setInteger(-1);
 		return true;
@@ -640,19 +650,19 @@ static bool str_kvs_fnc_findfirst(KviKvsModuleFunctionCall * c)
 	return true;
 }
 /*
-    @doc: str.findfirstnocase
-    @type:
-        function
-    @title:
-        $str.findfirstnocase
-    @short:
-        Find the index of a substring in a string, case insensitive
-    @syntax:
-        <int> $str.findfirstnocase(<findIn:string>,<toFind:string>)
-    @description:
-        This function search in the string given as the first parameter for the string
-        given as his second parameter, and will return the index where is first located or
-        -1 if it's not located. This function is case insensitive.
+	@doc: str.findfirstnocase
+	@type:
+		function
+	@title:
+		$str.findfirstnocase
+	@short:
+		Find the index of a substring in a string, case insensitive
+	@syntax:
+		<int> $str.findfirstnocase(<findIn:string>,<toFind:string>)
+	@description:
+		This function search in the string given as the first parameter for the string
+		given as his second parameter, and will return the index where is first located or
+		-1 if it's not located. This function is case insensitive.
 */
 
 static bool str_kvs_fnc_findfirstnocase(KviKvsModuleFunctionCall * c)
@@ -666,19 +676,19 @@ static bool str_kvs_fnc_findfirstnocase(KviKvsModuleFunctionCall * c)
 	return true;
 }
 /*
-    @doc: str.findlast
-    @type:
-        function
-    @title:
-        $str.findlast
-    @short:
-        Find the last index of a substring in a string
-    @syntax:
-        <int> $str.findlast(<findIn:string>,<toFind:string>)
-    @description:
-        This function search in the string given as the first parameter for the string
-        given as his second parameter, and will return the index where is last located or
-        -1 if it's not located.
+	@doc: str.findlast
+	@type:
+		function
+	@title:
+		$str.findlast
+	@short:
+		Find the last index of a substring in a string
+	@syntax:
+		<int> $str.findlast(<findIn:string>,<toFind:string>)
+	@description:
+		This function search in the string given as the first parameter for the string
+		given as his second parameter, and will return the index where is last located or
+		-1 if it's not located.
 */
 
 static bool str_kvs_fnc_findlast(KviKvsModuleFunctionCall * c)
@@ -692,19 +702,19 @@ static bool str_kvs_fnc_findlast(KviKvsModuleFunctionCall * c)
 	return true;
 }
 /*
-    @doc: str.findlastnocase
-    @type:
-        function
-    @title:
-        $str.findlastnocase
-    @short:
-        Find the last index of a substring in a string, case insensitive
-    @syntax:
-        <int> $str.findlastnocase(<findIn:string>,<toFind:string>)
-    @description:
-        This function search in the string given as the first parameter for the string
-        given as his second parameter, and will return the index where is last located or
-        -1 if it's not located. This function is case insensitive.
+	@doc: str.findlastnocase
+	@type:
+		function
+	@title:
+		$str.findlastnocase
+	@short:
+		Find the last index of a substring in a string, case insensitive
+	@syntax:
+		<int> $str.findlastnocase(<findIn:string>,<toFind:string>)
+	@description:
+		This function search in the string given as the first parameter for the string
+		given as his second parameter, and will return the index where is last located or
+		-1 if it's not located. This function is case insensitive.
 */
 
 static bool str_kvs_fnc_findlastnocase(KviKvsModuleFunctionCall * c)
@@ -718,16 +728,16 @@ static bool str_kvs_fnc_findlastnocase(KviKvsModuleFunctionCall * c)
 	return true;
 }
 /*
-    @doc: str.left
-    @type:
-        function
-    @title:
-        $str.left
-    @short:
+	@doc: str.left
+	@type:
+		function
+	@title:
+		$str.left
+	@short:
 		Returns a substring starting from the left until the given index.
-    @syntax:
-        <string> $str.left(<data:string>,<index:int>)
-    @description:
+	@syntax:
+		<string> $str.left(<data:string>,<index:int>)
+	@description:
 		This function returns a substring of the first string parameter which is the
 		string starting from the left until the index specified in the second parameter.
 */
@@ -744,16 +754,16 @@ static bool str_kvs_fnc_left(KviKvsModuleFunctionCall * c)
 	return true;
 }
 /*
-    @doc: str.right
-    @type:
-        function
-    @title:
-        $str.right
-    @short:
+	@doc: str.right
+	@type:
+		function
+	@title:
+		$str.right
+	@short:
 		Returns a substring starting from the right until the given index.
-    @syntax:
-        <string> $str.right(<data:string>,<index:int>)
-    @description:
+	@syntax:
+		<string> $str.right(<data:string>,<index:int>)
+	@description:
 		This function returns a substring of the first string parameter which is the
 		string starting from the right until the index specified in the second parameter.
 		The index start counting at the last character and increase until the first.
@@ -771,16 +781,16 @@ static bool str_kvs_fnc_right(KviKvsModuleFunctionCall * c)
 	return true;
 }
 /*
-    @doc: str.mid
-    @type:
-        function
-    @title:
-        $str.mid
-    @short:
+	@doc: str.mid
+	@type:
+		function
+	@title:
+		$str.mid
+	@short:
 		Returns a substring starting from a given index.
-    @syntax:
-        <string> $str.mid(<data:string>,<startidx:int>,<nchars:int>)
-    @description:
+	@syntax:
+		<string> $str.mid(<data:string>,<startidx:int>,<nchars:int>)
+	@description:
 		This function returns a substring of the first string parameter wich is the
 		string starting at the (numeric) index given with startidx and counting nchars
 		forward.
@@ -799,16 +809,16 @@ static bool str_kvs_fnc_mid(KviKvsModuleFunctionCall * c)
 	return true;
 }
 /*
-    @doc: str.append
-    @type:
-        function
-    @title:
-        $str.append
-    @short:
+	@doc: str.append
+	@type:
+		function
+	@title:
+		$str.append
+	@short:
 		Append one string to another.
-    @syntax:
-        <string> $str.append(<string:string>,<toappend:string>)
-    @description:
+	@syntax:
+		<string> $str.append(<string:string>,<toappend:string>)
+	@description:
 		This function returns a string created appending the second string parameter
 		to the end of the first string parameter.
 */
@@ -824,16 +834,16 @@ static bool str_kvs_fnc_append(KviKvsModuleFunctionCall * c)
 	return true;
 }
 /*
-    @doc: str.prepend
-    @type:
-        function
-    @title:
-        $str.prepend
-    @short:
+	@doc: str.prepend
+	@type:
+		function
+	@title:
+		$str.prepend
+	@short:
 		Prepend one string to another.
-    @syntax:
-        <string> $str.prepend(<string:string>,<toprepend:string>)
-    @description:
+	@syntax:
+		<string> $str.prepend(<string:string>,<toprepend:string>)
+	@description:
 		This function returns a string created prepending the second string parameter
 		to the start of the first string parameter.
 */
@@ -849,16 +859,16 @@ static bool str_kvs_fnc_prepend(KviKvsModuleFunctionCall * c)
 	return true;
 }
 /*
-    @doc: str.insert
-    @type:
-        function
-    @title:
-        $str.insert
-    @short:
-        Inserts a substring in a string at a given index
-    @syntax:
-        <string> $str.insert(<string:string>,<substring:string>,<index:int>)
-    @description:
+	@doc: str.insert
+	@type:
+		function
+	@title:
+		$str.insert
+	@short:
+		Inserts a substring in a string at a given index
+	@syntax:
+		<string> $str.insert(<string:string>,<substring:string>,<index:int>)
+	@description:
 		Inserts the substring given in the second parameter in the string given in the
 		first parameter at the index given in the third parameter, then returns the
 		resulting string.
@@ -877,16 +887,16 @@ static bool str_kvs_fnc_insert(KviKvsModuleFunctionCall * c)
 	return true;
 }
 /*
-    @doc: str.strip
-    @type:
-        function
-    @title:
-        $str.strip
-    @short:
+	@doc: str.strip
+	@type:
+		function
+	@title:
+		$str.strip
+	@short:
 		Returns a whitespace stripped string
-    @syntax:
-        <string> $str.strip(<string:string>)
-    @description:
+	@syntax:
+		<string> $str.strip(<string:string>)
+	@description:
 		Returns a left and right whitespace stripped version of the string given as the
 		first parameter.
 */
@@ -901,16 +911,16 @@ static bool str_kvs_fnc_strip(KviKvsModuleFunctionCall * c)
 	return true;
 }
 /*
-    @doc: str.stripleft
-    @type:
-        function
-    @title:
-        $str.stripleft
-    @short:
+	@doc: str.stripleft
+	@type:
+		function
+	@title:
+		$str.stripleft
+	@short:
 		Returns a left whitespace stripped string
-    @syntax:
-        <string> $str.stripleft(<string:string>)
-    @description:
+	@syntax:
+		<string> $str.stripleft(<string:string>)
+	@description:
 		Returns a left whitespace stripped version of the string given as the
 		first parameter.
 */
@@ -931,16 +941,16 @@ static bool str_kvs_fnc_stripleft(KviKvsModuleFunctionCall * c)
 	return true;
 }
 /*
-    @doc: str.stripright
-    @type:
-        function
-    @title:
-        $str.stripright
-    @short:
+	@doc: str.stripright
+	@type:
+		function
+	@title:
+		$str.stripright
+	@short:
 		Returns a right whitespace stripped string
-    @syntax:
-        <string> $str.stripright(<string:string>)
-    @description:
+	@syntax:
+		<string> $str.stripright(<string:string>)
+	@description:
 		Returns a right whitespace stripped version of the string given as the
 		first parameter.
 */
@@ -959,16 +969,16 @@ static bool str_kvs_fnc_stripright(KviKvsModuleFunctionCall * c)
 }
 
 /*
-    @doc: str.stripcolors
-    @type:
-        function
-    @title:
-        $str.stripcolors
-    @short:
+	@doc: str.stripcolors
+	@type:
+		function
+	@title:
+		$str.stripcolors
+	@short:
 		Returns a mirc color codes stripped string
-    @syntax:
-        <string> $str.stripcolors(<string:string>)
-    @description:
+	@syntax:
+		<string> $str.stripcolors(<string:string>)
+	@description:
 		Removes all mirc color codes from a string, including also bold, underline, reverse,
 		icon, crypting and ctcp control codes.
 */
@@ -1244,7 +1254,7 @@ static bool str_kvs_fnc_rightfromlast(KviKvsModuleFunctionCall * c)
 			[cmd]if[/cmd]($str.match(H*y*i?K*a,%test))[cmd]echo[/cmd] "Matches H*y*i?K*a"
 		[/example]
 	@seealso:
-		[fnc]$str.matchnocase[/fnc]()
+		[fnc]$str.matchnocase[/fnc]
 */
 
 static bool str_kvs_fnc_match(KviKvsModuleFunctionCall * c)
@@ -1290,7 +1300,7 @@ static bool str_kvs_fnc_match(KviKvsModuleFunctionCall * c)
 			[cmd]if[/cmd]($str.match(G*if?sx,%test))[cmd]echo[/cmd] "Matches G*if?sx"
 		[/example]
 	@seealso:
-		[fnc]$str.match[/fnc]()
+		[fnc]$str.match[/fnc]
 */
 
 static bool str_kvs_fnc_matchnocase(KviKvsModuleFunctionCall * c)
@@ -1333,7 +1343,7 @@ static bool str_kvs_fnc_matchnocase(KviKvsModuleFunctionCall * c)
 			[cmd]echo[/cmd] $str.word(4,%test)
 		[/example]
 	@seealso:
-		[fnc]$str.token[/fnc]()
+		[fnc]$str.token[/fnc]
 */
 
 static bool str_kvs_fnc_word(KviKvsModuleFunctionCall * c)
@@ -1389,7 +1399,7 @@ static bool str_kvs_fnc_word(KviKvsModuleFunctionCall * c)
 		[fnc]$str.word[/fnc]() is an optimized function dedicated to the special case
 		in that <separators> is a string containing all the whitespace characters.[br]
 		Please note that this function is SLOW. You might want to take a look at [fnc]$str.word[/fnc]()
-		or even better to [fnc]$split[/fnc]().[br]
+		or even better to [fnc]$str.split[/fnc]().[br]
 		This function is case sensitive: you need to specify both cases in the <separators> string
 		if you want to do a case insensitive tokenization.[br]
 	@examples:
@@ -1398,8 +1408,8 @@ static bool str_kvs_fnc_word(KviKvsModuleFunctionCall * c)
 			[cmd]echo[/cmd] $str.token(1," hoursmintecd",%test)
 		[/example]
 	@seealso:
-		[fnc]$str.word[/fnc]()[br]
-		[fnc]$split[/fnc]()[br]
+		[fnc]$str.word[/fnc][br]
+		[fnc]$str.split[/fnc][br]
 */
 
 static bool str_kvs_fnc_token(KviKvsModuleFunctionCall * c)
@@ -1505,7 +1515,7 @@ static bool str_kvs_fnc_charsum(KviKvsModuleFunctionCall * c)
 	@syntax:
 		<string> $str.digest(<data:string>[,<algorythm:string>])
 	@description:
-		Calcilates digest for given string,using algorytm,passed as 2nd argument.
+		Calculates digest for given string using algorithm passed as 2nd argument.
 		Currently supported: md5, md4, md2, sha1, mdc2, ripemd160, dss1
 		Default is md5. Requires OpenSSL support
 */
@@ -1640,7 +1650,7 @@ static bool str_kvs_fnc_join(KviKvsModuleFunctionCall * c)
 	@title:
 		$str.grep
 	@short:
-		Emulates the GNU Regular ExPression engine
+		Emulates the GNU Regular Expression Parser
 	@syntax:
 		<array> $str.grep(<match:string>,<strings:array>[,<flags:string>])
 	@description:
@@ -1659,7 +1669,7 @@ static bool str_kvs_fnc_join(KviKvsModuleFunctionCall * c)
 			[comment]# Find all the nicknames starting with the letter A or a[/comment]
 			[cmd]echo[/cmd] $str.grep("^a",[fnc]$chan.users[/fnc],"r")
 			[comment]# Find the current CPU speed (on UNIX like machines only)[/comment]
-			[cmd]echo[/cmd] $str.grep("MHz",[fnc]$split[/fnc]([fnc]$lf[/fnc],[fnc]$file.read[/fnc]("/proc/cpuinfo")))
+			[cmd]echo[/cmd] $str.grep("MHz",[fnc]$str.split[/fnc]([fnc]$lf[/fnc],[fnc]$file.read[/fnc]("/proc/cpuinfo")))
 			[comment]# simply check if the specified string matches a regular expression[/comment]
 			[comment]# (this in fact is a little tricky, but you will probably not notice it :D)[/comment]
 			[cmd]if[/cmd]($str.grep("[st]+","test string","r"))[cmd]echo[/cmd] "Yeah, it matches!"
@@ -1981,12 +1991,14 @@ static bool str_kvs_fnc_printf(KviKvsModuleFunctionCall * c)
 	
 		KviKvsVariant * pVar;
 	
+		pVar = vArgs.first();
+
 		for(; fmt->unicode() ; ++fmt)
 		{
 			if(reallen == allocsize)INCREMENT_MEM
 	
 			//copy up to a '?'
-			if(*fmt != '?')
+			if(fmt->unicode() != '?')
 			{
 				*p++ = *fmt;
 				reallen++;
@@ -1994,12 +2006,11 @@ static bool str_kvs_fnc_printf(KviKvsModuleFunctionCall * c)
 			}
 	
 			++fmt; //skip this '?'
-			switch(*fmt)
+			switch(fmt->unicode())
 			{
 				case 's':
 				{
 					QString sz;
-					pVar = vArgs.first();
 					if(pVar)pVar->asString(sz);
 					if(sz.isEmpty())continue;
 					int len = sz.length();
@@ -2007,11 +2018,11 @@ static bool str_kvs_fnc_printf(KviKvsModuleFunctionCall * c)
 					const QChar * ch = sz.unicode();
 					while(len--)*p++ = *ch++;
 					reallen += sz.length();
+					pVar = vArgs.next();
 					continue;
 				}
 				case 'd': //signed integer
 				{
-					pVar = vArgs.first();
 					if(pVar)
 					{
 						if(!pVar->asInteger(argValue))
@@ -2043,11 +2054,11 @@ static bool str_kvs_fnc_printf(KviKvsModuleFunctionCall * c)
 					if((allocsize - reallen) < (int)argUValue)INCREMENT_MEM_BY(argUValue)
 					do { *p++ = QChar(*--pNumBuf); } while(pNumBuf != numberBuffer);
 					reallen += argUValue;
+					pVar = vArgs.next();
 					continue;
 				}
 				case 'u': //unsigned integer
 				{
-					pVar = vArgs.first();
 					if(pVar)
 					{
 						if(!pVar->asInteger(argValue))
@@ -2071,6 +2082,7 @@ static bool str_kvs_fnc_printf(KviKvsModuleFunctionCall * c)
 					if((allocsize - reallen) < argValue)INCREMENT_MEM_BY(argValue)
 					do { *p++ = *--pNumBuf; } while(pNumBuf != numberBuffer);
 					reallen += argValue;
+					pVar = vArgs.next();
 					continue;
 				}
 				case 'h':
@@ -2078,7 +2090,6 @@ static bool str_kvs_fnc_printf(KviKvsModuleFunctionCall * c)
 				{
 					static char hexsmalldigits[]="0123456789abcdef";
 	
-					pVar = vArgs.first();
 					if(pVar)
 					{
 						if(!pVar->asInteger(argValue))
@@ -2103,13 +2114,13 @@ static bool str_kvs_fnc_printf(KviKvsModuleFunctionCall * c)
 					if((allocsize - reallen) < argValue)INCREMENT_MEM_BY(argValue)
 					do { *p++ = *--pNumBuf; } while(pNumBuf != numberBuffer);
 					reallen += argValue;
+					pVar = vArgs.next();
 					continue;
 				}
 				case 'H':
 				case 'X': // hexadecimal unsigned integer
 				{
 					static char hexbigdigits[]="0123456789ABCDEF";
-					pVar = vArgs.first();
 					if(pVar)
 					{
 						if(!pVar->asInteger(argValue))
@@ -2133,11 +2144,12 @@ static bool str_kvs_fnc_printf(KviKvsModuleFunctionCall * c)
 					if((allocsize - reallen) < argValue)INCREMENT_MEM_BY(argValue)
 					do { *p++ = *--pNumBuf; } while(pNumBuf != numberBuffer);
 					reallen += argValue;
+					pVar = vArgs.next();
 					continue;
 				}
 				case '?':
 				{
-					if(*fmt)
+					if(fmt->unicode())
 					{
 						if(reallen == allocsize)INCREMENT_MEM
 						*p++ = *fmt;
@@ -2170,7 +2182,6 @@ static bool str_kvs_fnc_printf(KviKvsModuleFunctionCall * c)
 					fmtbuffer[idx] = fmt->unicode();
 					fmtbuffer[idx+1] = 0;
 	
-					pVar = vArgs.first();
 					if(pVar)
 					{
 						if(!pVar->asReal(argRValue))
@@ -2201,7 +2212,7 @@ static bool str_kvs_fnc_printf(KviKvsModuleFunctionCall * c)
 							fmt = save;
 							*p++ = '?';  //write it
 							reallen++;
-							if(*fmt)
+							if(fmt->unicode())
 							{
 								if(reallen == allocsize)INCREMENT_MEM
 								*p++ = *fmt;
@@ -2209,6 +2220,7 @@ static bool str_kvs_fnc_printf(KviKvsModuleFunctionCall * c)
 							}
 						break;
 					}
+					pVar = vArgs.next();
 					continue;
 				}
 				break;
@@ -2216,7 +2228,7 @@ static bool str_kvs_fnc_printf(KviKvsModuleFunctionCall * c)
 				{
 					*p++ = '?';  //write it
 					reallen++;
-					if(*fmt)
+					if(fmt->unicode())
 					{
 						if(reallen == allocsize)INCREMENT_MEM
 						*p++ = *fmt;
@@ -2308,8 +2320,8 @@ KVIRC_MODULE(
 	"1.0.0",                                                // module version
 	"Copyright (C) 2002 Szymon Stefanek (pragma at kvirc dot net)"\
 	"          (C) 2002 Juanjo Alvarez (juanjux@yahoo.es)" \
-    "          (C) 2005 Tonino Imbesi (grifisx at barmes dot org)" \
-    "          (C) 2005 Alessandro Carbone (noldor at barmes dot org)", // author & (C)
+	"          (C) 2005 Tonino Imbesi (grifisx at barmes dot org)" \
+	"          (C) 2005 Alessandro Carbone (noldor at barmes dot org)", // author & (C)
 	"Interface to the str system",
 	str_module_init,
 	0,
