@@ -25,12 +25,15 @@
 #include "kvi_settings.h"
 #include "kvi_module.h"
 #include "kvi_string.h"
-//#include "kvi_uparser.h"
+#include "kvi_library.h"
+#include "kvi_thread.h"
+
 #include "kvi_locale.h"
-#include "kvi_command.h"
+#include "kvi_qcstring.h"
 #include "kvi_app.h"
 #include "kvi_env.h"
 #include "kvi_osinfo.h"
+#include "kvi_qcstring.h"
 
 #include <qclipboard.h>
 
@@ -44,6 +47,12 @@
 	#include <dcopclient.h>
 #endif
 
+#include "kvi_modulemanager.h"
+
+#include "plugin.h"
+
+KviPluginManager * g_pPluginManager;
+
 /*
 	@doc: system.ostype
 	@type:
@@ -194,11 +203,11 @@ static bool system_kvs_fnc_getenv(KviKvsModuleFunctionCall *c)
 		KVSM_PARAMETER("variable",KVS_PT_NONEMPTYSTRING,0,szVariable)
 	KVSM_PARAMETERS_END(c)
 
-	QCString szVar = szVariable.local8Bit();
+	KviQCString szVar = szVariable.local8Bit();
 #ifdef COMPILE_ON_WINDOWS
 	QString env = getenv(szVar.data());
 	QString def = __tr2qs("No environment variable found, please don't use the %% in the request");
-	c->returnValue()->setString(env ? QString::fromLocal8Bit(env) : QString::fromLocal8Bit(def));
+	c->returnValue()->setString(env.isEmpty() ? QString::fromLocal8Bit(env) : QString::fromLocal8Bit(def));
 #else
 	char * b = kvi_getenv(szVar.data());
 	c->returnValue()->setString(b ? QString::fromLocal8Bit(b) : QString::null);
@@ -224,7 +233,7 @@ static bool system_kvs_fnc_getenv(KviKvsModuleFunctionCall *c)
 		of "selection" (most notably X11) which is NOT the same as the clipboard.
 		See [fnc]$system.selection[/fnc]().
 	@seealso:
-		[fnc]$system.selection[/fnc](),
+		[fnc]$system.selection[/fnc],
 		[cmd]system.setClipboard[/cmd],
 		[cmd]system.setSelection[/cmd]
 */
@@ -254,8 +263,8 @@ static bool system_kvs_fnc_clipboard(KviKvsModuleFunctionCall *c)
 		of "selection" (most notably X11) which is NOT the same as the clipboard.
 		See [fnc]$system.selection[/fnc]().
 	@seealso:
-		[fnc]$system.selection[/fnc](),
-		[fnc]$system.clipboard[/fnc](),
+		[fnc]$system.selection[/fnc],
+		[fnc]$system.clipboard[/fnc],
 		[cmd]system.setSelection[/cmd]
 */
 
@@ -287,8 +296,8 @@ static bool system_kvs_cmd_setClipboard(KviKvsModuleCommandCall * c)
 		Please note that this command will work only on systems that have the concept
 		of "selection" (most notably X11) which is NOT the same as the clipboard.
 	@seealso:
-		[fnc]$system.selection[/fnc](),
-		[fnc]$system.clipboard[/fnc](),
+		[fnc]$system.selection[/fnc],
+		[fnc]$system.clipboard[/fnc],
 		[cmd]system.setClipboard[/cmd]
 */
 
@@ -321,7 +330,7 @@ static bool system_kvs_cmd_setSelection(KviKvsModuleCommandCall * c)
 		On other systems this function will always return an empty string.
 		See [fnc]$system.clipboard[/fnc]().
 	@seealso:
-		[fnc]$system.clipboard[/fnc](),
+		[fnc]$system.clipboard[/fnc],
 		[cmd]system.setClipboard[/cmd],
 		[cmd]system.setSelection[/cmd]
 */
@@ -333,6 +342,39 @@ static bool system_kvs_fnc_selection(KviKvsModuleFunctionCall *c)
 }
 
 
+/*
+	@doc: system.checkModule
+	@keyterms:
+		Module checking
+	@type:
+		function
+	@title:
+		$system.checkModule
+	@short:
+		Checks if a KVIrc module is loadable
+	@syntax:
+		<boolean> $system.checkModule(<module_name:string>)
+	@description:
+		Attempts to load the specified module and returns
+		$true if succesfull and $false otherwise. This can
+		be effectively used to test if a KVIrc exension module
+		is present on the system and can be loaded by the
+		KVIrc engine.
+*/
+
+static bool system_kvs_fnc_checkModule(KviKvsModuleFunctionCall *c)
+{
+	QString szModuleName;
+
+	KVSM_PARAMETERS_BEGIN(c)
+		KVSM_PARAMETER("module_name",KVS_PT_STRING,0,szModuleName)
+	KVSM_PARAMETERS_END(c)
+
+	c->returnValue()->setBoolean(g_pModuleManager->loadModule(szModuleName.utf8().data()));
+	return true;
+}
+
+
 /*
 	@doc: system.hostname
 	@keyterms:
@@ -382,7 +424,7 @@ static bool system_kvs_fnc_hostname(KviKvsModuleFunctionCall *c)
 		The parameters MUST be in the form "type=value"
 		where "type" is the C++ type of the parameter and value
 		is the string rappresentation of the parameter data. Currently
-		KVIrc supports only QString,QCString,bool,int and uint data types.[br]
+		KVIrc supports only QString,KviQCString,bool,int and uint data types.[br]
 		The returned value is the string rappresentation of the returned
 		data if the return type is known, otherwise it is the name of the data type returned.
 		[br]
@@ -407,7 +449,7 @@ static bool system_kvs_fnc_dcop(KviKvsModuleFunctionCall *c)
 {
 	bool bTestMode = false;
 
-	QCString szApp,szObj,szFun;
+	KviQCString szApp,szObj,szFun;
 	QStringList parms;
 	
 	KVSM_PARAMETERS_BEGIN(c)
@@ -458,9 +500,9 @@ static bool system_kvs_fnc_dcop(KviKvsModuleFunctionCall *c)
 		{
 			QString ddd = tmp.ptr();
 			ds << ddd;
-		} else if(kvi_strEqualCI("QCString",szType.ptr()))
+		} else if(kvi_strEqualCI("KviQCString",szType.ptr()))
 		{
-			QCString qcs = tmp.ptr();
+			KviQCString qcs = tmp.ptr();
 			ds << qcs;
 		} else if(kvi_strEqualCI("bool",szType.ptr()))
 		{
@@ -482,7 +524,7 @@ static bool system_kvs_fnc_dcop(KviKvsModuleFunctionCall *c)
 	}
 
 	QByteArray rba;
-	QCString szRetType;
+	KviQCString szRetType;
 
 	bool bRet = g_pApp->dcopClient()->call(szApp,szObj,szFun,ba,szRetType,rba);
 
@@ -508,7 +550,7 @@ static bool system_kvs_fnc_dcop(KviKvsModuleFunctionCall *c)
 				c->returnValue()->setString(szz);
 			} else if(szRetType == "QCString")
 			{
-				QCString sss;
+				KviQCString sss;
 				ret >> sss;
 				c->returnValue()->setString(sss.data());
 			} else if((szRetType == "uint") || (szRetType == "unsigned int") || (szRetType == "Q_UINT32"))
@@ -523,6 +565,7 @@ static bool system_kvs_fnc_dcop(KviKvsModuleFunctionCall *c)
 				c->returnValue()->setInteger(iii);
 			} else if(szRetType == "QCStringList")
 			{
+#ifndef COMPILE_USE_QT4
 				QCStringList csl;
 				ret >> csl;
 				KviKvsArray * arry = new KviKvsArray();
@@ -533,6 +576,7 @@ static bool system_kvs_fnc_dcop(KviKvsModuleFunctionCall *c)
 					idx++;
 				}
 				c->returnValue()->setArray(arry);
+#endif
 			} else if(szRetType == "QStringList")
 			{
 				QStringList csl;
@@ -576,7 +620,7 @@ static bool system_kvs_fnc_dcop(KviKvsModuleFunctionCall *c)
 		Sets the enviroinement <variable> to the <value> string.[br]
 		If <value> is not given , the <variable> is unset.[br]
 	@seealso:
-		[fnc]$system.getenv[/fnc]()
+		[fnc]$system.getenv[/fnc]
 */
 
 
@@ -589,8 +633,8 @@ static bool system_kvs_cmd_setenv(KviKvsModuleCommandCall * c)
 		KVSM_PARAMETER("value",KVS_PT_STRING,KVS_PF_OPTIONAL,szValue)
 	KVSM_PARAMETERS_END(c)
 
-	QCString szVar = szVariable.local8Bit();
-	QCString szVal = szValue.local8Bit();
+	KviQCString szVar = szVariable.local8Bit();
+	KviQCString szVal = szValue.local8Bit();
 
 	if(szVal.isEmpty())kvi_unsetenv(szVar.data());
 	else
@@ -608,6 +652,50 @@ static bool system_kvs_cmd_setenv(KviKvsModuleCommandCall * c)
 	return true;
 }
 
+/*
+	@doc: system.call
+	@keyterms:
+		call plugin
+	@type:
+		function
+	@title:
+		$system.call
+	@short:
+		Allows to call functions of a plugin
+	@syntax:
+		<string> $system.call(<plugin:string>, <function:string>[,<parameters:string>,...])
+	@description:
+		This function allows you to call simple functions of "easyplugins" (dll/so) and
+		get the result of this function. The easyplugins have to be coded in a special way.
+		If you want to write your own easyplugins, have a look on the easyplugins documentation.
+		[br]
+		[br]
+		The function needs a minimum of 2 parameters. The others are optional and not limited.[br]
+		The first one is the complete name like "example.dll" or "example.so"
+		If you have a relative path or only the filename KVIrc looks for the easyplugins in the following dirs:[br]
+		In a subdir called "easyplugins" in the local and global KVIrc directory.
+		If you give an absolute path KVIrc will load it directly.
+		[br]
+		[br]
+		You are free to add more parameters, they will be given to the easyplugin.[br]
+		The easyplugin decides how much parameters you need in addition to the first 2.
+		[br]
+		[br]
+		[b]Warning:  Only use easyplugins of known and trustable sources![/b]
+	@examples:
+		[example]
+			echo $system.call("my.dll","myfunction")
+			echo $system.call("my.dll","myfunction","parameter1","parameter2")
+			echo $system.call("c:/my.dll","myfunction")
+			echo $system.call("my.so","myfunction","parameter1")
+		[/example]
+*/
+
+
+static bool system_kvs_fnc_plugin_call(KviKvsModuleFunctionCall *c)
+{
+	return g_pPluginManager->pluginCall(c);
+}
 
 static bool system_module_init(KviModule * m)
 {
@@ -622,16 +710,28 @@ static bool system_module_init(KviModule * m)
 	KVSM_REGISTER_FUNCTION(m,"dcop",system_kvs_fnc_dcop);
 	KVSM_REGISTER_FUNCTION(m,"clipboard",system_kvs_fnc_clipboard);
 	KVSM_REGISTER_FUNCTION(m,"selection",system_kvs_fnc_selection);
+	KVSM_REGISTER_FUNCTION(m,"checkModule",system_kvs_fnc_checkModule);
+	KVSM_REGISTER_FUNCTION(m,"call",system_kvs_fnc_plugin_call);
 
 	KVSM_REGISTER_SIMPLE_COMMAND(m,"setenv",system_kvs_cmd_setenv);
 	KVSM_REGISTER_SIMPLE_COMMAND(m,"setClipboard",system_kvs_cmd_setClipboard);
 	KVSM_REGISTER_SIMPLE_COMMAND(m,"setSelection",system_kvs_cmd_setSelection);
 
+	g_pPluginManager = new(KviPluginManager);
+	
 	return true;
 }
 
 static bool system_module_cleanup(KviModule *m)
 {
+	g_pPluginManager->unloadAll();
+	delete g_pPluginManager;
+	return true;
+}
+
+static bool system_module_can_unload(KviModule *m)
+{
+	if(!g_pPluginManager->checkUnload()) return false;
 	return true;
 }
 
@@ -643,7 +743,7 @@ KVIRC_MODULE(
 	"			(C) 2005 Alessandro Carbone (noldor at barmes dot org)",// author & (C)
 	"System informations module",
 	system_module_init,
-	0,
+	system_module_can_unload,
 	0,
 	system_module_cleanup
 )
