@@ -29,7 +29,7 @@
 #include "kvi_locale.h"
 
 #include <qlabel.h>
-#include "kvi_list.h"
+#include "kvi_pointerlist.h"
 #include <qtooltip.h>
 #include <qtimer.h>
 
@@ -40,8 +40,8 @@
 #include "kparts/factory.h"
 
 extern KviModule            * g_pTermModule;
-extern KviPtrList<KviTermWidget> * g_pTermWidgetList;
-extern KviPtrList<KviTermWindow> * g_pTermWindowList;
+extern KviPointerList<KviTermWidget> * g_pTermWidgetList;
+extern KviPointerList<KviTermWindow> * g_pTermWindowList;
 extern KviStr                 g_szKonsoleLibraryName;
 
 KviTermWidget::KviTermWidget(QWidget * par,KviFrame * lpFrm,bool bIsStandalone)
@@ -55,7 +55,7 @@ KviTermWidget::KviTermWidget(QWidget * par,KviFrame * lpFrm,bool bIsStandalone)
 
 	if(bIsStandalone)
 	{
-		m_pHBox = new QHBox(this);
+		m_pHBox = new KviTalHBox(this);
 		m_pTitleLabel = new QLabel(__tr2qs("Terminal emulator"),m_pHBox);
 		m_pTitleLabel->setFrameStyle(QFrame::Raised | QFrame::WinPanel);
 		m_pCloseButton = new QPushButton("",m_pHBox);
