@@ -26,13 +26,23 @@
 
 #include "kvi_locale.h"
 #include "kvi_app.h"
-//#include "kvi_uparser.h"
+
 #include "kvi_iconmanager.h"
 #include "kvi_options.h"
 #include "kvi_fileutils.h"
 
 #include <qpushbutton.h>
+
+#ifdef COMPILE_USE_QT4
+#include <q3simplerichtext.h>
+#include <QDesktopWidget>
+#include <QCloseEvent>
+#define KviTalSimpleRichText Q3SimpleRichText
+#else
 #include <qsimplerichtext.h>
+#define KviTalSimpleRichText QSimpleRichText
+#endif
+
 #include <qfont.h>
 #include <qtextcodec.h>
 #include <qpainter.h>
@@ -54,7 +64,11 @@ KviTipFrame::KviTipFrame(QWidget * par)
 	KviStr buffer;
 	g_pApp->findImage(buffer,"kvi_tip.png");
 	m_pTipPixmap = new QPixmap(buffer.ptr());
+#ifdef COMPILE_USE_QT4
+	setBackgroundMode(Qt::NoBackground);
+#else
 	setBackgroundMode(QWidget::NoBackground);
+#endif
 	setFrameStyle(QFrame::Sunken | QFrame::WinPanel);
 }
 
@@ -79,7 +93,8 @@ void KviTipFrame::drawContents(QPainter *p)
 	QFont f = QFont();
 	f.setStyleHint(QFont::SansSerif);
 	f.setPointSize(12);
-	QSimpleRichText doc(m_szText,f);
+
+	KviTalSimpleRichText doc(m_szText,f);
 	doc.setWidth(width() - 80);
 
 	QRegion reg(0,0,1000,20000);
@@ -251,7 +266,7 @@ void KviTipWindow::closeEvent(QCloseEvent *e)
 
 
 static bool tip_kvs_cmd_open(KviKvsModuleCommandCall * c)
-{ 
+{
 	QString szTipfilename;
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("filename",KVS_PT_STRING,KVS_PF_OPTIONAL,szTipfilename)
