@@ -24,9 +24,9 @@
 
 #include "toolbareditor.h"
 #include "kvi_module.h"
-//#include "kvi_uparser.h"
+
 #include "kvi_locale.h"
-#include "kvi_command.h"
+
 #include "kvi_frame.h"
 #include "kvi_actionmanager.h"
 #include "kvi_config.h"
