@@ -34,18 +34,20 @@
 #include "kvi_fileutils.h"
 #include "kvi_filedialog.h"
 #include "kvi_kvs_useraction.h"
+#include "kvi_draganddrop.h"
 
 #include <qpushbutton.h>
 #include <qlayout.h>
 #include <qapplication.h>
 #include <qtooltip.h>
-#include <qdragobject.h>
+
 #include <qlineedit.h>
 #include <qlabel.h>
 #include <qmessagebox.h>
 #include <qframe.h>
 #include <qdir.h>
 #include <qtimer.h>
+#include <qevent.h>
 
 KviCustomizeToolBarsDialog * KviCustomizeToolBarsDialog::m_pInstance = 0;
 extern QRect g_rectToolBarEditorDialogGeometry;
@@ -59,7 +61,7 @@ KviTrashcanLabel::KviTrashcanLabel(QWidget * p)
 	QToolTip::add(this,__tr2qs("Drop here the icons from the toolbars to remove them"));
 	setFrameStyle(QFrame::Sunken | QFrame::WinPanel);
 	setAcceptDrops(true);
-	setAlignment(AlignCenter);
+	setAlignment(Qt::AlignCenter);
 	setMinimumSize(40,40);
 	m_uFlashCount = 0;
 	m_pFlashTimer = 0;
@@ -103,14 +105,14 @@ void KviTrashcanLabel::heartbeat()
 
 void KviTrashcanLabel::dropEvent(QDropEvent * e)
 {
-	if(QTextDrag::canDecode(e))
+	if(KviTextDrag::canDecode(e))
 		e->accept();
 }
 
 void KviTrashcanLabel::dragEnterEvent(QDragEnterEvent * e)
 {
 	QString s;
-	if(QTextDrag::decode(e,s))
+	if(KviTextDrag::decode(e,s))
 		e->accept();
 }
 
@@ -404,7 +406,7 @@ void KviCustomizeToolBarsDialog::exportToolBar()
 
 	if(bExportActions)
 	{
-		KviPtrList<QString> * a = t->descriptor()->actions();
+		KviPointerList<QString> * a = t->descriptor()->actions();
 		if(a)
 		{
 			for(QString * s = a->first();s;s = a->next())
@@ -430,7 +432,7 @@ void KviCustomizeToolBarsDialog::exportToolBar()
 	szCode += t->descriptor()->iconId();
 	szCode += "\n";
 
-	KviPtrList<QString> * aa = t->descriptor()->actions();
+	KviPointerList<QString> * aa = t->descriptor()->actions();
 	if(aa)
 	{
 		for(QString * ss = aa->first();ss;ss = aa->next())
