@@ -17,14 +17,14 @@
 //   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 //
 
-
 #include "kvi_styled_controls.h"
 #include "kvi_module.h"
 #include "libkviurl.h"
 #include "kvi_app.h"
 #include "kvi_frame.h"
 #include "kvi_kvs_eventmanager.h"
-//#include "kvi_uparser.h"
+#include "kvi_tal_popupmenu.h"
+
 #include "kvi_menubar.h"
 #include "kvi_internalcmd.h"
 #include "kvi_iconmanager.h"
@@ -32,11 +32,16 @@
 #include "kvi_actionmanager.h"
 #include "kvi_taskbar.h"
 #include "icons.h"
-#include "kvi_list.h"
+#include "kvi_pointerlist.h"
 #include <qfiledialog.h>
 #include <qmessagebox.h>
 #include <qcursor.h>
+#include <qdatetime.h>
 
+#ifdef COMPILE_USE_QT4
+	#include <q3textstream.h>
+	#include <QTextStream>
+#endif
 
 static QPixmap * g_pUrlIconPixmap = 0;
 static KviUrlAction * g_pUrlAction = 0;
@@ -50,9 +55,9 @@ typedef struct _UrlDlgList
 const char *g_pUrlListFilename = "/list.kviurl";
 const char *g_pBanListFilename = "/list.kviban";
 
-KviPtrList<KviUrl> *g_pList;
-KviPtrList<UrlDlgList> *g_pUrlDlgList;
-KviPtrList<KviStr> *g_pBanList;
+KviPointerList<KviUrl> *g_pList;
+KviPointerList<UrlDlgList> *g_pUrlDlgList;
+KviPointerList<KviStr> *g_pBanList;
 ConfigDialog *g_pConfigDialog;
 
 KviStr szConfigPath;
@@ -105,23 +110,23 @@ QPixmap * KviUrlAction::smallIcon()
 
 // ---------------------------- CLASS URLDIALOG ------------------------begin //
 
-UrlDialog::UrlDialog(KviPtrList<KviUrl> *g_pList)
+UrlDialog::UrlDialog(KviPointerList<KviUrl> *g_pList)
 :KviWindow(KVI_WINDOW_TYPE_TOOL,g_pFrame,"URL List")
 {
 	m_pMenuBar = new KviTalMenuBar(this,"url menu");
-	m_pUrlList = new QListView(this,"list");
+	m_pUrlList = new KviTalListView(this);
 	//m_pUrlList = new KviListView(this,"list");
 	KviConfig cfg(szConfigPath.ptr(),KviConfig::Read);
 
-	QPopupMenu *pop;
+	KviTalPopupMenu *pop;
 
-	pop = new QPopupMenu(this);
+	pop = new KviTalPopupMenu(this);
 	pop->insertItem(__tr2qs("&Configure"),this,SLOT(config()));
 	pop->insertItem(__tr2qs("&Help"),this,SLOT(help()));
 	pop->insertItem(__tr2qs("Clo&se"),this,SLOT(close_slot()));
 	m_pMenuBar->insertItem(__tr2qs("&Module"),pop);
 
-	pop = new QPopupMenu(this);
+	pop = new KviTalPopupMenu(this);
 	pop->insertItem(__tr2qs("&Load"),this,SLOT(loadList()));
 	pop->insertItem(__tr2qs("&Save"),this,SLOT(saveList()));
 	pop->insertItem(__tr2qs("&Clear"),this,SLOT(clear()));
@@ -139,11 +144,15 @@ UrlDialog::UrlDialog(KviPtrList<KviUrl> *g_pList)
 	m_pUrlList->setColumnWidth(2,cfg.readIntEntry("Count",70));
 	m_pUrlList->setColumnWidth(3,cfg.readIntEntry("Timestamp",70));
 
-	connect(m_pUrlList,SIGNAL(doubleClicked(QListViewItem *)),SLOT(dblclk_url(QListViewItem *)));
-	connect(m_pUrlList,SIGNAL(rightButtonPressed(QListViewItem *, const QPoint &, int)),SLOT(popup(QListViewItem *, const QPoint &, int)));
+	connect(m_pUrlList,SIGNAL(doubleClicked(KviTalListViewItem *)),SLOT(dblclk_url(KviTalListViewItem *)));
+	connect(m_pUrlList,SIGNAL(rightButtonPressed(KviTalListViewItem *, const QPoint &, int)),SLOT(popup(KviTalListViewItem *, const QPoint &, int)));
 
 //	setFocusHandlerNoChildren(m_pUrlList);
+#ifdef COMPILE_USE_QT4
+	m_pUrlList->setFocusPolicy(Qt::StrongFocus);
+#else
 	m_pUrlList->setFocusPolicy(QWidget::StrongFocus);
+#endif
 	m_pUrlList->setFocus();
 }
 
@@ -207,11 +216,11 @@ void UrlDialog::remove()
 		QMessageBox::warning(0,__tr2qs("Warning - KVIrc"),__tr2qs("Select an URL."),QMessageBox::Ok,QMessageBox::NoButton,QMessageBox::NoButton);
 		return;
 	}
+
 	for(KviUrl *tmp=g_pList->first();tmp;tmp=g_pList->next())
 	{
 		if (tmp->url == m_pUrlList->currentItem()->text(0)) {
-			g_pList->find(tmp);
-			g_pList->remove();
+			g_pList->removeRef(tmp);
 			m_pUrlList->takeItem(m_pUrlList->currentItem());
 			return;
 		}
@@ -244,22 +253,22 @@ void UrlDialog::findtext()
 */
 }
 
-void UrlDialog::dblclk_url(QListViewItem *item)
+void UrlDialog::dblclk_url(KviTalListViewItem *item)
 {
 	QString cmd="openurl ";
 	cmd.append(item->text(0));
 	KviKvsScript::run(cmd,this);
 }
 
-void UrlDialog::popup(QListViewItem *item, const QPoint &point, int col)
+void UrlDialog::popup(KviTalListViewItem *item, const QPoint &point, int col)
 {
 	if (col == 0) {
 		m_szUrl = item->text(0);
-		QPopupMenu p(0,"menu");
+		KviTalPopupMenu p(0,"menu");
 		p.insertItem(__tr2qs("&Remove"),this,SLOT(remove()));
 		p.insertItem(__tr2qs("&Find Text"),this,SLOT(findtext()));
 		p.insertSeparator();
-		m_pListPopup = new QPopupMenu(0,"list");
+		m_pListPopup = new KviTalPopupMenu(0,"list");
 		int i=0;
 		for(KviWindow *w=g_pFrame->windowList()->first();w;w=g_pFrame->windowList()->next()){
 			if ((w->type() <= 2) || (w->type() == 2) || (w->type() == 6)) {	// values defined in kvi_define.h (console,channel,query,chat,uwindow)
@@ -294,7 +303,7 @@ QPixmap *UrlDialog::myIconPtr()
 
 void UrlDialog::addUrl(QString url, QString window, QString count, QString timestamp)
 {
-	QListViewItem *UrlItem = new QListViewItem(m_pUrlList);
+	KviTalListViewItem *UrlItem = new KviTalListViewItem(m_pUrlList);
 
 	UrlItem->setText(0, url);
 	UrlItem->setText(1, window);
@@ -416,7 +425,7 @@ BanFrame::BanFrame(QWidget *parent, const char *name, bool banEnabled)
 	m_pEnable->setChecked(banEnabled);
 	g->addMultiCellWidget(m_pEnable,0,0,0,1);
 
-	m_pBanList = new QListBox(this,"listbox");
+	m_pBanList = new KviTalListBox(this);
 	m_pBanList->setMinimumHeight(100);
 	loadBanList();
 	for(KviStr *tmp=g_pBanList->first();tmp;tmp=g_pBanList->next()) m_pBanList->insertItem(tmp->ptr()); // load ban list into listbox
@@ -462,7 +471,11 @@ void BanFrame::removeBan()
 	KviStr item(m_pBanList->text(i).utf8().data());
 	for(KviStr *tmp=g_pBanList->first();tmp;tmp=g_pBanList->next())
 	{
-		if (*tmp == item) g_pBanList->remove();
+		if (*tmp == item)
+		{
+			g_pBanList->removeCurrent();
+			return;
+		}
 	}
 
 	m_pBanList->removeItem(i);
@@ -517,7 +530,12 @@ void loadUrlList()
 	QFile file;
 	file.setName(QString::fromUtf8(urllist.ptr()));
 	if (!file.open(IO_ReadOnly))return;
+#ifdef COMPILE_USE_QT4
+	Q3TextStream stream(&file);
+#else
 	QTextStream stream(&file);
+#endif
+
 
 	g_pList->clear();
 
@@ -576,8 +594,11 @@ void loadBanList()
 	QFile file;
 	file.setName(QString::fromUtf8(banlist.ptr()));
 	if (!file.open(IO_ReadOnly))return;
+#ifdef COMPILE_USE_QT4
+	Q3TextStream stream(&file);
+#else
 	QTextStream stream(&file);
-
+#endif
 	g_pBanList->clear();
 
 	int i=0;
@@ -616,20 +637,11 @@ void loadBanList()
 
   */
 
-bool urllist_command(KviModule *m,KviCommand *c)
-{
-	ENTER_STACK_FRAME(c,"urllist_command");
-	urllist();
-	return c->leaveStackFrame();
-}
-
-#ifdef COMPILE_NEW_KVS
 static bool url_kvs_cmd_list(KviKvsModuleCommandCall * c)
 {
 	urllist();
 	return true;
 }
-#endif
 
 
 UrlDlgList *findFrame()
@@ -686,20 +698,11 @@ bool urllist()
 		<HR>
   */
 
-bool urllistconfig(KviModule *m,KviCommand *c)
-{
-	ENTER_STACK_FRAME(c,"urllistconfig");
-	if (!g_pConfigDialog) g_pConfigDialog = new ConfigDialog();
-	return c->leaveStackFrame();
-}
-
-#ifdef COMPILE_NEW_KVS
 static bool url_kvs_cmd_config(KviKvsModuleCommandCall * c)
 {
 	if (!g_pConfigDialog) g_pConfigDialog = new ConfigDialog();
 	return true;
 }
-#endif
 
 int check_url(KviWindow *w,const QString &szUrl) // return 0 if no occurence of the url were found
 {
@@ -722,7 +725,7 @@ int check_url(KviWindow *w,const QString &szUrl) // return 0 if no occurence of
 
 	for (UrlDlgList *tmpitem=g_pUrlDlgList->first();tmpitem;tmpitem=g_pUrlDlgList->next()) {
 		if (tmpitem->dlg) {
-			QListViewItemIterator lvi(tmpitem->dlg->m_pUrlList);
+			KviTalListViewItemIterator lvi(tmpitem->dlg->m_pUrlList);
 			for(;lvi.current();++lvi)
 			{
 				if (lvi.current()->text(0) == szUrl) {
@@ -795,13 +798,13 @@ static bool url_module_init(KviModule *m)
 							url_extension_alloc);
 	if(d)d->setIcon(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_URL)));
 
-	g_pList = new KviPtrList<KviUrl>;
+	g_pList = new KviPointerList<KviUrl>;
 	g_pList->setAutoDelete(true);
 
-	g_pUrlDlgList = new KviPtrList<UrlDlgList>;
+	g_pUrlDlgList = new KviPointerList<UrlDlgList>;
 	g_pUrlDlgList->setAutoDelete(true);
 
-	g_pBanList = new KviPtrList<KviStr>;
+	g_pBanList = new KviPointerList<KviStr>;
 	g_pBanList->setAutoDelete(true);
 
 	g_pUrlIconPixmap = new QPixmap(url_icon_xpm);
@@ -835,18 +838,18 @@ static bool url_module_cleanup(KviModule *m)
 	}
 
 	delete g_pList;
-    g_pList = 0;
+	g_pList = 0;
 	delete g_pBanList;
-    g_pBanList = 0;
+	g_pBanList = 0;
 
 	delete g_pUrlDlgList;
-    g_pUrlDlgList = 0;
+	g_pUrlDlgList = 0;
 	delete g_pUrlAction;
 	g_pUrlAction = 0;
 
 
 	delete g_pUrlIconPixmap;
-    g_pUrlIconPixmap = 0;
+	g_pUrlIconPixmap = 0;
 
 	return true;
 }
@@ -859,7 +862,6 @@ static bool url_module_can_unload(KviModule *m)
 
 void url_module_config()
 {
-
 	if (!g_pConfigDialog) g_pConfigDialog = new ConfigDialog();
 }
 
