@@ -23,7 +23,7 @@
 //=================================================================================
 
 #include "kvi_module.h"
-//#include "kvi_uparser.h"
+
 #include "kvi_console.h"
 #include "kvi_options.h"
 #include "kvi_ircsocket.h"
@@ -37,11 +37,11 @@
 #include "kvi_modulemanager.h"
 #include "kvi_memmove.h"
 #include "kvi_malloc.h"
-#include "kvi_scriptobject.h"
+
 #include "kvi_channel.h"
 #include "userwindow.h"
 
-#include <qasciidict.h>
+#include "kvi_pointerhashtable.h"
 #include <qtimer.h>
 
 
@@ -54,8 +54,8 @@
 
 
 // kvi_app.cpp
-extern KVIRC_API QAsciiDict<KviWindow> * g_pGlobalWindowDict;
-KviPtrList<KviUserWindow> * g_pUserWindowList = 0;
+extern KVIRC_API KviPointerHashTable<const char *,KviWindow> * g_pGlobalWindowDict;
+KviPointerList<KviUserWindow> * g_pUserWindowList = 0;
 
 // $window.caption $window.x $window.y $window.width $window.height $window.isActive $window.type
 // $window.input.text $window.input.cursorpos $window.input.textlen
@@ -114,7 +114,7 @@ KviPtrList<KviUserWindow> * g_pUserWindowList = 0;
 		If the specified window does not exist a warning is printed (unless the -q switch is used)
 		but the execution continues normally.
 	@seealso:
-		[fnc]$window.hasOutput[/fnc]()
+		[fnc]$window.hasOutput[/fnc]
 */
 
 static bool window_kvs_cmd_clearOutput(KviKvsModuleCommandCall * c)
@@ -234,8 +234,8 @@ static bool window_kvs_cmd_undock(KviKvsModuleCommandCall * c)
 		no operation is performed. If the specified window
 		does not exist a warning is printed unless the -q switch is used.
 	@seealso:
-		[cmd]window.minimize[/cmd], [cmd]window.restore[/cmd], [fnc]$window.isMaxmimized[/cmd],
-		[fnc]$window.isMinimized[/cmd]
+		[cmd]window.minimize[/cmd], [cmd]window.restore[/cmd], [fnc]$window.isMaxmimized[/fnc],
+		[fnc]$window.isMinimized[/fnc]
 */
 
 static bool window_kvs_cmd_maximize(KviKvsModuleCommandCall * c)
@@ -264,8 +264,8 @@ static bool window_kvs_cmd_maximize(KviKvsModuleCommandCall * c)
 		no operation is performed. If the specified window
 		does not exist a warning is printed unless the -q switch is used.
 	@seealso:
-		[cmd]window.maximize[/cmd], [cmd]window.restore[/cmd], [fnc]$window.isMaxmimized[/cmd],
-		[fnc]$window.isMinimized[/cmd]
+		[cmd]window.maximize[/cmd], [cmd]window.restore[/cmd], [fnc]$window.isMaxmimized[/fnc],
+		[fnc]$window.isMinimized[/fnc]
 */
 
 static bool window_kvs_cmd_minimize(KviKvsModuleCommandCall * c)
@@ -294,8 +294,8 @@ static bool window_kvs_cmd_minimize(KviKvsModuleCommandCall * c)
 		no operation is performed. If the specified window
 		does not exist a warning is printed unless the -q switch is used.
 	@seealso:
-		[cmd]window.maximize[/cmd], [cmd]window.minimize[/cmd], [fnc]$window.isMaxmimized[/cmd],
-		[fnc]$window.isMinimized[/cmd]
+		[cmd]window.maximize[/cmd], [cmd]window.minimize[/cmd], [fnc]$window.isMaxmimized[/fnc],
+		[fnc]$window.isMinimized[/fnc]
 */
 
 static bool window_kvs_cmd_restore(KviKvsModuleCommandCall * c)
@@ -391,7 +391,7 @@ static bool window_kvs_cmd_demandAttention(KviKvsModuleCommandCall * c)
 		The form with no parameters works on the current window. If the specified window
 		doesn't exist then 0 is returned.
 	@seealso:
-		[fnc]$window.isMinimized[/fnc](), [cmd]window.maximize[/cmd],
+		[fnc]$window.isMinimized[/fnc], [cmd]window.maximize[/cmd],
 		[cmd]window.minimize[/cmd], [cmd]window.restore[/cmd]
 */
 
@@ -495,7 +495,7 @@ static bool window_kvs_fnc_activityTemperature(KviKvsModuleFunctionCall * c)
 		The form with no parameters works on the current window. If the specified window
 		doesn't exist then 0 is returned.
 	@seealso:
-		[fnc]$window.isMaximized[/fnc](), [cmd]window.maximize[/cmd],
+		[fnc]$window.isMaximized[/fnc], [cmd]window.maximize[/cmd],
 		[cmd]window.minimize[/cmd], [cmd]window.restore[/cmd]
 */
 
@@ -686,6 +686,34 @@ static bool window_kvs_fnc_type(KviKvsModuleFunctionCall * c)
 	return true;
 }
 
+/*
+	@doc: window.context
+	@type:
+		function
+	@title:
+		$window.context
+	@short:
+		Returns the IRC context of a window
+	@syntax:
+		$window.context
+		$window.context(<window_id>)
+	@description:
+		Returns the IRC context of the window with the specified <window_id>.[br]
+		The form with no parameters returns the IRC context of the current window.[br]
+		If the window with the specified id does not exist, an empty string is returned.[br]
+	@seealso:
+*/
+
+static bool window_kvs_fnc_context(KviKvsModuleFunctionCall * c)
+{
+	GET_KVS_FNC_WINDOW_ID
+	if(pWnd)
+	{
+		c->returnValue()->setInteger(pWnd->console() ? pWnd->console()->ircContextId() : 0);
+	}
+	return true;
+}
+
 /*
 	@doc: window.caption
 	@type:
@@ -830,7 +858,7 @@ static bool window_kvs_fnc_list(KviKvsModuleFunctionCall * c)
 	{
 		// all contexts but no "no_context" windows
 		bool bAllWindows = KviQString::equalCI(szType,"all");
-		QAsciiDictIterator<KviWindow> it(*g_pGlobalWindowDict);
+		KviPointerHashTableIterator<const char *,KviWindow> it(*g_pGlobalWindowDict);
 
 		while(KviWindow * wnd = it.current())
 		{
@@ -854,7 +882,7 @@ static bool window_kvs_fnc_list(KviKvsModuleFunctionCall * c)
 	{
 		// all contexts and also "no_context" windows
 		bool bAllWindows = KviQString::equalCI(szType.lower(),"all");
-		QAsciiDictIterator<KviWindow> it(*g_pGlobalWindowDict);
+		KviPointerHashTableIterator<const char *,KviWindow> it(*g_pGlobalWindowDict);
 
 		while(KviWindow * wnd = it.current())
 		{
@@ -875,7 +903,7 @@ static bool window_kvs_fnc_list(KviKvsModuleFunctionCall * c)
 	{
 		// only "no_context" windows
 		bool bAllWindows = KviQString::equalCI(szType.lower(),"all");
-		QAsciiDictIterator<KviWindow> it(*g_pGlobalWindowDict);
+		KviPointerHashTableIterator<const char *,KviWindow> it(*g_pGlobalWindowDict);
 
 		while(KviWindow * wnd = it.current())
 		{
@@ -920,7 +948,7 @@ static bool window_kvs_fnc_list(KviKvsModuleFunctionCall * c)
 		}
 
 		bool bAllWindows = KviQString::equalCI(szType.lower(),"all");
-		QAsciiDictIterator<KviWindow> it(*g_pGlobalWindowDict);
+		KviPointerHashTableIterator<const char *,KviWindow> it(*g_pGlobalWindowDict);
 
 		while(KviWindow * wnd = it.current())
 		{
@@ -1012,18 +1040,18 @@ static bool window_kvs_fnc_open(KviKvsModuleFunctionCall * c)
 	if(c->parameterList()->count() >= 3)
 	{
 		pConsole = g_pApp->findConsole(uCtx);
-		if(!pConsole)
+		if(!pConsole && !szFlags.contains('q'))
 		{
 			c->warning(__tr2qs("The specified IRC context is not valid: creating a context free window"));
 		}
 	}
 
 	KviUserWindow * wnd = new KviUserWindow(
-						c->window()->frame(),
-						szCaption,
-						iIcon,
-						pConsole,
-						iFlags);
+		c->window()->frame(),
+		szCaption,
+		iIcon,
+		pConsole,
+		iFlags);
 
 	c->window()->frame()->addWindow(wnd,!szFlags.contains('m'));
 	if(szFlags.contains('m'))wnd->minimize();
@@ -1154,7 +1182,7 @@ static bool window_kvs_cmd_setInputText(KviKvsModuleCommandCall * c)
 	@description:
 		Sets the window input text to <text>
 	@seealso:
-	[cmd]window.setInputText[/cmd] [fnc]$window.inputText[/fnc]
+		[cmd]window.setInputText[/cmd], [fnc]$window.inputText[/fnc]
 */
 
 static bool window_kvs_cmd_insertInInputText(KviKvsModuleCommandCall * c)
@@ -1195,7 +1223,8 @@ static bool window_kvs_cmd_insertInInputText(KviKvsModuleCommandCall * c)
 	@description:
 		Returns the window input line text
 	@seealso:
-	[cmd]window.setInputText[/cmd] [cmd]window.insertInInputText[/cmd]
+		[cmd]window.setInputText[/cmd],
+		[cmd]window.insertInInputText[/cmd]
 */
 
 static bool window_kvs_fnc_inputText(KviKvsModuleFunctionCall * c)
@@ -1247,6 +1276,7 @@ static bool window_kvs_cmd_setBackground(KviKvsModuleCommandCall * c)
 		return true;
 	}
 
+	/*
 	QPixmap *pix=0;
 	pix = g_pIconManager->getImage(szBackground);
 	if (!pix){
@@ -1267,9 +1297,12 @@ static bool window_kvs_cmd_setBackground(KviKvsModuleCommandCall * c)
 		pWnd->view()->setPrivateBackgroundPixmap(pix1.asPixmap());
 		return true;
 		}
-
 	if(pWnd)
 		pWnd->view()->setPrivateBackgroundPixmap(*pix);
+	*/
+	
+	//FIXME: This is broken
+
 	return true;
 }
 
@@ -1309,7 +1342,7 @@ static bool window_kvs_cmd_setBackground(KviKvsModuleCommandCall * c)
 		[/example]
 
 	@seealso:
-		[fnc]$asciitohex[/fnc], [fnc]$features[/fnc]
+		[fnc]$asciiToHex[/fnc], [fnc]$features[/fnc]
 */
 
 
@@ -1429,7 +1462,7 @@ static bool window_kvs_cmd_setCryptEngine(KviKvsModuleCommandCall * c)
 
 static bool window_module_init(KviModule *m)
 {
-	g_pUserWindowList = new KviPtrList<KviUserWindow>();
+	g_pUserWindowList = new KviPointerList<KviUserWindow>();
 	g_pUserWindowList->setAutoDelete(false);
 
 	KVSM_REGISTER_FUNCTION(m,"activityTemperature",window_kvs_fnc_activityTemperature);
@@ -1446,6 +1479,7 @@ static bool window_module_init(KviModule *m)
 	KVSM_REGISTER_FUNCTION(m,"list",window_kvs_fnc_list);
 	KVSM_REGISTER_FUNCTION(m,"open",window_kvs_fnc_open);
 	KVSM_REGISTER_FUNCTION(m,"inputText",window_kvs_fnc_inputText);
+	KVSM_REGISTER_FUNCTION(m,"context",window_kvs_fnc_context);
 
 	KVSM_REGISTER_SIMPLE_COMMAND(m,"close",window_kvs_cmd_close);
 	KVSM_REGISTER_SIMPLE_COMMAND(m,"clearOutput",window_kvs_cmd_clearOutput);
